function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var group = require('@visx/group');
var React = require('react');
var React__default = _interopDefault(React);
var axis = require('@visx/axis');
var scale = require('@visx/scale');
var shape = require('@visx/shape');
var clipPath = require('@visx/clip-path');
var text = require('@visx/text');
var event = require('@visx/event');
var tooltip = require('@visx/tooltip');
var grid = require('@visx/grid');
var styled = require('styled-components');
var styled__default = _interopDefault(styled);
var os = _interopDefault(require('os'));
var hxReactComponents = require('hx-react-components');
var d3 = require('d3');
var theme = _interopDefault(require('hx-theme'));
var PropTypes = _interopDefault(require('prop-types'));
var gradient = require('@visx/gradient');
var venn = require('venn.js');
var topojson = require('topojson-client');
var geo = require('@visx/geo');
var hierarchy = require('@visx/hierarchy');

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function _taggedTemplateLiteralLoose(strings, raw) {
  if (!raw) {
    raw = strings.slice(0);
  }

  strings.raw = raw;
  return strings;
}

var METRICS = {
  AFFINITY: 'target_audience_affinity',
  REACH: 'target_audience_population_perc',
  BASE: 'base_population_perc',
  PENETRATION: 'penetration',
  RELEVANCY: 'relevancy'
};
var MAP_CHART_FIELDS_THRESHOLD = {
  target_audience_affinity: 1,
  base_population_perc: 0,
  target_audience_population_perc: 0,
  target_audience_perc: 0,
  relevancy: 0,
  penetration: 0
};
function debounce(func, wait, immediate) {
  var _arguments = arguments,
      _this = this;

  var timeout;
  return function () {
    var context = _this;
    var args = _arguments;

    var later = function later() {
      timeout = null;
      if (!immediate) func.apply(context, args);
    };

    var callNow = immediate && !timeout;
    clearTimeout(timeout);
    timeout = setTimeout(later, wait);
    if (callNow) func.apply(context, args);
  };
}
var isReach = function isReach(metric) {
  return metric === 'target_audience_population_perc' || metric === 'target_audience_perc';
};
var numberWithCommas = function numberWithCommas(number) {
  if (!number) {
    return false;
  }

  return number.toString().replace(/\B(?=(\d{3})+(?!\d))/g, ',');
};
var MAP_CHART_FIELDS_LABEL = {
  target_audience_affinity: 'Affinity',
  base_population_perc: 'Base',
  target_audience_population_perc: 'Reach',
  target_audience_perc: 'Reach',
  penetration: 'Penetration',
  relevancy: 'Relevance'
};
var DEFAULT_COLORS = ['#ff271a', '#FFF600', '#2563D5'];
var DEFAULT_OPAC_COLORS = ['#BA635E', '#94920b', '#0b5394'];
var MAP_DEFAULT_COLORS = ['#bde725', '#41B6A8'];
var MAP_DEFAULT_OPAC_COLORS = ['#99b33d', '#1e7b44'];
var convertHexToHSL = function convertHexToHSL(color, saturation, lightness) {
  var r = 0;
  var g = 0;
  var b = 0;

  if (color.length === 4) {
    r = '0x' + color[1] + color[1];
    g = '0x' + color[2] + color[2];
    b = '0x' + color[3] + color[3];
  } else if (color.length === 7) {
    r = '0x' + color[1] + color[2];
    g = '0x' + color[3] + color[4];
    b = '0x' + color[5] + color[6];
  }

  r /= 255;
  g /= 255;
  b /= 255;
  var cmin = Math.min(r, g, b);
  var cmax = Math.max(r, g, b);
  var delta = cmax - cmin;
  var h = 0;
  var s = 0;
  var l = 0;
  if (delta === 0) h = 0;else if (cmax === r) h = (g - b) / delta % 6;else if (cmax === g) h = (b - r) / delta + 2;else h = (r - g) / delta + 4;
  h = Math.round(h * 60);
  if (h < 0) h += 360;
  l = (cmax + cmin) / 2;
  s = delta === 0 ? 0 : delta / (1 - Math.abs(2 * l - 1));
  s = +(s * saturation).toFixed(1);
  l = +(l * lightness).toFixed(1);
  return 'hsl(' + h + ',' + s + '%,' + l + '%)';
};
var getColors = function getColors(color) {
  if (!color || color === 'default') {
    return DEFAULT_COLORS;
  }

  if (color === 'opac') {
    return DEFAULT_OPAC_COLORS;
  }

  return [convertHexToHSL(color, 100, 100), convertHexToHSL(color, 100, 50), convertHexToHSL(color, 70, 30)];
};
var getMapColors = function getMapColors(color) {
  if (color && !['default', 'opac'].includes(color)) {
    return [convertHexToHSL(color, 100, 100), convertHexToHSL(color, 100, 50)];
  }

  if (color === 'opac') {
    return [MAP_DEFAULT_OPAC_COLORS[0], MAP_DEFAULT_OPAC_COLORS[1]];
  }

  return [MAP_DEFAULT_COLORS[0], MAP_DEFAULT_COLORS[1]];
};
var getBarColors = function getBarColors(value, threshold, color) {
  if (color && !['default', 'opac'].includes(color)) {
    return convertHexToHSL(color, 100, value < threshold ? 100 : 50);
  }

  if (value < threshold) {
    return color === 'opac' ? '#0e7cdb' : '#2590EC';
  }

  return color === 'opac' ? '#1e7b44' : '#26a65b';
};

var useWindowSize = function useWindowSize() {
  var isClient = typeof window === 'object';
  var getSize = React.useCallback(function () {
    return {
      width: isClient ? window.innerWidth : undefined,
      height: isClient ? window.innerHeight : undefined
    };
  }, [isClient]);

  var _useState = React.useState(getSize),
      windowSize = _useState[0],
      setWindowSize = _useState[1];

  React.useEffect(function () {
    if (!isClient) {
      return false;
    }

    function handleResize() {
      setWindowSize(getSize());
    }

    var handleResizeFn = debounce(handleResize, 500);
    window.addEventListener('resize', handleResizeFn);
    return function () {
      return window.removeEventListener('resize', handleResizeFn);
    };
  }, [getSize, isClient]);
  return windowSize;
};

var MAP_MISSING_VALUES_LABELS = {
  low_engagement: 'L.E.',
  less_than_zero: '<0.01%',
  affinity_null: '-'
};

var getFixedParam = function getFixedParam(data, fixed) {
  var choosenFixed = fixed;
  var dataToFixed = data * 10 % 10;

  if (dataToFixed % 1 === 0) {
    choosenFixed = data % 1 === 0 ? 0 : 1;
  }

  return choosenFixed;
};

var formattedValue = function formattedValue(data, type, fixed) {
  if (fixed === void 0) {
    fixed = 2;
  }

  var choosenFixed = getFixedParam(data, fixed);

  if (data === 0) {
    return type === METRICS.AFFINITY ? data + 'x' : type === METRICS.RELEVANCY ? data : data + '%';
  }

  if (!data) {
    return type === METRICS.AFFINITY || type === METRICS.RELEVANCY ? MAP_MISSING_VALUES_LABELS.affinity_null : MAP_MISSING_VALUES_LABELS.low_engagement;
  }

  if (type === METRICS.AFFINITY) {
    return data.toFixed(choosenFixed) + 'x';
  }

  if (type === METRICS.RELEVANCY) {
    return data.toFixed(choosenFixed);
  }

  var dataToFixed = data.toFixed(4);

  if (dataToFixed === '0.0000') {
    return MAP_MISSING_VALUES_LABELS.less_than_zero;
  }

  var dataToFixedPerCent = Number((dataToFixed * 100).toFixed(2));
  choosenFixed = getFixedParam(dataToFixedPerCent, fixed);
  return dataToFixedPerCent.toFixed(choosenFixed) + '%';
};

var formatVisualItemValues = function formatVisualItemValues(item) {
  return _extends({}, item, {
    base_population_perc: formattedValue(item.base_population_perc, 'base_population_perc'),
    target_audience_population_perc: formattedValue(item.target_audience_population_perc, 'target_audience_population_perc'),
    target_audience_affinity: formattedValue(item.target_audience_affinity, 'target_audience_affinity'),
    penetration: formattedValue(item.penetration, 'penetration')
  });
};

var capitalizeString = function capitalizeString(lower) {
  return lower.charAt(0).toUpperCase() + lower.substring(1);
};

var truncateString = function truncateString(text, limit) {
  if ((text === null || text === void 0 ? void 0 : text.length) < limit) return text;else return (text === null || text === void 0 ? void 0 : text.slice(0, limit)) + "...";
};

var FormatUtils = {
  formattedValue: formattedValue,
  formatVisualItemValues: formatVisualItemValues,
  truncateString: truncateString,
  capitalizeString: capitalizeString
};

var getPopulationPerc = function getPopulationPerc(tooltipData) {
  return (tooltipData === null || tooltipData === void 0 ? void 0 : tooltipData.target_audience_perc) || (tooltipData === null || tooltipData === void 0 ? void 0 : tooltipData.target_audience_population_perc);
};

var ColumnChartImage = function ColumnChartImage(_ref) {
  var d = _ref.d,
      showItemsPreview = _ref.showItemsPreview,
      color = _ref.color,
      chartId = _ref.chartId;

  var _useState = React.useState(false),
      errorLoadingImage = _useState[0],
      setErrorLoadingImage = _useState[1];

  React.useEffect(function () {
    setErrorLoadingImage(false);
  }, [d.pic]);
  var onErrorLoadingImage = React.useCallback(function () {
    setErrorLoadingImage(true);
  }, []);

  if (showItemsPreview && (!d.pic || errorLoadingImage)) {
    return /*#__PURE__*/React__default.createElement("svg", {
      overflow: "visible"
    }, /*#__PURE__*/React__default.createElement(shape.Circle, {
      r: 15,
      cx: d.x,
      cy: d.y,
      fill: color
    }));
  }

  if (!showItemsPreview) {
    return /*#__PURE__*/React__default.createElement("svg", {
      overflow: "visible"
    }, /*#__PURE__*/React__default.createElement(text.Text, {
      height: 80,
      width: 80,
      x: d.x,
      y: d.y + 10,
      fontSize: "10px",
      textAnchor: "middle",
      verticalAnchor: "middle",
      fill: "#000000",
      angle: -45
    }, FormatUtils.capitalizeString(FormatUtils.truncateString(d.label, 15))));
  }

  return /*#__PURE__*/React__default.createElement("svg", {
    overflow: "visible"
  }, /*#__PURE__*/React__default.createElement("image", {
    href: d.pic,
    height: 30,
    width: 30,
    clipPath: "url(#category-" + chartId + "-icon-" + d.id + ")",
    x: d.x - 15,
    y: d.y - 15,
    onError: onErrorLoadingImage
  }), /*#__PURE__*/React__default.createElement(clipPath.CircleClipPath, {
    id: "category-" + chartId + "-icon-" + d.id,
    key: "category-" + chartId + "-icon-" + d.id,
    r: 15,
    cx: d.x,
    cy: d.y
  }));
};

function _templateObject4() {
  var data = _taggedTemplateLiteralLoose(["\n  text-align: left;\n  font-size: 12px;\n  padding: 5px;\n"]);

  _templateObject4 = function _templateObject4() {
    return data;
  };

  return data;
}

function _templateObject3() {
  var data = _taggedTemplateLiteralLoose(["\n  text-align: center;\n  font-size: 14px;\n  font-weight: bold;\n  padding: 5px;\n  word-break: break-word;\n"]);

  _templateObject3 = function _templateObject3() {
    return data;
  };

  return data;
}

function _templateObject2() {
  var data = _taggedTemplateLiteralLoose(["\n  border: 1px solid #c6c6c6;\n"]);

  _templateObject2 = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject() {
  var data = _taggedTemplateLiteralLoose(["\n  display: flex;\n  flex-direction: column;\n  max-width: 250px;\n"]);

  _templateObject = function _templateObject() {
    return data;
  };

  return data;
}
var StyledTooltipContainer = styled__default.div(_templateObject());
var StyledTooltipBorder = styled__default.div(_templateObject2());
var StyledTooltipTitle = styled__default.div(_templateObject3());
var StyledTooltipContent = styled__default.div(_templateObject4());

var ChartTooltip = function ChartTooltip(props) {
  var nodeRef = React.useRef(null);

  var tooltipStyles = _extends({}, tooltip.defaultStyles, {
    minWidth: 60,
    backgroundColor: 'rgba(255,255,255,0.8)',
    color: '#000',
    zIndex: 2000
  });

  return /*#__PURE__*/React__default.createElement(tooltip.TooltipWithBounds, {
    ref: nodeRef,
    top: props.top,
    left: props.left,
    style: _extends({}, tooltipStyles, {
      borderStyle: 'solid',
      borderWidth: '2px',
      borderColor: props.data.color
    })
  }, /*#__PURE__*/React__default.createElement(StyledTooltipContainer, null, /*#__PURE__*/React__default.createElement(StyledTooltipTitle, null, props.data.label), /*#__PURE__*/React__default.createElement(StyledTooltipBorder, null), /*#__PURE__*/React__default.createElement(StyledTooltipContent, null, props.children)));
};

function createCommonjsModule(fn, module) {
	return module = { exports: {} }, fn(module, module.exports), module.exports;
}

var uniqid = createCommonjsModule(function (module) {
/* 
(The MIT License)
Copyright (c) 2014-2021 Halász Ádám <adam@aimform.com>
Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

//  Unique Hexatridecimal ID Generator
// ================================================

//  Dependencies
// ================================================
var pid = typeof process !== 'undefined' && process.pid ? process.pid.toString(36) : '' ;
var address = '';
if(typeof __webpack_require__ !== 'function'){
    var mac = '', networkInterfaces = os.networkInterfaces();
    loop:
    for(let interface_key in networkInterfaces){
        const networkInterface = networkInterfaces[interface_key];
        const length = networkInterface.length;
        for(var i = 0; i < length; i++){
            if(networkInterface[i] !== undefined && networkInterface[i].mac && networkInterface[i].mac != '00:00:00:00:00:00'){
                mac = networkInterface[i].mac; break loop;
            }
        }
    }
    address = mac ? parseInt(mac.replace(/\:|\D+/gi, '')).toString(36) : '' ;
} 

//  Exports
// ================================================
module.exports = module.exports.default = function(prefix, suffix){ return (prefix ? prefix : '') + address + pid + now().toString(36) + (suffix ? suffix : ''); };
module.exports.process = function(prefix, suffix){ return (prefix ? prefix : '') + pid + now().toString(36) + (suffix ? suffix : ''); };
module.exports.time    = function(prefix, suffix){ return (prefix ? prefix : '') + now().toString(36) + (suffix ? suffix : ''); };

//  Helpers
// ================================================
function now(){
    var time = Date.now();
    var last = now.last || time;
    return now.last = time > last ? time : last + 1;
}
});

function _templateObject$1() {
  var data = _taggedTemplateLiteralLoose(["\n  width: 100%;\n  height: 100%;\n  position: relative;\n  background-color: #ffffff;\n  padding: 10px;\n"]);

  _templateObject$1 = function _templateObject() {
    return data;
  };

  return data;
}
var StyledColumnChartWrapper = styled__default.div(_templateObject$1());
var tooltipTimeout;
var defaultMargin = {
  top: 50,
  right: 50,
  bottom: 50,
  left: 100
};

var ColumnChart = function ColumnChart(_ref) {
  var data = _ref.data,
      _ref$margin = _ref.margin,
      margin = _ref$margin === void 0 ? defaultMargin : _ref$margin,
      yAxis = _ref.yAxis,
      zAxis = _ref.zAxis,
      color = _ref.color,
      emptyDataMessage = _ref.emptyDataMessage,
      showValuesOn100 = _ref.showValuesOn100,
      _ref$limit = _ref.limit,
      limit = _ref$limit === void 0 ? 'auto' : _ref$limit,
      showItemsPreview = _ref.showItemsPreview;
  var svgRef = React.useRef(null);
  var chartId = React.useRef(uniqid());

  var _useState = React.useState(0),
      width = _useState[0],
      setWidth = _useState[1];

  var _useState2 = React.useState(0),
      height = _useState2[0],
      setHeight = _useState2[1];

  var isEmpty = !data || data.length === 0;

  var _useTooltip = tooltip.useTooltip(),
      tooltipOpen = _useTooltip.tooltipOpen,
      tooltipLeft = _useTooltip.tooltipLeft,
      tooltipTop = _useTooltip.tooltipTop,
      tooltipData = _useTooltip.tooltipData,
      hideTooltip = _useTooltip.hideTooltip,
      showTooltip = _useTooltip.showTooltip;

  var windowSize = useWindowSize();
  var chartRef = React.useCallback(function (node) {
    if (node != null) {
      setWidth(node.getBoundingClientRect().width);
      setHeight(node.getBoundingClientRect().height);
    }
  }, [windowSize]);
  var filteredData = React.useMemo(function () {
    if (isEmpty) {
      return [];
    }

    return limit !== 'auto' ? data.slice(0, limit) : data;
  }, [isEmpty, data, limit]);
  var yValues = filteredData && filteredData.map(function (item) {
    return item[yAxis];
  }) || [];
  var zValues = filteredData && filteredData.map(function (item) {
    return item[zAxis];
  }) || [];
  var minMaxValues = React.useMemo(function () {
    return {
      yMin: isReach(yAxis) || showValuesOn100 ? 0 : Math.min.apply(Math, yValues),
      yMax: Math.max.apply(Math, yValues),
      zMin: isReach(yAxis) || showValuesOn100 ? Math.min.apply(Math, zValues) : 0,
      zMax: isReach(yAxis) || showValuesOn100 ? Math.max.apply(Math, zValues) : 0
    };
  }, [yAxis, yValues, zValues]);
  var yzDiff = Math.max(minMaxValues.yMax - minMaxValues.yMin, minMaxValues.zMax - minMaxValues.zMin, 0);
  var yzMin = Math.min(minMaxValues.yMin, minMaxValues.zMin);
  var yzMax = Math.max(minMaxValues.yMax, minMaxValues.zMax);
  var yDomain = React.useMemo(function () {
    return [yzMin - yzDiff / 3 < 0 ? 0 : yzMin - yzDiff / 3, showValuesOn100 || yAxis !== METRICS.AFFINITY && yzMax + yzDiff / 3 > 1 ? 1 : yzMax + yzDiff / 3];
  }, [minMaxValues, yzDiff, showValuesOn100, yzMin, yzMax, yAxis]);
  var yScale = React.useMemo(function () {
    return scale.scaleLinear({
      domain: yDomain,
      range: [0, showValuesOn100 || yzMax > 1 ? 1 : yzMax],
      nice: true
    });
  }, [yzMax, yDomain, showValuesOn100]);
  var xScale = React.useMemo(function () {
    return scale.scaleBand({
      domain: filteredData && filteredData.map(function (item) {
        return item.id;
      }) || [],
      padding: 0.7
    });
  }, [filteredData]);
  var colorScale = React.useMemo(function () {
    return scale.scaleLinear({
      domain: [0, isEmpty ? 0 : filteredData.length / 2, isEmpty ? 0 : filteredData.length],
      range: getColors(color)
    });
  }, [filteredData, isEmpty, color]);
  var xMax = width - margin.left - margin.right;
  var yMax = height - margin.top - margin.bottom;
  xScale.rangeRound([0, xMax]);
  yScale.rangeRound([yMax, 0]);
  var getTickInsightType = React.useCallback(function (d) {
    var item = filteredData.find(function (i) {
      return i.id === d;
    });
    return item && item.insight_type || '';
  }, [filteredData]);
  var getTickImage = React.useCallback(function (d) {
    var item = filteredData.find(function (i) {
      return i.id === d;
    });
    return item && item.pic || '';
  }, [filteredData]);
  var getTickLabel = React.useCallback(function (d) {
    var item = filteredData.find(function (i) {
      return i.id === d;
    });
    return item && item.label || '';
  }, [filteredData]);
  var getGroupContent = React.useCallback(function (group, groups, index) {
    var options = groups.tickLabelProps(group.value);

    var props = _extends({}, options, {
      x: group.to.x,
      y: 10 + group.to.y,
      index: index
    });

    return groups.tickComponent(props);
  }, []);
  var getTickComponent = React.useCallback(function (d) {
    return /*#__PURE__*/React__default.createElement(React__default.Fragment, {
      key: "column-" + chartId.current + "-category-" + d.id
    }, /*#__PURE__*/React__default.createElement(ColumnChartImage, {
      d: d,
      color: colorScale(d.index),
      showItemsPreview: showItemsPreview,
      chartId: chartId.current
    }));
  }, [showItemsPreview]);
  var handleMouseLeave = React.useCallback(function (event) {
    tooltipTimeout = window.setTimeout(function () {
      hideTooltip();
    }, 0);
  }, [hideTooltip]);
  var handleMouseMove = React.useCallback(function (event$1, index) {
    if (tooltipTimeout) clearTimeout(tooltipTimeout);
    var eventSvgCoords = event.localPoint(event$1);
    showTooltip({
      tooltipData: _extends({}, filteredData[index], {
        color: colorScale(index)
      }),
      tooltipTop: eventSvgCoords === null || eventSvgCoords === void 0 ? void 0 : eventSvgCoords.y,
      tooltipLeft: eventSvgCoords === null || eventSvgCoords === void 0 ? void 0 : eventSvgCoords.x
    });
  }, [showTooltip, filteredData, colorScale]);

  if (isEmpty) {
    return /*#__PURE__*/React__default.createElement(StyledColumnChartWrapper, null, /*#__PURE__*/React__default.createElement(hxReactComponents.Box, {
      minWidth: "100%"
    }, /*#__PURE__*/React__default.createElement(hxReactComponents.EmptyState, {
      icon: "analytics",
      mainText: emptyDataMessage,
      size: "large"
    })));
  }

  return /*#__PURE__*/React__default.createElement(StyledColumnChartWrapper, {
    ref: chartRef
  }, /*#__PURE__*/React__default.createElement("svg", {
    ref: svgRef,
    width: width,
    height: height
  }, /*#__PURE__*/React__default.createElement("rect", {
    width: width,
    height: height,
    fill: "#ffffff",
    rx: 14
  }), /*#__PURE__*/React__default.createElement(grid.Grid, {
    top: margin.top,
    left: margin.left,
    xScale: xScale,
    yScale: yScale,
    width: xMax,
    height: yMax
  }), /*#__PURE__*/React__default.createElement(group.Group, {
    top: margin.top,
    left: margin.left,
    key: "group-" + chartId.current
  }, filteredData.map(function (d, index) {
    var _yScale, _yScale2;

    var barWidth = xScale.bandwidth();
    var barZWidth = xScale.bandwidth() + 20;
    var barValue = d[yAxis] || 0;
    var barHeight = yMax - ((_yScale = yScale(barValue)) != null ? _yScale : 0);
    var barZHeight = yMax - ((_yScale2 = yScale(d[zAxis])) != null ? _yScale2 : 0);
    var barX = xScale(d.id);
    var barY = yMax - barHeight;
    var barZ = yMax - barZHeight;
    return /*#__PURE__*/React__default.createElement(React__default.Fragment, {
      key: "column-" + chartId.current + "-bar-" + d.id
    }, barX > 0 && barY >= 0 && barHeight >= 0 && /*#__PURE__*/React__default.createElement(shape.BarRounded, {
      x: barX,
      y: barY,
      width: barWidth,
      height: barHeight,
      fill: colorScale(index),
      fillOpacity: isReach(yAxis) ? 0.7 : 1,
      radius: barWidth / 4,
      all: true,
      onMouseMove: function onMouseMove(event) {
        return handleMouseMove(event, index);
      },
      onMouseLeave: function onMouseLeave(event) {
        return handleMouseLeave(event);
      },
      onTouchMove: function onTouchMove(event) {
        return handleMouseMove(event, index);
      },
      onTouchEnd: function onTouchEnd(event) {
        return handleMouseLeave(event);
      }
    }), barX > 0 && barZ > 0 && isReach(yAxis) && /*#__PURE__*/React__default.createElement(shape.BarRounded, {
      x: barX - 10,
      y: barZ,
      all: true,
      radius: barZWidth / 4,
      width: barZWidth,
      height: barZHeight,
      fill: colorScale(index),
      fillOpacity: 0.4,
      onMouseMove: function onMouseMove(event) {
        return handleMouseMove(event, index);
      },
      onMouseLeave: function onMouseLeave(event) {
        return handleMouseLeave(event);
      },
      onTouchMove: function onTouchMove(event) {
        return handleMouseMove(event, index);
      },
      onTouchEnd: function onTouchEnd(event) {
        return handleMouseLeave(event);
      }
    }));
  }), /*#__PURE__*/React__default.createElement(axis.AxisLeft, {
    label: MAP_CHART_FIELDS_LABEL[yAxis],
    scale: yScale,
    stroke: "#9493A6",
    tickStroke: "#9493A6",
    tickFormat: function tickFormat(d) {
      return FormatUtils.formattedValue(d, yAxis);
    },
    tickLabelProps: function tickLabelProps() {
      return {
        fill: '#9493A6',
        fontSize: 11,
        textAnchor: 'end',
        dy: '0.33em',
        dx: '-0.33em',
        fontWeight: 'bold'
      };
    },
    labelProps: {
      fill: 'black',
      textAnchor: 'middle',
      fontSize: 14,
      fontWeight: 'bold',
      dx: '-1.2em'
    }
  }), /*#__PURE__*/React__default.createElement(axis.AxisBottom, {
    top: yMax,
    scale: xScale,
    tickLabelProps: function tickLabelProps(d) {
      return {
        fontSize: '11px',
        pic: getTickImage(d),
        id: d,
        label: getTickLabel(d),
        insight_type: getTickInsightType(d)
      };
    },
    tickComponent: function tickComponent(d) {
      return getTickComponent(d);
    }
  }, function (axisGroups) {
    return /*#__PURE__*/React__default.createElement(React__default.Fragment, null, axisGroups.ticks.map(function (group$1, index) {
      return /*#__PURE__*/React__default.createElement(group.Group, {
        key: "column-" + chartId.current + "-axis-group-" + index
      }, getGroupContent(group$1, axisGroups, index));
    }));
  }))), tooltipOpen && tooltipData && /*#__PURE__*/React__default.createElement(ChartTooltip, {
    opened: tooltipOpen,
    top: tooltipTop || 0,
    left: tooltipLeft || 0,
    data: tooltipData
  }, /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Reach: "), FormatUtils.formattedValue(getPopulationPerc(tooltipData), METRICS.REACH)), /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Affinity: "), FormatUtils.formattedValue(tooltipData.target_audience_affinity, METRICS.AFFINITY)), /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Base: "), FormatUtils.formattedValue(tooltipData.base_population_perc, METRICS.BASE)), /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Penetration: "), FormatUtils.formattedValue(tooltipData.penetration, METRICS.PENETRATION))));
};

function _templateObject$2() {
  var data = _taggedTemplateLiteralLoose(["\n  font-size: ", ";\n  text-align: end;\n"]);

  _templateObject$2 = function _templateObject() {
    return data;
  };

  return data;
}
var StyledStackedChartText = styled__default.div(_templateObject$2(), function (props) {
  return props.minFontSize ? '9px' : '11px';
});

var StackedChartImage = function StackedChartImage(_ref) {
  var d = _ref.d,
      showItemsPreview = _ref.showItemsPreview,
      color = _ref.color,
      chartId = _ref.chartId,
      setMinFontSize = _ref.setMinFontSize,
      _ref$limitText = _ref.limitText,
      limitText = _ref$limitText === void 0 ? 20 : _ref$limitText,
      _ref$textWidth = _ref.textWidth,
      textWidth = _ref$textWidth === void 0 ? 80 : _ref$textWidth;

  var _useState = React.useState(false),
      errorLoadingImage = _useState[0],
      setErrorLoadingImage = _useState[1];

  React.useEffect(function () {
    setErrorLoadingImage(false);
  }, [d.pic]);
  var onErrorLoadingImage = React.useCallback(function () {
    setErrorLoadingImage(true);
  }, []);

  if (showItemsPreview && (!d.pic || errorLoadingImage)) {
    return /*#__PURE__*/React__default.createElement("svg", {
      overflow: "visible"
    }, /*#__PURE__*/React__default.createElement(shape.Circle, {
      r: 15,
      cx: d.x - 15,
      cy: d.y,
      fill: color
    }));
  }

  if (!showItemsPreview) {
    return /*#__PURE__*/React__default.createElement("svg", {
      overflow: "visible"
    }, /*#__PURE__*/React__default.createElement("foreignObject", {
      x: d.x - textWidth,
      y: d.y - 5,
      width: textWidth,
      height: 80
    }, /*#__PURE__*/React__default.createElement(StyledStackedChartText, {
      minFontSize: setMinFontSize
    }, FormatUtils.capitalizeString(FormatUtils.truncateString(d.label, limitText)))));
  }

  return /*#__PURE__*/React__default.createElement("svg", {
    overflow: "visible"
  }, /*#__PURE__*/React__default.createElement("image", {
    href: d.pic,
    height: 30,
    width: 30,
    clipPath: "url(#category-" + chartId + "-icon-" + d.id + ")",
    x: d.x - 30,
    y: d.y - 15,
    onError: onErrorLoadingImage
  }), /*#__PURE__*/React__default.createElement(clipPath.CircleClipPath, {
    id: "category-" + chartId + "-icon-" + d.id,
    key: "category-" + chartId + "-icon-" + d.id,
    r: 15,
    cx: d.x - 15,
    cy: d.y
  }));
};

var StackedBarValue = function StackedBarValue(_ref) {
  var bar = _ref.bar,
      threshold = _ref.threshold,
      onMove = _ref.onMove,
      onLeave = _ref.onLeave;
  var left = 0;

  if (bar.value) {
    left = bar.value < threshold.value ? bar.x + 40 > threshold.x ? threshold.x - 40 : bar.x : bar.x + bar.width - 40 < threshold.x ? threshold.x : bar.x + bar.width - 40;
  }

  return /*#__PURE__*/React__default.createElement(group.Group, {
    top: bar.y,
    left: left
  }, bar.width > 0 ? /*#__PURE__*/React__default.createElement(React__default.Fragment, null, /*#__PURE__*/React__default.createElement("rect", {
    width: "40",
    rx: bar.height / 3,
    height: bar.height,
    stroke: bar.color,
    strokeWidth: "2",
    fill: "#fff",
    onMouseMove: onMove,
    onMouseLeave: onLeave,
    onTouchMove: onMove,
    onTouchEnd: onLeave
  }), /*#__PURE__*/React__default.createElement(text.Text, {
    y: bar.height / 2,
    x: 20,
    verticalAnchor: "middle",
    textAnchor: "middle",
    fontSize: "9px",
    fontWeight: "bold",
    fill: bar.color
  }, bar.formattedValue)) : /*#__PURE__*/React__default.createElement(text.Text, {
    y: bar.height / 2,
    x: 5,
    verticalAnchor: "middle",
    textAnchor: "middle",
    fontSize: "9px",
    fontWeight: "bold",
    fill: bar.color
  }, bar.formattedValue));
};

function _templateObject$3() {
  var data = _taggedTemplateLiteralLoose(["\n  width: 100%;\n  height: 100%;\n  position: relative;\n  background-color: #ffffff;\n  padding: 10px;\n"]);

  _templateObject$3 = function _templateObject() {
    return data;
  };

  return data;
}
var StyledStackedChartWrapper = styled__default.div(_templateObject$3());
var tooltipTimeout$1;
var defaultMargin$1 = {
  top: 50,
  right: 50,
  bottom: 50,
  left: 100
};

var StackedChart = function StackedChart(_ref) {
  var data = _ref.data,
      xAxis = _ref.xAxis,
      zAxis = _ref.zAxis,
      _ref$margin = _ref.margin,
      margin = _ref$margin === void 0 ? defaultMargin$1 : _ref$margin,
      emptyDataMessage = _ref.emptyDataMessage,
      color = _ref.color,
      limit = _ref.limit,
      _ref$showAxisLeft = _ref.showAxisLeft,
      showAxisLeft = _ref$showAxisLeft === void 0 ? true : _ref$showAxisLeft,
      showItemsPreview = _ref.showItemsPreview,
      includedInDouble = _ref.includedInDouble,
      limitText = _ref.limitText,
      textWidth = _ref.textWidth;
  var svgRef = React.useRef(null);
  var chartId = React.useRef(uniqid());
  var isEmpty = !data || data.length === 0;

  var _useState = React.useState(0),
      width = _useState[0],
      setWidth = _useState[1];

  var _useState2 = React.useState(0),
      height = _useState2[0],
      setHeight = _useState2[1];

  var _useTooltip = tooltip.useTooltip(),
      tooltipOpen = _useTooltip.tooltipOpen,
      tooltipLeft = _useTooltip.tooltipLeft,
      tooltipTop = _useTooltip.tooltipTop,
      tooltipData = _useTooltip.tooltipData,
      hideTooltip = _useTooltip.hideTooltip,
      showTooltip = _useTooltip.showTooltip;

  var windowSize = useWindowSize();
  var chartRef = React.useCallback(function (node) {
    if (node != null) {
      setWidth(node.getBoundingClientRect().width);
      setHeight(node.getBoundingClientRect().height);
    }
  }, [windowSize]);
  var filteredData = React.useMemo(function () {
    if (isEmpty) {
      return [];
    }

    return limit !== 'auto' ? data.slice(0, limit) : data;
  }, [isEmpty, data, limit]);
  var getGroupContent = React.useCallback(function (group, groups, index) {
    var options = groups.tickLabelProps(group.value);

    var props = _extends({}, options, {
      x: group.to.x,
      y: 10 + group.to.y,
      index: index
    });

    return groups.tickComponent(props);
  }, []);
  var xValues = filteredData && filteredData.map(function (item) {
    return item[xAxis];
  }) || [];
  var zValues = filteredData && filteredData.map(function (item) {
    return item[zAxis];
  }) || [];
  var minMaxValues = React.useMemo(function () {
    return {
      xMin: Math.min.apply(Math, xValues),
      xMax: Math.max.apply(Math, xValues),
      zMin: isReach(xAxis) ? Math.min.apply(Math, zValues) : Math.min.apply(Math, xValues),
      zMax: isReach(xAxis) ? Math.max.apply(Math, zValues) : Math.max.apply(Math, xValues)
    };
  }, [xAxis, xValues, zValues]);
  var getTickComponent = React.useCallback(function (d) {
    return /*#__PURE__*/React__default.createElement(React__default.Fragment, {
      key: "stacked-" + chartId.current + "-category-" + d.id
    }, /*#__PURE__*/React__default.createElement(StackedChartImage, {
      d: d,
      chartId: chartId.current,
      color: "#e6e6e6",
      showItemsPreview: showItemsPreview,
      setMinFontSize: filteredData && filteredData.length > 5,
      limitText: limitText,
      textWidth: textWidth
    }));
  }, [filteredData, showItemsPreview, chartId.current]);
  var handleMouseLeave = React.useCallback(function (event) {
    tooltipTimeout$1 = window.setTimeout(function () {
      hideTooltip();
    }, 0);
  }, [hideTooltip]);
  var handleMouseMove = React.useCallback(function (event$1, index, color) {
    if (color === void 0) {
      color = '#26a65b';
    }

    if (tooltipTimeout$1) clearTimeout(tooltipTimeout$1);
    var eventSvgCoords = event.localPoint(event$1);
    showTooltip({
      tooltipData: _extends({}, filteredData[index], {
        color: includedInDouble && isReach(xAxis) ? '#2590EC' : color
      }),
      tooltipTop: eventSvgCoords === null || eventSvgCoords === void 0 ? void 0 : eventSvgCoords.y,
      tooltipLeft: eventSvgCoords === null || eventSvgCoords === void 0 ? void 0 : eventSvgCoords.x
    });
  }, [showTooltip, filteredData]);
  var xzDiff = Math.max(minMaxValues.xMax - minMaxValues.xMin, minMaxValues.zMax - minMaxValues.zMin, 0);
  var xzMin = Math.min(minMaxValues.xMin, minMaxValues.zMin);
  var xzMax = Math.max(minMaxValues.xMax, minMaxValues.zMax);
  var offsetXZMin = MAP_CHART_FIELDS_THRESHOLD[xAxis] > 0 && xzMin >= MAP_CHART_FIELDS_THRESHOLD[xAxis] ? MAP_CHART_FIELDS_THRESHOLD[xAxis] : (xzMin - xzDiff) / 10;
  var offsetXZMax = MAP_CHART_FIELDS_THRESHOLD[xAxis] > 0 && xzMax + xzDiff / 10 < MAP_CHART_FIELDS_THRESHOLD[xAxis] ? MAP_CHART_FIELDS_THRESHOLD[xAxis] : xzMax + xzDiff / 10;
  var xDomain = React.useMemo(function () {
    return [METRICS.AFFINITY !== xAxis || offsetXZMin < 0 ? 0 : offsetXZMin, offsetXZMax];
  }, [xAxis, offsetXZMin, offsetXZMax]);
  var xScale = React.useMemo(function () {
    return scale.scaleLinear({
      domain: xDomain,
      range: [0, xzMax]
    });
  }, [xDomain, xzMax]);
  var yScale = React.useMemo(function () {
    return scale.scaleBand({
      domain: filteredData && filteredData.map(function (item) {
        return item.id;
      }) || [],
      padding: 0.7
    });
  }, [filteredData]);
  var getTickImage = React.useCallback(function (d) {
    var item = filteredData.find(function (i) {
      return i.id === d;
    });
    return item && item.pic || '';
  }, [filteredData]);
  var getTickLabel = React.useCallback(function (d) {
    var item = filteredData.find(function (i) {
      return i.id === d;
    });
    return item && item.label || '';
  }, [filteredData]);
  var xTicks = React.useMemo(function () {
    var min = xzDiff < 1 ? 5 : xzDiff + 4;

    if (xAxis !== METRICS.AFFINITY) {
      min = xzDiff <= 0.01 ? 1 : xzDiff * 100;
    }

    if (width < 520) {
      return Math.min(min, 2);
    }

    return Math.min(min, 10);
  }, [xzDiff, width, xAxis]);
  var xMax = width - margin.left - margin.right;
  var yMax = height - margin.top - margin.bottom;
  xScale.rangeRound([0, xMax]);
  yScale.rangeRound([yMax, 0]);

  if (isEmpty) {
    return /*#__PURE__*/React__default.createElement(StyledStackedChartWrapper, null, /*#__PURE__*/React__default.createElement(hxReactComponents.Box, {
      minWidth: "100%"
    }, /*#__PURE__*/React__default.createElement(hxReactComponents.EmptyState, {
      icon: "analytics",
      mainText: emptyDataMessage,
      size: "large"
    })));
  }

  return /*#__PURE__*/React__default.createElement(StyledStackedChartWrapper, {
    ref: chartRef
  }, /*#__PURE__*/React__default.createElement("svg", {
    ref: svgRef,
    width: width,
    height: height
  }, /*#__PURE__*/React__default.createElement("rect", {
    width: width,
    height: height,
    fill: "#ffffff",
    rx: 14
  }), /*#__PURE__*/React__default.createElement(grid.GridRows, {
    top: margin.top,
    left: margin.left,
    scale: yScale,
    width: xMax,
    height: yMax,
    offset: 10
  }), /*#__PURE__*/React__default.createElement(group.Group, {
    top: margin.top,
    left: margin.left,
    key: "group-" + chartId.current
  }, filteredData.map(function (d, index) {
    var barValue = d[xAxis];
    var barHeight = yScale.bandwidth();
    var barY = yScale(d.id);
    var barWidth = barValue < MAP_CHART_FIELDS_THRESHOLD[xAxis] ? xScale(MAP_CHART_FIELDS_THRESHOLD[xAxis]) - xScale(barValue) : xScale(barValue) - xScale(MAP_CHART_FIELDS_THRESHOLD[xAxis]);
    var barX = barValue < MAP_CHART_FIELDS_THRESHOLD[xAxis] ? xScale(barValue) : xScale(MAP_CHART_FIELDS_THRESHOLD[xAxis]);
    var barColor = includedInDouble && isReach(xAxis) ? '#2590EC' : getBarColors(barValue, MAP_CHART_FIELDS_THRESHOLD[xAxis], color);
    var barZValue = d[zAxis] || 0;
    var barZWidth = barZValue < MAP_CHART_FIELDS_THRESHOLD[zAxis] ? xScale(MAP_CHART_FIELDS_THRESHOLD[zAxis]) - xScale(barZValue) : xScale(barZValue) - xScale(MAP_CHART_FIELDS_THRESHOLD[zAxis]);
    var barZ = barZValue < MAP_CHART_FIELDS_THRESHOLD[zAxis] ? xScale(barZValue) : xScale(MAP_CHART_FIELDS_THRESHOLD[zAxis]);
    return /*#__PURE__*/React__default.createElement(React__default.Fragment, {
      key: "stacked-" + chartId.current + "-bar-" + d.id
    }, barX >= 0 && barY > 0 && barWidth > 0 && /*#__PURE__*/React__default.createElement(shape.BarRounded, {
      x: barX,
      y: barY + 10,
      width: barWidth,
      height: barHeight,
      fill: barColor,
      fillOpacity: isReach(xAxis) ? 0.7 : 1,
      all: true,
      radius: barWidth / 4,
      onMouseMove: function onMouseMove(event) {
        return handleMouseMove(event, index, barColor);
      },
      onMouseLeave: function onMouseLeave(event) {
        return handleMouseLeave(event);
      },
      onTouchMove: function onTouchMove(event) {
        return handleMouseMove(event, index, barColor);
      },
      onTouchEnd: function onTouchEnd(event) {
        return handleMouseLeave(event);
      }
    }), barZ >= 0 && barY > 0 && barZWidth > 0 && isReach(xAxis) && /*#__PURE__*/React__default.createElement(shape.BarRounded, {
      x: barZ,
      y: barY + 5,
      all: true,
      radius: barZWidth / 4,
      width: barZWidth,
      height: barHeight + 10,
      fill: barColor,
      fillOpacity: 0.4,
      onMouseMove: function onMouseMove(event) {
        return handleMouseMove(event, index);
      },
      onMouseLeave: function onMouseLeave(event) {
        return handleMouseLeave(event);
      },
      onTouchMove: function onTouchMove(event) {
        return handleMouseMove(event, index);
      },
      onTouchEnd: function onTouchEnd(event) {
        return handleMouseLeave(event);
      }
    }), /*#__PURE__*/React__default.createElement(StackedBarValue, {
      threshold: {
        x: xScale(MAP_CHART_FIELDS_THRESHOLD[xAxis]),
        value: MAP_CHART_FIELDS_THRESHOLD[xAxis]
      },
      bar: {
        x: barX,
        y: barY + 5,
        height: barHeight + 10,
        width: barWidth,
        value: barValue,
        color: barColor,
        formattedValue: !barValue && xAxis === METRICS.AFFINITY ? '0x' : FormatUtils.formattedValue(barValue, xAxis)
      },
      onMove: function onMove(event) {
        return handleMouseMove(event, index, barColor);
      },
      onLeave: function onLeave(event) {
        return handleMouseLeave(event);
      }
    }));
  }), /*#__PURE__*/React__default.createElement(shape.Line, {
    from: {
      x: xScale(MAP_CHART_FIELDS_THRESHOLD[xAxis]),
      y: 0
    },
    to: {
      x: xScale(MAP_CHART_FIELDS_THRESHOLD[xAxis]),
      y: yMax
    },
    stroke: "#9493A6",
    strokeWidth: "1",
    strokeOpacity: 0.5
  }), showAxisLeft && /*#__PURE__*/React__default.createElement(axis.AxisLeft, {
    scale: yScale,
    tickLabelProps: function tickLabelProps(d) {
      return {
        fontSize: '11px',
        pic: getTickImage(d),
        id: d,
        label: getTickLabel(d)
      };
    },
    tickComponent: function tickComponent(d) {
      return getTickComponent(d);
    }
  }, function (axisGroups) {
    return /*#__PURE__*/React__default.createElement(React__default.Fragment, null, axisGroups.ticks.map(function (group$1, index) {
      return /*#__PURE__*/React__default.createElement(group.Group, {
        key: "stacked-" + chartId.current + "-axis-group-" + index
      }, getGroupContent(group$1, axisGroups, index));
    }));
  }), /*#__PURE__*/React__default.createElement(axis.AxisTop, {
    label: MAP_CHART_FIELDS_LABEL[xAxis],
    top: 0,
    scale: xScale,
    numTicks: xTicks,
    stroke: "#9493A6",
    tickStroke: "#9493A6",
    tickFormat: function tickFormat(d) {
      return FormatUtils.formattedValue(d, xAxis);
    },
    tickLabelProps: function tickLabelProps() {
      return {
        fill: '#9493A6',
        fontSize: 11,
        textAnchor: 'middle',
        fontWeight: 'bold',
        dy: -2
      };
    },
    labelProps: {
      fill: 'black',
      textAnchor: 'middle',
      fontSize: 14,
      fontWeight: 'bold',
      dy: -5
    }
  }))), tooltipOpen && tooltipData && /*#__PURE__*/React__default.createElement(ChartTooltip, {
    opened: tooltipOpen,
    top: tooltipTop || 0,
    left: tooltipLeft || 0,
    data: tooltipData
  }, /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Reach: "), FormatUtils.formattedValue(getPopulationPerc(tooltipData), METRICS.REACH)), /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Affinity: "), FormatUtils.formattedValue(tooltipData.target_audience_affinity, METRICS.AFFINITY)), /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Base: "), FormatUtils.formattedValue(tooltipData.base_population_perc, METRICS.BASE)), /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Penetration: "), FormatUtils.formattedValue(tooltipData.penetration, METRICS.PENETRATION))));
};

var MosaicChartImage = function MosaicChartImage(_ref) {
  var id = _ref.id,
      label = _ref.label,
      pic = _ref.pic,
      metric = _ref.metric,
      width = _ref.width,
      height = _ref.height,
      x = _ref.x,
      y = _ref.y,
      color = _ref.color,
      showItemsPreview = _ref.showItemsPreview,
      onMouseMove = _ref.onMouseMove,
      onMouseLeave = _ref.onMouseLeave;

  var _useState = React.useState(false),
      errorLoadingImage = _useState[0],
      setErrorLoadingImage = _useState[1];

  React.useEffect(function () {
    setErrorLoadingImage(false);
  }, [pic]);
  var onErrorLoadingImage = React.useCallback(function () {
    setErrorLoadingImage(true);
  }, []);

  if (!pic || errorLoadingImage || !showItemsPreview) {
    return /*#__PURE__*/React__default.createElement("svg", {
      overflow: "visible"
    }, /*#__PURE__*/React__default.createElement(group.Group, null, /*#__PURE__*/React__default.createElement("rect", {
      height: height,
      width: width,
      x: x,
      y: y,
      fill: color,
      stroke: "#ffffff",
      strokeWidth: 2,
      onMouseMove: onMouseMove,
      onMouseLeave: onMouseLeave,
      onTouchMove: onMouseMove,
      onTouchEnd: onMouseLeave
    }), /*#__PURE__*/React__default.createElement(text.Text, {
      height: height,
      width: width,
      x: x + width / 2,
      y: y + height / 2,
      fontSize: "10px",
      textAnchor: "middle",
      verticalAnchor: "middle",
      fill: "#ffffff"
    }, FormatUtils.capitalizeString(FormatUtils.truncateString(label, 30))), metric && /*#__PURE__*/React__default.createElement(React__default.Fragment, null, /*#__PURE__*/React__default.createElement("rect", {
      height: 30,
      width: width,
      x: x,
      y: y + height - 30,
      fill: "#ffffff",
      fillOpacity: "90%",
      onMouseMove: onMouseMove,
      onMouseLeave: onMouseLeave,
      onTouchMove: onMouseMove,
      onTouchEnd: onMouseLeave
    }), /*#__PURE__*/React__default.createElement(text.Text, {
      height: 30,
      width: width,
      x: x + width / 2,
      y: y + height - 15,
      fontSize: "9px",
      fontWeight: "bold",
      textAnchor: "middle",
      verticalAnchor: "middle",
      fill: "#000000"
    }, metric))));
  }

  return /*#__PURE__*/React__default.createElement("svg", {
    overflow: "visible"
  }, /*#__PURE__*/React__default.createElement("svg", {
    overflow: "visible"
  }, /*#__PURE__*/React__default.createElement("image", {
    preserveAspectRatio: "xMidYMid slice",
    href: pic,
    width: width,
    height: height,
    clipPath: "url(#" + id + ")",
    x: x,
    y: y,
    onMouseMove: onMouseMove,
    onMouseLeave: onMouseLeave,
    onTouchMove: onMouseMove,
    onTouchEnd: onMouseLeave,
    onError: onErrorLoadingImage
  }), /*#__PURE__*/React__default.createElement(clipPath.RectClipPath, {
    id: id,
    key: id,
    width: width,
    height: height,
    x: x,
    y: y
  }), /*#__PURE__*/React__default.createElement("rect", {
    height: height,
    width: width,
    x: x,
    y: y,
    stroke: "#ffffff",
    strokeWidth: 2,
    fill: "transparent",
    onMouseMove: onMouseMove,
    onMouseLeave: onMouseLeave,
    onTouchMove: onMouseMove,
    onTouchEnd: onMouseLeave
  }), metric && /*#__PURE__*/React__default.createElement(React__default.Fragment, null, /*#__PURE__*/React__default.createElement("rect", {
    height: 30,
    width: width,
    x: x,
    y: y + height - 30,
    fill: "#ffffff",
    fillOpacity: "90%",
    onMouseMove: onMouseMove,
    onMouseLeave: onMouseLeave,
    onTouchMove: onMouseMove,
    onTouchEnd: onMouseLeave
  }), /*#__PURE__*/React__default.createElement(text.Text, {
    height: 30,
    width: width,
    x: x + width / 2,
    y: y + height - 15,
    fontSize: "9px",
    fontWeight: "bold",
    textAnchor: "middle",
    verticalAnchor: "middle",
    fill: "#000000"
  }, metric))));
};

function _templateObject2$1() {
  var data = _taggedTemplateLiteralLoose(["\n  z-index: 1;\n"]);

  _templateObject2$1 = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$4() {
  var data = _taggedTemplateLiteralLoose(["\n  width: 100%;\n  height: 100%;\n  position: relative;\n  background-color: #ffffff;\n  overflow: ", ";\n  z-index: 0;\n"]);

  _templateObject$4 = function _templateObject() {
    return data;
  };

  return data;
}
var StyledMosaicChartWrapper = styled__default.div(_templateObject$4(), function (props) {
  return props.isScrollable ? 'hidden auto' : 'hidden';
});
var StyledMosaicChartSvg = styled__default.svg(_templateObject2$1());
var tooltipTimeout$2;
var defaultMargin$2 = {
  top: 0,
  right: 0,
  bottom: 0,
  left: 0
};

var MosaicChart = function MosaicChart(_ref) {
  var _ref$margin = _ref.margin,
      margin = _ref$margin === void 0 ? defaultMargin$2 : _ref$margin,
      data = _ref.data,
      color = _ref.color,
      emptyDataMessage = _ref.emptyDataMessage,
      isScrollable = _ref.isScrollable,
      showItemsPreview = _ref.showItemsPreview,
      metric = _ref.metric;
  var svgRef = React.useRef(null);
  var chartId = React.useRef(uniqid());

  var _useState = React.useState(0),
      width = _useState[0],
      setWidth = _useState[1];

  var _useState2 = React.useState(0),
      height = _useState2[0],
      setHeight = _useState2[1];

  var _useTooltip = tooltip.useTooltip(),
      tooltipOpen = _useTooltip.tooltipOpen,
      tooltipLeft = _useTooltip.tooltipLeft,
      tooltipTop = _useTooltip.tooltipTop,
      tooltipData = _useTooltip.tooltipData,
      hideTooltip = _useTooltip.hideTooltip,
      showTooltip = _useTooltip.showTooltip;

  var windowSize = useWindowSize();
  var chartRef = React.useCallback(function (node) {
    if (node != null) {
      setWidth(node.getBoundingClientRect().width);
      setHeight(node.getBoundingClientRect().height);
    }
  }, [windowSize]);
  var numColumns = 5;
  var numRows = 5;
  var columnWidth = Math.max((width - margin.left - margin.right) / numColumns, 0);
  var rowHeight = Math.max((height - margin.bottom - margin.top) / numRows, 0);
  var xMax = width - margin.left - margin.right;
  var yMax = height - margin.top - margin.bottom;
  var isEmpty = !data || data.length === 0;
  var handleMouseLeave = React.useCallback(function (event) {
    tooltipTimeout$2 = window.setTimeout(function () {
      hideTooltip();
    }, 0);
  }, [hideTooltip]);
  var handleMouseMove = React.useCallback(function (event$1, index) {
    if (tooltipTimeout$2) clearTimeout(tooltipTimeout$2);
    if (!svgRef.current) return;
    var eventSvgCoords = event.localPoint(svgRef.current, event$1);
    showTooltip({
      tooltipData: _extends({}, data[index]),
      tooltipTop: eventSvgCoords === null || eventSvgCoords === void 0 ? void 0 : eventSvgCoords.y,
      tooltipLeft: eventSvgCoords === null || eventSvgCoords === void 0 ? void 0 : eventSvgCoords.x
    });
  }, [showTooltip, data]);
  var colorScale = React.useMemo(function () {
    return scale.scaleLinear({
      domain: [0, isEmpty ? 0 : data.length / 2, isEmpty ? 0 : data.length],
      range: getColors(color)
    });
  }, [data, isEmpty, color]);

  if (isEmpty) {
    return /*#__PURE__*/React__default.createElement(StyledMosaicChartWrapper, null, /*#__PURE__*/React__default.createElement(hxReactComponents.Box, {
      minWidth: "100%"
    }, /*#__PURE__*/React__default.createElement(hxReactComponents.EmptyState, {
      icon: "analytics",
      mainText: emptyDataMessage,
      size: "large"
    })));
  }

  return /*#__PURE__*/React__default.createElement(StyledMosaicChartWrapper, {
    ref: chartRef,
    isScrollable: isScrollable
  }, /*#__PURE__*/React__default.createElement(StyledMosaicChartSvg, {
    ref: svgRef,
    width: width,
    height: Math.floor((data.length - 1) / numColumns) * rowHeight + rowHeight
  }, /*#__PURE__*/React__default.createElement("rect", {
    width: width,
    height: height,
    fill: "#ffffff"
  }), /*#__PURE__*/React__default.createElement(group.Group, {
    top: margin.top,
    left: margin.left,
    key: "group-" + chartId.current
  }, /*#__PURE__*/React__default.createElement("rect", {
    fill: "#ffffff",
    stroke: "#9493A6",
    strokeWidth: "1",
    width: xMax,
    height: yMax
  }), data.map(function (item, index) {
    var columnIndex = index % numColumns;
    var rowIndex = Math.floor(index / numColumns);
    var id = "mosaic-" + chartId.current + "-item-icon-" + index + "-" + rowIndex + "-" + columnIndex;
    return /*#__PURE__*/React__default.createElement(React__default.Fragment, {
      key: "mosaic-" + chartId.current + "-item-" + index + "-" + rowIndex + "-" + columnIndex
    }, /*#__PURE__*/React__default.createElement(MosaicChartImage, {
      id: id,
      pic: item.pic,
      label: item.label,
      width: columnWidth,
      height: rowHeight,
      metric: metric && MAP_CHART_FIELDS_LABEL[metric] + " " + FormatUtils.formattedValue(item[metric], metric),
      x: columnIndex * columnWidth,
      y: rowIndex * rowHeight,
      color: colorScale(index),
      showItemsPreview: showItemsPreview,
      onMouseMove: function onMouseMove(event) {
        return handleMouseMove(event, index);
      },
      onMouseLeave: function onMouseLeave(event) {
        return handleMouseLeave(event);
      }
    }));
  }))), tooltipOpen && tooltipData && /*#__PURE__*/React__default.createElement(ChartTooltip, {
    opened: tooltipOpen,
    top: tooltipTop || 0,
    left: tooltipLeft || 0,
    data: tooltipData
  }, /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Reach: "), FormatUtils.formattedValue(getPopulationPerc(tooltipData), METRICS.REACH)), /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Affinity: "), FormatUtils.formattedValue(tooltipData.target_audience_affinity, METRICS.AFFINITY)), /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Base: "), FormatUtils.formattedValue(tooltipData.base_population_perc, METRICS.BASE)), /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Penetration: "), FormatUtils.formattedValue(tooltipData.penetration, METRICS.PENETRATION))));
};

function _templateObject11() {
  var data = _taggedTemplateLiteralLoose(["\n  fill: transparent;\n  stroke: transparent;\n  &:hover {\n    fill: ", ";\n    stroke: ", ";\n  }\n"]);

  _templateObject11 = function _templateObject11() {
    return data;
  };

  return data;
}

function _templateObject10() {
  var data = _taggedTemplateLiteralLoose(["\n  color: ", ";\n  font-size: ", ";\n  display: inline-flex;\n"]);

  _templateObject10 = function _templateObject10() {
    return data;
  };

  return data;
}

function _templateObject9() {
  var data = _taggedTemplateLiteralLoose(["\n  background-color: ", ";\n  border-radius: 50%;\n  width: 15px;\n  height: 15px;\n  display: inline-flex;\n  margin-right: ", ";\n"]);

  _templateObject9 = function _templateObject9() {
    return data;
  };

  return data;
}

function _templateObject8() {
  var data = _taggedTemplateLiteralLoose(["\n  display: inline-flex;\n  align-items: center;\n  margin-right: ", ";\n"]);

  _templateObject8 = function _templateObject8() {
    return data;
  };

  return data;
}

function _templateObject7() {
  var data = _taggedTemplateLiteralLoose(["\n  font-size: ", ";\n  fill: ", ";\n  text-anchor: middle;\n  alignment-baseline: center;\n"]);

  _templateObject7 = function _templateObject7() {
    return data;
  };

  return data;
}

function _templateObject6() {
  var data = _taggedTemplateLiteralLoose(["\n  .domain {\n    stroke: none;\n  }\n  .tick line {\n    stroke: ", ";\n  }\n"]);

  _templateObject6 = function _templateObject6() {
    return data;
  };

  return data;
}

function _templateObject5() {
  var data = _taggedTemplateLiteralLoose(["\n  font-size: ", ";\n  text {\n    fill: ", ";\n  }\n  .domain {\n    stroke: none;\n  }\n  .tick line {\n    stroke: none;\n  }\n"]);

  _templateObject5 = function _templateObject5() {
    return data;
  };

  return data;
}

function _templateObject4$1() {
  var data = _taggedTemplateLiteralLoose(["\n  .domain {\n    stroke: none;\n  }\n  .tick {\n    &:nth-child(2) line {\n      stroke-dasharray: 0;\n    }\n    & line {\n      stroke-dasharray: 5 5;\n      stroke: ", ";\n    }\n  }\n"]);

  _templateObject4$1 = function _templateObject4() {
    return data;
  };

  return data;
}

function _templateObject3$1() {
  var data = _taggedTemplateLiteralLoose(["\n  font-size: ", ";\n  text {\n    fill: ", ";\n  }\n  .domain {\n    stroke: ", ";\n  }\n  .tick line {\n    stroke: none;\n  }\n"]);

  _templateObject3$1 = function _templateObject3() {
    return data;
  };

  return data;
}

function _templateObject2$2() {
  var data = _taggedTemplateLiteralLoose(["\n  fill: none;\n"]);

  _templateObject2$2 = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$5() {
  var data = _taggedTemplateLiteralLoose(["\n  width: 100%;\n  height: 100%;\n  position: relative;\n  background-color: ", ";\n  max-height: 500px;\n"]);

  _templateObject$5 = function _templateObject() {
    return data;
  };

  return data;
}
var fontGrey = '#6C6B7C';
var ChartWrapper = styled__default.div(_templateObject$5(), function (props) {
  return props.theme.colors.light;
});
var Line = styled__default.path(_templateObject2$2());
var XAxis = styled__default.g(_templateObject3$1(), function (props) {
  return props.theme.size.small;
}, fontGrey, function (props) {
  return props.theme.colors.light_darker_1;
});
var XAxisGrid = styled__default.g(_templateObject4$1(), function (props) {
  return props.theme.colors.light_darker_1;
});
var YAxis = styled__default.g(_templateObject5(), function (props) {
  return props.theme.size.small;
}, fontGrey);
var YAxisGrid = styled__default.g(_templateObject6(), function (props) {
  return props.theme.colors.light_darker_1;
});
var CircleLabel = styled__default.text(_templateObject7(), function (props) {
  return props.theme.size.small;
}, fontGrey);
var LabelWrapper = styled__default.div(_templateObject8(), function (props) {
  return props.theme.spacing.large;
});
var LabelCircle = styled__default.div(_templateObject9(), function (props) {
  return props.color;
}, function (props) {
  return props.theme.spacing.small;
});
var LabelText = styled__default.div(_templateObject10(), function (props) {
  return props.theme.colors.dark;
}, function (props) {
  return props.theme.size.xbody;
});
var HiddenCircle = styled__default.circle(_templateObject11(), function (props) {
  return props.color;
}, function (props) {
  return props.color;
});

var LineChartLabels = function LineChartLabels(_ref) {
  var labels = _ref.labels,
      getColor = _ref.getColor;
  if (!labels || !labels.length) return null;
  return labels.map(function (label, i) {
    return /*#__PURE__*/React__default.createElement(LabelWrapper, {
      key: i
    }, /*#__PURE__*/React__default.createElement(LabelCircle, {
      color: getColor(i)
    }, "\xA0"), /*#__PURE__*/React__default.createElement(LabelText, null, label));
  });
};

var LineChartLabels$1 = React.memo(LineChartLabels);

var LineChartAxes = function LineChartAxes(props) {
  var highlightTicks = props.highlightTicks,
      chartWidth = props.chartWidth,
      chartHeight = props.chartHeight,
      padding = props.padding,
      xScale = props.xScale,
      yScale = props.yScale,
      yDelta = props.yDelta,
      allowDecimalTicks = props.allowDecimalTicks,
      rotateXAxisLabels = props.rotateXAxisLabels,
      onXAxisMouseOver = props.onXAxisMouseOver,
      onXAxisMouseLeave = props.onXAxisMouseLeave;
  var xAxisRef = React.useRef(null);
  var xAxisGridRef = React.useRef(null);
  var yAxisRef = React.useRef(null);
  var yAxisGridRef = React.useRef(null);
  React.useEffect(function () {
    var xAxis = d3.axisBottom().scale(xScale).ticks(chartWidth / 100);
    var bottom = d3.select(xAxisRef.current).call(xAxis);
    if (rotateXAxisLabels) bottom.selectAll('text').attr('dx', '-1.5em').attr('dy', '1.5em').attr('transform', 'rotate(-45)');
    var xAxisGrid = d3.axisBottom().scale(xScale).tickSize(-(chartHeight - 2 * padding)).tickFormat('').ticks(chartWidth / 100);
    d3.select(xAxisGridRef.current).call(xAxisGrid).selectAll('.tick').each(function () {
      var d = d3.select(this);
      var h = Math.abs(d.select('line').attr('y2'));
      d.append('rect').attr('width', 20).attr('height', h).attr('x', -10).attr('y', d.select('line').attr('y2')).style('pointer-events', 'visible');
    }).on('mousemove', function (event, item) {
      if (highlightTicks) {
        var d = d3.select(event.currentTarget);
        d.select('line').style('stroke', theme.colors.dark_lighter).style('stroke-width', 3);
        onXAxisMouseOver(event, item);
      }
    }).on('mouseleave', function (event) {
      if (highlightTicks) {
        var d = d3.select(event.currentTarget);
        d.select('line').style('stroke', theme.colors.light_darker_1).style('stroke-width', 1);
        onXAxisMouseLeave(event);
      }
    });
    var yTicks = allowDecimalTicks ? chartHeight / 50 : Math.min(yDelta, chartHeight / 50);
    var yAxis = d3.axisLeft().scale(yScale).tickFormat(d3.format('~s')).ticks(yTicks);
    d3.select(yAxisRef.current).call(yAxis);
    var yAxisGrid = d3.axisLeft().scale(yScale).tickSize(-(chartWidth - 2 * padding)).tickFormat('').ticks(yTicks);
    d3.select(yAxisGridRef.current).call(yAxisGrid);
  }, [props]);
  return /*#__PURE__*/React__default.createElement("g", null, /*#__PURE__*/React__default.createElement(XAxis, {
    ref: xAxisRef,
    transform: "translate(0, " + (chartHeight - padding) + ")"
  }), /*#__PURE__*/React__default.createElement(XAxisGrid, {
    ref: xAxisGridRef,
    transform: "translate(0, " + (chartHeight - padding) + ")"
  }), /*#__PURE__*/React__default.createElement(YAxis, {
    ref: yAxisRef,
    transform: "translate(" + padding + ", 0)"
  }), /*#__PURE__*/React__default.createElement(YAxisGrid, {
    ref: yAxisGridRef,
    transform: "translate(" + padding + ", 0)"
  }));
};

var LineChartAxes$1 = React.memo(LineChartAxes);

var tooltipTimeout$3;

var LineChart = function LineChart(_ref) {
  var _ref$data = _ref.data,
      data = _ref$data === void 0 ? {} : _ref$data,
      labels = _ref.labels,
      _ref$colors = _ref.colors,
      colors = _ref$colors === void 0 ? [] : _ref$colors,
      _ref$padding = _ref.padding,
      padding = _ref$padding === void 0 ? 50 : _ref$padding,
      emptyChartMessage = _ref.emptyChartMessage,
      _ref$allowDecimalTick = _ref.allowDecimalTicks,
      allowDecimalTicks = _ref$allowDecimalTick === void 0 ? false : _ref$allowDecimalTick,
      theme = _ref.theme,
      _ref$showMarkers = _ref.showMarkers,
      showMarkers = _ref$showMarkers === void 0 ? true : _ref$showMarkers,
      pointContent = _ref.pointContent,
      tickContent = _ref.tickContent,
      _ref$lineWeight = _ref.lineWeight,
      lineWeight = _ref$lineWeight === void 0 ? 1 : _ref$lineWeight;
  var svgRef = React.useRef(null);

  var _useTooltip = tooltip.useTooltip(),
      tooltipOpen = _useTooltip.tooltipOpen,
      tooltipLeft = _useTooltip.tooltipLeft,
      tooltipTop = _useTooltip.tooltipTop,
      tooltipData = _useTooltip.tooltipData,
      hideTooltip = _useTooltip.hideTooltip,
      showTooltip = _useTooltip.showTooltip;

  var _data$linesData = data.linesData,
      linesData = _data$linesData === void 0 ? [] : _data$linesData,
      _data$xAxisData = data.xAxisData,
      xAxisData = _data$xAxisData === void 0 ? [] : _data$xAxisData;

  var _useState = React.useState([]),
      lines = _useState[0],
      setLines = _useState[1];

  var _useState2 = React.useState(),
      markers = _useState2[0],
      setMarkers = _useState2[1];

  var _useState3 = React.useState({}),
      isOverlapping = _useState3[0],
      setOverlapping = _useState3[1];

  var _useState4 = React.useState(0),
      chartWidth = _useState4[0],
      setChartWidth = _useState4[1];

  var _useState5 = React.useState(0),
      chartHeight = _useState5[0],
      setChartHeight = _useState5[1];

  var chartRef = React.useRef(null);
  var windowSize = useWindowSize();
  var yDelta = React.useMemo(function () {
    var domain = d3.extent(linesData.flat(), function (d) {
      return d;
    });
    return domain[1] - domain[0] || 0;
  }, [linesData]);
  var xScale = React.useMemo(function () {
    return d3.scalePoint().domain(xAxisData).range([padding, chartWidth - padding]);
  }, [xAxisData, chartWidth, padding]);
  var yScale = React.useMemo(function () {
    return d3.scaleLinear().domain(d3.extent(linesData.flat(), function (d) {
      return d;
    })).range([chartHeight - padding, padding]);
  }, [linesData, chartHeight, padding]);
  var defaultColors = React.useMemo(function () {
    return theme ? [theme.colors.secondary, theme.colors.warning, theme.colors.error_bg, theme.colors.success_bg] : [];
  }, [theme]);
  var getColor = React.useCallback(function (index) {
    var availableColors = colors.length ? colors : defaultColors;
    return availableColors[index % availableColors.length];
  }, [colors, defaultColors]);
  var handleMouseLeave = React.useCallback(function (event, marker) {
    tooltipTimeout$3 = window.setTimeout(function () {
      hideTooltip();
    }, 0);

    if (marker) {
      setOverlapping(function (prev) {
        var _extends2;

        return _extends({}, prev, (_extends2 = {}, _extends2[marker.lineId] = false, _extends2));
      });
    }
  }, [hideTooltip]);
  var handleMouseMove = React.useCallback(function (event$1, item) {
    if (tooltipTimeout$3) clearTimeout(tooltipTimeout$3);
    var eventSvgCoords = event.localPoint(svgRef.current, event$1);
    showTooltip({
      tooltipData: _extends({}, item, {
        tick: false
      }),
      tooltipTop: eventSvgCoords === null || eventSvgCoords === void 0 ? void 0 : eventSvgCoords.y,
      tooltipLeft: eventSvgCoords === null || eventSvgCoords === void 0 ? void 0 : eventSvgCoords.x
    });
  }, [showTooltip, svgRef.current]);
  var handleXAxisMouseOver = React.useCallback(function (event$1, date) {
    if (tooltipTimeout$3) clearTimeout(tooltipTimeout$3);
    var eventSvgCoords = event.localPoint(svgRef.current, event$1);
    var tickIndex = xAxisData.findIndex(function (d) {
      return d === date;
    });
    showTooltip({
      tooltipData: {
        label: date,
        tick: true,
        tickIndex: tickIndex
      },
      tooltipTop: eventSvgCoords === null || eventSvgCoords === void 0 ? void 0 : eventSvgCoords.y,
      tooltipLeft: eventSvgCoords === null || eventSvgCoords === void 0 ? void 0 : eventSvgCoords.x
    });
  }, [showTooltip, svgRef.current]);
  React.useEffect(function () {
    if (chartRef.current) {
      setChartWidth(chartRef.current.parentElement.offsetWidth);
      setChartHeight(chartRef.current.parentElement.offsetHeight);
    }
  }, [chartRef.current, windowSize]);
  React.useEffect(function () {
    if (!windowSize || !linesData.length) {
      return;
    }

    var lineGenerator = d3.line().x(function (d, i) {
      return xScale(xAxisData[i]);
    }).y(function (d) {
      return yScale(d);
    });
    setLines(linesData.map(lineGenerator));
    setMarkers(linesData.flat().map(function (d, i) {
      var index = i % xAxisData.length;
      var lineId = Math.floor(i / xAxisData.length);
      return !showMarkers || index > 0 ? {
        value: d,
        lineId: lineId,
        index: index,
        x: xScale(xAxisData[index]),
        y: yScale(d)
      } : undefined;
    }));
  }, [windowSize, linesData, xAxisData, xScale, yScale, showMarkers]);

  if (!linesData.length) {
    return /*#__PURE__*/React__default.createElement(ChartWrapper, null, /*#__PURE__*/React__default.createElement(hxReactComponents.Box, {
      minWidth: "100%"
    }, /*#__PURE__*/React__default.createElement(hxReactComponents.EmptyState, {
      icon: "alert",
      mainText: "Sorry, no content.",
      smallText: emptyChartMessage,
      size: "large"
    })));
  }

  return /*#__PURE__*/React__default.createElement(ChartWrapper, {
    ref: chartRef
  }, showMarkers && /*#__PURE__*/React__default.createElement(LineChartLabels$1, {
    labels: labels,
    getColor: getColor
  }), /*#__PURE__*/React__default.createElement("svg", {
    ref: svgRef,
    width: chartWidth,
    height: chartHeight
  }, /*#__PURE__*/React__default.createElement(LineChartAxes$1, {
    highlightTicks: tickContent,
    chartWidth: chartWidth,
    chartHeight: chartHeight,
    padding: padding,
    xScale: xScale,
    yScale: yScale,
    yDelta: yDelta,
    allowDecimalTicks: allowDecimalTicks,
    rotateXAxisLabels: !showMarkers,
    onXAxisMouseOver: function onXAxisMouseOver(event, date) {
      return handleXAxisMouseOver(event, date);
    },
    onXAxisMouseLeave: function onXAxisMouseLeave(event) {
      return handleMouseLeave(event);
    }
  }), /*#__PURE__*/React__default.createElement("g", null, lines && lines.map(function (line, i) {
    return /*#__PURE__*/React__default.createElement(React__default.Fragment, {
      key: i
    }, showMarkers ? /*#__PURE__*/React__default.createElement(Line, {
      stroke: getColor(i),
      d: line,
      data: linesData
    }) : /*#__PURE__*/React__default.createElement(Line, {
      stroke: getColor(i),
      strokeOpacity: isOverlapping[i] ? 1 : 0.5,
      strokeWidth: isOverlapping[i] ? lineWeight + 2 : lineWeight,
      d: line,
      data: linesData,
      onMouseOver: function onMouseOver(e) {
        setOverlapping(function (prev) {
          var _extends3;

          return _extends({}, prev, (_extends3 = {}, _extends3[i] = true, _extends3));
        });
        handleMouseMove(e, {
          label: labels[i],
          color: getColor(i),
          lineId: i
        });
      },
      onMouseLeave: function onMouseLeave(e) {
        setOverlapping(function (prev) {
          var _extends4;

          return _extends({}, prev, (_extends4 = {}, _extends4[i] = false, _extends4));
        });
        handleMouseLeave(e);
      }
    }));
  }), markers && markers.map(function (marker, i) {
    return marker && /*#__PURE__*/React__default.createElement(React__default.Fragment, {
      key: i
    }, showMarkers ? /*#__PURE__*/React__default.createElement(React__default.Fragment, null, /*#__PURE__*/React__default.createElement("circle", {
      cx: marker.x,
      cy: marker.y,
      r: 7.5,
      stroke: getColor(marker.lineId),
      fill: getColor(marker.lineId)
    }), /*#__PURE__*/React__default.createElement(CircleLabel, {
      x: marker.x,
      y: marker.y - 15
    }, marker.value)) : /*#__PURE__*/React__default.createElement(HiddenCircle, {
      cx: marker.x,
      cy: marker.y,
      r: 7.5,
      color: getColor(marker.lineId),
      onMouseMove: function onMouseMove(e) {
        handleMouseMove(e, {
          label: labels[marker.lineId],
          color: getColor(marker.lineId),
          lineId: marker.lineId,
          index: marker.index
        });
        setOverlapping(function (prev) {
          var _extends5;

          return _extends({}, prev, (_extends5 = {}, _extends5[marker.lineId] = true, _extends5));
        });
      },
      onMouseLeave: function onMouseLeave(event) {
        return handleMouseLeave(event, marker);
      }
    }));
  }))), pointContent && tooltipOpen && !tooltipData.tick && /*#__PURE__*/React__default.createElement(ChartTooltip, {
    opened: tooltipOpen,
    top: tooltipTop || 0,
    left: tooltipLeft || 0,
    data: tooltipData
  }, pointContent(tooltipData)), tickContent && tooltipOpen && tooltipData.tick && /*#__PURE__*/React__default.createElement(ChartTooltip, {
    opened: tooltipOpen,
    top: tooltipTop || 0,
    left: tooltipLeft || 0,
    data: tooltipData
  }, tickContent(tooltipData)));
};

LineChart.propTypes = {
  data: PropTypes.shape({
    linesData: PropTypes.array,
    xAxisData: PropTypes.array
  }),
  labels: PropTypes.array,
  colors: PropTypes.array,
  padding: PropTypes.number,
  emptyChartMessage: PropTypes.string,
  allowDecimalTicks: PropTypes.bool,
  showMarkers: PropTypes.bool,
  pointContent: PropTypes.func,
  tickContent: PropTypes.func,
  lineWeight: PropTypes.number
};
var LineChart$1 = React.memo(styled.withTheme(LineChart));

var PieChartImage = function PieChartImage(_ref) {
  var d = _ref.d,
      showItemsPreview = _ref.showItemsPreview,
      color = _ref.color,
      chartId = _ref.chartId,
      limitText = _ref.limitText;

  var _useState = React.useState(false),
      errorLoadingImage = _useState[0],
      setErrorLoadingImage = _useState[1];

  React.useEffect(function () {
    setErrorLoadingImage(false);
  }, [d.pic]);
  var onErrorLoadingImage = React.useCallback(function () {
    setErrorLoadingImage(true);
  }, []);

  if (showItemsPreview && (!d.pic || errorLoadingImage)) {
    return /*#__PURE__*/React__default.createElement("svg", {
      overflow: "visible"
    }, /*#__PURE__*/React__default.createElement(shape.Circle, {
      r: 15,
      cx: d.x,
      cy: d.y,
      fill: color
    }));
  }

  if (!showItemsPreview) {
    return /*#__PURE__*/React__default.createElement("svg", {
      overflow: "visible"
    }, /*#__PURE__*/React__default.createElement(text.Text, {
      height: 80,
      width: 80,
      x: d.x,
      y: d.y,
      fontSize: "10px",
      textAnchor: "middle",
      verticalAnchor: "middle",
      fill: "#000000"
    }, FormatUtils.capitalizeString(FormatUtils.truncateString(d.label, limitText))));
  }

  return /*#__PURE__*/React__default.createElement("svg", {
    overflow: "visible"
  }, /*#__PURE__*/React__default.createElement("image", {
    href: d.pic,
    height: 30,
    width: 30,
    clipPath: "url(#category-" + chartId + "-icon-" + d.id + ")",
    x: d.x - 15,
    y: d.y - 15,
    onError: onErrorLoadingImage
  }), /*#__PURE__*/React__default.createElement(clipPath.CircleClipPath, {
    id: "category-" + chartId + "-icon-" + d.id,
    key: "category-" + chartId + "-icon-" + d.id,
    r: 15,
    cx: d.x,
    cy: d.y
  }));
};

function _templateObject$6() {
  var data = _taggedTemplateLiteralLoose(["\n  width: 100%;\n  height: 100%;\n  position: relative;\n  background-color: #ffffff;\n  padding: 10px;\n"]);

  _templateObject$6 = function _templateObject() {
    return data;
  };

  return data;
}
var StyledPieChartWrapper = styled__default.div(_templateObject$6());
var tooltipTimeout$4;
var defaultMargin$3 = {
  top: 50,
  right: 50,
  bottom: 50,
  left: 100
};

var PieChart = function PieChart(_ref) {
  var data = _ref.data,
      _ref$margin = _ref.margin,
      margin = _ref$margin === void 0 ? defaultMargin$3 : _ref$margin,
      hasInnerRadius = _ref.hasInnerRadius,
      metric = _ref.metric,
      color = _ref.color,
      emptyDataMessage = _ref.emptyDataMessage,
      _ref$limit = _ref.limit,
      limit = _ref$limit === void 0 ? 'auto' : _ref$limit,
      showItemsPreview = _ref.showItemsPreview,
      _ref$limitText = _ref.limitText,
      limitText = _ref$limitText === void 0 ? 25 : _ref$limitText,
      _ref$showMarkers = _ref.showMarkers,
      showMarkers = _ref$showMarkers === void 0 ? true : _ref$showMarkers;
  var svgRef = React.useRef(null);
  var chartId = React.useRef(uniqid());

  var _useState = React.useState(0),
      width = _useState[0],
      setWidth = _useState[1];

  var _useState2 = React.useState(0),
      height = _useState2[0],
      setHeight = _useState2[1];

  var _useTooltip = tooltip.useTooltip(),
      tooltipOpen = _useTooltip.tooltipOpen,
      tooltipLeft = _useTooltip.tooltipLeft,
      tooltipTop = _useTooltip.tooltipTop,
      tooltipData = _useTooltip.tooltipData,
      hideTooltip = _useTooltip.hideTooltip,
      showTooltip = _useTooltip.showTooltip;

  var windowSize = useWindowSize();
  var chartRef = React.useCallback(function (node) {
    if (node != null) {
      setWidth(node.getBoundingClientRect().width);
      setHeight(node.getBoundingClientRect().height);
    }
  }, [windowSize]);
  var innerWidth = width - margin.left - margin.right;
  var innerHeight = height - margin.top - margin.bottom;
  var radius = Math.min(innerWidth, innerHeight) / 2;
  var centerY = innerHeight / 2;
  var centerX = innerWidth / 2;
  var isEmpty = !data || data.length === 0;
  var filteredData = React.useMemo(function () {
    if (isEmpty) {
      return [];
    }

    var filtered = limit !== 'auto' ? data.slice(0, limit) : data;
    return filtered.filter(function (d) {
      return d[metric] && d[metric] > 0;
    });
  }, [isEmpty, data, limit, metric]);
  var colorScale = React.useMemo(function () {
    return scale.scaleLinear({
      domain: [0, isEmpty ? 0 : filteredData.length / 2, isEmpty ? 0 : filteredData.length],
      range: getColors(color)
    });
  }, [isEmpty, filteredData, color]);
  var handleMouseLeave = React.useCallback(function (event) {
    tooltipTimeout$4 = window.setTimeout(function () {
      hideTooltip();
    }, 0);
  }, [hideTooltip]);
  var handleMouseMove = React.useCallback(function (event$1, index) {
    if (tooltipTimeout$4) clearTimeout(tooltipTimeout$4);
    var eventSvgCoords = event.localPoint(event$1);
    var color = filteredData[index].color || colorScale(index);
    showTooltip({
      tooltipData: _extends({}, filteredData[index], {
        color: color
      }),
      tooltipTop: eventSvgCoords === null || eventSvgCoords === void 0 ? void 0 : eventSvgCoords.y,
      tooltipLeft: eventSvgCoords === null || eventSvgCoords === void 0 ? void 0 : eventSvgCoords.x
    });
  }, [showTooltip, filteredData, colorScale]);

  if (isEmpty) {
    return /*#__PURE__*/React__default.createElement(StyledPieChartWrapper, null, /*#__PURE__*/React__default.createElement(hxReactComponents.Box, {
      minWidth: "100%"
    }, /*#__PURE__*/React__default.createElement(hxReactComponents.EmptyState, {
      icon: "analytics",
      mainText: emptyDataMessage,
      size: "large"
    })));
  }

  return /*#__PURE__*/React__default.createElement(StyledPieChartWrapper, {
    ref: chartRef
  }, /*#__PURE__*/React__default.createElement("svg", {
    ref: svgRef,
    width: width,
    height: height
  }, /*#__PURE__*/React__default.createElement("rect", {
    width: width,
    height: height,
    fill: "#ffffff",
    rx: 14
  }), /*#__PURE__*/React__default.createElement(group.Group, {
    top: centerY + margin.top,
    left: centerX + margin.left,
    key: "group-" + chartId.current
  }, /*#__PURE__*/React__default.createElement(shape.Pie, {
    data: filteredData,
    pieValue: function pieValue(d) {
      return metric === METRICS.BASE ? d[metric] * 100 : d[metric];
    },
    pieSortValues: function pieSortValues() {
      return -1;
    },
    outerRadius: radius - 2 * 1.3
  }, function (pie) {
    return pie.arcs.map(function (arc, index) {
      var _pie$path$centroid = pie.path.centroid(arc),
          centroidX = _pie$path$centroid[0],
          centroidY = _pie$path$centroid[1];

      var point = (arc.startAngle + arc.endAngle) / 2 - Math.PI / 2;
      var offsetX = Math.cos(point) * (radius / 2) < 0 ? Math.cos(point) * (radius / 2) - 30 : Math.cos(point) * (radius / 2) + 30;
      var offsetY = Math.sin(point) * (radius / 2) < 0 ? Math.sin(point) * (radius / 2) - 30 : Math.sin(point) * (radius / 2) + 30;
      return /*#__PURE__*/React__default.createElement(React__default.Fragment, {
        key: "arc-" + chartId.current + "-" + index
      }, /*#__PURE__*/React__default.createElement(group.Group, null, /*#__PURE__*/React__default.createElement(shape.Arc, {
        startAngle: arc.startAngle,
        endAngle: arc.endAngle,
        innerRadius: hasInnerRadius ? radius / 2 : 0,
        cornerRadius: 1,
        outerRadius: radius,
        padAngle: arc.padAngle,
        padRadius: 2,
        fill: filteredData[index].color || colorScale(index),
        stroke: "#fff",
        strokeWidth: "1",
        onMouseMove: function onMouseMove(event) {
          return handleMouseMove(event, index);
        },
        onMouseLeave: function onMouseLeave(event) {
          return handleMouseLeave(event);
        },
        onTouchMove: function onTouchMove(event) {
          return handleMouseMove(event, index);
        },
        onTouchEnd: function onTouchEnd(event) {
          return handleMouseLeave(event);
        }
      }), showMarkers && arc.endAngle - arc.startAngle > 0.2 && /*#__PURE__*/React__default.createElement(PieChartImage, {
        d: _extends({}, arc.data, {
          x: centroidX + offsetX,
          y: centroidY + offsetY
        }),
        color: colorScale(index),
        showItemsPreview: showItemsPreview,
        chartId: chartId.current,
        limitText: limitText
      })));
    });
  }))), tooltipOpen && tooltipData && /*#__PURE__*/React__default.createElement(ChartTooltip, {
    opened: tooltipOpen,
    top: tooltipTop || 0,
    left: tooltipLeft || 0,
    data: tooltipData
  }, !Object.values(METRICS).includes(metric) && !isReach(metric) ? /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Value: "), tooltipData[metric]) : /*#__PURE__*/React__default.createElement(React.Fragment, null, /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Affinity: "), FormatUtils.formattedValue(tooltipData.target_audience_affinity, METRICS.AFFINITY)), /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Reach: "), FormatUtils.formattedValue(getPopulationPerc(tooltipData), METRICS.REACH)), /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Base: "), FormatUtils.formattedValue(tooltipData.base_population_perc, METRICS.BASE)), /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Penetration: "), FormatUtils.formattedValue(tooltipData.penetration, METRICS.PENETRATION)))));
};

function _templateObject3$2() {
  var data = _taggedTemplateLiteralLoose(["\n  width: 100%;\n  height: 100%;\n  position: relative;\n  background-color: ", ";\n"]);

  _templateObject3$2 = function _templateObject3() {
    return data;
  };

  return data;
}

function _templateObject2$3() {
  var data = _taggedTemplateLiteralLoose(["\n  border-radius: ", ";\n  display: flex;\n  flex-wrap: wrap;\n  flex-direction: column;\n  text-align: left;\n  width: max-content;\n  max-width: 250px;\n  white-space: pre-line;\n  font-size: ", ";\n  line-height: 18px;\n  color: ", ";\n  background-color: ", ";\n  box-shadow: ", "\n    ", ";\n  padding: ", ";\n  ", ";\n  ", ";\n  z-index: ", ";\n"]);

  _templateObject2$3 = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$7() {
  var data = _taggedTemplateLiteralLoose(["\n    &::after {\n      content: '';\n      width: 0;\n      height: 0;\n      border-style: solid;\n      border-width: 6px 4px 0 4px;\n      border-color: rgb(58, 57, 73) transparent transparent transparent;\n      z-index: 1;\n      position: absolute;\n      bottom: -6px;\n      left: 50%;\n      transform: translate(-50%, 0);\n    }\n  "]);

  _templateObject$7 = function _templateObject() {
    return data;
  };

  return data;
}

var getTriangle = function getTriangle() {
  return styled.css(_templateObject$7());
};

var getPosition = function getPosition(_ref) {
  var left = _ref.left,
      top = _ref.top;
  return "\n    position: absolute;\n    top: " + top + "px;\n    left: " + left + "px;\n    transform: translate(-50%, calc(-100% - 12px));\n  ";
};

var StyledDotTooltip = styled__default.div(_templateObject2$3(), function (props) {
  return props.theme.border_radius.standard;
}, function (props) {
  return props.theme.size.small;
}, function (props) {
  return props.theme.colors.light;
}, function (props) {
  return props.theme.colors.dark_light;
}, function (props) {
  return props.theme.shadow.position;
}, function (props) {
  return props.theme.shadow.color;
}, function (props) {
  return props.theme.spacing.small;
}, function (props) {
  return getTriangle();
}, function (props) {
  return getPosition(props);
}, function (props) {
  return props.theme.zindex.small;
});
var StyledDotsChartWrapper = styled__default.div(_templateObject3$2(), function (props) {
  return props.theme.colors.light;
});

var DotsChart = function DotsChart(_ref) {
  var _ref$data = _ref.data,
      data = _ref$data === void 0 ? [] : _ref$data,
      _ref$padding = _ref.padding,
      padding = _ref$padding === void 0 ? 40 : _ref$padding,
      radius = _ref.radius,
      showTooltips = _ref.showTooltips,
      emptyDataMessage = _ref.emptyDataMessage;
  var svgRef = React.useRef(null);
  var chartId = React.useRef(uniqid());
  var windowSize = useWindowSize();

  var _useState = React.useState(0),
      width = _useState[0],
      setWidth = _useState[1];

  var _useState2 = React.useState(0),
      height = _useState2[0],
      setHeight = _useState2[1];

  var _useState3 = React.useState(0),
      tooltipTop = _useState3[0],
      setTooltipTop = _useState3[1];

  var _useState4 = React.useState(0),
      tooltipLeft = _useState4[0],
      setTooltipLeft = _useState4[1];

  var _useState5 = React.useState(null),
      tooltipData = _useState5[0],
      setTooltipData = _useState5[1];

  var _useState6 = React.useState(false),
      tooltipOpen = _useState6[0],
      setTooltipOpen = _useState6[1];

  var chartRef = React.useCallback(function (node) {
    if (node != null) {
      setWidth(node.getBoundingClientRect().width);
      setHeight(node.getBoundingClientRect().height);
    }
  }, [windowSize]);
  var points = [];
  data.map(function (segment) {
    points = points.concat(segment.values);
  });

  var _points$reduce = points.reduce(function (_ref2, _ref3) {
    var xList = _ref2[0],
        yList = _ref2[1];
    var x = _ref3.x,
        y = _ref3.y;
    xList.push(x);
    yList.push(y);
    return [xList, yList];
  }, [[], []]),
      xValues = _points$reduce[0],
      yValues = _points$reduce[1];

  var minMaxValues = {
    xMin: Math.min.apply(Math, xValues),
    xMax: Math.max.apply(Math, xValues),
    yMin: Math.min.apply(Math, yValues),
    yMax: Math.max.apply(Math, yValues)
  };
  var xScale = React.useMemo(function () {
    return scale.scaleLinear({
      domain: [minMaxValues.xMin, minMaxValues.xMax],
      range: [padding, width - padding],
      clamp: true
    });
  }, [width, padding]);
  var yScale = React.useMemo(function () {
    return scale.scaleLinear({
      domain: [minMaxValues.yMin, minMaxValues.yMax],
      range: [height - padding, padding],
      clamp: true
    });
  }, [height, padding]);
  var getColor = React.useCallback(function (color, index) {
    var availableColors = ['#AB47BC', '#009A7F', '#FF3B30', '#F5A741', '#5B53DF', '#47F5F0', '#FF8896', '#7B9A1D'];
    return color || availableColors[index % availableColors.length];
  }, []);
  var handleMouseMove = React.useCallback(function (event$1, label) {
    if (!svgRef.current) return;
    var point = event.localPoint(svgRef.current, event$1);
    if (!point) return;
    setTooltipLeft(point.x);
    setTooltipTop(point.y);
    setTooltipOpen(true);
    setTooltipData(label);
  }, [svgRef, xScale, yScale]);
  var handleMouseLeave = React.useCallback(function (event) {
    window.setTimeout(function () {
      setTooltipOpen(false);
    }, 300);
  }, []);

  if (!data || data.length === 0) {
    return /*#__PURE__*/React__default.createElement(StyledDotsChartWrapper, null, /*#__PURE__*/React__default.createElement(hxReactComponents.Box, {
      minWidth: "100%"
    }, /*#__PURE__*/React__default.createElement(hxReactComponents.EmptyState, {
      icon: "analytics",
      mainText: emptyDataMessage,
      size: "large"
    })));
  }

  return /*#__PURE__*/React__default.createElement(StyledDotsChartWrapper, {
    ref: chartRef
  }, /*#__PURE__*/React__default.createElement("svg", {
    width: width,
    height: height,
    ref: svgRef
  }, /*#__PURE__*/React__default.createElement("rect", {
    width: width,
    height: height,
    rx: 14,
    fill: "white"
  }), data.map(function (group$1, index) {
    return /*#__PURE__*/React__default.createElement(group.Group, {
      key: "group-" + chartId.current + "-" + index
    }, /*#__PURE__*/React__default.createElement(gradient.RadialGradient, {
      to: "#ffffff",
      from: getColor(group$1.color, index),
      id: "dots-gradient-" + chartId.current + "-" + index,
      r: "70%"
    }), group$1.values.map(function (point, i) {
      return /*#__PURE__*/React__default.createElement(shape.Circle, {
        key: "point-" + chartId.current + "-" + index + "-" + i,
        id: "point-" + chartId.current + "-" + index + "-" + i,
        className: "dot",
        cx: xScale(point.x),
        cy: yScale(point.y),
        r: radius,
        fill: "url(#dots-gradient-" + chartId.current + "-" + index + ")",
        onMouseMove: function onMouseMove(event) {
          return handleMouseMove(event, group$1.label);
        },
        onMouseLeave: function onMouseLeave(event) {
          return handleMouseLeave(event);
        },
        onTouchMove: function onTouchMove(event) {
          return handleMouseMove(event, group$1.label);
        },
        onTouchEnd: function onTouchEnd(event) {
          return handleMouseLeave(event);
        }
      });
    }));
  })), showTooltips && tooltipOpen && tooltipLeft != null && tooltipTop != null && /*#__PURE__*/React__default.createElement(StyledDotTooltip, {
    left: tooltipLeft,
    top: tooltipTop
  }, /*#__PURE__*/React__default.createElement("div", null, tooltipData)));
};

DotsChart.propTypes = {
  data: PropTypes.array,
  padding: PropTypes.number,
  radius: PropTypes.number,
  showTooltips: PropTypes.bool,
  emptyDataMessage: PropTypes.string
};
var DotsChart$1 = React.memo(styled.withTheme(DotsChart));

function _templateObject$8() {
  var data = _taggedTemplateLiteralLoose(["\n  width: 100%;\n  height: 100%;\n  position: relative;\n  background-color: #ffffff;\n  max-height: 500px;\n"]);

  _templateObject$8 = function _templateObject() {
    return data;
  };

  return data;
}
var StyledSpiderChartWrapper = styled__default.div(_templateObject$8());

var SpiderChartImage = function SpiderChartImage(item) {
  var _useState = React.useState(false),
      errorLoadingImage = _useState[0],
      setErrorLoadingImage = _useState[1];

  React.useEffect(function () {
    setErrorLoadingImage(false);
  }, [item.pic]);
  var onErrorLoadingImage = React.useCallback(function () {
    setErrorLoadingImage(true);
  }, []);
  var radius = Math.max(item.width, item.height) / 2;

  if (!item.pic || errorLoadingImage) {
    return /*#__PURE__*/React__default.createElement("svg", {
      overflow: "visible"
    }, /*#__PURE__*/React__default.createElement(group.Group, null, /*#__PURE__*/React__default.createElement(shape.Circle, {
      key: "point-" + item.x + "-" + item.y,
      id: "point-" + item.x + "-" + item.y,
      cx: item.x,
      cy: item.y,
      r: radius,
      fill: item.color
    }), /*#__PURE__*/React__default.createElement(text.Text, {
      x: item.x,
      y: item.y,
      fontSize: "11px",
      fontWeight: "bold",
      textAnchor: "middle",
      verticalAnchor: "middle",
      fill: "#ffffff"
    }, item.initials.toUpperCase())));
  }

  return /*#__PURE__*/React__default.createElement("svg", {
    overflow: "visible"
  }, /*#__PURE__*/React__default.createElement("image", {
    href: item.pic,
    height: item.width,
    width: item.height,
    x: item.x - radius,
    y: item.y - radius,
    clipPath: "url(#icon-" + item.x + "-" + item.y + ")",
    onError: function onError() {
      onErrorLoadingImage();
    }
  }), /*#__PURE__*/React__default.createElement(clipPath.CircleClipPath, {
    id: "icon-" + item.x + "-" + item.y,
    key: "icon-" + item.x + "-" + item.y,
    className: "dot",
    cx: item.x,
    cy: item.y,
    r: radius
  }));
};

var tooltipTimeout$5;
var defaultMargin$4 = {
  top: 50,
  right: 50,
  bottom: 50,
  left: 100
};

var SpiderChart = function SpiderChart(_ref) {
  var _ref$margin = _ref.margin,
      margin = _ref$margin === void 0 ? defaultMargin$4 : _ref$margin,
      metric = _ref.metric,
      degrees = _ref.degrees,
      levels = _ref.levels,
      showItemsPreview = _ref.showItemsPreview,
      categories = _ref.categories,
      groups = _ref.groups,
      showPolygonPoints = _ref.showPolygonPoints,
      color = _ref.color,
      emptyDataMessage = _ref.emptyDataMessage,
      limit = _ref.limit;
  var svgRef = React.useRef(null);
  var chartId = React.useRef(uniqid());

  var _useState = React.useState(0),
      width = _useState[0],
      setWidth = _useState[1];

  var _useState2 = React.useState(0),
      height = _useState2[0],
      setHeight = _useState2[1];

  var _useTooltip = tooltip.useTooltip(),
      tooltipOpen = _useTooltip.tooltipOpen,
      tooltipLeft = _useTooltip.tooltipLeft,
      tooltipTop = _useTooltip.tooltipTop,
      tooltipData = _useTooltip.tooltipData,
      hideTooltip = _useTooltip.hideTooltip,
      showTooltip = _useTooltip.showTooltip;

  var windowSize = useWindowSize();
  var chartRef = React.useCallback(function (node) {
    if (node != null) {
      setWidth(node.getBoundingClientRect().width);
      setHeight(node.getBoundingClientRect().height);
    }
  }, [windowSize]);
  var isEmptyCategories = !categories || categories.length === 0;
  var xMax = width - margin.left - margin.right - 70;
  var yMax = height - margin.top - margin.bottom - 70;
  var radius = Math.min(xMax, yMax) / 2;
  var zeroPoint = {
    x: 0,
    y: 0
  };
  var filteredCategories = React.useMemo(function () {
    if (isEmptyCategories) {
      return [];
    }

    return limit !== 'auto' ? categories.slice(0, limit) : categories;
  }, [isEmptyCategories, categories, limit]);
  var sides = filteredCategories && filteredCategories.length || 0;
  var webs = React.useMemo(function () {
    var list = [];

    for (var i = 0; i < sides + 5; i++) {
      list.push({
        angle: i * (degrees / sides)
      });
    }

    return list;
  }, [sides, degrees]);
  var radialScale = React.useMemo(function () {
    return scale.scaleLinear({
      range: [0, Math.PI * 2],
      domain: [degrees, 0]
    });
  }, [degrees]);
  var points = React.useMemo(function () {
    var step = Math.PI * 2 / sides;
    var xMax = width - margin.left - margin.right - 70;
    var yMax = height - margin.top - margin.bottom - 70;
    var r = Math.min(xMax, yMax) / 2;
    var list = [];

    for (var i = 0; i < sides; i++) {
      list.push({
        x: r * Math.sin(i * step),
        y: r * Math.cos(i * step)
      });
    }

    return list;
  }, [height, width, sides, margin]);
  var maxValue = React.useMemo(function () {
    return Math.max(groups ? Math.max.apply(Math, groups.map(function (group) {
      return Math.max.apply(Math, group.values.map(function (item) {
        return item[metric];
      }));
    })) : 0, isReach(metric) && groups ? Math.max.apply(Math, groups.map(function (group) {
      return Math.max.apply(Math, group.values.map(function (item) {
        return item[METRICS.BASE];
      }));
    })) : 0);
  }, [groups, metric]);
  var yScale = React.useMemo(function () {
    return scale.scaleLinear({
      range: [0, radius],
      domain: [0, maxValue],
      clamp: true
    });
  }, [radius, maxValue]);
  var getPolygonPoints = React.useCallback(function (group) {
    var step = Math.PI * 2 / sides;
    var values = group.values;
    return filteredCategories.reduce(function (_ref2, category, i) {
      var path = _ref2.path,
          points = _ref2.points;
      var point = values.find(function (item) {
        return item.id === category.id;
      });
      var xVal = point[metric] && yScale(point[metric]) * Math.sin(i * step) || 0;
      var yVal = point[metric] && yScale(point[metric]) * Math.cos(i * step) || 0;
      points.push({
        x: xVal,
        y: yVal
      });
      path += xVal + "," + yVal + " ";
      return {
        path: path,
        points: points
      };
    }, {
      path: '',
      points: []
    });
  }, [sides, metric, yScale, filteredCategories]);
  var icons = React.useMemo(function () {
    var step = Math.PI * 2 / sides;
    var xMax = width - margin.left - margin.right;
    var yMax = height - margin.top - margin.bottom;
    var r = Math.min(xMax, yMax) / 2;
    var list = [];

    for (var i = 0; i < sides; i++) {
      list.push({
        x: r * Math.sin(i * step),
        y: r * Math.cos(i * step)
      });
    }

    return list;
  }, [height, width, sides, margin]);
  var colorScale = React.useMemo(function () {
    return scale.scaleLinear({
      domain: [0, isEmptyCategories ? 0 : filteredCategories.length / 2, isEmptyCategories ? 0 : filteredCategories.length],
      range: getColors(color)
    });
  }, [filteredCategories, isEmptyCategories, color]);
  var handlePointMouseLeave = React.useCallback(function (event) {
    tooltipTimeout$5 = window.setTimeout(function () {
      hideTooltip();
    }, 0);
  }, [hideTooltip]);
  var getTooltipContent = React.useCallback(function (label, item) {
    var isBaseGroup = label === MAP_CHART_FIELDS_LABEL[METRICS.BASE];
    var formattedValue = isReach(metric) ? FormatUtils.formattedValue(getPopulationPerc(item), METRICS.REACH) : FormatUtils.formattedValue(item[metric], metric);

    if (isBaseGroup) {
      formattedValue = FormatUtils.formattedValue(item[METRICS.BASE], METRICS.BASE);
    }

    return /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, (isBaseGroup ? MAP_CHART_FIELDS_LABEL[METRICS.BASE] : MAP_CHART_FIELDS_LABEL[metric]) + ": "), formattedValue);
  }, [metric]);
  var handlePointMouseMove = React.useCallback(function (event$1, index, group, groupIndex) {
    if (tooltipTimeout$5) clearTimeout(tooltipTimeout$5);
    var eventSvgCoords = event.localPoint(event$1);
    showTooltip({
      tooltipData: _extends({}, group.values[index], {
        content: getTooltipContent(group.label, group.values[index]),
        color: group.color || colorScale(groupIndex)
      }),
      tooltipTop: eventSvgCoords === null || eventSvgCoords === void 0 ? void 0 : eventSvgCoords.y,
      tooltipLeft: eventSvgCoords === null || eventSvgCoords === void 0 ? void 0 : eventSvgCoords.x
    });
  }, [showTooltip, colorScale, getTooltipContent]);
  var handlePolygonMouseLeave = React.useCallback(function (event) {
    tooltipTimeout$5 = window.setTimeout(function () {
      hideTooltip();
    }, 0);
  }, [hideTooltip]);
  var handlePolygonMouseMove = React.useCallback(function (event$1, group, groupIndex) {
    if (tooltipTimeout$5) clearTimeout(tooltipTimeout$5);
    var eventSvgCoords = event.localPoint(event$1);
    showTooltip({
      tooltipData: {
        label: group.label,
        color: group.color || colorScale(groupIndex)
      },
      tooltipTop: eventSvgCoords === null || eventSvgCoords === void 0 ? void 0 : eventSvgCoords.y,
      tooltipLeft: eventSvgCoords === null || eventSvgCoords === void 0 ? void 0 : eventSvgCoords.x
    });
  }, [showTooltip, colorScale]);
  var levelsList = React.useMemo(function () {
    var list = [];

    for (var i = 0; i < levels; i++) {
      list.push(i);
    }

    return list;
  }, [levels]);
  var baseFragment = React.useMemo(function () {
    var step = Math.PI * 2 / sides;
    var group = {
      label: MAP_CHART_FIELDS_LABEL[METRICS.BASE],
      color: groups && groups.length > 1 ? '#0abaa6' : '#2590ec'
    };
    var polygon = filteredCategories.reduce(function (_ref3, category, i) {
      var _values$push;

      var values = _ref3.values,
          path = _ref3.path,
          points = _ref3.points;
      var max = Math.max.apply(Math, groups.map(function (group) {
        return group.values.filter(function (item) {
          return item.id === category.id;
        }).map(function (item) {
          return item[METRICS.BASE];
        });
      }));
      values.push((_values$push = {
        id: category.id
      }, _values$push[METRICS.BASE] = max, _values$push.label = category.label, _values$push));
      var xVal = max && yScale(max) * Math.sin(i * step) || 0;
      var yVal = max && yScale(max) * Math.cos(i * step) || 0;
      points.push({
        x: xVal,
        y: yVal
      });
      path += xVal + "," + yVal + " ";
      return {
        values: values,
        path: path,
        points: points
      };
    }, {
      values: [],
      path: '',
      points: []
    });
    group.values = polygon.values;
    return /*#__PURE__*/React__default.createElement(React.Fragment, {
      key: "polygon-" + chartId.current + "-base"
    }, /*#__PURE__*/React__default.createElement("polygon", {
      points: polygon.path,
      fill: group.color,
      fillOpacity: 0.3,
      stroke: group.color,
      strokeWidth: 1
    }), polygon.points.map(function (point, i) {
      return /*#__PURE__*/React__default.createElement("circle", {
        key: "radar-" + chartId.current + "-point-base-" + i,
        cx: point.x,
        cy: point.y,
        r: 4,
        fill: group.color,
        onMouseMove: function onMouseMove(event) {
          return handlePointMouseMove(event, i, group, 0);
        },
        onMouseLeave: function onMouseLeave(event) {
          return handlePointMouseLeave(event);
        },
        onTouchMove: function onTouchMove(event) {
          return handlePointMouseMove(event, i, group, 0);
        },
        onTouchEnd: function onTouchEnd(event) {
          return handlePointMouseLeave(event);
        }
      });
    }));
  }, [chartId, filteredCategories, yScale, sides, groups, handlePointMouseMove, handlePointMouseLeave]);

  if (!groups || groups.length === 0) {
    return /*#__PURE__*/React__default.createElement(StyledSpiderChartWrapper, null, /*#__PURE__*/React__default.createElement(hxReactComponents.Box, {
      minWidth: "100%"
    }, /*#__PURE__*/React__default.createElement(hxReactComponents.EmptyState, {
      icon: "analytics",
      mainText: emptyDataMessage,
      size: "large"
    })));
  }

  return /*#__PURE__*/React__default.createElement(StyledSpiderChartWrapper, {
    ref: chartRef
  }, /*#__PURE__*/React__default.createElement("svg", {
    width: width,
    height: height,
    ref: svgRef
  }, /*#__PURE__*/React__default.createElement("rect", {
    fill: "white",
    width: width,
    height: height,
    rx: 14
  }), /*#__PURE__*/React__default.createElement(group.Group, {
    top: height / 2,
    left: width / 2,
    key: "group-" + chartId.current
  }, levelsList.map(function (_, i) {
    return /*#__PURE__*/React__default.createElement(shape.LineRadial, {
      key: "web-" + chartId.current + "-" + i,
      data: webs,
      angle: function angle(d) {
        var _radialScale;

        return (_radialScale = radialScale(d.angle)) != null ? _radialScale : 0;
      },
      radius: (i + 1) * radius / levels,
      fill: "none",
      stroke: "#d9d9d9",
      strokeWidth: 2,
      strokeOpacity: 0.8,
      strokeLinecap: "round"
    });
  }), filteredCategories.map(function (category, i) {
    return /*#__PURE__*/React__default.createElement(React.Fragment, {
      key: "line-" + chartId.current + "-icon-" + i
    }, showItemsPreview ? /*#__PURE__*/React__default.createElement(React.Fragment, null, /*#__PURE__*/React__default.createElement(SpiderChartImage, {
      pic: category.img || category.pic,
      x: icons[i].x,
      y: icons[i].y,
      width: 48,
      height: 48,
      initials: category.label.substring(0, 2),
      color: colorScale(i)
    }), /*#__PURE__*/React__default.createElement(text.Text, {
      width: 100,
      height: 100,
      x: icons[i].x,
      y: icons[i].y < 0 ? icons[i].y - 30 : icons[i].y + 30,
      fontSize: "11px",
      fontWeight: "bold",
      textAnchor: "middle",
      verticalAnchor: icons[i].y < 0 ? 'end' : 'start'
    }, category.label)) : /*#__PURE__*/React__default.createElement(text.Text, {
      width: 100,
      height: 100,
      x: icons[i].x,
      y: icons[i].y,
      fontSize: "11px",
      fontWeight: "bold",
      textAnchor: "middle",
      verticalAnchor: icons[i].y < 0 ? 'end' : 'start'
    }, category.label), /*#__PURE__*/React__default.createElement(shape.Line, {
      key: "radar-" + chartId.current + "-line-" + i,
      from: zeroPoint,
      to: points[i],
      stroke: "#d9d9d9"
    }));
  }), groups.map(function (group, index) {
    var polygonPoints = getPolygonPoints(group);
    return /*#__PURE__*/React__default.createElement(React.Fragment, {
      key: "polygon-" + chartId.current + "-" + index
    }, !group.isHidden && /*#__PURE__*/React__default.createElement(React.Fragment, null, /*#__PURE__*/React__default.createElement("polygon", {
      points: polygonPoints.path,
      fill: group.color || colorScale(index),
      fillOpacity: 0.3,
      stroke: group.color || colorScale(index),
      strokeWidth: 1,
      onMouseMove: function onMouseMove(event) {
        return !showPolygonPoints && handlePolygonMouseMove(event, group, index);
      },
      onMouseLeave: function onMouseLeave(event) {
        return !showPolygonPoints && handlePolygonMouseLeave(event);
      },
      onTouchMove: function onTouchMove(event) {
        return !showPolygonPoints && handlePolygonMouseMove(event, group, index);
      },
      onTouchEnd: function onTouchEnd(event) {
        return !showPolygonPoints && handlePolygonMouseLeave(event);
      }
    }), showPolygonPoints && polygonPoints.points.map(function (point, i) {
      return /*#__PURE__*/React__default.createElement("circle", {
        key: "radar-" + chartId.current + "-point-" + i,
        cx: point.x,
        cy: point.y,
        r: 4,
        fill: group.color || colorScale(index),
        onMouseMove: function onMouseMove(event) {
          return handlePointMouseMove(event, i, group, index);
        },
        onMouseLeave: function onMouseLeave(event) {
          return handlePointMouseLeave(event);
        },
        onTouchMove: function onTouchMove(event) {
          return handlePointMouseMove(event, i, group, index);
        },
        onTouchEnd: function onTouchEnd(event) {
          return handlePointMouseLeave(event);
        }
      });
    })));
  }), isReach(metric) && baseFragment)), tooltipOpen && tooltipData && /*#__PURE__*/React__default.createElement(ChartTooltip, {
    opened: tooltipOpen,
    top: tooltipTop || 0,
    left: tooltipLeft || 0,
    data: tooltipData
  }, showPolygonPoints && tooltipData.content));
};

function _templateObject3$3() {
  var data = _taggedTemplateLiteralLoose(["\n  position: absolute;\n  text-align: center;\n"]);

  _templateObject3$3 = function _templateObject3() {
    return data;
  };

  return data;
}

function _templateObject2$4() {
  var data = _taggedTemplateLiteralLoose(["\n  position: relative;\n  width: ", ";\n  height: ", ";\n"]);

  _templateObject2$4 = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$9() {
  var data = _taggedTemplateLiteralLoose(["\n  width: 100%;\n  height: 100%;\n  position: relative;\n  display: flex;\n  justify-content: center;\n  align-items: center;\n"]);

  _templateObject$9 = function _templateObject() {
    return data;
  };

  return data;
}
var StyledDonutChartWrapper = styled__default.div(_templateObject$9());
var StyledDonutChartSvg = styled__default.div(_templateObject2$4(), function (props) {
  return props.width + 'px';
}, function (props) {
  return props.height + 'px';
});
var StyledDonutChartText = styled__default.div(_templateObject3$3());

var defaultMargin$5 = {
  top: 20,
  left: 20,
  right: 20,
  bottom: 20
};

var DonutChart = function DonutChart(_ref) {
  var donutThickness = _ref.donutThickness,
      _ref$margin = _ref.margin,
      margin = _ref$margin === void 0 ? defaultMargin$5 : _ref$margin,
      data = _ref.data,
      color = _ref.color,
      children = _ref.children;

  var _useState = React.useState(0),
      width = _useState[0],
      setWidth = _useState[1];

  var _useState2 = React.useState(0),
      height = _useState2[0],
      setHeight = _useState2[1];

  var windowSize = useWindowSize();
  var chartId = React.useRef(uniqid());
  var chartRef = React.useCallback(function (node) {
    if (node != null) {
      setWidth(node.getBoundingClientRect().width);
      setHeight(node.getBoundingClientRect().height);
    }
  }, [windowSize]);
  var innerWidth = width - margin.left - margin.right;
  var innerHeight = height - margin.top - margin.bottom;
  var radius = Math.min(innerWidth, innerHeight) / 2;
  var centerY = innerHeight / 2;
  var centerX = innerWidth / 2;
  var pieData = React.useMemo(function () {
    var arcs = [{
      index: 0,
      value: data,
      isBackground: false
    }];
    var diff = Number((1 - data).toFixed(2));

    if (data !== 0 && data % 1 !== 0) {
      arcs = arcs.concat({
        index: 1,
        value: diff,
        isBackground: true
      });
    }

    if (data === 0) {
      arcs = [{
        index: 1,
        value: diff,
        isBackground: true
      }];
    }

    return arcs;
  }, [data]);
  var chartText = React.useMemo(function () {
    var texts = children && React.Children.map(children, function (child, index) {
      return /*#__PURE__*/React__default.createElement(React.Fragment, {
        key: "child-" + chartId.current + "-" + index
      }, child);
    });
    return /*#__PURE__*/React__default.createElement(React.Fragment, null, /*#__PURE__*/React__default.createElement("div", {
      style: {
        fontSize: '24px',
        fontWeight: 'bold',
        paddingBottom: '10px'
      }
    }, Number((data * 100).toFixed(2)), "%"), texts);
  }, [data, children]);

  var pieSort = function pieSort(a, b) {
    return a.index - b.index;
  };

  var pieValue = function pieValue(d) {
    return d.value;
  };

  return /*#__PURE__*/React__default.createElement(StyledDonutChartWrapper, {
    ref: chartRef
  }, /*#__PURE__*/React__default.createElement(StyledDonutChartSvg, {
    width: width,
    height: height
  }, /*#__PURE__*/React__default.createElement("svg", {
    width: width,
    height: height
  }, /*#__PURE__*/React__default.createElement("rect", {
    rx: 14,
    width: width,
    height: height,
    fill: "#ffffff"
  }), /*#__PURE__*/React__default.createElement(group.Group, {
    key: "group-" + chartId.current,
    top: centerY + margin.top,
    left: centerX + margin.left
  }, /*#__PURE__*/React__default.createElement(shape.Pie, {
    data: pieData,
    pieValue: pieValue,
    outerRadius: radius,
    innerRadius: radius - donutThickness,
    cornerRadius: 25,
    pieSort: pieSort
  }, function (pie) {
    return pie.arcs.map(function (arc, index) {
      return /*#__PURE__*/React__default.createElement(React.Fragment, {
        key: "arc-" + chartId.current + "-" + index
      }, !arc.data.isBackground && /*#__PURE__*/React__default.createElement(shape.Arc, {
        startAngle: arc.startAngle,
        endAngle: arc.endAngle,
        innerRadius: radius - donutThickness,
        cornerRadius: donutThickness / 2,
        outerRadius: radius,
        padAngle: arc.padAngle,
        padRadius: arc.padRadius,
        fill: color
      }), arc.data.isBackground && /*#__PURE__*/React__default.createElement(shape.Arc, {
        startAngle: 0,
        endAngle: arc.endAngle,
        innerRadius: radius - donutThickness,
        cornerRadius: 3,
        outerRadius: radius,
        padAngle: arc.padAngle,
        padRadius: arc.padRadius,
        fill: color,
        opacity: 0.15
      }));
    });
  })))), /*#__PURE__*/React__default.createElement(StyledDonutChartText, null, chartText));
};

DonutChart.propTypes = {
  donutThickness: PropTypes.number,
  margin: PropTypes.object,
  data: PropTypes.number,
  color: PropTypes.string
};
var DonutChart$1 = React.memo(styled.withTheme(DonutChart));

function _templateObject4$2() {
  var data = _taggedTemplateLiteralLoose(["\n  font-size: 11px;\n  font-weight: normal;\n  padding-left: 10px;\n"]);

  _templateObject4$2 = function _templateObject4() {
    return data;
  };

  return data;
}

function _templateObject3$4() {
  var data = _taggedTemplateLiteralLoose(["\n  width: 16px;\n  background: ", ";\n  border-radius: 8px;\n  height: 16px;\n"]);

  _templateObject3$4 = function _templateObject3() {
    return data;
  };

  return data;
}

function _templateObject2$5() {
  var data = _taggedTemplateLiteralLoose(["\n  display: flex;\n  align-items: center;\n  padding-left: 10px;\n"]);

  _templateObject2$5 = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$a() {
  var data = _taggedTemplateLiteralLoose(["\n  width: 100%;\n  height: 100%;\n  position: relative;\n  background-color: ", ";\n  display: flex;\n  flex-direction: column;\n"]);

  _templateObject$a = function _templateObject() {
    return data;
  };

  return data;
}
var StyledBarGroupChartWrapper = styled__default.div(_templateObject$a(), function (props) {
  return props.theme.colors.light;
});
var LegendWrapper = styled__default.div(_templateObject2$5());
var LegendCircle = styled__default.div(_templateObject3$4(), function (props) {
  return props.color;
});
var LegendText = styled__default.div(_templateObject4$2());

var BarGroupChartLegend = function BarGroupChartLegend(_ref) {
  var legend = _ref.legend;
  return legend.map(function (item, i) {
    return /*#__PURE__*/React__default.createElement(LegendWrapper, {
      key: i
    }, /*#__PURE__*/React__default.createElement(LegendCircle, {
      color: item.color
    }, "\xA0"), /*#__PURE__*/React__default.createElement(LegendText, null, item.label));
  });
};

var BarGroupChartImage = function BarGroupChartImage(item) {
  var _useState = React.useState(false),
      errorLoadingImage = _useState[0],
      setErrorLoadingImage = _useState[1];

  React.useEffect(function () {
    setErrorLoadingImage(false);
  }, [item.pic]);
  var onErrorLoadingImage = React.useCallback(function () {
    setErrorLoadingImage(true);
  }, []);
  var radius = Math.max(item.width, item.height) / 2;

  if (!item.pic || errorLoadingImage) {
    return /*#__PURE__*/React__default.createElement("svg", {
      overflow: "visible"
    }, /*#__PURE__*/React__default.createElement(group.Group, null, /*#__PURE__*/React__default.createElement(shape.Circle, {
      key: "point-" + item.parentId + "-" + item.x + "-" + item.y,
      id: "point-" + item.parentId + "-" + item.x + "-" + item.y,
      cx: item.x,
      cy: item.y,
      r: radius,
      fill: "#5b53df"
    }), /*#__PURE__*/React__default.createElement(text.Text, {
      x: item.x,
      y: item.y,
      fontSize: "11px",
      fontWeight: "bold",
      textAnchor: "middle",
      verticalAnchor: "middle",
      fill: "#ffffff"
    }, item.initials.toUpperCase())));
  }

  return /*#__PURE__*/React__default.createElement("svg", {
    overflow: "visible"
  }, /*#__PURE__*/React__default.createElement("image", {
    href: item.pic,
    height: item.width,
    width: item.height,
    x: item.x - radius,
    y: item.y - radius,
    clipPath: "url(#icon-" + item.parentId + "-" + item.x + "-" + item.y + ")",
    onError: function onError() {
      onErrorLoadingImage();
    }
  }), /*#__PURE__*/React__default.createElement(clipPath.CircleClipPath, {
    id: "icon-" + item.parentId + "-" + item.x + "-" + item.y,
    key: "icon-" + item.parentId + "-" + item.x + "-" + item.y,
    className: "dot",
    cx: item.x,
    cy: item.y,
    r: radius
  }));
};

var defaultMargin$6 = {
  top: 40,
  left: 0,
  right: 0,
  bottom: 120
};

var BarGroupChart = function BarGroupChart(_ref) {
  var data = _ref.data,
      _ref$margin = _ref.margin,
      margin = _ref$margin === void 0 ? defaultMargin$6 : _ref$margin,
      xValueKey = _ref.xValueKey,
      xLabelKey = _ref.xLabelKey,
      xImageKey = _ref.xImageKey,
      keys = _ref.keys,
      colors = _ref.colors,
      legend = _ref.legend,
      emptyDataMessage = _ref.emptyDataMessage,
      areBarsRounded = _ref.areBarsRounded;

  var _useState = React.useState(0),
      width = _useState[0],
      setWidth = _useState[1];

  var _useState2 = React.useState(0),
      height = _useState2[0],
      setHeight = _useState2[1];

  var windowSize = useWindowSize();
  var chartId = React.useRef(uniqid());
  var chartRef = React.useCallback(function (node) {
    if (node != null) {
      setWidth(node.getBoundingClientRect().width);
      setHeight(node.getBoundingClientRect().height);
    }
  }, [windowSize]);
  var xMax = width - margin.left - margin.right;
  var yMax = height - margin.top - margin.bottom;

  var getXValue = function getXValue(d) {
    return d[xValueKey];
  };

  var xScale = scale.scaleBand({
    domain: data && data.map(getXValue) || [],
    padding: 0.6
  });
  var keysScale = scale.scaleBand({
    domain: keys,
    padding: 0.0
  });
  var valueScale = scale.scaleLinear({
    domain: [0, Math.max.apply(Math, data && data.map(function (d) {
      return Math.max.apply(Math, keys.map(function (key) {
        return Number(d[key]);
      }));
    }) || [])]
  });
  var colorScale = scale.scaleOrdinal({
    domain: keys,
    range: colors || ['#D8D7EA']
  });
  xScale.rangeRound([0, xMax]);
  keysScale.rangeRound([0, xScale.bandwidth()]);
  valueScale.range([yMax, 0]);
  var getTickComponent = React.useCallback(function (d) {
    return /*#__PURE__*/React__default.createElement(React.Fragment, null, /*#__PURE__*/React__default.createElement(BarGroupChartImage, {
      pic: d.pic,
      x: d.x,
      y: d.y,
      width: 36,
      height: 36,
      parentId: chartId.current,
      initials: d.label.substring(0, 2)
    }), /*#__PURE__*/React__default.createElement(text.Text, {
      width: 80,
      height: 80,
      x: d.x,
      y: d.y + 25,
      fontSize: "10px",
      fontWeight: "bold",
      textAnchor: "middle",
      verticalAnchor: "start"
    }, FormatUtils.capitalizeString(d.label)));
  }, []);
  var getTickLabel = React.useCallback(function (d) {
    var item = data.find(function (i) {
      return i[xValueKey] === d;
    });
    return item && item[xLabelKey] || '';
  }, [data, xValueKey, xLabelKey]);
  var getTickImage = React.useCallback(function (d) {
    var item = data.find(function (i) {
      return i[xValueKey] === d;
    });
    return item && item[xImageKey] || '';
  }, [data, xValueKey, xImageKey]);
  var getGroupContent = React.useCallback(function (group, groups) {
    var options = groups.tickLabelProps(group.value);

    var props = _extends({}, options, {
      x: group.to.x,
      y: 10 + group.to.y
    });

    return groups.tickComponent(props);
  }, []);

  if (!data || data.length === 0) {
    return /*#__PURE__*/React__default.createElement(StyledBarGroupChartWrapper, null, /*#__PURE__*/React__default.createElement(hxReactComponents.Box, {
      minWidth: "100%"
    }, /*#__PURE__*/React__default.createElement(hxReactComponents.EmptyState, {
      icon: "analytics",
      mainText: emptyDataMessage,
      size: "large"
    })));
  }

  return /*#__PURE__*/React__default.createElement(StyledBarGroupChartWrapper, {
    ref: chartRef
  }, /*#__PURE__*/React__default.createElement("svg", {
    width: width,
    height: height
  }, /*#__PURE__*/React__default.createElement("rect", {
    rx: 14,
    width: width,
    height: height,
    fill: "#ffffff"
  }), /*#__PURE__*/React__default.createElement(group.Group, {
    key: "group-" + chartId.current,
    top: margin.top,
    left: margin.left
  }, /*#__PURE__*/React__default.createElement(shape.BarGroup, {
    data: data,
    keys: keys,
    height: yMax,
    x0: getXValue,
    x0Scale: xScale,
    x1Scale: keysScale,
    yScale: valueScale,
    color: colorScale
  }, function (barGroups) {
    return barGroups.map(function (barGroup, index) {
      return /*#__PURE__*/React__default.createElement(group.Group, {
        key: "bar-group-" + chartId.current + "-" + barGroup.index,
        left: barGroup.x0
      }, barGroup.bars.map(function (bar) {
        return /*#__PURE__*/React__default.createElement(React.Fragment, {
          key: "bar-group-bar-" + chartId.current + "-" + barGroup.index + "-" + bar.index
        }, areBarsRounded && /*#__PURE__*/React__default.createElement(shape.BarRounded, {
          x: bar.x,
          y: bar.y,
          width: 12,
          height: bar.height,
          radius: bar.width / 2,
          all: true,
          fill: bar.color
        }), !areBarsRounded && /*#__PURE__*/React__default.createElement(shape.Bar, {
          x: bar.x,
          y: bar.y,
          width: bar.width,
          height: bar.height,
          fill: bar.color
        }));
      }));
    });
  })), /*#__PURE__*/React__default.createElement(axis.AxisBottom, {
    top: yMax + margin.top + 10,
    left: margin.left,
    scale: xScale,
    hideAxisLine: true,
    hideTicks: true,
    tickLabelProps: function tickLabelProps(d) {
      return {
        fontSize: '11px',
        pic: getTickImage(d),
        label: getTickLabel(d)
      };
    },
    tickComponent: function tickComponent(d) {
      return getTickComponent(d);
    }
  }, function (axisGroups) {
    return axisGroups.ticks.map(function (group$1, index) {
      return /*#__PURE__*/React__default.createElement(group.Group, {
        key: "axis-group-" + chartId.current + "-" + index
      }, getGroupContent(group$1, axisGroups));
    });
  })), legend && /*#__PURE__*/React__default.createElement(BarGroupChartLegend, {
    legend: legend
  }));
};

BarGroupChart.propTypes = {
  data: PropTypes.array,
  margin: PropTypes.object,
  xValueKey: PropTypes.string,
  xLabelKey: PropTypes.string,
  keys: PropTypes.array,
  colors: PropTypes.array,
  legend: PropTypes.array,
  padding: PropTypes.number,
  emptyDataMessage: PropTypes.string,
  areBarsRounded: PropTypes.bool
};
BarGroupChart.defaultProps = {
  emptyDataMessage: 'No content'
};
var BarGroupChart$1 = React.memo(styled.withTheme(BarGroupChart));

function _templateObject$b() {
  var data = _taggedTemplateLiteralLoose(["\n  width: 100%;\n  height: 100%;\n  .venntooltip {\n    position: absolute;\n    text-align: center;\n    background: #000000;\n    opacity: 0;\n    color: #ffffff;\n    padding: 2px;\n    min-width: 128px;\n    border-radius: 8px;\n  }\n"]);

  _templateObject$b = function _templateObject() {
    return data;
  };

  return data;
}
var ChartWrapper$1 = styled__default.div(_templateObject$b());

var VennDiagram = function VennDiagram(_ref) {
  var sets = _ref.sets,
      emptyDataMessage = _ref.emptyDataMessage,
      showMoreDetail = _ref.showMoreDetail,
      _ref$tooltipText = _ref.tooltipText,
      tooltipText = _ref$tooltipText === void 0 ? 'users' : _ref$tooltipText;
  var vennRef = React.useRef();

  var _useState = React.useState(0),
      width = _useState[0],
      setWidth = _useState[1];

  var _useState2 = React.useState(0),
      height = _useState2[0],
      setHeight = _useState2[1];

  var windowSize = useWindowSize();
  var vennDiagramNode = vennRef && vennRef.current && d3.select(vennRef.current);
  var chartRef = React.useCallback(function (node) {
    if (node != null) {
      setWidth(node.getBoundingClientRect().width);
      setHeight(node.getBoundingClientRect().height);
    }
  }, [windowSize]);
  var getColor = React.useCallback(function (color, index) {
    var availableColors = ['#AB47BC', '#009A7F', '#FF3B30', '#F5A741', '#5B53DF', '#47F5F0', '#FF8896', '#7B9A1D'];
    return color || availableColors[index % availableColors.length];
  }, []);

  var wrap = function wrap(maxWidth) {
    return function () {
      var self = d3.select(this);
      var textLength = self.node().getComputedTextLength();
      var text = self.text();

      while (textLength > maxWidth && text.length > 0) {
        text = text.slice(0, -1);
        self.text(text + '...');
        textLength = self.node().getComputedTextLength();
      }
    };
  };

  React.useEffect(function () {
    if (vennDiagramNode) {
      vennDiagramNode.select('svg').remove();
      vennDiagramNode.selectAll('div').remove();
      var chart = venn.VennDiagram().width(width).height(height).duration(0);
      vennDiagramNode.datum(sets).call(chart);
      var circles = [];
      vennDiagramNode.selectAll('.venn-circle path').each(function () {
        var d = d3.select(this).attr('d');
        var circle = venn.circleFromPath(d);
        circles.push(circle);
      }).style('fill', function (d, i) {
        return sets[i] && getColor(sets[i].color) || '#ffffff';
      }).style('fill-opacity', 0.4);
      var i = 0;

      if (showMoreDetail) {
        vennDiagramNode.selectAll('.venn-circle').each(function () {
          var d = d3.select(this);
          var x = d.select('tspan').attr('x');
          var y = d.select('tspan').attr('y');
          var color = sets[i] && getColor(sets[i].color) || '#ffffff';
          var label = sets[i] && sets[i].label || '';
          var offsetX = circles[i].x >= x ? circles[i].x - circles[i].radius - 20 : circles[i].x + circles[i].radius + 20;
          var offsetY = circles[i].y >= y ? Number(y) : Number(y) - 25;
          d.append('image').attr('href', function (d) {
            return d.src;
          }).attr('height', 60).attr('width', 60).attr('x', offsetX - 30).attr('y', offsetY - 30).attr('clip-path', 'url(#icon-' + i + ')').on('error', function (event) {
            var dd = d3.select(event.currentTarget);
            dd.style('visibility', 'hidden');
            d.append('circle').attr('cx', offsetX).attr('cy', offsetY).attr('r', 30).style('fill', 'rgb(91,83,223)').style('stroke', color).style('stroke-width', '4');
            d.append('text').style('fill', '#fff').attr('x', offsetX - 10).attr('y', offsetY + 5).text(label.substring(0, 2).toUpperCase());
          });
          d.append('clipPath').attr('id', 'icon-' + i);
          d.select('clipPath').append('circle').attr('cx', offsetX).attr('cy', offsetY).attr('r', 30);
          d.append('circle').attr('cx', offsetX).attr('cy', offsetY).attr('r', 30).style('fill', 'none').style('stroke', color).style('stroke-width', '4');
          i++;
        });
      }

      i = 0;
      vennDiagramNode.selectAll('.venn-circle text').each(function () {
        var text = d3.select(this);
        text.selectAll('tspan').each(wrap(circles[i].radius));
        i++;
      }).style('fill', function (d, i) {
        return sets[i] && getColor(sets[i].color) || '#ffffff';
      }).style('font-weight', '700').style('font-size', '14px');
      var tooltip = vennDiagramNode.append('div').attr('class', 'venntooltip');
      vennDiagramNode.selectAll('g').on('mouseover', function (event, item) {
        tooltip.transition().duration(400).style('opacity', 0.7);
        tooltip.text(numberWithCommas(item.size) + " " + tooltipText);
        var selection = d3.select(event.currentTarget).transition('tooltip').duration(400);
        selection.select('path').style('stroke', '#ffffff').style('stroke-width', '3').style('fill-opacity', item.sets && item.sets.length === 1 ? 0.5 : 0.1).style('stroke-opacity', 1);
      }).on('mousemove', function (event$1) {
        if (!vennRef.current) return;
        var point = event.localPoint(vennRef.current, event$1);
        var pointX = (point === null || point === void 0 ? void 0 : point.x) || 0;
        var pointY = (point === null || point === void 0 ? void 0 : point.y) || 0;
        tooltip.style('left', pointX + 'px').style('top', pointY - 28 + 'px');
      }).on('mouseout', function (event, item) {
        tooltip.transition().duration(400).style('opacity', 0);
        var selection = d3.select(event.currentTarget).transition('tooltip').duration(400);
        selection.select('path').style('stroke-width', 0).style('fill-opacity', item.sets && item.sets.length === 1 ? 0.4 : 0.0).style('stroke-opacity', 0);
      });
    }
  }, [vennDiagramNode, sets, getColor, width, height]);

  if (!sets || sets.length === 0) {
    return /*#__PURE__*/React__default.createElement(ChartWrapper$1, null, /*#__PURE__*/React__default.createElement(hxReactComponents.Box, {
      minWidth: "100%"
    }, /*#__PURE__*/React__default.createElement(hxReactComponents.EmptyState, {
      icon: "analytics",
      mainText: emptyDataMessage,
      size: "large"
    })));
  }

  return /*#__PURE__*/React__default.createElement(ChartWrapper$1, {
    ref: chartRef
  }, /*#__PURE__*/React__default.createElement("div", {
    ref: vennRef
  }));
};

var type = "Topology";
var arcs = [
	[
		[
			42725,
			45726
		],
		[
			144,
			-104
		],
		[
			90,
			-52
		],
		[
			109,
			-41
		],
		[
			-18,
			-41
		],
		[
			-73,
			-63
		],
		[
			0,
			-103
		],
		[
			49,
			-83
		],
		[
			30,
			-93
		],
		[
			120,
			-125
		],
		[
			-24,
			-31
		],
		[
			6,
			-103
		],
		[
			-120,
			0
		],
		[
			-73,
			-93
		]
	],
	[
		[
			42965,
			44794
		],
		[
			-84,
			0
		]
	],
	[
		[
			42881,
			44794
		],
		[
			-24,
			0
		]
	],
	[
		[
			42857,
			44794
		],
		[
			-30,
			20
		]
	],
	[
		[
			42827,
			44814
		],
		[
			12,
			11
		]
	],
	[
		[
			42839,
			44825
		],
		[
			-12,
			0
		]
	],
	[
		[
			42827,
			44825
		],
		[
			0,
			-11
		]
	],
	[
		[
			42827,
			44814
		],
		[
			-6,
			0
		]
	],
	[
		[
			42821,
			44814
		],
		[
			-6,
			11
		]
	],
	[
		[
			42815,
			44825
		],
		[
			-12,
			0
		]
	],
	[
		[
			42803,
			44825
		],
		[
			-6,
			-11
		]
	],
	[
		[
			42797,
			44814
		],
		[
			0,
			11
		]
	],
	[
		[
			42797,
			44825
		],
		[
			-12,
			-11
		]
	],
	[
		[
			42785,
			44814
		],
		[
			-12,
			31
		]
	],
	[
		[
			42773,
			44845
		],
		[
			-18,
			-20
		]
	],
	[
		[
			42755,
			44825
		],
		[
			-18,
			-21
		]
	],
	[
		[
			42737,
			44804
		],
		[
			-30,
			21
		]
	],
	[
		[
			42707,
			44825
		],
		[
			-12,
			-11
		]
	],
	[
		[
			42695,
			44814
		],
		[
			-18,
			0
		]
	],
	[
		[
			42677,
			44814
		],
		[
			-96,
			-10
		],
		[
			-67,
			41
		],
		[
			-72,
			-20
		],
		[
			-42,
			62
		],
		[
			-96,
			93
		],
		[
			-78,
			10
		],
		[
			0,
			-72
		],
		[
			-48,
			-10
		],
		[
			-114,
			31
		],
		[
			-61,
			41
		],
		[
			-78,
			10
		]
	],
	[
		[
			41925,
			44990
		],
		[
			108,
			52
		],
		[
			73,
			-10
		],
		[
			48,
			21
		],
		[
			-30,
			124
		],
		[
			78,
			83
		],
		[
			6,
			134
		],
		[
			24,
			42
		],
		[
			90,
			41
		],
		[
			66,
			114
		],
		[
			-24,
			73
		],
		[
			36,
			31
		],
		[
			78,
			10
		],
		[
			18,
			31
		],
		[
			79,
			31
		],
		[
			66,
			-10
		],
		[
			30,
			-52
		],
		[
			54,
			21
		]
	],
	[
		[
			42989,
			44400
		],
		[
			-24,
			-31
		]
	],
	[
		[
			42965,
			44369
		],
		[
			-6,
			10
		]
	],
	[
		[
			42959,
			44379
		],
		[
			30,
			21
		]
	],
	[
		[
			42965,
			44369
		],
		[
			6,
			-10
		]
	],
	[
		[
			42971,
			44359
		],
		[
			55,
			-21
		],
		[
			72,
			-62
		],
		[
			12,
			-62
		],
		[
			54,
			-73
		],
		[
			-132,
			-52
		],
		[
			-55,
			-41
		],
		[
			211,
			-197
		],
		[
			18,
			-72
		],
		[
			126,
			0
		],
		[
			-12,
			-62
		],
		[
			-36,
			-52
		]
	],
	[
		[
			43284,
			43665
		],
		[
			-6,
			-21
		],
		[
			-96,
			21
		],
		[
			-60,
			-11
		],
		[
			-66,
			52
		],
		[
			-109,
			-10
		],
		[
			-24,
			21
		],
		[
			-132,
			31
		],
		[
			-24,
			-21
		]
	],
	[
		[
			42767,
			43727
		],
		[
			-90,
			31
		],
		[
			-72,
			-10
		],
		[
			-103,
			51
		],
		[
			-12,
			94
		],
		[
			-6,
			0
		],
		[
			-6,
			31
		]
	],
	[
		[
			42478,
			43924
		],
		[
			0,
			51
		],
		[
			36,
			63
		],
		[
			49,
			124
		],
		[
			-61,
			83
		]
	],
	[
		[
			42502,
			44245
		],
		[
			109,
			41
		],
		[
			30,
			166
		],
		[
			66,
			31
		],
		[
			66,
			-52
		],
		[
			186,
			-52
		]
	],
	[
		[
			42965,
			44369
		],
		[
			6,
			-10
		]
	],
	[
		[
			45322,
			44193
		],
		[
			-48,
			-73
		],
		[
			-78,
			0
		],
		[
			-90,
			-41
		],
		[
			-36,
			-41
		],
		[
			-72,
			-125
		],
		[
			-18,
			-114
		],
		[
			-6,
			-145
		],
		[
			54,
			-103
		],
		[
			-30,
			-31
		],
		[
			-103,
			10
		],
		[
			-54,
			21
		],
		[
			-24,
			52
		],
		[
			-78,
			0
		],
		[
			-168,
			-52
		],
		[
			-54,
			0
		],
		[
			-121,
			-31
		],
		[
			-78,
			83
		],
		[
			-210,
			62
		],
		[
			-120,
			-11
		],
		[
			-73,
			-72
		]
	],
	[
		[
			43915,
			43582
		],
		[
			-60,
			10
		],
		[
			-78,
			42
		],
		[
			-24,
			-11
		],
		[
			-78,
			42
		],
		[
			-54,
			0
		],
		[
			-42,
			31
		],
		[
			-97,
			-21
		],
		[
			-18,
			-52
		],
		[
			-72,
			0
		],
		[
			-108,
			42
		]
	],
	[
		[
			42989,
			44400
		],
		[
			73,
			83
		],
		[
			156,
			145
		],
		[
			36,
			72
		],
		[
			-6,
			156
		],
		[
			66,
			-21
		],
		[
			12,
			124
		],
		[
			126,
			-114
		],
		[
			91,
			-51
		],
		[
			96,
			-31
		],
		[
			66,
			10
		],
		[
			108,
			-42
		],
		[
			102,
			-103
		],
		[
			115,
			-73
		],
		[
			186,
			-82
		],
		[
			138,
			-42
		],
		[
			127,
			42
		],
		[
			108,
			-42
		],
		[
			126,
			-124
		],
		[
			78,
			0
		],
		[
			72,
			-21
		],
		[
			24,
			21
		],
		[
			133,
			-11
		],
		[
			84,
			-41
		],
		[
			36,
			-41
		],
		[
			90,
			-31
		],
		[
			90,
			10
		]
	],
	[
		[
			42767,
			43727
		],
		[
			-42,
			-83
		],
		[
			-72,
			-21
		],
		[
			-30,
			-103
		],
		[
			-121,
			20
		],
		[
			-60,
			-62
		],
		[
			-12,
			-41
		],
		[
			-102,
			-10
		],
		[
			-30,
			-52
		],
		[
			-42,
			-11
		],
		[
			-114,
			-72
		],
		[
			6,
			41
		],
		[
			-6,
			0
		],
		[
			-6,
			42
		],
		[
			-66,
			0
		],
		[
			-49,
			-62
		],
		[
			-60,
			72
		],
		[
			0,
			104
		],
		[
			-36,
			83
		]
	],
	[
		[
			41925,
			43572
		],
		[
			18,
			72
		]
	],
	[
		[
			41943,
			43644
		],
		[
			6,
			10
		]
	],
	[
		[
			41949,
			43654
		],
		[
			96,
			11
		]
	],
	[
		[
			42045,
			43665
		],
		[
			13,
			20
		]
	],
	[
		[
			42058,
			43685
		],
		[
			0,
			11
		]
	],
	[
		[
			42058,
			43696
		],
		[
			-7,
			52
		]
	],
	[
		[
			42051,
			43748
		],
		[
			37,
			-11
		]
	],
	[
		[
			42088,
			43737
		],
		[
			18,
			-62
		]
	],
	[
		[
			42106,
			43675
		],
		[
			12,
			-10
		]
	],
	[
		[
			42118,
			43665
		],
		[
			18,
			0
		]
	],
	[
		[
			42136,
			43665
		],
		[
			12,
			20
		]
	],
	[
		[
			42148,
			43685
		],
		[
			36,
			32
		],
		[
			6,
			82
		]
	],
	[
		[
			42190,
			43799
		],
		[
			-24,
			94
		]
	],
	[
		[
			42166,
			43893
		],
		[
			-6,
			10
		]
	],
	[
		[
			42160,
			43903
		],
		[
			18,
			21
		]
	],
	[
		[
			42178,
			43924
		],
		[
			24,
			51
		]
	],
	[
		[
			42202,
			43975
		],
		[
			12,
			-41
		],
		[
			60,
			21
		],
		[
			42,
			-11
		],
		[
			18,
			52
		]
	],
	[
		[
			42334,
			43996
		],
		[
			12,
			0
		]
	],
	[
		[
			42346,
			43996
		],
		[
			-18,
			114
		]
	],
	[
		[
			42328,
			44110
		],
		[
			66,
			124
		],
		[
			108,
			11
		]
	],
	[
		[
			42827,
			44825
		],
		[
			12,
			0
		]
	],
	[
		[
			42677,
			44814
		],
		[
			18,
			0
		]
	],
	[
		[
			42695,
			44814
		],
		[
			12,
			11
		]
	],
	[
		[
			42707,
			44825
		],
		[
			30,
			-21
		]
	],
	[
		[
			42755,
			44825
		],
		[
			18,
			20
		]
	],
	[
		[
			42785,
			44814
		],
		[
			12,
			11
		]
	],
	[
		[
			42797,
			44814
		],
		[
			6,
			11
		]
	],
	[
		[
			42815,
			44825
		],
		[
			6,
			-11
		]
	],
	[
		[
			42821,
			44814
		],
		[
			36,
			-20
		]
	],
	[
		[
			42881,
			44794
		],
		[
			84,
			0
		]
	],
	[
		[
			42965,
			44794
		],
		[
			157,
			-21
		],
		[
			84,
			-31
		],
		[
			-6,
			-73
		],
		[
			-120,
			-134
		],
		[
			-133,
			-125
		],
		[
			-54,
			0
		],
		[
			-96,
			31
		],
		[
			-90,
			73
		],
		[
			-72,
			-41
		],
		[
			-18,
			-145
		],
		[
			-30,
			-52
		],
		[
			-103,
			-31
		],
		[
			-150,
			0
		],
		[
			12,
			-73
		],
		[
			-18,
			-62
		]
	],
	[
		[
			42328,
			44110
		],
		[
			-6,
			-72
		],
		[
			24,
			-42
		]
	],
	[
		[
			42346,
			43996
		],
		[
			-12,
			0
		]
	],
	[
		[
			42334,
			43996
		],
		[
			-18,
			-41
		],
		[
			-48,
			10
		],
		[
			-48,
			-31
		],
		[
			-18,
			41
		]
	],
	[
		[
			42202,
			43975
		],
		[
			-24,
			-51
		]
	],
	[
		[
			42178,
			43924
		],
		[
			-18,
			-21
		]
	],
	[
		[
			42160,
			43903
		],
		[
			6,
			-10
		]
	],
	[
		[
			42166,
			43893
		],
		[
			24,
			-94
		]
	],
	[
		[
			42190,
			43799
		],
		[
			-12,
			-82
		],
		[
			-30,
			-32
		]
	],
	[
		[
			42136,
			43665
		],
		[
			-18,
			0
		]
	],
	[
		[
			42118,
			43665
		],
		[
			-12,
			10
		]
	],
	[
		[
			42088,
			43737
		],
		[
			-37,
			11
		]
	],
	[
		[
			42051,
			43748
		],
		[
			7,
			-52
		]
	],
	[
		[
			42058,
			43685
		],
		[
			-13,
			-20
		]
	],
	[
		[
			42045,
			43665
		],
		[
			-66,
			10
		],
		[
			-30,
			-21
		]
	],
	[
		[
			41943,
			43644
		],
		[
			-30,
			-93
		]
	],
	[
		[
			41913,
			43551
		],
		[
			6,
			-31
		]
	],
	[
		[
			41919,
			43520
		],
		[
			-78,
			-21
		]
	],
	[
		[
			41841,
			43499
		],
		[
			-18,
			21
		]
	],
	[
		[
			41823,
			43520
		],
		[
			6,
			31
		]
	],
	[
		[
			41829,
			43551
		],
		[
			-24,
			31
		]
	],
	[
		[
			41805,
			43582
		],
		[
			-30,
			-10
		]
	],
	[
		[
			41775,
			43572
		],
		[
			-18,
			-32
		]
	],
	[
		[
			41757,
			43540
		],
		[
			12,
			-72
		]
	],
	[
		[
			41769,
			43468
		],
		[
			-24,
			-52
		],
		[
			-108,
			21
		],
		[
			24,
			62
		],
		[
			-48,
			21
		]
	],
	[
		[
			41613,
			43520
		],
		[
			-6,
			31
		],
		[
			66,
			83
		],
		[
			-24,
			124
		],
		[
			42,
			62
		],
		[
			-54,
			31
		],
		[
			-18,
			42
		],
		[
			-61,
			0
		],
		[
			-30,
			51
		],
		[
			36,
			94
		],
		[
			-18,
			124
		],
		[
			61,
			41
		],
		[
			144,
			42
		],
		[
			-30,
			83
		],
		[
			18,
			134
		],
		[
			-6,
			73
		],
		[
			-42,
			62
		],
		[
			-36,
			0
		],
		[
			-18,
			-62
		],
		[
			-42,
			-11
		]
	],
	[
		[
			41595,
			44524
		],
		[
			-73,
			94
		],
		[
			36,
			51
		],
		[
			85,
			52
		],
		[
			24,
			-41
		],
		[
			78,
			51
		],
		[
			78,
			73
		],
		[
			48,
			145
		],
		[
			54,
			41
		]
	],
	[
		[
			41613,
			43520
		],
		[
			-157,
			155
		],
		[
			-60,
			-31
		],
		[
			6,
			-52
		],
		[
			66,
			0
		],
		[
			-12,
			-93
		],
		[
			30,
			-41
		],
		[
			-36,
			-83
		],
		[
			48,
			-73
		],
		[
			-42,
			-20
		],
		[
			30,
			-104
		],
		[
			-60,
			10
		],
		[
			-24,
			31
		]
	],
	[
		[
			41402,
			43219
		],
		[
			24,
			63
		],
		[
			-66,
			124
		],
		[
			-48,
			-31
		],
		[
			-66,
			20
		],
		[
			30,
			63
		],
		[
			-48,
			31
		],
		[
			-54,
			-94
		],
		[
			-30,
			94
		],
		[
			-85,
			-11
		],
		[
			12,
			-83
		],
		[
			-30,
			-51
		],
		[
			-96,
			51
		],
		[
			-36,
			104
		],
		[
			-96,
			41
		],
		[
			-36,
			94
		],
		[
			-6,
			124
		],
		[
			-120,
			-21
		],
		[
			-12,
			83
		],
		[
			-61,
			0
		],
		[
			-54,
			-52
		],
		[
			-54,
			0
		],
		[
			6,
			94
		],
		[
			-30,
			20
		],
		[
			-102,
			-20
		],
		[
			-6,
			82
		],
		[
			-24,
			21
		],
		[
			-78,
			0
		],
		[
			-48,
			-21
		],
		[
			-85,
			31
		]
	],
	[
		[
			40103,
			43975
		],
		[
			-36,
			208
		],
		[
			-36,
			41
		],
		[
			0,
			104
		],
		[
			54,
			103
		],
		[
			30,
			21
		],
		[
			91,
			-11
		],
		[
			-12,
			114
		],
		[
			-6,
			187
		],
		[
			144,
			-21
		],
		[
			90,
			42
		],
		[
			199,
			-21
		],
		[
			6,
			-104
		],
		[
			72,
			-20
		],
		[
			18,
			-135
		],
		[
			42,
			-83
		],
		[
			108,
			-10
		],
		[
			30,
			103
		],
		[
			60,
			0
		],
		[
			126,
			52
		],
		[
			97,
			-21
		],
		[
			72,
			11
		],
		[
			54,
			31
		],
		[
			96,
			0
		],
		[
			66,
			-21
		],
		[
			48,
			-52
		],
		[
			79,
			31
		]
	],
	[
		[
			34915,
			32541
		],
		[
			-79,
			-72
		],
		[
			-54,
			10
		],
		[
			-36,
			-62
		],
		[
			-108,
			-21
		],
		[
			-240,
			83
		],
		[
			-97,
			-93
		],
		[
			-126,
			73
		],
		[
			-42,
			-11
		],
		[
			-48,
			-52
		],
		[
			-78,
			73
		]
	],
	[
		[
			34007,
			32469
		],
		[
			-54,
			93
		],
		[
			-6,
			52
		],
		[
			54,
			124
		],
		[
			60,
			21
		],
		[
			120,
			-10
		],
		[
			78,
			51
		],
		[
			54,
			62
		],
		[
			85,
			0
		],
		[
			54,
			-20
		]
	],
	[
		[
			34452,
			32842
		],
		[
			258,
			93
		],
		[
			24,
			-52
		],
		[
			-30,
			-114
		],
		[
			102,
			11
		],
		[
			12,
			-63
		],
		[
			-24,
			-62
		],
		[
			121,
			-114
		]
	],
	[
		[
			34361,
			33132
		],
		[
			-36,
			-31
		],
		[
			0,
			-125
		],
		[
			24,
			-62
		]
	],
	[
		[
			34349,
			32914
		],
		[
			-42,
			0
		],
		[
			-108,
			-62
		],
		[
			-42,
			0
		],
		[
			-36,
			-72
		],
		[
			-102,
			31
		],
		[
			-78,
			-21
		],
		[
			-73,
			-104
		],
		[
			-6,
			-82
		],
		[
			-30,
			-42
		],
		[
			-66,
			-21
		],
		[
			-144,
			104
		],
		[
			-42,
			-10
		]
	],
	[
		[
			33580,
			32635
		],
		[
			36,
			82
		]
	],
	[
		[
			33616,
			32717
		],
		[
			6,
			63
		]
	],
	[
		[
			33622,
			32780
		],
		[
			60,
			72
		],
		[
			126,
			10
		],
		[
			36,
			94
		],
		[
			-12,
			41
		],
		[
			36,
			83
		],
		[
			55,
			41
		],
		[
			36,
			-10
		],
		[
			78,
			52
		],
		[
			12,
			134
		]
	],
	[
		[
			34049,
			33297
		],
		[
			96,
			-31
		],
		[
			54,
			11
		],
		[
			36,
			-93
		],
		[
			126,
			-52
		]
	],
	[
		[
			35756,
			33422
		],
		[
			-24,
			-21
		],
		[
			-108,
			-197
		],
		[
			138,
			21
		],
		[
			67,
			-52
		],
		[
			60,
			-21
		],
		[
			6,
			0
		]
	],
	[
		[
			35895,
			33152
		],
		[
			0,
			-72
		],
		[
			-30,
			-62
		],
		[
			-54,
			-21
		],
		[
			0,
			-41
		],
		[
			-109,
			20
		],
		[
			-12,
			-41
		],
		[
			-54,
			0
		],
		[
			-48,
			31
		],
		[
			-66,
			0
		],
		[
			-72,
			-104
		],
		[
			-60,
			-31
		],
		[
			-30,
			-103
		]
	],
	[
		[
			35360,
			32728
		],
		[
			-115,
			-62
		],
		[
			-36,
			-42
		],
		[
			-42,
			11
		],
		[
			-60,
			-83
		],
		[
			-78,
			20
		],
		[
			-30,
			32
		],
		[
			-84,
			-63
		]
	],
	[
		[
			34452,
			32842
		],
		[
			-103,
			72
		]
	],
	[
		[
			34361,
			33132
		],
		[
			85,
			20
		],
		[
			0,
			63
		],
		[
			30,
			62
		],
		[
			-6,
			207
		],
		[
			48,
			62
		],
		[
			-48,
			31
		],
		[
			12,
			83
		],
		[
			-66,
			-21
		],
		[
			24,
			83
		],
		[
			42,
			21
		],
		[
			108,
			-21
		],
		[
			36,
			-31
		],
		[
			72,
			-21
		],
		[
			30,
			-72
		],
		[
			66,
			62
		],
		[
			55,
			21
		],
		[
			60,
			-11
		],
		[
			30,
			42
		],
		[
			36,
			-62
		],
		[
			48,
			62
		]
	],
	[
		[
			35023,
			33712
		],
		[
			36,
			114
		],
		[
			120,
			31
		],
		[
			-6,
			62
		],
		[
			313,
			114
		],
		[
			42,
			-42
		],
		[
			-18,
			-103
		],
		[
			12,
			-52
		]
	],
	[
		[
			35522,
			33836
		],
		[
			84,
			-114
		],
		[
			6,
			-72
		],
		[
			72,
			-31
		],
		[
			78,
			-135
		],
		[
			-6,
			-62
		]
	],
	[
		[
			35660,
			36860
		],
		[
			114,
			-134
		],
		[
			-36,
			-52
		],
		[
			12,
			-52
		]
	],
	[
		[
			35750,
			36622
		],
		[
			24,
			0
		],
		[
			24,
			-93
		],
		[
			13,
			-114
		],
		[
			36,
			-52
		],
		[
			6,
			-83
		]
	],
	[
		[
			35853,
			36280
		],
		[
			84,
			-72
		],
		[
			42,
			-62
		]
	],
	[
		[
			35979,
			36146
		],
		[
			60,
			-114
		],
		[
			54,
			-42
		],
		[
			96,
			-10
		],
		[
			0,
			-155
		],
		[
			18,
			-32
		]
	],
	[
		[
			36207,
			35793
		],
		[
			48,
			-113
		],
		[
			-24,
			-94
		],
		[
			-30,
			-31
		],
		[
			24,
			-72
		],
		[
			-60,
			-31
		]
	],
	[
		[
			36165,
			35452
		],
		[
			-42,
			20
		],
		[
			-66,
			-10
		],
		[
			-24,
			-72
		],
		[
			-48,
			10
		],
		[
			-66,
			-21
		],
		[
			-30,
			104
		],
		[
			-72,
			103
		],
		[
			-37,
			-31
		],
		[
			-6,
			-10
		],
		[
			-42,
			-176
		]
	],
	[
		[
			35732,
			35369
		],
		[
			-54,
			0
		],
		[
			-90,
			-52
		],
		[
			-186,
			93
		]
	],
	[
		[
			35402,
			35410
		],
		[
			-54,
			42
		],
		[
			-25,
			103
		],
		[
			19,
			21
		],
		[
			-43,
			145
		],
		[
			0,
			72
		],
		[
			24,
			73
		],
		[
			37,
			21
		],
		[
			6,
			155
		],
		[
			-85,
			21
		],
		[
			-66,
			103
		],
		[
			12,
			42
		]
	],
	[
		[
			35227,
			36208
		],
		[
			6,
			62
		],
		[
			-96,
			155
		],
		[
			-42,
			42
		],
		[
			12,
			72
		]
	],
	[
		[
			35107,
			36539
		],
		[
			54,
			42
		],
		[
			6,
			51
		]
	],
	[
		[
			35167,
			36632
		],
		[
			36,
			31
		],
		[
			127,
			0
		],
		[
			90,
			94
		],
		[
			54,
			-11
		],
		[
			102,
			52
		],
		[
			24,
			62
		],
		[
			60,
			0
		]
	],
	[
		[
			32516,
			37285
		],
		[
			48,
			-21
		],
		[
			42,
			-52
		],
		[
			18,
			-93
		],
		[
			48,
			-134
		],
		[
			-90,
			0
		],
		[
			-24,
			-63
		],
		[
			42,
			-124
		],
		[
			-187,
			-10
		],
		[
			-24,
			72
		],
		[
			-138,
			-41
		]
	],
	[
		[
			32251,
			36819
		],
		[
			-12,
			62
		],
		[
			12,
			155
		],
		[
			0,
			280
		],
		[
			12,
			197
		],
		[
			18,
			62
		],
		[
			18,
			176
		]
	],
	[
		[
			32299,
			37751
		],
		[
			96,
			-10
		],
		[
			30,
			-52
		],
		[
			73,
			-176
		],
		[
			-24,
			-21
		]
	],
	[
		[
			32474,
			37492
		],
		[
			60,
			-135
		],
		[
			-18,
			-72
		]
	],
	[
		[
			47890,
			36808
		],
		[
			36,
			-20
		]
	],
	[
		[
			47926,
			36788
		],
		[
			48,
			-21
		]
	],
	[
		[
			47974,
			36767
		],
		[
			6,
			0
		]
	],
	[
		[
			47980,
			36767
		],
		[
			12,
			-31
		]
	],
	[
		[
			47992,
			36736
		],
		[
			12,
			-21
		]
	],
	[
		[
			48004,
			36715
		],
		[
			-24,
			-10
		]
	],
	[
		[
			47980,
			36705
		],
		[
			-24,
			-42
		]
	],
	[
		[
			47956,
			36663
		],
		[
			30,
			-31
		]
	],
	[
		[
			47986,
			36632
		],
		[
			12,
			-31
		]
	],
	[
		[
			47998,
			36601
		],
		[
			-18,
			-10
		]
	],
	[
		[
			47980,
			36591
		],
		[
			0,
			-21
		]
	],
	[
		[
			47980,
			36570
		],
		[
			24,
			-41
		],
		[
			-24,
			-73
		],
		[
			-295,
			-124
		],
		[
			-120,
			-21
		],
		[
			-84,
			-31
		]
	],
	[
		[
			47481,
			36280
		],
		[
			-24,
			104
		],
		[
			66,
			114
		],
		[
			6,
			41
		],
		[
			-66,
			31
		],
		[
			24,
			104
		],
		[
			54,
			10
		],
		[
			54,
			52
		],
		[
			54,
			10
		],
		[
			-12,
			207
		],
		[
			187,
			21
		]
	],
	[
		[
			47824,
			36974
		],
		[
			0,
			-10
		]
	],
	[
		[
			47824,
			36964
		],
		[
			48,
			-31
		]
	],
	[
		[
			47872,
			36933
		],
		[
			0,
			-42
		]
	],
	[
		[
			47872,
			36891
		],
		[
			18,
			-20
		]
	],
	[
		[
			47890,
			36871
		],
		[
			0,
			-63
		]
	],
	[
		[
			48497,
			36467
		],
		[
			-12,
			-21
		]
	],
	[
		[
			48485,
			36446
		],
		[
			-30,
			-31
		]
	],
	[
		[
			48455,
			36415
		],
		[
			-132,
			62
		],
		[
			-73,
			21
		],
		[
			-138,
			0
		],
		[
			-126,
			-42
		],
		[
			18,
			62
		],
		[
			-24,
			52
		]
	],
	[
		[
			47980,
			36570
		],
		[
			0,
			21
		]
	],
	[
		[
			47998,
			36601
		],
		[
			-12,
			31
		]
	],
	[
		[
			47986,
			36632
		],
		[
			-30,
			31
		]
	],
	[
		[
			47956,
			36663
		],
		[
			24,
			42
		]
	],
	[
		[
			47980,
			36705
		],
		[
			24,
			10
		]
	],
	[
		[
			47992,
			36736
		],
		[
			-12,
			31
		]
	],
	[
		[
			47974,
			36767
		],
		[
			-48,
			21
		]
	],
	[
		[
			47890,
			36808
		],
		[
			0,
			63
		]
	],
	[
		[
			47890,
			36871
		],
		[
			-18,
			20
		]
	],
	[
		[
			47872,
			36933
		],
		[
			-48,
			31
		]
	],
	[
		[
			47824,
			36964
		],
		[
			0,
			21
		]
	],
	[
		[
			47824,
			36985
		],
		[
			-7,
			10
		]
	],
	[
		[
			47817,
			36995
		],
		[
			-30,
			72
		]
	],
	[
		[
			47787,
			37067
		],
		[
			24,
			21
		]
	],
	[
		[
			47811,
			37088
		],
		[
			37,
			21
		]
	],
	[
		[
			47848,
			37109
		],
		[
			12,
			10
		]
	],
	[
		[
			47860,
			37119
		],
		[
			42,
			21
		],
		[
			174,
			21
		],
		[
			66,
			-135
		],
		[
			90,
			-83
		],
		[
			60,
			-72
		],
		[
			61,
			31
		],
		[
			90,
			-42
		],
		[
			-12,
			-165
		],
		[
			72,
			-73
		],
		[
			-30,
			-145
		],
		[
			24,
			-10
		]
	],
	[
		[
			45863,
			35949
		],
		[
			-84,
			-62
		],
		[
			-48,
			20
		],
		[
			-6,
			-51
		],
		[
			-138,
			-42
		],
		[
			-138,
			-93
		],
		[
			-6,
			41
		],
		[
			-127,
			-62
		],
		[
			-48,
			-41
		],
		[
			-12,
			-52
		],
		[
			-60,
			-41
		],
		[
			-108,
			-21
		],
		[
			-84,
			-73
		],
		[
			-103,
			42
		]
	],
	[
		[
			44901,
			35514
		],
		[
			-469,
			197
		],
		[
			-246,
			0
		]
	],
	[
		[
			44186,
			35711
		],
		[
			-6,
			134
		],
		[
			258,
			62
		]
	],
	[
		[
			44438,
			35907
		],
		[
			349,
			135
		],
		[
			108,
			21
		]
	],
	[
		[
			44895,
			36063
		],
		[
			79,
			-104
		],
		[
			36,
			0
		],
		[
			126,
			145
		],
		[
			78,
			31
		],
		[
			72,
			-10
		],
		[
			102,
			-73
		],
		[
			85,
			11
		],
		[
			120,
			72
		],
		[
			150,
			0
		],
		[
			114,
			-52
		],
		[
			6,
			-134
		]
	],
	[
		[
			44895,
			36063
		],
		[
			-114,
			-11
		],
		[
			-343,
			-145
		]
	],
	[
		[
			44438,
			35907
		],
		[
			-264,
			-51
		],
		[
			6,
			-125
		]
	],
	[
		[
			44180,
			35731
		],
		[
			-277,
			-62
		],
		[
			-60,
			21
		]
	],
	[
		[
			43843,
			35690
		],
		[
			-126,
			10
		],
		[
			-84,
			42
		],
		[
			-36,
			62
		],
		[
			-72,
			10
		],
		[
			96,
			124
		],
		[
			66,
			135
		],
		[
			6,
			62
		],
		[
			36,
			0
		]
	],
	[
		[
			43729,
			36135
		],
		[
			36,
			31
		]
	],
	[
		[
			43765,
			36166
		],
		[
			48,
			-51
		]
	],
	[
		[
			43813,
			36115
		],
		[
			36,
			-32
		]
	],
	[
		[
			43849,
			36083
		],
		[
			12,
			0
		]
	],
	[
		[
			43861,
			36083
		],
		[
			30,
			-31
		]
	],
	[
		[
			43891,
			36052
		],
		[
			36,
			11
		]
	],
	[
		[
			43927,
			36063
		],
		[
			73,
			20
		]
	],
	[
		[
			44000,
			36083
		],
		[
			60,
			-10
		]
	],
	[
		[
			44060,
			36073
		],
		[
			24,
			-21
		]
	],
	[
		[
			44084,
			36052
		],
		[
			18,
			11
		]
	],
	[
		[
			44102,
			36063
		],
		[
			6,
			20
		]
	],
	[
		[
			44108,
			36083
		],
		[
			48,
			-10
		]
	],
	[
		[
			44156,
			36073
		],
		[
			48,
			0
		]
	],
	[
		[
			44204,
			36073
		],
		[
			36,
			0
		]
	],
	[
		[
			44240,
			36073
		],
		[
			-12,
			21
		]
	],
	[
		[
			44228,
			36094
		],
		[
			-6,
			31
		]
	],
	[
		[
			44222,
			36125
		],
		[
			48,
			31
		]
	],
	[
		[
			44270,
			36156
		],
		[
			48,
			0
		]
	],
	[
		[
			44318,
			36156
		],
		[
			-6,
			-21
		]
	],
	[
		[
			44312,
			36135
		],
		[
			6,
			-31
		]
	],
	[
		[
			44318,
			36104
		],
		[
			24,
			0
		]
	],
	[
		[
			44342,
			36104
		],
		[
			6,
			31
		]
	],
	[
		[
			44348,
			36135
		],
		[
			24,
			21
		],
		[
			-6,
			83
		]
	],
	[
		[
			44366,
			36239
		],
		[
			24,
			0
		]
	],
	[
		[
			44390,
			36239
		],
		[
			79,
			-11
		]
	],
	[
		[
			44469,
			36228
		],
		[
			96,
			42
		],
		[
			78,
			0
		]
	],
	[
		[
			44643,
			36270
		],
		[
			30,
			-10
		]
	],
	[
		[
			44673,
			36260
		],
		[
			6,
			10
		]
	],
	[
		[
			44679,
			36270
		],
		[
			6,
			41
		],
		[
			54,
			42
		],
		[
			90,
			-42
		],
		[
			72,
			-10
		],
		[
			91,
			72
		],
		[
			36,
			-113
		],
		[
			-18,
			-83
		],
		[
			-73,
			-21
		],
		[
			-42,
			-41
		],
		[
			0,
			-52
		]
	],
	[
		[
			48485,
			36446
		],
		[
			-30,
			-31
		]
	],
	[
		[
			48671,
			40413
		],
		[
			241,
			-62
		],
		[
			48,
			-52
		],
		[
			78,
			-21
		],
		[
			72,
			-62
		],
		[
			90,
			-42
		],
		[
			121,
			-20
		],
		[
			102,
			-83
		],
		[
			6,
			-104
		],
		[
			-132,
			-62
		],
		[
			-211,
			0
		],
		[
			-156,
			-52
		],
		[
			-84,
			-103
		],
		[
			-30,
			-62
		],
		[
			-61,
			-31
		],
		[
			-54,
			-94
		],
		[
			-30,
			-134
		],
		[
			-18,
			-145
		],
		[
			0,
			-156
		],
		[
			12,
			-124
		],
		[
			139,
			-456
		],
		[
			96,
			-269
		],
		[
			60,
			-114
		],
		[
			48,
			-186
		],
		[
			120,
			-228
		],
		[
			66,
			-104
		],
		[
			151,
			-207
		],
		[
			396,
			-580
		],
		[
			79,
			-93
		],
		[
			96,
			-135
		],
		[
			150,
			-186
		],
		[
			102,
			-166
		],
		[
			67,
			-72
		],
		[
			66,
			-104
		],
		[
			156,
			-186
		],
		[
			120,
			-176
		],
		[
			42,
			-94
		],
		[
			121,
			-372
		],
		[
			-73,
			41
		],
		[
			-162,
			145
		],
		[
			-192,
			104
		],
		[
			-217,
			51
		],
		[
			-72,
			-10
		],
		[
			-36,
			-31
		],
		[
			-138,
			-31
		],
		[
			-151,
			-62
		],
		[
			-90,
			-21
		],
		[
			-24,
			-31
		],
		[
			-192,
			31
		],
		[
			-90,
			31
		],
		[
			-157,
			124
		],
		[
			-96,
			104
		],
		[
			-156,
			197
		],
		[
			-102,
			83
		],
		[
			-151,
			155
		],
		[
			-54,
			21
		],
		[
			-48,
			114
		],
		[
			-6,
			72
		],
		[
			-36,
			10
		],
		[
			0,
			94
		]
	],
	[
		[
			47860,
			37119
		],
		[
			-12,
			-10
		]
	],
	[
		[
			47848,
			37109
		],
		[
			-37,
			-21
		]
	],
	[
		[
			47811,
			37088
		],
		[
			-24,
			-21
		]
	],
	[
		[
			47787,
			37067
		],
		[
			30,
			-72
		]
	],
	[
		[
			47824,
			36985
		],
		[
			0,
			-11
		]
	],
	[
		[
			47481,
			36280
		],
		[
			-193,
			-52
		],
		[
			-66,
			32
		],
		[
			-132,
			-11
		],
		[
			-343,
			-72
		],
		[
			-132,
			62
		],
		[
			-78,
			83
		],
		[
			-6,
			31
		],
		[
			-108,
			31
		],
		[
			-85,
			10
		],
		[
			-282,
			-83
		],
		[
			-60,
			-31
		],
		[
			-30,
			-62
		],
		[
			-85,
			-83
		],
		[
			-150,
			31
		],
		[
			-156,
			-10
		],
		[
			-150,
			-83
		],
		[
			-37,
			0
		],
		[
			-78,
			73
		],
		[
			-108,
			20
		],
		[
			-66,
			-31
		],
		[
			-108,
			-134
		],
		[
			-48,
			-31
		],
		[
			-43,
			51
		],
		[
			-24,
			94
		],
		[
			91,
			31
		],
		[
			42,
			62
		],
		[
			-6,
			114
		],
		[
			-42,
			72
		],
		[
			-54,
			11
		],
		[
			-79,
			-83
		],
		[
			-90,
			41
		],
		[
			-138,
			0
		],
		[
			0,
			52
		],
		[
			-84,
			-10
		],
		[
			-115,
			10
		],
		[
			-90,
			31
		],
		[
			-6,
			93
		],
		[
			-60,
			31
		]
	],
	[
		[
			44282,
			36570
		],
		[
			120,
			31
		],
		[
			73,
			42
		],
		[
			66,
			72
		],
		[
			-6,
			83
		],
		[
			-42,
			62
		],
		[
			12,
			73
		],
		[
			36,
			83
		],
		[
			-36,
			31
		],
		[
			36,
			83
		],
		[
			36,
			41
		],
		[
			-30,
			52
		],
		[
			-78,
			41
		],
		[
			0,
			83
		],
		[
			-37,
			104
		],
		[
			6,
			82
		],
		[
			25,
			21
		],
		[
			-37,
			83
		],
		[
			55,
			52
		],
		[
			0,
			62
		],
		[
			78,
			21
		],
		[
			6,
			31
		]
	],
	[
		[
			44565,
			37803
		],
		[
			18,
			93
		],
		[
			-78,
			-10
		],
		[
			-61,
			20
		],
		[
			31,
			73
		],
		[
			6,
			83
		],
		[
			36,
			0
		],
		[
			6,
			93
		],
		[
			54,
			41
		],
		[
			-42,
			62
		],
		[
			30,
			52
		],
		[
			-24,
			62
		],
		[
			0,
			104
		],
		[
			36,
			41
		],
		[
			-18,
			73
		],
		[
			-36,
			10
		],
		[
			0,
			62
		],
		[
			42,
			156
		],
		[
			-6,
			31
		]
	],
	[
		[
			44559,
			38849
		],
		[
			54,
			10
		],
		[
			66,
			52
		],
		[
			54,
			0
		],
		[
			36,
			103
		],
		[
			48,
			21
		],
		[
			36,
			52
		],
		[
			84,
			-10
		],
		[
			127,
			51
		],
		[
			96,
			-10
		],
		[
			102,
			31
		],
		[
			18,
			-41
		],
		[
			114,
			31
		],
		[
			205,
			41
		],
		[
			60,
			31
		],
		[
			24,
			-83
		],
		[
			0,
			-82
		],
		[
			120,
			-21
		],
		[
			24,
			-42
		],
		[
			127,
			21
		],
		[
			24,
			73
		],
		[
			-48,
			134
		],
		[
			42,
			62
		],
		[
			120,
			0
		],
		[
			6,
			52
		],
		[
			78,
			114
		],
		[
			-90,
			83
		],
		[
			186,
			62
		],
		[
			72,
			0
		],
		[
			55,
			73
		],
		[
			126,
			103
		],
		[
			102,
			11
		],
		[
			18,
			41
		],
		[
			126,
			-21
		],
		[
			36,
			-41
		],
		[
			42,
			21
		],
		[
			49,
			-32
		],
		[
			174,
			135
		],
		[
			138,
			62
		],
		[
			-18,
			31
		],
		[
			84,
			52
		],
		[
			-24,
			93
		],
		[
			181,
			104
		],
		[
			-36,
			248
		],
		[
			60,
			32
		],
		[
			30,
			72
		]
	],
	[
		[
			47487,
			40568
		],
		[
			84,
			0
		],
		[
			72,
			21
		],
		[
			48,
			-42
		],
		[
			48,
			-93
		],
		[
			6,
			-62
		],
		[
			72,
			-21
		],
		[
			31,
			-41
		],
		[
			54,
			-21
		],
		[
			126,
			31
		],
		[
			6,
			-52
		],
		[
			54,
			11
		],
		[
			54,
			-93
		],
		[
			78,
			31
		],
		[
			145,
			10
		],
		[
			162,
			-31
		],
		[
			42,
			-31
		],
		[
			42,
			31
		],
		[
			60,
			197
		]
	],
	[
		[
			50000,
			34457
		],
		[
			-72,
			-62
		],
		[
			-60,
			-20
		],
		[
			-84,
			10
		],
		[
			-73,
			-10
		],
		[
			-42,
			-31
		],
		[
			-42,
			62
		],
		[
			-78,
			0
		],
		[
			-42,
			-42
		],
		[
			-42,
			-248
		],
		[
			-42,
			-11
		],
		[
			-66,
			-62
		]
	],
	[
		[
			49357,
			34043
		],
		[
			24,
			-41
		],
		[
			-102,
			-73
		],
		[
			24,
			-41
		],
		[
			102,
			-93
		],
		[
			18,
			-42
		],
		[
			-163,
			-103
		],
		[
			-54,
			-63
		],
		[
			-18,
			42
		],
		[
			-48,
			-21
		]
	],
	[
		[
			49140,
			33608
		],
		[
			-42,
			52
		],
		[
			-36,
			0
		],
		[
			-72,
			166
		],
		[
			-12,
			93
		],
		[
			-90,
			-10
		],
		[
			-42,
			20
		],
		[
			0,
			62
		],
		[
			-48,
			73
		],
		[
			-115,
			21
		],
		[
			36,
			196
		],
		[
			-12,
			94
		],
		[
			-78,
			145
		],
		[
			42,
			82
		],
		[
			145,
			208
		],
		[
			-43,
			82
		],
		[
			-18,
			-20
		],
		[
			-126,
			0
		],
		[
			-48,
			31
		],
		[
			-36,
			124
		],
		[
			-90,
			31
		]
	],
	[
		[
			48455,
			35058
		],
		[
			6,
			21
		]
	],
	[
		[
			48461,
			35079
		],
		[
			0,
			10
		]
	],
	[
		[
			48461,
			35089
		],
		[
			-30,
			0
		],
		[
			-90,
			52
		],
		[
			-127,
			145
		]
	],
	[
		[
			48214,
			35286
		],
		[
			54,
			31
		],
		[
			49,
			0
		],
		[
			180,
			62
		],
		[
			60,
			0
		],
		[
			162,
			135
		]
	],
	[
		[
			48719,
			35514
		],
		[
			97,
			-62
		],
		[
			198,
			-145
		],
		[
			60,
			-73
		],
		[
			30,
			-10
		],
		[
			150,
			-166
		],
		[
			73,
			-52
		],
		[
			102,
			-51
		],
		[
			54,
			51
		],
		[
			60,
			-10
		],
		[
			54,
			-62
		],
		[
			114,
			-93
		],
		[
			37,
			-63
		],
		[
			204,
			-238
		],
		[
			48,
			-83
		]
	],
	[
		[
			45479,
			34219
		],
		[
			-60,
			-114
		],
		[
			12,
			-93
		],
		[
			-49,
			0
		],
		[
			-24,
			-52
		],
		[
			12,
			-83
		],
		[
			-78,
			-82
		]
	],
	[
		[
			45292,
			33795
		],
		[
			-120,
			41
		],
		[
			-307,
			62
		],
		[
			-12,
			-41
		],
		[
			-246,
			-11
		],
		[
			-24,
			42
		],
		[
			114,
			93
		],
		[
			-198,
			259
		]
	],
	[
		[
			44499,
			34240
		],
		[
			18,
			72
		],
		[
			-103,
			32
		],
		[
			36,
			155
		],
		[
			205,
			31
		],
		[
			60,
			-10
		],
		[
			30,
			51
		],
		[
			-42,
			62
		],
		[
			0,
			104
		],
		[
			30,
			93
		],
		[
			-36,
			31
		],
		[
			18,
			135
		],
		[
			60,
			166
		],
		[
			0,
			83
		],
		[
			126,
			269
		]
	],
	[
		[
			45863,
			35949
		],
		[
			55,
			-62
		],
		[
			0,
			-42
		],
		[
			-43,
			-155
		],
		[
			-84,
			-93
		],
		[
			-18,
			-42
		],
		[
			0,
			-134
		],
		[
			30,
			-73
		],
		[
			48,
			-52
		],
		[
			-42,
			-62
		],
		[
			-84,
			11
		],
		[
			-60,
			-42
		],
		[
			-30,
			-52
		],
		[
			-6,
			-72
		],
		[
			42,
			-52
		],
		[
			-6,
			-52
		],
		[
			-72,
			-72
		],
		[
			-18,
			-52
		],
		[
			6,
			-83
		],
		[
			48,
			-93
		],
		[
			-24,
			-114
		],
		[
			30,
			-104
		],
		[
			-36,
			-155
		],
		[
			-48,
			-83
		],
		[
			-72,
			0
		]
	],
	[
		[
			46693,
			36011
		],
		[
			175,
			-52
		],
		[
			-55,
			-41
		],
		[
			-54,
			20
		],
		[
			-66,
			73
		]
	],
	[
		[
			48214,
			35286
		],
		[
			-84,
			0
		],
		[
			18,
			-218
		],
		[
			-42,
			0
		],
		[
			-108,
			-207
		],
		[
			-36,
			-93
		],
		[
			-78,
			-31
		],
		[
			-79,
			31
		],
		[
			-150,
			10
		],
		[
			-180,
			42
		],
		[
			-54,
			93
		],
		[
			-60,
			-31
		],
		[
			-73,
			-104
		],
		[
			-84,
			-41
		],
		[
			0,
			-62
		],
		[
			-54,
			-31
		],
		[
			-84,
			0
		],
		[
			-60,
			-73
		],
		[
			156,
			11
		],
		[
			181,
			72
		],
		[
			72,
			0
		],
		[
			48,
			-114
		],
		[
			54,
			11
		],
		[
			24,
			-31
		],
		[
			18,
			-135
		],
		[
			-114,
			-52
		],
		[
			-109,
			-31
		],
		[
			-102,
			10
		],
		[
			-84,
			-10
		],
		[
			-60,
			-41
		],
		[
			36,
			-83
		],
		[
			-48,
			-104
		],
		[
			12,
			-52
		],
		[
			84,
			-41
		],
		[
			-463,
			-145
		],
		[
			-186,
			-31
		],
		[
			-169,
			0
		],
		[
			-96,
			21
		],
		[
			6,
			62
		],
		[
			-30,
			41
		],
		[
			12,
			114
		],
		[
			36,
			135
		],
		[
			-12,
			103
		],
		[
			18,
			52
		],
		[
			-108,
			11
		],
		[
			-186,
			-11
		],
		[
			-72,
			31
		],
		[
			-79,
			-10
		],
		[
			-138,
			41
		],
		[
			-72,
			11
		]
	],
	[
		[
			45635,
			34406
		],
		[
			12,
			62
		],
		[
			-30,
			62
		],
		[
			30,
			114
		],
		[
			-54,
			145
		],
		[
			12,
			114
		],
		[
			66,
			62
		],
		[
			18,
			41
		],
		[
			-48,
			83
		],
		[
			12,
			52
		],
		[
			48,
			83
		],
		[
			72,
			-11
		],
		[
			72,
			21
		],
		[
			24,
			52
		],
		[
			-78,
			145
		],
		[
			0,
			114
		],
		[
			66,
			72
		],
		[
			55,
			94
		],
		[
			36,
			155
		],
		[
			-18,
			83
		],
		[
			-43,
			83
		],
		[
			19,
			41
		],
		[
			192,
			62
		],
		[
			108,
			62
		],
		[
			162,
			42
		],
		[
			67,
			-73
		],
		[
			42,
			-72
		],
		[
			102,
			-83
		],
		[
			54,
			-21
		],
		[
			66,
			-72
		],
		[
			66,
			-21
		],
		[
			145,
			0
		],
		[
			84,
			21
		],
		[
			102,
			103
		],
		[
			84,
			62
		],
		[
			48,
			-10
		],
		[
			265,
			0
		],
		[
			84,
			10
		],
		[
			78,
			32
		],
		[
			90,
			10
		],
		[
			235,
			83
		],
		[
			144,
			10
		],
		[
			42,
			21
		],
		[
			96,
			-31
		],
		[
			49,
			-62
		],
		[
			132,
			-259
		],
		[
			60,
			-83
		],
		[
			48,
			-42
		],
		[
			48,
			-93
		],
		[
			120,
			-155
		]
	],
	[
		[
			44565,
			37803
		],
		[
			-60,
			0
		],
		[
			-42,
			62
		],
		[
			-37,
			-21
		],
		[
			-114,
			-21
		],
		[
			-144,
			-72
		],
		[
			-90,
			135
		],
		[
			-223,
			-83
		],
		[
			-102,
			-62
		],
		[
			-78,
			82
		],
		[
			-42,
			-10
		],
		[
			-60,
			21
		]
	],
	[
		[
			43573,
			37834
		],
		[
			-6,
			-21
		]
	],
	[
		[
			43567,
			37813
		],
		[
			-18,
			-21
		]
	],
	[
		[
			43549,
			37792
		],
		[
			-6,
			-31
		]
	],
	[
		[
			43543,
			37761
		],
		[
			-24,
			-10
		]
	],
	[
		[
			43519,
			37751
		],
		[
			-73,
			41
		],
		[
			-90,
			104
		],
		[
			-18,
			52
		],
		[
			-42,
			-31
		],
		[
			-36,
			10
		],
		[
			-60,
			62
		],
		[
			-24,
			83
		],
		[
			-36,
			-10
		],
		[
			-48,
			82
		],
		[
			-36,
			-10
		],
		[
			-61,
			62
		]
	],
	[
		[
			42995,
			38196
		],
		[
			-12,
			62
		],
		[
			-78,
			239
		],
		[
			-48,
			82
		],
		[
			-24,
			104
		],
		[
			42,
			104
		],
		[
			78,
			10
		],
		[
			60,
			-21
		],
		[
			61,
			11
		],
		[
			6,
			72
		],
		[
			-48,
			42
		],
		[
			0,
			41
		]
	],
	[
		[
			43032,
			38942
		],
		[
			48,
			-31
		],
		[
			30,
			31
		]
	],
	[
		[
			43110,
			38942
		],
		[
			138,
			-124
		],
		[
			72,
			20
		],
		[
			0,
			42
		],
		[
			-54,
			62
		],
		[
			36,
			83
		],
		[
			-12,
			134
		],
		[
			24,
			42
		],
		[
			72,
			21
		],
		[
			42,
			-21
		],
		[
			36,
			62
		],
		[
			85,
			21
		],
		[
			30,
			83
		],
		[
			186,
			31
		],
		[
			18,
			62
		]
	],
	[
		[
			43783,
			39460
		],
		[
			199,
			-42
		],
		[
			60,
			-31
		],
		[
			60,
			62
		],
		[
			60,
			-82
		],
		[
			6,
			-52
		],
		[
			60,
			-21
		],
		[
			0,
			-83
		],
		[
			36,
			0
		],
		[
			30,
			-72
		],
		[
			-72,
			-125
		],
		[
			48,
			-41
		],
		[
			18,
			-83
		],
		[
			-42,
			0
		],
		[
			-12,
			-52
		],
		[
			-54,
			-31
		],
		[
			0,
			-51
		],
		[
			84,
			0
		],
		[
			54,
			31
		],
		[
			54,
			-11
		],
		[
			72,
			42
		],
		[
			115,
			31
		]
	],
	[
		[
			41384,
			29186
		],
		[
			42,
			-11
		],
		[
			-6,
			-134
		],
		[
			108,
			-21
		],
		[
			103,
			21
		],
		[
			90,
			-42
		],
		[
			-36,
			-72
		],
		[
			12,
			-62
		],
		[
			96,
			0
		],
		[
			102,
			-52
		],
		[
			-18,
			-62
		],
		[
			12,
			-83
		],
		[
			-6,
			-93
		]
	],
	[
		[
			41883,
			28575
		],
		[
			-84,
			-11
		],
		[
			-48,
			-145
		],
		[
			-42,
			0
		],
		[
			-6,
			-62
		],
		[
			-36,
			-41
		],
		[
			12,
			-83
		],
		[
			-102,
			-31
		],
		[
			-49,
			52
		],
		[
			-78,
			51
		],
		[
			-24,
			-20
		],
		[
			-96,
			10
		],
		[
			-36,
			-21
		],
		[
			-54,
			73
		],
		[
			-18,
			72
		],
		[
			-66,
			0
		],
		[
			-60,
			62
		],
		[
			-67,
			-31
		],
		[
			-30,
			21
		],
		[
			-18,
			83
		],
		[
			-36,
			31
		],
		[
			-36,
			114
		],
		[
			72,
			93
		]
	],
	[
		[
			40981,
			28792
		],
		[
			30,
			0
		],
		[
			72,
			83
		],
		[
			31,
			-10
		],
		[
			78,
			51
		],
		[
			6,
			156
		],
		[
			54,
			21
		],
		[
			12,
			93
		],
		[
			120,
			0
		]
	],
	[
		[
			43843,
			26255
		],
		[
			6,
			-187
		],
		[
			-30,
			-72
		],
		[
			-60,
			-73
		],
		[
			-42,
			-10
		]
	],
	[
		[
			43717,
			25913
		],
		[
			-18,
			-52
		],
		[
			-132,
			31
		],
		[
			0,
			-93
		],
		[
			-60,
			-104
		],
		[
			-73,
			21
		],
		[
			-42,
			-62
		],
		[
			-84,
			-10
		],
		[
			-12,
			-21
		]
	],
	[
		[
			43296,
			25623
		],
		[
			-36,
			-62
		],
		[
			-54,
			103
		],
		[
			-54,
			11
		],
		[
			-12,
			124
		],
		[
			30,
			62
		],
		[
			-175,
			124
		],
		[
			-96,
			52
		],
		[
			-18,
			31
		],
		[
			54,
			73
		],
		[
			91,
			-21
		],
		[
			36,
			83
		],
		[
			-6,
			104
		]
	],
	[
		[
			43056,
			26307
		],
		[
			48,
			41
		],
		[
			-6,
			124
		],
		[
			24,
			11
		]
	],
	[
		[
			43122,
			26483
		],
		[
			0,
			31
		],
		[
			72,
			83
		],
		[
			78,
			0
		],
		[
			66,
			-104
		],
		[
			-6,
			-41
		],
		[
			48,
			-63
		],
		[
			60,
			42
		],
		[
			79,
			-11
		],
		[
			84,
			-31
		],
		[
			90,
			11
		],
		[
			72,
			-62
		],
		[
			18,
			-63
		],
		[
			60,
			-20
		]
	],
	[
		[
			47042,
			26120
		],
		[
			-132,
			21
		],
		[
			-18,
			-52
		],
		[
			-115,
			-104
		],
		[
			12,
			-51
		],
		[
			-114,
			-249
		],
		[
			-18,
			-72
		],
		[
			-60,
			-11
		],
		[
			-30,
			21
		]
	],
	[
		[
			46567,
			25623
		],
		[
			-6,
			31
		]
	],
	[
		[
			46561,
			25654
		],
		[
			-60,
			-41
		],
		[
			-84,
			20
		],
		[
			-30,
			-41
		],
		[
			-145,
			-83
		]
	],
	[
		[
			46242,
			25509
		],
		[
			-30,
			-41
		],
		[
			-162,
			-42
		],
		[
			-30,
			-31
		],
		[
			0,
			-10
		],
		[
			-18,
			-31
		]
	],
	[
		[
			46002,
			25354
		],
		[
			-78,
			-114
		],
		[
			-55,
			-11
		],
		[
			-12,
			-82
		]
	],
	[
		[
			45857,
			25147
		],
		[
			-36,
			-52
		]
	],
	[
		[
			45821,
			25095
		],
		[
			0,
			-11
		]
	],
	[
		[
			45821,
			25084
		],
		[
			0,
			11
		]
	],
	[
		[
			45821,
			25095
		],
		[
			0,
			-11
		]
	],
	[
		[
			45821,
			25084
		],
		[
			-42,
			-51
		]
	],
	[
		[
			45779,
			25033
		],
		[
			-54,
			20
		],
		[
			-42,
			73
		],
		[
			-54,
			41
		],
		[
			-12,
			52
		]
	],
	[
		[
			45617,
			25219
		],
		[
			6,
			10
		]
	],
	[
		[
			45623,
			25229
		],
		[
			0,
			42
		]
	],
	[
		[
			45623,
			25271
		],
		[
			0,
			10
		]
	],
	[
		[
			45623,
			25281
		],
		[
			-90,
			135
		],
		[
			-24,
			-11
		],
		[
			-12,
			114
		],
		[
			-24,
			63
		],
		[
			-48,
			31
		]
	],
	[
		[
			45425,
			25613
		],
		[
			-6,
			10
		],
		[
			-7,
			0
		],
		[
			-54,
			83
		],
		[
			-132,
			0
		],
		[
			-42,
			-21
		],
		[
			-18,
			145
		],
		[
			60,
			52
		],
		[
			-12,
			103
		],
		[
			36,
			52
		],
		[
			-18,
			135
		]
	],
	[
		[
			45232,
			26172
		],
		[
			36,
			52
		],
		[
			66,
			145
		],
		[
			48,
			20
		],
		[
			-24,
			176
		],
		[
			6,
			63
		],
		[
			-60,
			20
		],
		[
			-24,
			104
		],
		[
			-78,
			41
		],
		[
			-42,
			42
		]
	],
	[
		[
			45160,
			26835
		],
		[
			18,
			52
		]
	],
	[
		[
			45178,
			26887
		],
		[
			6,
			31
		]
	],
	[
		[
			45184,
			26918
		],
		[
			66,
			62
		],
		[
			30,
			52
		]
	],
	[
		[
			45280,
			27032
		],
		[
			48,
			20
		]
	],
	[
		[
			45328,
			27052
		],
		[
			139,
			42
		],
		[
			30,
			-52
		],
		[
			66,
			-10
		],
		[
			180,
			31
		],
		[
			12,
			41
		],
		[
			90,
			10
		],
		[
			103,
			63
		],
		[
			0,
			41
		],
		[
			114,
			0
		]
	],
	[
		[
			46062,
			27218
		],
		[
			144,
			0
		],
		[
			96,
			21
		],
		[
			85,
			0
		],
		[
			18,
			-83
		],
		[
			90,
			31
		],
		[
			96,
			-10
		],
		[
			42,
			-73
		],
		[
			30,
			10
		],
		[
			90,
			-62
		],
		[
			36,
			-52
		],
		[
			-24,
			-103
		],
		[
			175,
			-31
		],
		[
			18,
			-42
		],
		[
			78,
			-41
		],
		[
			90,
			0
		],
		[
			96,
			-21
		],
		[
			72,
			11
		],
		[
			36,
			-31
		],
		[
			85,
			-11
		],
		[
			12,
			-41
		],
		[
			-36,
			-166
		],
		[
			-24,
			0
		],
		[
			-73,
			-93
		],
		[
			-84,
			-42
		],
		[
			-144,
			-41
		],
		[
			-18,
			-41
		],
		[
			-114,
			-32
		],
		[
			54,
			-103
		],
		[
			54,
			-52
		]
	],
	[
		[
			43627,
			29020
		],
		[
			-78,
			-62
		],
		[
			-73,
			31
		],
		[
			-30,
			-21
		],
		[
			-78,
			0
		],
		[
			-48,
			-93
		],
		[
			-90,
			-21
		],
		[
			-24,
			-165
		],
		[
			6,
			-125
		],
		[
			-36,
			0
		],
		[
			-78,
			-83
		],
		[
			-211,
			114
		]
	],
	[
		[
			42887,
			28595
		],
		[
			0,
			11
		],
		[
			36,
			83
		],
		[
			54,
			-31
		],
		[
			97,
			72
		],
		[
			-97,
			124
		],
		[
			-90,
			52
		],
		[
			-54,
			62
		],
		[
			-18,
			-20
		],
		[
			-84,
			62
		],
		[
			-30,
			51
		],
		[
			54,
			177
		],
		[
			-54,
			113
		],
		[
			132,
			-20
		],
		[
			120,
			62
		],
		[
			-90,
			31
		],
		[
			24,
			62
		],
		[
			-60,
			93
		]
	],
	[
		[
			42827,
			29579
		],
		[
			66,
			42
		],
		[
			18,
			52
		],
		[
			42,
			10
		],
		[
			30,
			-31
		],
		[
			85,
			31
		]
	],
	[
		[
			43068,
			29683
		],
		[
			-6,
			-42
		],
		[
			96,
			0
		],
		[
			12,
			-41
		],
		[
			84,
			-10
		],
		[
			12,
			-104
		],
		[
			42,
			-10
		],
		[
			6,
			-73
		],
		[
			84,
			-41
		],
		[
			0,
			-42
		],
		[
			60,
			-145
		],
		[
			67,
			-10
		],
		[
			12,
			-41
		],
		[
			60,
			-42
		],
		[
			30,
			-62
		]
	],
	[
		[
			34049,
			23158
		],
		[
			48,
			-62
		],
		[
			60,
			10
		],
		[
			42,
			-72
		],
		[
			48,
			-42
		],
		[
			24,
			21
		],
		[
			109,
			0
		],
		[
			18,
			135
		],
		[
			36,
			41
		],
		[
			30,
			83
		],
		[
			42,
			41
		],
		[
			36,
			-10
		],
		[
			36,
			-83
		],
		[
			60,
			11
		],
		[
			78,
			-114
		],
		[
			24,
			0
		]
	],
	[
		[
			34740,
			23117
		],
		[
			12,
			-11
		],
		[
			0,
			-10
		],
		[
			-24,
			-52
		],
		[
			54,
			-62
		]
	],
	[
		[
			34782,
			22982
		],
		[
			-90,
			-10
		],
		[
			-54,
			20
		],
		[
			-24,
			-31
		],
		[
			-84,
			0
		],
		[
			0,
			-31
		]
	],
	[
		[
			34530,
			22930
		],
		[
			54,
			-62
		],
		[
			48,
			-10
		],
		[
			24,
			-73
		],
		[
			78,
			21
		],
		[
			48,
			-62
		],
		[
			24,
			41
		],
		[
			79,
			-10
		],
		[
			24,
			-83
		],
		[
			-60,
			-10
		],
		[
			-55,
			-104
		],
		[
			-66,
			-31
		],
		[
			-18,
			-73
		]
	],
	[
		[
			34710,
			22474
		],
		[
			-18,
			-62
		],
		[
			30,
			-62
		],
		[
			72,
			31
		],
		[
			67,
			-10
		],
		[
			102,
			52
		],
		[
			60,
			0
		],
		[
			96,
			41
		],
		[
			66,
			-21
		],
		[
			42,
			31
		],
		[
			103,
			-41
		],
		[
			42,
			62
		],
		[
			84,
			21
		],
		[
			36,
			-10
		],
		[
			12,
			72
		],
		[
			-60,
			73
		],
		[
			6,
			51
		],
		[
			42,
			0
		],
		[
			66,
			62
		],
		[
			186,
			11
		],
		[
			42,
			-62
		],
		[
			61,
			-31
		],
		[
			-24,
			-83
		],
		[
			-127,
			-52
		],
		[
			-72,
			-73
		],
		[
			-12,
			-113
		],
		[
			54,
			-63
		],
		[
			163,
			31
		],
		[
			96,
			-20
		],
		[
			36,
			-42
		],
		[
			120,
			0
		],
		[
			24,
			-41
		],
		[
			-84,
			-73
		],
		[
			66,
			-103
		],
		[
			-60,
			-11
		],
		[
			-6,
			-51
		]
	],
	[
		[
			36021,
			21988
		],
		[
			-24,
			10
		],
		[
			-18,
			-93
		],
		[
			-30,
			-73
		],
		[
			-96,
			-124
		],
		[
			42,
			-166
		],
		[
			60,
			-82
		],
		[
			132,
			20
		],
		[
			72,
			73
		],
		[
			78,
			-42
		],
		[
			42,
			11
		],
		[
			43,
			-73
		],
		[
			42,
			-114
		],
		[
			-66,
			-52
		],
		[
			12,
			-134
		],
		[
			24,
			-62
		],
		[
			0,
			-94
		],
		[
			48,
			0
		],
		[
			6,
			0
		],
		[
			12,
			-93
		],
		[
			-12,
			-72
		],
		[
			6,
			-93
		],
		[
			-66,
			-145
		],
		[
			12,
			-42
		],
		[
			6,
			-145
		],
		[
			-24,
			-114
		]
	],
	[
		[
			36322,
			20289
		],
		[
			-55,
			-31
		],
		[
			-72,
			-10
		],
		[
			-36,
			-31
		],
		[
			-78,
			-11
		],
		[
			-18,
			-103
		],
		[
			-36,
			-52
		],
		[
			-114,
			-21
		],
		[
			-78,
			31
		],
		[
			0,
			166
		],
		[
			-157,
			10
		],
		[
			-6,
			73
		],
		[
			-54,
			0
		],
		[
			-54,
			-93
		],
		[
			-48,
			-31
		],
		[
			30,
			-94
		],
		[
			48,
			0
		],
		[
			30,
			-51
		],
		[
			-102,
			-83
		],
		[
			-30,
			-52
		],
		[
			0,
			-93
		],
		[
			30,
			-145
		],
		[
			96,
			10
		],
		[
			54,
			-72
		],
		[
			-12,
			-197
		],
		[
			66,
			-83
		],
		[
			36,
			0
		],
		[
			36,
			-145
		],
		[
			-6,
			-73
		],
		[
			-126,
			-31
		],
		[
			-48,
			-62
		],
		[
			-78,
			-10
		],
		[
			-6,
			-42
		],
		[
			-60,
			11
		],
		[
			-18,
			41
		],
		[
			-42,
			-10
		],
		[
			-54,
			-104
		],
		[
			-24,
			-82
		],
		[
			-55,
			-42
		],
		[
			-84,
			0
		],
		[
			-72,
			31
		],
		[
			-102,
			-10
		],
		[
			-48,
			-21
		],
		[
			36,
			-72
		],
		[
			-18,
			-31
		],
		[
			-114,
			62
		],
		[
			-49,
			-94
		],
		[
			-66,
			-31
		],
		[
			-24,
			-41
		],
		[
			-60,
			10
		],
		[
			-84,
			-124
		]
	],
	[
		[
			34596,
			18456
		],
		[
			-42,
			62
		],
		[
			-78,
			31
		],
		[
			-84,
			0
		],
		[
			-79,
			62
		],
		[
			-90,
			-31
		],
		[
			-24,
			83
		],
		[
			-48,
			-83
		],
		[
			-48,
			0
		],
		[
			-126,
			73
		],
		[
			-66,
			134
		],
		[
			-55,
			42
		],
		[
			6,
			52
		],
		[
			49,
			82
		],
		[
			-91,
			32
		],
		[
			-72,
			41
		],
		[
			-48,
			72
		],
		[
			-60,
			32
		],
		[
			-30,
			62
		],
		[
			-66,
			-11
		],
		[
			-24,
			83
		],
		[
			-54,
			93
		],
		[
			-48,
			0
		],
		[
			-25,
			42
		],
		[
			-66,
			-11
		],
		[
			-30,
			63
		],
		[
			-78,
			-11
		],
		[
			-18,
			-62
		],
		[
			-72,
			0
		],
		[
			-42,
			-62
		],
		[
			-48,
			-10
		],
		[
			-42,
			-42
		],
		[
			-36,
			11
		],
		[
			-49,
			-52
		],
		[
			-66,
			-31
		],
		[
			-108,
			0
		],
		[
			-18,
			176
		],
		[
			-30,
			31
		],
		[
			-108,
			-42
		],
		[
			-48,
			31
		],
		[
			-6,
			104
		],
		[
			-24,
			73
		],
		[
			-48,
			41
		],
		[
			-25,
			72
		],
		[
			-60,
			21
		],
		[
			-36,
			83
		],
		[
			-54,
			31
		],
		[
			-90,
			104
		]
	],
	[
		[
			32191,
			19927
		],
		[
			-12,
			62
		],
		[
			-84,
			134
		],
		[
			-18,
			94
		],
		[
			-72,
			83
		],
		[
			78,
			165
		],
		[
			-42,
			73
		],
		[
			12,
			31
		],
		[
			-151,
			145
		],
		[
			-24,
			93
		],
		[
			-24,
			21
		],
		[
			36,
			93
		],
		[
			-18,
			135
		],
		[
			97,
			20
		],
		[
			0,
			114
		],
		[
			-67,
			52
		],
		[
			-66,
			21
		],
		[
			-48,
			-11
		],
		[
			-24,
			63
		],
		[
			30,
			72
		],
		[
			120,
			10
		],
		[
			121,
			52
		],
		[
			126,
			104
		],
		[
			-12,
			41
		],
		[
			-60,
			31
		]
	],
	[
		[
			32089,
			21625
		],
		[
			-54,
			-72
		],
		[
			-103,
			31
		],
		[
			-60,
			41
		],
		[
			60,
			93
		],
		[
			91,
			73
		],
		[
			6,
			83
		],
		[
			-30,
			124
		],
		[
			36,
			10
		],
		[
			102,
			94
		],
		[
			48,
			217
		],
		[
			54,
			-10
		],
		[
			84,
			31
		],
		[
			-18,
			103
		],
		[
			66,
			63
		],
		[
			54,
			10
		],
		[
			121,
			62
		],
		[
			54,
			-31
		],
		[
			168,
			10
		]
	],
	[
		[
			32768,
			22557
		],
		[
			12,
			52
		],
		[
			60,
			42
		]
	],
	[
		[
			32840,
			22651
		],
		[
			-48,
			20
		],
		[
			-60,
			-10
		],
		[
			-126,
			10
		]
	],
	[
		[
			32606,
			22671
		],
		[
			-66,
			21
		]
	],
	[
		[
			32540,
			22692
		],
		[
			-18,
			114
		],
		[
			48,
			103
		],
		[
			-12,
			94
		],
		[
			12,
			103
		],
		[
			24,
			42
		],
		[
			66,
			-11
		],
		[
			78,
			52
		],
		[
			60,
			62
		],
		[
			42,
			125
		]
	],
	[
		[
			32840,
			23376
		],
		[
			109,
			20
		],
		[
			6,
			62
		],
		[
			36,
			83
		],
		[
			78,
			21
		],
		[
			-30,
			72
		],
		[
			42,
			94
		],
		[
			114,
			-62
		],
		[
			36,
			0
		]
	],
	[
		[
			33231,
			23666
		],
		[
			18,
			62
		],
		[
			114,
			20
		],
		[
			49,
			63
		],
		[
			84,
			-32
		],
		[
			144,
			-10
		],
		[
			42,
			-62
		],
		[
			6,
			-73
		],
		[
			60,
			-31
		],
		[
			30,
			-72
		],
		[
			-18,
			-62
		],
		[
			120,
			-11
		],
		[
			43,
			21
		],
		[
			138,
			-10
		],
		[
			30,
			-156
		],
		[
			-60,
			-72
		],
		[
			-42,
			21
		],
		[
			-42,
			-52
		],
		[
			102,
			-52
		]
	],
	[
		[
			35949,
			27881
		],
		[
			222,
			-145
		],
		[
			36,
			-156
		],
		[
			-54,
			-10
		],
		[
			18,
			-103
		],
		[
			54,
			0
		],
		[
			6,
			-52
		],
		[
			73,
			-62
		],
		[
			30,
			-52
		],
		[
			108,
			-73
		],
		[
			6,
			-41
		],
		[
			48,
			-31
		],
		[
			30,
			-52
		]
	],
	[
		[
			36526,
			27104
		],
		[
			24,
			-41
		]
	],
	[
		[
			36550,
			27063
		],
		[
			-18,
			-73
		]
	],
	[
		[
			36532,
			26990
		],
		[
			-84,
			-31
		],
		[
			-36,
			31
		],
		[
			-96,
			-21
		],
		[
			-85,
			21
		],
		[
			-48,
			73
		],
		[
			-30,
			-156
		],
		[
			-114,
			-186
		],
		[
			-24,
			-93
		],
		[
			18,
			-114
		],
		[
			-36,
			-21
		],
		[
			-12,
			-83
		],
		[
			-54,
			-83
		],
		[
			18,
			-165
		],
		[
			-24,
			-104
		],
		[
			-96,
			-62
		],
		[
			18,
			-83
		],
		[
			-61,
			-31
		],
		[
			-114,
			83
		],
		[
			-48,
			-21
		],
		[
			-114,
			62
		],
		[
			-48,
			11
		],
		[
			-54,
			82
		],
		[
			-115,
			104
		],
		[
			-90,
			31
		],
		[
			-6,
			52
		],
		[
			-48,
			21
		],
		[
			-6,
			103
		],
		[
			-156,
			104
		],
		[
			-36,
			10
		],
		[
			-48,
			62
		],
		[
			-36,
			-10
		],
		[
			-31,
			52
		],
		[
			-84,
			82
		],
		[
			72,
			11
		],
		[
			79,
			134
		],
		[
			-151,
			11
		],
		[
			-24,
			52
		],
		[
			-96,
			41
		],
		[
			-78,
			10
		],
		[
			-54,
			187
		],
		[
			36,
			52
		],
		[
			-12,
			41
		],
		[
			114,
			62
		],
		[
			48,
			-72
		],
		[
			36,
			31
		],
		[
			6,
			62
		],
		[
			36,
			72
		],
		[
			36,
			-10
		],
		[
			97,
			31
		],
		[
			24,
			52
		],
		[
			-6,
			124
		],
		[
			84,
			83
		],
		[
			42,
			0
		],
		[
			42,
			-62
		],
		[
			36,
			-10
		],
		[
			42,
			41
		],
		[
			114,
			-166
		],
		[
			42,
			93
		],
		[
			91,
			32
		],
		[
			42,
			-21
		],
		[
			24,
			41
		],
		[
			114,
			0
		],
		[
			-30,
			-124
		],
		[
			-36,
			-41
		]
	],
	[
		[
			35522,
			27467
		],
		[
			30,
			-32
		],
		[
			78,
			42
		],
		[
			78,
			-10
		],
		[
			6,
			31
		],
		[
			-30,
			165
		],
		[
			-36,
			73
		],
		[
			-6,
			103
		],
		[
			150,
			-10
		],
		[
			61,
			52
		],
		[
			42,
			-42
		],
		[
			54,
			42
		]
	],
	[
		[
			37308,
			30356
		],
		[
			48,
			-10
		],
		[
			36,
			-62
		],
		[
			24,
			-104
		]
	],
	[
		[
			37416,
			30180
		],
		[
			84,
			-10
		],
		[
			48,
			-52
		],
		[
			66,
			10
		],
		[
			-12,
			-165
		],
		[
			48,
			-280
		]
	],
	[
		[
			37650,
			29683
		],
		[
			72,
			-52
		]
	],
	[
		[
			37722,
			29631
		],
		[
			31,
			-21
		],
		[
			-24,
			-82
		],
		[
			36,
			-63
		],
		[
			36,
			31
		],
		[
			42,
			-20
		],
		[
			-12,
			-125
		],
		[
			42,
			-31
		],
		[
			-30,
			-62
		]
	],
	[
		[
			37843,
			29258
		],
		[
			42,
			-62
		],
		[
			-108,
			-62
		],
		[
			-18,
			31
		],
		[
			-73,
			-72
		],
		[
			-36,
			0
		],
		[
			-72,
			165
		],
		[
			-66,
			21
		],
		[
			-36,
			-41
		],
		[
			12,
			-63
		],
		[
			-54,
			-10
		],
		[
			-18,
			-93
		],
		[
			-54,
			-21
		],
		[
			-18,
			-41
		],
		[
			-97,
			31
		],
		[
			-24,
			124
		],
		[
			-78,
			93
		],
		[
			-18,
			62
		]
	],
	[
		[
			37127,
			29320
		],
		[
			-6,
			156
		],
		[
			-24,
			72
		],
		[
			18,
			52
		],
		[
			-6,
			0
		],
		[
			60,
			114
		],
		[
			-24,
			135
		],
		[
			-60,
			72
		],
		[
			-48,
			187
		],
		[
			-30,
			0
		],
		[
			-36,
			93
		],
		[
			84,
			52
		],
		[
			48,
			62
		],
		[
			84,
			10
		],
		[
			18,
			52
		],
		[
			103,
			-21
		]
	],
	[
		[
			36652,
			14707
		],
		[
			66,
			-62
		],
		[
			24,
			-62
		],
		[
			-18,
			-52
		],
		[
			-54,
			-42
		],
		[
			42,
			-83
		],
		[
			-60,
			-10
		],
		[
			-18,
			-103
		],
		[
			42,
			-114
		],
		[
			-54,
			-94
		],
		[
			-48,
			21
		],
		[
			-12,
			-72
		],
		[
			-72,
			0
		],
		[
			-60,
			-52
		],
		[
			126,
			-93
		],
		[
			84,
			-42
		],
		[
			42,
			-114
		]
	],
	[
		[
			36682,
			13733
		],
		[
			-60,
			-41
		],
		[
			-66,
			-21
		],
		[
			-78,
			-52
		]
	],
	[
		[
			36478,
			13619
		],
		[
			-48,
			-41
		],
		[
			-90,
			0
		],
		[
			-121,
			-73
		],
		[
			-60,
			0
		],
		[
			-42,
			-62
		],
		[
			-30,
			11
		],
		[
			-42,
			93
		],
		[
			-78,
			-42
		],
		[
			-42,
			-41
		],
		[
			-12,
			-83
		],
		[
			-42,
			-10
		]
	],
	[
		[
			35871,
			13371
		],
		[
			-54,
			-11
		],
		[
			-97,
			-114
		],
		[
			-96,
			32
		],
		[
			-30,
			-32
		],
		[
			-72,
			11
		],
		[
			-60,
			72
		],
		[
			18,
			73
		]
	],
	[
		[
			35480,
			13402
		],
		[
			-48,
			0
		],
		[
			-48,
			31
		],
		[
			-79,
			0
		],
		[
			-78,
			52
		],
		[
			-96,
			41
		],
		[
			-30,
			-41
		],
		[
			-66,
			-42
		],
		[
			-66,
			-10
		],
		[
			-30,
			31
		],
		[
			-30,
			-52
		],
		[
			-97,
			-62
		],
		[
			-30,
			21
		],
		[
			-36,
			-42
		],
		[
			-54,
			31
		],
		[
			-30,
			83
		],
		[
			-138,
			83
		],
		[
			0,
			42
		],
		[
			-60,
			41
		],
		[
			-127,
			62
		]
	],
	[
		[
			34337,
			13671
		],
		[
			49,
			114
		],
		[
			-85,
			62
		],
		[
			67,
			145
		],
		[
			-25,
			52
		],
		[
			0,
			207
		],
		[
			31,
			0
		],
		[
			54,
			-166
		],
		[
			60,
			-10
		],
		[
			0,
			-41
		],
		[
			-48,
			-31
		],
		[
			48,
			-104
		],
		[
			102,
			21
		],
		[
			6,
			196
		],
		[
			42,
			83
		]
	],
	[
		[
			34638,
			14199
		],
		[
			66,
			0
		],
		[
			18,
			73
		]
	],
	[
		[
			34722,
			14272
		],
		[
			-6,
			0
		]
	],
	[
		[
			34716,
			14272
		],
		[
			0,
			10
		]
	],
	[
		[
			34716,
			14282
		],
		[
			0,
			-10
		]
	],
	[
		[
			34722,
			14272
		],
		[
			72,
			31
		]
	],
	[
		[
			34794,
			14303
		],
		[
			67,
			31
		],
		[
			6,
			52
		],
		[
			66,
			-11
		],
		[
			12,
			42
		]
	],
	[
		[
			34945,
			14417
		],
		[
			48,
			31
		],
		[
			66,
			-21
		],
		[
			18,
			52
		]
	],
	[
		[
			35077,
			14479
		],
		[
			42,
			62
		],
		[
			84,
			-21
		],
		[
			48,
			31
		],
		[
			66,
			197
		],
		[
			85,
			-41
		]
	],
	[
		[
			35402,
			14707
		],
		[
			18,
			-42
		],
		[
			78,
			52
		],
		[
			24,
			-114
		],
		[
			54,
			42
		],
		[
			48,
			-52
		],
		[
			168,
			21
		],
		[
			-6,
			41
		],
		[
			139,
			10
		],
		[
			54,
			21
		],
		[
			48,
			52
		],
		[
			144,
			10
		],
		[
			60,
			42
		],
		[
			54,
			-11
		],
		[
			91,
			31
		],
		[
			102,
			-41
		],
		[
			60,
			-62
		],
		[
			0,
			-52
		],
		[
			114,
			52
		]
	],
	[
		[
			34945,
			14417
		],
		[
			-72,
			10
		],
		[
			-133,
			52
		],
		[
			-42,
			52
		],
		[
			24,
			62
		],
		[
			-48,
			62
		],
		[
			18,
			31
		],
		[
			0,
			93
		],
		[
			-24,
			52
		],
		[
			30,
			52
		],
		[
			42,
			10
		],
		[
			-36,
			83
		],
		[
			-12,
			93
		],
		[
			-72,
			31
		],
		[
			-30,
			73
		],
		[
			-66,
			83
		],
		[
			-30,
			-52
		],
		[
			-72,
			-10
		],
		[
			-61,
			62
		]
	],
	[
		[
			34361,
			15256
		],
		[
			-72,
			72
		],
		[
			-78,
			52
		]
	],
	[
		[
			34211,
			15380
		],
		[
			150,
			-124
		]
	],
	[
		[
			34361,
			15256
		],
		[
			-36,
			72
		],
		[
			-66,
			31
		],
		[
			-30,
			104
		],
		[
			90,
			93
		],
		[
			145,
			238
		]
	],
	[
		[
			34464,
			15794
		],
		[
			54,
			-62
		],
		[
			-6,
			-62
		],
		[
			78,
			-93
		],
		[
			-18,
			-52
		],
		[
			42,
			-31
		],
		[
			54,
			0
		],
		[
			96,
			31
		],
		[
			54,
			-21
		],
		[
			181,
			42
		],
		[
			-30,
			-42
		],
		[
			-12,
			-114
		],
		[
			108,
			-10
		],
		[
			78,
			-72
		],
		[
			78,
			10
		],
		[
			72,
			31
		],
		[
			37,
			-41
		],
		[
			72,
			-21
		],
		[
			-36,
			-52
		],
		[
			36,
			-93
		],
		[
			0,
			-93
		],
		[
			-48,
			-73
		],
		[
			6,
			-31
		],
		[
			-49,
			-93
		],
		[
			0,
			-73
		],
		[
			31,
			-41
		],
		[
			60,
			-31
		]
	],
	[
		[
			34337,
			13671
		],
		[
			-126,
			-21
		],
		[
			-108,
			31
		],
		[
			-102,
			0
		],
		[
			-18,
			42
		],
		[
			-48,
			-10
		]
	],
	[
		[
			33935,
			13713
		],
		[
			-271,
			41
		],
		[
			-36,
			-10
		],
		[
			0,
			-73
		],
		[
			42,
			-10
		],
		[
			6,
			-156
		],
		[
			-313,
			-10
		],
		[
			-24,
			21
		],
		[
			-54,
			-21
		],
		[
			-60,
			52
		],
		[
			-54,
			-135
		],
		[
			-120,
			31
		],
		[
			-90,
			73
		],
		[
			-163,
			31
		],
		[
			-12,
			-73
		],
		[
			-60,
			-20
		],
		[
			-108,
			51
		]
	],
	[
		[
			32618,
			13505
		],
		[
			24,
			73
		]
	],
	[
		[
			32642,
			13578
		],
		[
			24,
			41
		],
		[
			-42,
			52
		],
		[
			54,
			269
		],
		[
			-54,
			104
		],
		[
			60,
			31
		],
		[
			72,
			10
		],
		[
			42,
			114
		],
		[
			-6,
			73
		],
		[
			-60,
			52
		],
		[
			48,
			41
		],
		[
			54,
			0
		],
		[
			109,
			52
		],
		[
			30,
			-31
		],
		[
			108,
			10
		],
		[
			102,
			104
		],
		[
			42,
			83
		],
		[
			54,
			155
		],
		[
			66,
			41
		],
		[
			30,
			73
		],
		[
			67,
			103
		],
		[
			120,
			104
		],
		[
			36,
			10
		],
		[
			36,
			62
		],
		[
			96,
			104
		],
		[
			126,
			41
		],
		[
			37,
			52
		],
		[
			60,
			11
		],
		[
			54,
			-31
		],
		[
			66,
			10
		],
		[
			138,
			62
		]
	],
	[
		[
			36105,
			16561
		],
		[
			-6,
			-83
		]
	],
	[
		[
			36099,
			16478
		],
		[
			-24,
			-62
		],
		[
			-12,
			-94
		],
		[
			36,
			-31
		],
		[
			114,
			11
		],
		[
			24,
			52
		],
		[
			205,
			-114
		],
		[
			66,
			20
		],
		[
			18,
			-31
		],
		[
			48,
			21
		],
		[
			96,
			10
		]
	],
	[
		[
			36670,
			16260
		],
		[
			18,
			-62
		],
		[
			54,
			-83
		],
		[
			37,
			0
		]
	],
	[
		[
			36779,
			16115
		],
		[
			48,
			-93
		],
		[
			-24,
			-83
		]
	],
	[
		[
			36803,
			15939
		],
		[
			0,
			-93
		],
		[
			36,
			-72
		],
		[
			-24,
			-52
		],
		[
			66,
			-104
		],
		[
			-6,
			-31
		],
		[
			-139,
			-52
		],
		[
			-96,
			-62
		],
		[
			-6,
			-31
		],
		[
			-84,
			-31
		],
		[
			-54,
			-52
		],
		[
			60,
			-93
		],
		[
			42,
			-21
		],
		[
			72,
			11
		]
	],
	[
		[
			36670,
			15256
		],
		[
			12,
			-83
		],
		[
			-30,
			-104
		],
		[
			-6,
			-83
		],
		[
			42,
			-31
		],
		[
			-6,
			-82
		],
		[
			-30,
			-166
		]
	],
	[
		[
			34464,
			15794
		],
		[
			30,
			83
		],
		[
			24,
			197
		],
		[
			42,
			10
		],
		[
			84,
			114
		],
		[
			84,
			176
		],
		[
			133,
			83
		],
		[
			78,
			83
		],
		[
			60,
			93
		],
		[
			66,
			207
		],
		[
			90,
			135
		],
		[
			108,
			72
		]
	],
	[
		[
			35263,
			17047
		],
		[
			145,
			-82
		],
		[
			108,
			-52
		],
		[
			-12,
			-104
		],
		[
			42,
			-62
		],
		[
			72,
			10
		],
		[
			78,
			63
		],
		[
			84,
			-31
		],
		[
			79,
			0
		],
		[
			84,
			-63
		],
		[
			60,
			-20
		],
		[
			48,
			51
		],
		[
			12,
			-93
		],
		[
			42,
			-103
		]
	],
	[
		[
			26094,
			4516
		],
		[
			0,
			145
		],
		[
			-54,
			82
		],
		[
			-36,
			-72
		],
		[
			-90,
			21
		],
		[
			-18,
			-42
		],
		[
			-84,
			52
		],
		[
			-54,
			-10
		],
		[
			-24,
			145
		],
		[
			-37,
			103
		],
		[
			-66,
			42
		],
		[
			6,
			72
		],
		[
			48,
			166
		],
		[
			18,
			31
		],
		[
			85,
			-21
		]
	],
	[
		[
			25788,
			5230
		],
		[
			36,
			0
		],
		[
			36,
			52
		]
	],
	[
		[
			25860,
			5282
		],
		[
			42,
			52
		],
		[
			54,
			-21
		],
		[
			126,
			42
		],
		[
			12,
			51
		],
		[
			54,
			31
		],
		[
			42,
			-51
		],
		[
			0,
			-83
		],
		[
			43,
			0
		],
		[
			96,
			-52
		],
		[
			66,
			-218
		],
		[
			180,
			0
		],
		[
			60,
			-82
		],
		[
			49,
			-11
		],
		[
			-19,
			-103
		],
		[
			-60,
			-31
		],
		[
			-90,
			0
		],
		[
			-30,
			-83
		],
		[
			30,
			-93
		],
		[
			-90,
			-32
		],
		[
			-78,
			-51
		],
		[
			-66,
			-73
		],
		[
			-97,
			31
		],
		[
			-90,
			11
		]
	],
	[
		[
			29636,
			6121
		],
		[
			-18,
			-93
		],
		[
			-6,
			-166
		],
		[
			12,
			-93
		],
		[
			60,
			-21
		],
		[
			6,
			-52
		],
		[
			72,
			-83
		],
		[
			-12,
			-41
		],
		[
			-84,
			10
		],
		[
			-54,
			-51
		],
		[
			-30,
			0
		],
		[
			-31,
			62
		],
		[
			-66,
			20
		],
		[
			-66,
			-103
		],
		[
			-24,
			0
		],
		[
			-36,
			-93
		],
		[
			-12,
			-197
		],
		[
			36,
			-145
		],
		[
			42,
			-31
		],
		[
			54,
			21
		],
		[
			103,
			-11
		],
		[
			36,
			-52
		],
		[
			72,
			31
		],
		[
			72,
			-31
		],
		[
			-30,
			-62
		],
		[
			-60,
			-20
		],
		[
			-18,
			-94
		],
		[
			-6,
			0
		]
	],
	[
		[
			29648,
			4826
		],
		[
			-97,
			-20
		],
		[
			-30,
			10
		],
		[
			-84,
			-41
		],
		[
			-78,
			51
		],
		[
			-42,
			125
		],
		[
			-42,
			20
		],
		[
			-54,
			156
		],
		[
			-102,
			-21
		],
		[
			-73,
			41
		],
		[
			-30,
			94
		],
		[
			-66,
			20
		],
		[
			18,
			145
		],
		[
			72,
			52
		],
		[
			121,
			21
		],
		[
			30,
			31
		],
		[
			-24,
			93
		],
		[
			48,
			62
		],
		[
			-12,
			83
		]
	],
	[
		[
			29203,
			5748
		],
		[
			90,
			124
		],
		[
			48,
			42
		],
		[
			96,
			21
		],
		[
			42,
			82
		],
		[
			97,
			52
		],
		[
			-6,
			62
		],
		[
			66,
			-10
		]
	],
	[
		[
			39081,
			8441
		],
		[
			54,
			10
		],
		[
			73,
			83
		],
		[
			54,
			-83
		],
		[
			60,
			-62
		],
		[
			78,
			0
		],
		[
			18,
			-135
		],
		[
			54,
			-20
		]
	],
	[
		[
			39472,
			8234
		],
		[
			12,
			0
		]
	],
	[
		[
			39484,
			8234
		],
		[
			0,
			-11
		]
	],
	[
		[
			39484,
			8223
		],
		[
			18,
			-10
		]
	],
	[
		[
			39502,
			8213
		],
		[
			12,
			0
		]
	],
	[
		[
			39514,
			8213
		],
		[
			12,
			0
		]
	],
	[
		[
			39526,
			8213
		],
		[
			18,
			-21
		]
	],
	[
		[
			39544,
			8192
		],
		[
			12,
			-41
		]
	],
	[
		[
			39556,
			8151
		],
		[
			-18,
			-10
		]
	],
	[
		[
			39538,
			8141
		],
		[
			12,
			-11
		]
	],
	[
		[
			39550,
			8130
		],
		[
			48,
			0
		]
	],
	[
		[
			39598,
			8130
		],
		[
			48,
			0
		]
	],
	[
		[
			39646,
			8130
		],
		[
			43,
			-31
		],
		[
			30,
			-83
		],
		[
			114,
			0
		],
		[
			6,
			31
		]
	],
	[
		[
			39839,
			8047
		],
		[
			6,
			0
		]
	],
	[
		[
			39845,
			8047
		],
		[
			-42,
			-93
		],
		[
			-120,
			52
		],
		[
			-199,
			31
		],
		[
			-216,
			0
		],
		[
			-163,
			-31
		],
		[
			-108,
			-31
		],
		[
			-72,
			-42
		]
	],
	[
		[
			38925,
			7933
		],
		[
			-42,
			63
		],
		[
			12,
			82
		],
		[
			72,
			176
		],
		[
			-144,
			42
		],
		[
			-102,
			83
		],
		[
			54,
			72
		],
		[
			36,
			104
		]
	],
	[
		[
			38811,
			8555
		],
		[
			6,
			-11
		]
	],
	[
		[
			38817,
			8544
		],
		[
			24,
			-10
		],
		[
			96,
			52
		]
	],
	[
		[
			38937,
			8586
		],
		[
			48,
			0
		],
		[
			18,
			-52
		],
		[
			54,
			-31
		],
		[
			24,
			-62
		]
	],
	[
		[
			38811,
			8555
		],
		[
			6,
			-11
		]
	],
	[
		[
			38925,
			7933
		],
		[
			-84,
			-51
		],
		[
			-96,
			-104
		],
		[
			-18,
			73
		],
		[
			-73,
			62
		],
		[
			-36,
			10
		],
		[
			-72,
			62
		],
		[
			-36,
			-41
		],
		[
			-120,
			31
		],
		[
			6,
			186
		],
		[
			-90,
			21
		],
		[
			24,
			-166
		],
		[
			60,
			0
		],
		[
			-18,
			-103
		],
		[
			-96,
			31
		],
		[
			-133,
			62
		],
		[
			-24,
			31
		]
	],
	[
		[
			38119,
			8037
		],
		[
			78,
			83
		]
	],
	[
		[
			38197,
			8120
		],
		[
			25,
			72
		],
		[
			54,
			0
		],
		[
			0,
			104
		]
	],
	[
		[
			38276,
			8296
		],
		[
			24,
			331
		],
		[
			48,
			21
		],
		[
			18,
			73
		],
		[
			54,
			-21
		],
		[
			108,
			21
		],
		[
			66,
			-32
		],
		[
			42,
			11
		],
		[
			55,
			72
		],
		[
			36,
			-41
		],
		[
			-12,
			-104
		],
		[
			24,
			-31
		],
		[
			72,
			42
		],
		[
			0,
			-83
		]
	],
	[
		[
			40182,
			17172
		],
		[
			-79,
			-73
		],
		[
			-18,
			-114
		],
		[
			49,
			-51
		],
		[
			12,
			-73
		],
		[
			84,
			-155
		],
		[
			60,
			0
		],
		[
			24,
			-62
		],
		[
			-72,
			-104
		],
		[
			30,
			-62
		],
		[
			-60,
			-31
		]
	],
	[
		[
			40212,
			16447
		],
		[
			-72,
			-73
		],
		[
			12,
			-72
		]
	],
	[
		[
			40152,
			16302
		],
		[
			18,
			-93
		]
	],
	[
		[
			40170,
			16209
		],
		[
			-24,
			-21
		],
		[
			30,
			-124
		],
		[
			42,
			-32
		],
		[
			126,
			73
		],
		[
			42,
			-52
		],
		[
			24,
			-72
		],
		[
			114,
			-187
		],
		[
			48,
			-52
		],
		[
			73,
			-186
		]
	],
	[
		[
			40645,
			15556
		],
		[
			-73,
			-10
		],
		[
			-48,
			-31
		],
		[
			-30,
			31
		],
		[
			-120,
			-83
		],
		[
			-102,
			-31
		],
		[
			-301,
			-42
		],
		[
			24,
			-124
		],
		[
			-66,
			10
		],
		[
			-114,
			-31
		],
		[
			-217,
			0
		],
		[
			-78,
			-10
		],
		[
			-90,
			114
		],
		[
			0,
			93
		],
		[
			-108,
			-52
		],
		[
			-30,
			0
		],
		[
			-30,
			166
		],
		[
			72,
			-31
		],
		[
			-54,
			104
		],
		[
			-30,
			155
		],
		[
			-54,
			72
		],
		[
			24,
			31
		],
		[
			-73,
			63
		],
		[
			12,
			31
		],
		[
			85,
			-21
		],
		[
			12,
			166
		],
		[
			72,
			20
		],
		[
			-6,
			145
		],
		[
			-48,
			31
		]
	],
	[
		[
			39274,
			16322
		],
		[
			-6,
			63
		]
	],
	[
		[
			39268,
			16385
		],
		[
			-6,
			51
		],
		[
			54,
			83
		]
	],
	[
		[
			39316,
			16519
		],
		[
			72,
			62
		],
		[
			36,
			-31
		],
		[
			48,
			83
		],
		[
			102,
			0
		],
		[
			-12,
			83
		],
		[
			-48,
			197
		],
		[
			60,
			41
		]
	],
	[
		[
			39574,
			16954
		],
		[
			36,
			21
		],
		[
			67,
			-10
		],
		[
			24,
			-52
		],
		[
			102,
			0
		],
		[
			48,
			41
		],
		[
			72,
			0
		],
		[
			84,
			42
		],
		[
			54,
			134
		],
		[
			42,
			62
		],
		[
			79,
			-20
		]
	],
	[
		[
			49717,
			26317
		],
		[
			37,
			-269
		],
		[
			54,
			-321
		],
		[
			18,
			-42
		]
	],
	[
		[
			49826,
			25685
		],
		[
			-66,
			-21
		]
	],
	[
		[
			49760,
			25664
		],
		[
			-25,
			0
		],
		[
			-306,
			-82
		]
	],
	[
		[
			49429,
			25582
		],
		[
			-30,
			0
		],
		[
			-217,
			-63
		]
	],
	[
		[
			49182,
			25519
		],
		[
			-240,
			-62
		],
		[
			-120,
			-10
		],
		[
			-24,
			-176
		],
		[
			18,
			-83
		]
	],
	[
		[
			48816,
			25188
		],
		[
			-49,
			31
		],
		[
			-96,
			-21
		],
		[
			-30,
			-41
		],
		[
			-30,
			41
		],
		[
			-66,
			11
		],
		[
			-6,
			-62
		]
	],
	[
		[
			48539,
			25147
		],
		[
			24,
			-21
		],
		[
			-66,
			-93
		],
		[
			-156,
			-42
		],
		[
			-24,
			-83
		],
		[
			-67,
			-51
		],
		[
			-48,
			51
		],
		[
			-222,
			332
		],
		[
			-90,
			165
		],
		[
			-79,
			0
		],
		[
			-36,
			-20
		],
		[
			-30,
			41
		],
		[
			-72,
			0
		],
		[
			-12,
			83
		],
		[
			-54,
			73
		],
		[
			-42,
			0
		],
		[
			-66,
			-42
		]
	],
	[
		[
			47499,
			25540
		],
		[
			-54,
			31
		],
		[
			-133,
			-31
		],
		[
			-78,
			-31
		],
		[
			-102,
			-21
		],
		[
			-36,
			62
		],
		[
			-72,
			63
		],
		[
			42,
			41
		],
		[
			30,
			104
		],
		[
			24,
			10
		],
		[
			12,
			104
		],
		[
			48,
			41
		],
		[
			0,
			52
		],
		[
			-36,
			62
		],
		[
			-78,
			41
		],
		[
			-24,
			52
		]
	],
	[
		[
			47042,
			26120
		],
		[
			108,
			83
		],
		[
			114,
			10
		],
		[
			18,
			42
		],
		[
			121,
			-62
		],
		[
			66,
			-11
		],
		[
			120,
			21
		],
		[
			24,
			41
		],
		[
			48,
			11
		],
		[
			6,
			0
		],
		[
			18,
			10
		]
	],
	[
		[
			47685,
			26265
		],
		[
			60,
			10
		],
		[
			30,
			32
		],
		[
			67,
			-11
		],
		[
			114,
			93
		],
		[
			0,
			52
		],
		[
			90,
			11
		],
		[
			156,
			-63
		],
		[
			30,
			11
		],
		[
			54,
			-42
		],
		[
			37,
			-62
		],
		[
			66,
			-72
		],
		[
			72,
			51
		],
		[
			144,
			83
		],
		[
			66,
			11
		]
	],
	[
		[
			48671,
			26369
		],
		[
			36,
			10
		],
		[
			54,
			-114
		],
		[
			37,
			-31
		],
		[
			60,
			73
		],
		[
			228,
			-83
		],
		[
			60,
			72
		],
		[
			163,
			124
		],
		[
			84,
			-51
		],
		[
			78,
			51
		],
		[
			90,
			21
		],
		[
			156,
			-124
		]
	],
	[
		[
			47673,
			19295
		],
		[
			66,
			-197
		],
		[
			54,
			0
		],
		[
			61,
			-93
		],
		[
			18,
			-83
		],
		[
			-24,
			-21
		]
	],
	[
		[
			47848,
			18901
		],
		[
			-43,
			0
		],
		[
			-42,
			-51
		],
		[
			-114,
			31
		],
		[
			-132,
			-83
		],
		[
			-60,
			-83
		],
		[
			-151,
			228
		],
		[
			-102,
			93
		],
		[
			-102,
			0
		],
		[
			0,
			31
		],
		[
			-126,
			83
		],
		[
			72,
			52
		],
		[
			66,
			20
		],
		[
			24,
			83
		],
		[
			-24,
			52
		],
		[
			66,
			21
		],
		[
			120,
			0
		],
		[
			73,
			31
		],
		[
			90,
			-21
		],
		[
			18,
			-124
		],
		[
			96,
			-21
		],
		[
			48,
			52
		],
		[
			48,
			0
		]
	],
	[
		[
			53517,
			15680
		],
		[
			-12,
			42
		]
	],
	[
		[
			53505,
			15722
		],
		[
			48,
			20
		]
	],
	[
		[
			53553,
			15742
		],
		[
			-36,
			-62
		]
	],
	[
		[
			54642,
			15763
		],
		[
			-72,
			-52
		],
		[
			-127,
			-124
		],
		[
			-60,
			11
		],
		[
			-150,
			62
		],
		[
			-108,
			0
		],
		[
			-67,
			31
		],
		[
			-102,
			0
		],
		[
			-186,
			51
		],
		[
			-72,
			0
		],
		[
			-54,
			21
		],
		[
			-91,
			-21
		]
	],
	[
		[
			53553,
			15742
		],
		[
			-36,
			0
		]
	],
	[
		[
			53517,
			15742
		],
		[
			-6,
			145
		],
		[
			54,
			63
		],
		[
			-18,
			93
		]
	],
	[
		[
			53547,
			16043
		],
		[
			43,
			62
		],
		[
			24,
			-21
		],
		[
			96,
			-20
		],
		[
			90,
			0
		],
		[
			48,
			-42
		],
		[
			114,
			-10
		],
		[
			84,
			-62
		],
		[
			175,
			-11
		],
		[
			24,
			-41
		],
		[
			132,
			-31
		],
		[
			66,
			10
		],
		[
			12,
			-93
		],
		[
			127,
			-31
		],
		[
			24,
			41
		],
		[
			36,
			-31
		]
	],
	[
		[
			52838,
			15711
		],
		[
			24,
			-31
		]
	],
	[
		[
			52862,
			15680
		],
		[
			-30,
			-10
		]
	],
	[
		[
			52832,
			15670
		],
		[
			6,
			41
		]
	],
	[
		[
			52766,
			15742
		],
		[
			54,
			0
		]
	],
	[
		[
			52820,
			15742
		],
		[
			6,
			-10
		]
	],
	[
		[
			52826,
			15732
		],
		[
			6,
			-62
		]
	],
	[
		[
			52832,
			15670
		],
		[
			66,
			-52
		],
		[
			6,
			-145
		],
		[
			-72,
			-41
		],
		[
			-289,
			0
		],
		[
			-60,
			-52
		],
		[
			-30,
			-52
		],
		[
			-30,
			-238
		],
		[
			-18,
			-72
		],
		[
			-102,
			-52
		],
		[
			-217,
			-42
		],
		[
			-186,
			0
		],
		[
			-36,
			11
		],
		[
			-36,
			103
		],
		[
			-66,
			83
		],
		[
			-78,
			21
		],
		[
			-67,
			-21
		],
		[
			-96,
			-103
		],
		[
			-198,
			103
		],
		[
			-120,
			124
		],
		[
			-91,
			42
		]
	],
	[
		[
			51112,
			15287
		],
		[
			30,
			62
		],
		[
			85,
			21
		],
		[
			-18,
			72
		],
		[
			84,
			11
		],
		[
			0,
			51
		],
		[
			30,
			125
		],
		[
			42,
			-83
		],
		[
			54,
			0
		],
		[
			12,
			134
		],
		[
			186,
			31
		],
		[
			18,
			31
		],
		[
			193,
			42
		],
		[
			-54,
			93
		],
		[
			-54,
			52
		],
		[
			-12,
			72
		]
	],
	[
		[
			51708,
			16001
		],
		[
			174,
			21
		],
		[
			228,
			-21
		]
	],
	[
		[
			52110,
			16001
		],
		[
			49,
			11
		],
		[
			12,
			-93
		],
		[
			138,
			0
		],
		[
			42,
			-83
		],
		[
			30,
			-21
		],
		[
			78,
			0
		],
		[
			18,
			41
		],
		[
			84,
			31
		],
		[
			36,
			-62
		],
		[
			73,
			11
		],
		[
			60,
			-42
		],
		[
			36,
			-52
		]
	],
	[
		[
			53439,
			14438
		],
		[
			-54,
			-63
		],
		[
			-42,
			31
		],
		[
			18,
			52
		],
		[
			78,
			-20
		]
	],
	[
		[
			53457,
			14500
		],
		[
			-12,
			-11
		]
	],
	[
		[
			53445,
			14489
		],
		[
			0,
			11
		]
	],
	[
		[
			53445,
			14500
		],
		[
			12,
			0
		]
	],
	[
		[
			53445,
			14489
		],
		[
			-30,
			11
		]
	],
	[
		[
			53415,
			14500
		],
		[
			30,
			-11
		]
	],
	[
		[
			53445,
			14500
		],
		[
			-30,
			0
		]
	],
	[
		[
			53415,
			14500
		],
		[
			42,
			0
		]
	],
	[
		[
			53457,
			14500
		],
		[
			-12,
			0
		]
	],
	[
		[
			53517,
			14199
		],
		[
			-18,
			-51
		],
		[
			66,
			-32
		],
		[
			-78,
			-155
		],
		[
			-114,
			-155
		]
	],
	[
		[
			53373,
			13806
		],
		[
			-42,
			0
		],
		[
			-108,
			41
		],
		[
			-72,
			11
		],
		[
			-49,
			-63
		],
		[
			-54,
			-20
		],
		[
			-42,
			20
		],
		[
			-30,
			52
		],
		[
			-42,
			-21
		]
	],
	[
		[
			52934,
			13826
		],
		[
			-36,
			42
		],
		[
			-78,
			31
		],
		[
			-66,
			93
		],
		[
			-217,
			145
		]
	],
	[
		[
			52537,
			14137
		],
		[
			60,
			52
		],
		[
			55,
			10
		],
		[
			90,
			52
		],
		[
			24,
			73
		],
		[
			48,
			51
		],
		[
			54,
			-82
		],
		[
			48,
			0
		],
		[
			18,
			103
		],
		[
			48,
			124
		],
		[
			84,
			-10
		],
		[
			24,
			-72
		],
		[
			97,
			-63
		],
		[
			72,
			-31
		],
		[
			30,
			11
		],
		[
			156,
			-125
		],
		[
			42,
			42
		],
		[
			30,
			-73
		]
	],
	[
		[
			52519,
			13878
		],
		[
			-132,
			42
		],
		[
			-24,
			20
		],
		[
			-114,
			11
		],
		[
			-36,
			41
		]
	],
	[
		[
			52213,
			13992
		],
		[
			132,
			218
		],
		[
			60,
			124
		],
		[
			78,
			0
		],
		[
			114,
			93
		],
		[
			43,
			73
		],
		[
			0,
			62
		],
		[
			84,
			21
		],
		[
			12,
			93
		],
		[
			-18,
			52
		],
		[
			18,
			72
		],
		[
			-18,
			41
		],
		[
			-66,
			32
		],
		[
			-67,
			72
		],
		[
			-36,
			10
		]
	],
	[
		[
			52549,
			14955
		],
		[
			-12,
			52
		],
		[
			30,
			145
		],
		[
			36,
			62
		],
		[
			73,
			42
		],
		[
			204,
			-21
		],
		[
			84,
			0
		],
		[
			72,
			21
		],
		[
			60,
			-21
		],
		[
			121,
			0
		],
		[
			24,
			-41
		],
		[
			42,
			41
		],
		[
			138,
			-52
		],
		[
			30,
			-41
		],
		[
			72,
			31
		],
		[
			103,
			10
		],
		[
			84,
			-10
		],
		[
			66,
			-52
		],
		[
			90,
			21
		],
		[
			90,
			-31
		],
		[
			108,
			-125
		],
		[
			13,
			-134
		],
		[
			-37,
			-62
		],
		[
			-102,
			-42
		],
		[
			-126,
			0
		],
		[
			-12,
			62
		],
		[
			-114,
			94
		],
		[
			-60,
			-52
		],
		[
			-73,
			10
		],
		[
			-36,
			-72
		],
		[
			-42,
			0
		],
		[
			-18,
			-52
		],
		[
			36,
			-83
		],
		[
			-90,
			-62
		],
		[
			-90,
			-21
		],
		[
			-72,
			21
		],
		[
			-84,
			-52
		],
		[
			-187,
			21
		],
		[
			-66,
			-166
		],
		[
			-12,
			-83
		],
		[
			-54,
			93
		],
		[
			-30,
			0
		],
		[
			-78,
			-72
		],
		[
			6,
			-52
		],
		[
			-145,
			-72
		],
		[
			-96,
			-83
		],
		[
			0,
			-166
		],
		[
			24,
			-83
		]
	],
	[
		[
			46044,
			14293
		],
		[
			-247,
			-135
		],
		[
			-126,
			-31
		],
		[
			-186,
			-280
		],
		[
			-60,
			-52
		]
	],
	[
		[
			45425,
			13795
		],
		[
			-49,
			42
		]
	],
	[
		[
			45376,
			13837
		],
		[
			-78,
			52
		],
		[
			-72,
			-11
		],
		[
			-30,
			52
		],
		[
			-132,
			62
		]
	],
	[
		[
			45064,
			13992
		],
		[
			60,
			104
		],
		[
			102,
			72
		],
		[
			120,
			0
		],
		[
			-78,
			352
		],
		[
			54,
			0
		],
		[
			-36,
			104
		],
		[
			6,
			52
		],
		[
			-12,
			145
		]
	],
	[
		[
			45280,
			14821
		],
		[
			0,
			41
		],
		[
			60,
			73
		],
		[
			30,
			72
		],
		[
			12,
			83
		],
		[
			73,
			-10
		],
		[
			30,
			-83
		],
		[
			66,
			31
		],
		[
			162,
			-62
		],
		[
			60,
			103
		],
		[
			48,
			11
		],
		[
			103,
			-11
		],
		[
			90,
			-83
		],
		[
			48,
			42
		],
		[
			42,
			-10
		],
		[
			-6,
			-114
		],
		[
			-24,
			-52
		],
		[
			120,
			-31
		],
		[
			66,
			10
		],
		[
			-42,
			-124
		],
		[
			36,
			-52
		],
		[
			0,
			-83
		],
		[
			-132,
			93
		],
		[
			-54,
			21
		],
		[
			-24,
			42
		],
		[
			-48,
			10
		],
		[
			-48,
			-93
		],
		[
			-36,
			-31
		],
		[
			-37,
			-73
		],
		[
			61,
			-72
		],
		[
			42,
			-94
		],
		[
			66,
			-82
		]
	],
	[
		[
			42815,
			15711
		],
		[
			48,
			21
		],
		[
			90,
			-10
		],
		[
			-12,
			-73
		],
		[
			85,
			11
		],
		[
			102,
			41
		],
		[
			66,
			0
		],
		[
			48,
			52
		],
		[
			72,
			31
		],
		[
			36,
			-93
		],
		[
			-48,
			-114
		]
	],
	[
		[
			43302,
			15577
		],
		[
			0,
			-42
		],
		[
			48,
			-51
		],
		[
			84,
			10
		],
		[
			60,
			-62
		],
		[
			37,
			-145
		],
		[
			78,
			-42
		],
		[
			174,
			63
		],
		[
			48,
			0
		],
		[
			48,
			-32
		],
		[
			30,
			-51
		],
		[
			6,
			-83
		]
	],
	[
		[
			43915,
			15142
		],
		[
			-96,
			-135
		],
		[
			36,
			-41
		],
		[
			0,
			-52
		],
		[
			72,
			21
		],
		[
			61,
			-83
		],
		[
			12,
			-73
		],
		[
			102,
			-20
		],
		[
			18,
			-73
		]
	],
	[
		[
			44120,
			14686
		],
		[
			6,
			-10
		]
	],
	[
		[
			44126,
			14676
		],
		[
			6,
			-125
		],
		[
			-78,
			-176
		],
		[
			114,
			-82
		],
		[
			60,
			-83
		],
		[
			-48,
			-114
		]
	],
	[
		[
			44180,
			14096
		],
		[
			24,
			-11
		]
	],
	[
		[
			44204,
			14085
		],
		[
			-24,
			11
		]
	],
	[
		[
			44180,
			14096
		],
		[
			-102,
			-42
		],
		[
			-241,
			-10
		],
		[
			-12,
			41
		],
		[
			-132,
			156
		],
		[
			-66,
			41
		],
		[
			-169,
			-83
		],
		[
			-12,
			-62
		],
		[
			12,
			-72
		],
		[
			-54,
			-21
		],
		[
			-114,
			-10
		],
		[
			-12,
			20
		],
		[
			-132,
			11
		],
		[
			-42,
			-31
		],
		[
			-66,
			62
		],
		[
			-97,
			31
		],
		[
			-90,
			10
		]
	],
	[
		[
			42851,
			14137
		],
		[
			-132,
			-10
		]
	],
	[
		[
			42719,
			14127
		],
		[
			-24,
			31
		]
	],
	[
		[
			42695,
			14158
		],
		[
			-18,
			10
		]
	],
	[
		[
			42677,
			14168
		],
		[
			-84,
			0
		],
		[
			-61,
			-41
		],
		[
			-66,
			10
		],
		[
			-36,
			31
		],
		[
			-90,
			0
		],
		[
			-18,
			21
		],
		[
			-72,
			-10
		],
		[
			-54,
			-31
		],
		[
			-265,
			-11
		],
		[
			-126,
			42
		],
		[
			-90,
			-21
		],
		[
			-30,
			-73
		],
		[
			-54,
			-62
		],
		[
			-73,
			-10
		],
		[
			0,
			-62
		],
		[
			85,
			-114
		]
	],
	[
		[
			41643,
			13837
		],
		[
			-121,
			-31
		],
		[
			-84,
			0
		],
		[
			-174,
			-42
		],
		[
			-18,
			11
		]
	],
	[
		[
			41246,
			13775
		],
		[
			72,
			176
		],
		[
			-78,
			72
		],
		[
			-18,
			125
		],
		[
			-84,
			93
		],
		[
			-36,
			0
		],
		[
			-67,
			52
		],
		[
			-66,
			82
		],
		[
			-54,
			21
		],
		[
			12,
			114
		],
		[
			-36,
			0
		],
		[
			-42,
			124
		],
		[
			84,
			0
		],
		[
			120,
			83
		],
		[
			49,
			114
		],
		[
			-6,
			83
		],
		[
			-55,
			52
		],
		[
			-84,
			41
		],
		[
			-12,
			52
		],
		[
			-48,
			31
		],
		[
			-12,
			73
		],
		[
			-30,
			0
		],
		[
			-24,
			93
		],
		[
			-36,
			20
		],
		[
			-54,
			125
		],
		[
			-12,
			103
		],
		[
			18,
			114
		]
	],
	[
		[
			40747,
			15618
		],
		[
			24,
			114
		],
		[
			66,
			52
		],
		[
			84,
			103
		],
		[
			72,
			-10
		],
		[
			66,
			-41
		],
		[
			85,
			31
		],
		[
			66,
			-52
		],
		[
			48,
			0
		],
		[
			60,
			-52
		],
		[
			0,
			-62
		],
		[
			54,
			-31
		],
		[
			78,
			-10
		],
		[
			6,
			62
		],
		[
			42,
			-11
		],
		[
			103,
			42
		],
		[
			60,
			52
		],
		[
			24,
			-83
		],
		[
			102,
			103
		],
		[
			54,
			-62
		],
		[
			78,
			0
		],
		[
			24,
			83
		],
		[
			60,
			31
		],
		[
			48,
			-62
		],
		[
			49,
			10
		],
		[
			42,
			-41
		],
		[
			60,
			166
		],
		[
			270,
			-83
		],
		[
			36,
			-52
		],
		[
			55,
			-10
		],
		[
			60,
			-73
		],
		[
			102,
			0
		],
		[
			90,
			-21
		]
	],
	[
		[
			44420,
			14997
		],
		[
			67,
			-52
		],
		[
			54,
			-83
		],
		[
			-24,
			-41
		],
		[
			-54,
			52
		],
		[
			-13,
			-156
		],
		[
			-78,
			-93
		],
		[
			-42,
			-73
		],
		[
			-36,
			-20
		],
		[
			-48,
			20
		],
		[
			-12,
			83
		],
		[
			-90,
			11
		],
		[
			-18,
			31
		]
	],
	[
		[
			44126,
			14676
		],
		[
			-6,
			10
		]
	],
	[
		[
			43915,
			15142
		],
		[
			133,
			-83
		],
		[
			36,
			72
		],
		[
			42,
			11
		],
		[
			12,
			83
		],
		[
			24,
			31
		],
		[
			66,
			-21
		],
		[
			48,
			21
		],
		[
			66,
			62
		],
		[
			30,
			0
		],
		[
			48,
			-62
		],
		[
			43,
			-114
		],
		[
			-37,
			-21
		],
		[
			-6,
			-124
		]
	],
	[
		[
			47072,
			15328
		],
		[
			-54,
			-52
		]
	],
	[
		[
			47018,
			15276
		],
		[
			-48,
			-176
		],
		[
			-12,
			-10
		]
	],
	[
		[
			46958,
			15090
		],
		[
			-84,
			21
		]
	],
	[
		[
			46874,
			15111
		],
		[
			0,
			72
		],
		[
			-61,
			73
		],
		[
			-114,
			41
		],
		[
			-36,
			52
		],
		[
			-24,
			-52
		],
		[
			-66,
			42
		],
		[
			-144,
			62
		],
		[
			-18,
			-42
		],
		[
			-133,
			62
		],
		[
			-42,
			-41
		],
		[
			-48,
			10
		]
	],
	[
		[
			46188,
			15390
		],
		[
			-60,
			-10
		],
		[
			-12,
			176
		],
		[
			-30,
			93
		],
		[
			48,
			11
		],
		[
			42,
			62
		],
		[
			114,
			20
		],
		[
			175,
			-134
		],
		[
			78,
			-10
		],
		[
			30,
			103
		],
		[
			48,
			-124
		],
		[
			-6,
			-93
		],
		[
			84,
			-21
		],
		[
			150,
			10
		],
		[
			13,
			-20
		],
		[
			-37,
			-135
		],
		[
			247,
			10
		]
	],
	[
		[
			45893,
			15970
		],
		[
			13,
			-51
		],
		[
			-6,
			-125
		],
		[
			-25,
			-41
		],
		[
			-30,
			-145
		],
		[
			0,
			-135
		],
		[
			91,
			-20
		],
		[
			48,
			-125
		],
		[
			72,
			-62
		],
		[
			84,
			-21
		],
		[
			60,
			42
		],
		[
			-12,
			103
		]
	],
	[
		[
			46874,
			15111
		],
		[
			-31,
			-21
		],
		[
			-66,
			-114
		],
		[
			78,
			-93
		],
		[
			-18,
			-31
		],
		[
			43,
			-83
		]
	],
	[
		[
			46880,
			14769
		],
		[
			-49,
			10
		],
		[
			-120,
			73
		],
		[
			-24,
			-21
		],
		[
			-66,
			83
		],
		[
			-120,
			-73
		],
		[
			-96,
			-103
		],
		[
			0,
			-135
		],
		[
			-73,
			-176
		],
		[
			-6,
			-62
		]
	],
	[
		[
			46326,
			14365
		],
		[
			-36,
			-93
		],
		[
			-90,
			52
		],
		[
			-36,
			-21
		],
		[
			-66,
			10
		],
		[
			-54,
			-20
		]
	],
	[
		[
			45280,
			14821
		],
		[
			-102,
			20
		],
		[
			-54,
			114
		],
		[
			-6,
			63
		],
		[
			36,
			103
		],
		[
			-42,
			145
		],
		[
			72,
			145
		],
		[
			-42,
			83
		],
		[
			-72,
			10
		],
		[
			-102,
			125
		],
		[
			42,
			62
		],
		[
			24,
			114
		]
	],
	[
		[
			45034,
			15805
		],
		[
			24,
			20
		],
		[
			54,
			-20
		],
		[
			24,
			51
		],
		[
			84,
			21
		],
		[
			90,
			-21
		],
		[
			72,
			52
		],
		[
			30,
			93
		],
		[
			115,
			-10
		],
		[
			168,
			114
		],
		[
			54,
			10
		],
		[
			36,
			-51
		],
		[
			6,
			-83
		],
		[
			102,
			-11
		]
	],
	[
		[
			45064,
			13992
		],
		[
			-163,
			11
		],
		[
			-78,
			-11
		],
		[
			-60,
			42
		],
		[
			-84,
			10
		],
		[
			-114,
			72
		],
		[
			-283,
			-51
		],
		[
			-78,
			0
		]
	],
	[
		[
			44204,
			14065
		],
		[
			0,
			20
		]
	],
	[
		[
			44420,
			14997
		],
		[
			97,
			62
		],
		[
			60,
			21
		],
		[
			66,
			134
		],
		[
			72,
			42
		],
		[
			24,
			93
		],
		[
			78,
			52
		],
		[
			48,
			0
		],
		[
			0,
			52
		],
		[
			-54,
			51
		],
		[
			18,
			94
		],
		[
			-126,
			124
		],
		[
			18,
			83
		]
	],
	[
		[
			44721,
			15805
		],
		[
			42,
			114
		],
		[
			36,
			41
		],
		[
			42,
			0
		],
		[
			72,
			-114
		],
		[
			121,
			-41
		]
	],
	[
		[
			46044,
			21926
		],
		[
			60,
			-52
		],
		[
			84,
			-11
		],
		[
			18,
			-51
		],
		[
			72,
			-11
		],
		[
			-6,
			-83
		],
		[
			-42,
			-41
		],
		[
			36,
			-83
		],
		[
			-6,
			-41
		],
		[
			-60,
			-31
		],
		[
			36,
			-135
		],
		[
			90,
			-41
		],
		[
			67,
			0
		],
		[
			48,
			-73
		],
		[
			6,
			-93
		],
		[
			36,
			-52
		]
	],
	[
		[
			46483,
			21128
		],
		[
			-54,
			-52
		],
		[
			-30,
			-124
		],
		[
			-55,
			-21
		],
		[
			-120,
			-114
		],
		[
			-30,
			-93
		],
		[
			-54,
			-31
		],
		[
			-18,
			-41
		],
		[
			-84,
			-104
		],
		[
			150,
			-103
		],
		[
			0,
			-114
		],
		[
			-48,
			-73
		],
		[
			36,
			-41
		],
		[
			-66,
			-73
		],
		[
			-30,
			-62
		],
		[
			36,
			-104
		],
		[
			-6,
			-62
		],
		[
			42,
			-51
		],
		[
			-24,
			-63
		]
	],
	[
		[
			46128,
			19802
		],
		[
			-72,
			63
		],
		[
			-156,
			62
		],
		[
			-67,
			51
		],
		[
			-54,
			-10
		],
		[
			-6,
			-62
		]
	],
	[
		[
			45773,
			19906
		],
		[
			6,
			-21
		],
		[
			-156,
			-83
		],
		[
			-18,
			52
		],
		[
			-108,
			104
		],
		[
			-48,
			-31
		],
		[
			-30,
			51
		],
		[
			-79,
			0
		],
		[
			-84,
			-20
		],
		[
			-12,
			93
		],
		[
			-36,
			93
		],
		[
			-42,
			62
		],
		[
			-42,
			21
		],
		[
			-132,
			104
		],
		[
			-55,
			82
		],
		[
			-72,
			52
		]
	],
	[
		[
			44865,
			20465
		],
		[
			24,
			62
		],
		[
			48,
			-20
		],
		[
			43,
			62
		],
		[
			-55,
			41
		],
		[
			25,
			83
		],
		[
			84,
			-10
		],
		[
			54,
			72
		],
		[
			-12,
			83
		],
		[
			-48,
			52
		],
		[
			-36,
			72
		],
		[
			-36,
			0
		],
		[
			-97,
			187
		],
		[
			-54,
			52
		],
		[
			18,
			72
		],
		[
			60,
			42
		],
		[
			91,
			10
		],
		[
			12,
			-21
		],
		[
			132,
			31
		],
		[
			-24,
			104
		],
		[
			102,
			-11
		],
		[
			72,
			156
		],
		[
			60,
			-73
		],
		[
			66,
			114
		],
		[
			12,
			52
		],
		[
			73,
			21
		],
		[
			90,
			-42
		],
		[
			90,
			62
		],
		[
			30,
			63
		],
		[
			48,
			20
		],
		[
			90,
			94
		]
	],
	[
		[
			45827,
			21895
		],
		[
			109,
			41
		],
		[
			108,
			-10
		]
	],
	[
		[
			49116,
			9601
		],
		[
			0,
			-83
		],
		[
			48,
			10
		],
		[
			66,
			-41
		],
		[
			127,
			21
		],
		[
			54,
			-31
		],
		[
			6,
			-94
		],
		[
			24,
			-93
		],
		[
			48,
			-72
		],
		[
			48,
			-42
		],
		[
			54,
			31
		],
		[
			54,
			0
		],
		[
			42,
			-31
		],
		[
			-18,
			-186
		],
		[
			48,
			-42
		],
		[
			67,
			42
		],
		[
			24,
			-62
		],
		[
			-73,
			-62
		],
		[
			-60,
			-83
		]
	],
	[
		[
			49675,
			8783
		],
		[
			-102,
			20
		],
		[
			-150,
			73
		],
		[
			-66,
			10
		],
		[
			-235,
			83
		],
		[
			-90,
			10
		],
		[
			-126,
			32
		],
		[
			-253,
			41
		]
	],
	[
		[
			48653,
			9052
		],
		[
			-66,
			155
		],
		[
			-48,
			73
		],
		[
			-24,
			93
		],
		[
			-30,
			10
		]
	],
	[
		[
			48485,
			9383
		],
		[
			30,
			42
		]
	],
	[
		[
			48515,
			9425
		],
		[
			12,
			41
		],
		[
			60,
			62
		],
		[
			78,
			-31
		],
		[
			0,
			-41
		],
		[
			151,
			-21
		],
		[
			-12,
			52
		],
		[
			48,
			62
		],
		[
			-6,
			73
		],
		[
			78,
			10
		],
		[
			0,
			-73
		],
		[
			90,
			-20
		],
		[
			0,
			51
		],
		[
			48,
			21
		],
		[
			54,
			-10
		]
	],
	[
		[
			43609,
			9052
		],
		[
			72,
			83
		],
		[
			90,
			-11
		]
	],
	[
		[
			43771,
			9124
		],
		[
			96,
			-41
		],
		[
			18,
			-62
		],
		[
			-6,
			-166
		],
		[
			24,
			-114
		],
		[
			54,
			-62
		],
		[
			-42,
			-31
		],
		[
			-108,
			-21
		],
		[
			-198,
			-51
		],
		[
			-115,
			124
		],
		[
			-12,
			155
		],
		[
			43,
			31
		],
		[
			60,
			-20
		],
		[
			18,
			82
		],
		[
			-24,
			63
		],
		[
			30,
			41
		]
	],
	[
		[
			43813,
			9321
		],
		[
			42,
			-31
		],
		[
			139,
			-10
		],
		[
			6,
			-93
		]
	],
	[
		[
			44000,
			9187
		],
		[
			6,
			-31
		]
	],
	[
		[
			44006,
			9156
		],
		[
			-6,
			-21
		]
	],
	[
		[
			44000,
			9135
		],
		[
			0,
			-11
		]
	],
	[
		[
			44000,
			9124
		],
		[
			-18,
			-82
		],
		[
			-61,
			20
		],
		[
			-18,
			52
		],
		[
			-90,
			-10
		],
		[
			-42,
			20
		]
	],
	[
		[
			43771,
			9124
		],
		[
			-102,
			11
		],
		[
			-60,
			-83
		]
	],
	[
		[
			43609,
			9052
		],
		[
			-96,
			93
		],
		[
			18,
			83
		],
		[
			-85,
			-21
		]
	],
	[
		[
			43446,
			9207
		],
		[
			12,
			125
		]
	],
	[
		[
			43458,
			9332
		],
		[
			97,
			10
		],
		[
			156,
			-21
		],
		[
			102,
			0
		]
	],
	[
		[
			41931,
			10181
		],
		[
			78,
			-11
		],
		[
			67,
			-51
		],
		[
			12,
			-52
		],
		[
			-30,
			-52
		],
		[
			78,
			-72
		],
		[
			30,
			10
		],
		[
			60,
			-83
		],
		[
			42,
			-135
		],
		[
			-78,
			-31
		],
		[
			-90,
			-103
		],
		[
			-42,
			-11
		],
		[
			-43,
			-51
		]
	],
	[
		[
			42015,
			9539
		],
		[
			-30,
			51
		],
		[
			-72,
			42
		],
		[
			-30,
			62
		],
		[
			-30,
			-124
		],
		[
			-24,
			93
		],
		[
			-108,
			72
		],
		[
			-132,
			73
		],
		[
			-67,
			-41
		],
		[
			-96,
			72
		],
		[
			-42,
			104
		],
		[
			-24,
			20
		]
	],
	[
		[
			41360,
			9963
		],
		[
			6,
			11
		]
	],
	[
		[
			41366,
			9974
		],
		[
			12,
			20
		]
	],
	[
		[
			41378,
			9994
		],
		[
			-6,
			0
		]
	],
	[
		[
			41372,
			9994
		],
		[
			60,
			63
		],
		[
			60,
			103
		],
		[
			127,
			31
		],
		[
			60,
			-21
		],
		[
			12,
			42
		],
		[
			72,
			0
		],
		[
			96,
			-21
		],
		[
			18,
			-31
		],
		[
			54,
			21
		]
	],
	[
		[
			42406,
			8462
		],
		[
			30,
			-73
		],
		[
			24,
			52
		],
		[
			54,
			31
		],
		[
			103,
			-52
		],
		[
			24,
			-52
		],
		[
			54,
			-31
		],
		[
			54,
			-83
		],
		[
			42,
			0
		],
		[
			90,
			-72
		],
		[
			145,
			-31
		],
		[
			66,
			21
		],
		[
			180,
			-31
		],
		[
			48,
			-42
		],
		[
			54,
			0
		],
		[
			127,
			-62
		],
		[
			30,
			-73
		],
		[
			24,
			-113
		],
		[
			-48,
			-63
		],
		[
			48,
			-31
		],
		[
			60,
			42
		],
		[
			36,
			-11
		],
		[
			66,
			-62
		],
		[
			6,
			-31
		],
		[
			-90,
			-62
		],
		[
			-66,
			-62
		],
		[
			-6,
			-52
		],
		[
			-157,
			-10
		],
		[
			-108,
			-52
		],
		[
			-90,
			-73
		],
		[
			-42,
			-62
		],
		[
			-48,
			-228
		],
		[
			12,
			-41
		],
		[
			-36,
			-145
		],
		[
			-133,
			-72
		],
		[
			-48,
			0
		],
		[
			-258,
			-125
		],
		[
			-96,
			0
		],
		[
			-181,
			-41
		],
		[
			-90,
			134
		],
		[
			-198,
			177
		],
		[
			-55,
			10
		],
		[
			-18,
			41
		],
		[
			-138,
			125
		],
		[
			-120,
			72
		],
		[
			-217,
			83
		],
		[
			-60,
			72
		],
		[
			-42,
			11
		],
		[
			-60,
			93
		],
		[
			-54,
			52
		],
		[
			-138,
			21
		],
		[
			-229,
			-52
		],
		[
			-78,
			-11
		],
		[
			-42,
			21
		],
		[
			-6,
			73
		],
		[
			126,
			41
		],
		[
			36,
			104
		],
		[
			54,
			72
		],
		[
			0,
			42
		],
		[
			67,
			62
		],
		[
			66,
			-11
		],
		[
			24,
			-31
		],
		[
			36,
			42
		],
		[
			78,
			0
		],
		[
			90,
			20
		],
		[
			169,
			125
		],
		[
			90,
			41
		],
		[
			78,
			-21
		],
		[
			-12,
			-93
		],
		[
			84,
			83
		],
		[
			-18,
			41
		],
		[
			126,
			42
		],
		[
			12,
			21
		],
		[
			145,
			41
		],
		[
			36,
			41
		],
		[
			12,
			63
		],
		[
			48,
			51
		],
		[
			54,
			21
		],
		[
			78,
			93
		],
		[
			96,
			-20
		]
	],
	[
		[
			40897,
			47227
		],
		[
			36,
			-51
		],
		[
			90,
			-21
		],
		[
			42,
			31
		],
		[
			61,
			-10
		]
	],
	[
		[
			41126,
			47176
		],
		[
			72,
			-52
		],
		[
			-18,
			-73
		],
		[
			12,
			-113
		],
		[
			30,
			-156
		],
		[
			48,
			-176
		],
		[
			60,
			-52
		],
		[
			-60,
			-83
		],
		[
			84,
			-10
		],
		[
			144,
			0
		],
		[
			66,
			21
		],
		[
			37,
			-21
		],
		[
			72,
			31
		],
		[
			18,
			93
		],
		[
			42,
			52
		],
		[
			6,
			52
		],
		[
			-42,
			83
		],
		[
			-6,
			62
		],
		[
			48,
			52
		],
		[
			120,
			0
		],
		[
			60,
			20
		],
		[
			78,
			94
		],
		[
			121,
			31
		]
	],
	[
		[
			42118,
			47031
		],
		[
			12,
			-52
		],
		[
			54,
			-104
		],
		[
			66,
			-82
		],
		[
			60,
			-208
		],
		[
			36,
			-259
		],
		[
			-12,
			-31
		],
		[
			54,
			-124
		],
		[
			78,
			-124
		],
		[
			24,
			-11
		],
		[
			97,
			-113
		],
		[
			0,
			-21
		],
		[
			144,
			-176
		],
		[
			-6,
			0
		]
	],
	[
		[
			40103,
			43975
		],
		[
			-150,
			31
		],
		[
			-24,
			-82
		],
		[
			-36,
			-31
		],
		[
			-60,
			20
		],
		[
			-102,
			-10
		],
		[
			-48,
			41
		],
		[
			-61,
			-10
		],
		[
			18,
			-62
		],
		[
			-6,
			-93
		],
		[
			12,
			-83
		],
		[
			-48,
			-11
		],
		[
			-54,
			-196
		],
		[
			-168,
			103
		],
		[
			-30,
			73
		],
		[
			-66,
			52
		],
		[
			-54,
			-52
		],
		[
			-54,
			0
		],
		[
			-7,
			-207
		],
		[
			-48,
			10
		],
		[
			-60,
			-41
		],
		[
			-90,
			-104
		],
		[
			-204,
			-104
		],
		[
			-79,
			-20
		],
		[
			-78,
			0
		],
		[
			-84,
			-21
		],
		[
			-42,
			83
		],
		[
			-48,
			10
		],
		[
			-60,
			52
		],
		[
			-102,
			41
		],
		[
			-175,
			31
		],
		[
			6,
			83
		],
		[
			-54,
			-31
		],
		[
			-36,
			11
		],
		[
			-156,
			-125
		],
		[
			-211,
			-62
		],
		[
			-156,
			-10
		],
		[
			-54,
			-52
		],
		[
			-66,
			31
		]
	],
	[
		[
			37368,
			43240
		],
		[
			48,
			62
		],
		[
			18,
			73
		],
		[
			-42,
			165
		],
		[
			24,
			135
		],
		[
			-36,
			145
		],
		[
			-36,
			21
		],
		[
			12,
			93
		],
		[
			-54,
			41
		],
		[
			-91,
			-31
		],
		[
			-72,
			104
		],
		[
			6,
			72
		],
		[
			-216,
			125
		],
		[
			-90,
			83
		],
		[
			-48,
			82
		],
		[
			-199,
			125
		],
		[
			-24,
			155
		],
		[
			-90,
			186
		],
		[
			108,
			104
		],
		[
			102,
			73
		],
		[
			-30,
			124
		],
		[
			-60,
			52
		],
		[
			-72,
			-11
		],
		[
			-60,
			52
		],
		[
			-54,
			10
		],
		[
			-42,
			73
		],
		[
			-36,
			10
		],
		[
			-24,
			135
		],
		[
			66,
			62
		],
		[
			-12,
			52
		],
		[
			108,
			155
		],
		[
			-36,
			42
		],
		[
			30,
			62
		],
		[
			0,
			93
		],
		[
			36,
			72
		],
		[
			-18,
			42
		],
		[
			18,
			62
		]
	],
	[
		[
			36502,
			46140
		],
		[
			60,
			52
		],
		[
			-24,
			93
		],
		[
			12,
			93
		]
	],
	[
		[
			36550,
			46378
		],
		[
			108,
			21
		],
		[
			72,
			41
		],
		[
			145,
			-62
		],
		[
			42,
			-31
		],
		[
			78,
			-10
		],
		[
			48,
			-42
		],
		[
			66,
			11
		],
		[
			96,
			197
		],
		[
			97,
			20
		],
		[
			72,
			-31
		],
		[
			18,
			93
		],
		[
			30,
			52
		],
		[
			102,
			73
		],
		[
			18,
			145
		],
		[
			30,
			10
		],
		[
			120,
			-31
		],
		[
			67,
			0
		],
		[
			30,
			-31
		],
		[
			108,
			21
		],
		[
			72,
			51
		],
		[
			72,
			31
		],
		[
			72,
			0
		],
		[
			36,
			52
		],
		[
			73,
			52
		],
		[
			18,
			41
		],
		[
			108,
			63
		],
		[
			120,
			-11
		],
		[
			60,
			-83
		],
		[
			144,
			-72
		],
		[
			127,
			-21
		],
		[
			18,
			-114
		],
		[
			72,
			21
		],
		[
			48,
			52
		],
		[
			24,
			-21
		],
		[
			96,
			41
		],
		[
			66,
			73
		],
		[
			-18,
			62
		],
		[
			48,
			41
		],
		[
			6,
			114
		],
		[
			43,
			21
		],
		[
			48,
			114
		],
		[
			126,
			124
		]
	],
	[
		[
			39376,
			47455
		],
		[
			12,
			0
		],
		[
			84,
			11
		],
		[
			66,
			-31
		],
		[
			18,
			51
		],
		[
			54,
			21
		],
		[
			67,
			-41
		],
		[
			54,
			10
		],
		[
			60,
			93
		],
		[
			102,
			0
		],
		[
			66,
			-93
		],
		[
			132,
			10
		],
		[
			55,
			-20
		],
		[
			84,
			20
		],
		[
			-12,
			-93
		],
		[
			120,
			-62
		],
		[
			36,
			10
		],
		[
			18,
			-72
		],
		[
			-12,
			-62
		],
		[
			72,
			10
		],
		[
			72,
			62
		],
		[
			97,
			104
		],
		[
			72,
			41
		],
		[
			60,
			-93
		],
		[
			24,
			-145
		],
		[
			120,
			41
		]
	],
	[
		[
			35895,
			33152
		],
		[
			84,
			-31
		],
		[
			120,
			-124
		],
		[
			48,
			0
		],
		[
			36,
			-52
		],
		[
			96,
			-10
		],
		[
			13,
			41
		],
		[
			78,
			-20
		],
		[
			36,
			10
		],
		[
			48,
			-62
		],
		[
			84,
			-31
		]
	],
	[
		[
			36538,
			32873
		],
		[
			90,
			-83
		],
		[
			18,
			-52
		],
		[
			42,
			0
		],
		[
			85,
			73
		],
		[
			36,
			0
		],
		[
			60,
			93
		],
		[
			90,
			-10
		]
	],
	[
		[
			36959,
			32894
		],
		[
			120,
			0
		],
		[
			72,
			-42
		],
		[
			90,
			-10
		],
		[
			25,
			-52
		],
		[
			-6,
			-124
		],
		[
			30,
			-21
		]
	],
	[
		[
			37290,
			32645
		],
		[
			12,
			-10
		]
	],
	[
		[
			37302,
			32635
		],
		[
			66,
			-11
		],
		[
			6,
			0
		],
		[
			54,
			-31
		],
		[
			48,
			31
		],
		[
			42,
			114
		],
		[
			-18,
			73
		]
	],
	[
		[
			37500,
			32811
		],
		[
			54,
			51
		],
		[
			-6,
			104
		],
		[
			66,
			-21
		],
		[
			18,
			-31
		],
		[
			54,
			31
		],
		[
			115,
			11
		],
		[
			66,
			-62
		],
		[
			48,
			-21
		],
		[
			90,
			10
		],
		[
			30,
			83
		],
		[
			84,
			62
		],
		[
			54,
			-31
		]
	],
	[
		[
			38173,
			32997
		],
		[
			43,
			-41
		],
		[
			84,
			-42
		],
		[
			6,
			-134
		],
		[
			-36,
			-73
		],
		[
			18,
			-145
		]
	],
	[
		[
			38288,
			32562
		],
		[
			54,
			-52
		],
		[
			-42,
			-134
		],
		[
			0,
			-228
		],
		[
			24,
			-104
		],
		[
			-24,
			-83
		],
		[
			48,
			-51
		],
		[
			6,
			-94
		],
		[
			102,
			-62
		],
		[
			18,
			-114
		]
	],
	[
		[
			38474,
			31640
		],
		[
			-48,
			-10
		],
		[
			-18,
			-62
		],
		[
			18,
			-52
		]
	],
	[
		[
			38426,
			31516
		],
		[
			-36,
			-52
		],
		[
			-6,
			-72
		],
		[
			-30,
			-62
		],
		[
			-108,
			-42
		],
		[
			-61,
			42
		],
		[
			-108,
			-11
		],
		[
			-60,
			-155
		],
		[
			-66,
			-41
		],
		[
			-114,
			-11
		],
		[
			-30,
			21
		],
		[
			-85,
			-42
		],
		[
			-42,
			32
		]
	],
	[
		[
			37680,
			31123
		],
		[
			-78,
			41
		],
		[
			-18,
			62
		],
		[
			-42,
			10
		],
		[
			-24,
			-62
		],
		[
			18,
			-196
		],
		[
			-54,
			31
		],
		[
			-54,
			-63
		],
		[
			-114,
			-93
		],
		[
			-79,
			-124
		],
		[
			-102,
			-135
		]
	],
	[
		[
			37133,
			30594
		],
		[
			-78,
			-114
		],
		[
			-54,
			0
		],
		[
			-54,
			-93
		],
		[
			-36,
			0
		],
		[
			-66,
			-41
		],
		[
			-91,
			-31
		],
		[
			-48,
			-62
		],
		[
			-60,
			0
		],
		[
			-36,
			31
		],
		[
			-96,
			-11
		],
		[
			-60,
			-41
		],
		[
			-12,
			-62
		],
		[
			-60,
			-94
		],
		[
			-54,
			-41
		],
		[
			-139,
			-10
		],
		[
			-54,
			-73
		],
		[
			0,
			-124
		],
		[
			36,
			-135
		],
		[
			42,
			-52
		],
		[
			-66,
			-62
		],
		[
			6,
			-51
		]
	],
	[
		[
			36153,
			29528
		],
		[
			0,
			-32
		]
	],
	[
		[
			36153,
			29496
		],
		[
			-96,
			-41
		],
		[
			-54,
			10
		]
	],
	[
		[
			36003,
			29465
		],
		[
			-24,
			-72
		],
		[
			-54,
			0
		],
		[
			-102,
			-31
		],
		[
			24,
			-52
		],
		[
			-6,
			-93
		],
		[
			-49,
			10
		],
		[
			-54,
			-41
		],
		[
			-162,
			-62
		],
		[
			-60,
			51
		],
		[
			0,
			31
		],
		[
			-108,
			-20
		],
		[
			-12,
			41
		],
		[
			-54,
			21
		],
		[
			-6,
			0
		],
		[
			-6,
			-73
		]
	],
	[
		[
			35330,
			29175
		],
		[
			0,
			-41
		]
	],
	[
		[
			35330,
			29134
		],
		[
			-13,
			-62
		],
		[
			-54,
			-52
		],
		[
			-66,
			83
		],
		[
			-42,
			0
		],
		[
			-24,
			52
		],
		[
			-90,
			-11
		],
		[
			-18,
			-51
		],
		[
			-48,
			0
		],
		[
			-60,
			93
		],
		[
			-24,
			103
		],
		[
			-49,
			104
		],
		[
			-84,
			-10
		],
		[
			-66,
			82
		],
		[
			-54,
			-20
		],
		[
			-30,
			20
		],
		[
			-150,
			-93
		],
		[
			-36,
			0
		],
		[
			-109,
			93
		]
	],
	[
		[
			34313,
			29465
		],
		[
			36,
			63
		],
		[
			25,
			93
		],
		[
			54,
			31
		],
		[
			-30,
			62
		],
		[
			36,
			52
		],
		[
			0,
			52
		],
		[
			54,
			51
		],
		[
			-145,
			125
		],
		[
			-48,
			20
		],
		[
			-90,
			-83
		],
		[
			-126,
			156
		],
		[
			-6,
			31
		],
		[
			-66,
			41
		],
		[
			12,
			73
		],
		[
			48,
			41
		],
		[
			66,
			93
		],
		[
			114,
			21
		],
		[
			18,
			135
		],
		[
			-6,
			83
		],
		[
			54,
			31
		],
		[
			103,
			-42
		],
		[
			60,
			0
		],
		[
			54,
			52
		],
		[
			12,
			93
		],
		[
			114,
			-20
		],
		[
			-6,
			103
		],
		[
			102,
			114
		],
		[
			84,
			-21
		],
		[
			25,
			-41
		],
		[
			78,
			10
		],
		[
			-30,
			114
		],
		[
			78,
			-10
		],
		[
			60,
			62
		],
		[
			60,
			-10
		],
		[
			48,
			-73
		],
		[
			66,
			-52
		],
		[
			109,
			42
		],
		[
			18,
			62
		],
		[
			42,
			-21
		],
		[
			6,
			0
		],
		[
			54,
			11
		],
		[
			6,
			41
		],
		[
			84,
			0
		],
		[
			36,
			-62
		],
		[
			66,
			-42
		],
		[
			72,
			32
		],
		[
			6,
			41
		],
		[
			66,
			-10
		],
		[
			12,
			51
		]
	],
	[
		[
			35798,
			31060
		],
		[
			-6,
			52
		],
		[
			-78,
			62
		],
		[
			0,
			42
		]
	],
	[
		[
			35714,
			31216
		],
		[
			-18,
			103
		],
		[
			0,
			83
		],
		[
			48,
			-21
		],
		[
			48,
			21
		],
		[
			37,
			-41
		],
		[
			36,
			10
		],
		[
			24,
			-52
		],
		[
			60,
			-41
		],
		[
			18,
			-73
		],
		[
			42,
			-51
		],
		[
			78,
			51
		],
		[
			78,
			-82
		],
		[
			60,
			103
		],
		[
			-24,
			42
		],
		[
			0,
			82
		],
		[
			-84,
			11
		],
		[
			-36,
			72
		],
		[
			-78,
			-10
		],
		[
			-18,
			21
		],
		[
			-18,
			145
		],
		[
			60,
			0
		],
		[
			36,
			124
		],
		[
			162,
			-104
		],
		[
			24,
			0
		],
		[
			30,
			93
		],
		[
			73,
			73
		],
		[
			-12,
			72
		],
		[
			-97,
			0
		],
		[
			-48,
			63
		],
		[
			-6,
			0
		],
		[
			-42,
			31
		]
	],
	[
		[
			36147,
			31941
		],
		[
			-36,
			31
		]
	],
	[
		[
			36111,
			31972
		],
		[
			-36,
			52
		],
		[
			-48,
			-11
		]
	],
	[
		[
			36027,
			32013
		],
		[
			-36,
			21
		],
		[
			-36,
			-31
		]
	],
	[
		[
			35955,
			32003
		],
		[
			-42,
			-52
		],
		[
			-30,
			21
		]
	],
	[
		[
			35883,
			31972
		],
		[
			-42,
			72
		],
		[
			-55,
			11
		],
		[
			-18,
			82
		]
	],
	[
		[
			35768,
			32137
		],
		[
			-30,
			52
		],
		[
			-102,
			11
		],
		[
			-48,
			41
		],
		[
			-114,
			0
		],
		[
			6,
			93
		],
		[
			-48,
			114
		],
		[
			-24,
			114
		],
		[
			30,
			21
		],
		[
			60,
			134
		],
		[
			-138,
			11
		]
	],
	[
		[
			31944,
			32303
		],
		[
			-6,
			-10
		]
	],
	[
		[
			31938,
			32293
		],
		[
			6,
			10
		]
	],
	[
		[
			34313,
			29465
		],
		[
			-30,
			-51
		],
		[
			-66,
			-63
		],
		[
			-60,
			0
		],
		[
			-6,
			0
		]
	],
	[
		[
			34151,
			29351
		],
		[
			-78,
			32
		],
		[
			-102,
			-11
		],
		[
			-24,
			52
		]
	],
	[
		[
			33947,
			29424
		],
		[
			-30,
			31
		],
		[
			-6,
			0
		],
		[
			-67,
			-10
		],
		[
			0,
			10
		],
		[
			-6,
			10
		],
		[
			6,
			0
		],
		[
			-24,
			-10
		]
	],
	[
		[
			33820,
			29455
		],
		[
			-42,
			0
		]
	],
	[
		[
			33778,
			29455
		],
		[
			-66,
			-41
		],
		[
			-90,
			41
		],
		[
			-42,
			-10
		],
		[
			-48,
			51
		],
		[
			-36,
			83
		],
		[
			-18,
			94
		],
		[
			-42,
			-11
		],
		[
			-43,
			31
		],
		[
			-12,
			83
		],
		[
			31,
			42
		],
		[
			-49,
			93
		],
		[
			24,
			114
		],
		[
			-42,
			0
		],
		[
			-18,
			145
		],
		[
			-54,
			72
		],
		[
			24,
			31
		],
		[
			-150,
			93
		],
		[
			48,
			42
		],
		[
			36,
			83
		],
		[
			-6,
			41
		],
		[
			42,
			114
		],
		[
			-66,
			-21
		],
		[
			-66,
			-62
		],
		[
			-60,
			11
		],
		[
			-42,
			41
		],
		[
			-139,
			52
		],
		[
			-12,
			41
		],
		[
			-96,
			52
		]
	],
	[
		[
			32786,
			30760
		],
		[
			-90,
			166
		],
		[
			-30,
			-31
		],
		[
			-30,
			93
		]
	],
	[
		[
			32636,
			30988
		],
		[
			48,
			-10
		],
		[
			60,
			41
		],
		[
			144,
			62
		],
		[
			12,
			-21
		],
		[
			97,
			63
		],
		[
			42,
			103
		]
	],
	[
		[
			33039,
			31226
		],
		[
			-12,
			62
		],
		[
			-90,
			83
		],
		[
			-67,
			124
		],
		[
			-162,
			135
		],
		[
			-277,
			217
		],
		[
			-60,
			32
		],
		[
			-72,
			0
		],
		[
			-150,
			20
		]
	],
	[
		[
			32149,
			31899
		],
		[
			-48,
			11
		]
	],
	[
		[
			32101,
			31910
		],
		[
			-30,
			20
		]
	],
	[
		[
			32071,
			31930
		],
		[
			-24,
			21
		]
	],
	[
		[
			32047,
			31951
		],
		[
			-6,
			10
		]
	],
	[
		[
			32041,
			31961
		],
		[
			-12,
			11
		]
	],
	[
		[
			32029,
			31972
		],
		[
			-36,
			52
		]
	],
	[
		[
			31993,
			32024
		],
		[
			66,
			103
		],
		[
			-36,
			62
		],
		[
			-73,
			62
		],
		[
			-6,
			52
		]
	],
	[
		[
			31944,
			32303
		],
		[
			79,
			73
		]
	],
	[
		[
			32023,
			32376
		],
		[
			6,
			0
		]
	],
	[
		[
			32029,
			32376
		],
		[
			120,
			114
		],
		[
			84,
			-73
		],
		[
			66,
			10
		],
		[
			96,
			-113
		],
		[
			109,
			10
		],
		[
			114,
			72
		],
		[
			138,
			-51
		],
		[
			60,
			31
		],
		[
			54,
			-11
		],
		[
			55,
			62
		],
		[
			66,
			-20
		]
	],
	[
		[
			32991,
			32407
		],
		[
			102,
			-31
		],
		[
			66,
			-94
		],
		[
			18,
			21
		],
		[
			102,
			-62
		],
		[
			102,
			21
		],
		[
			67,
			41
		],
		[
			36,
			104
		],
		[
			126,
			-11
		],
		[
			84,
			-31
		],
		[
			36,
			-41
		],
		[
			66,
			-21
		],
		[
			211,
			166
		]
	],
	[
		[
			36153,
			29496
		],
		[
			6,
			-72
		],
		[
			66,
			-114
		],
		[
			-78,
			-72
		],
		[
			30,
			-63
		],
		[
			-48,
			-51
		],
		[
			-12,
			-63
		],
		[
			-36,
			-20
		],
		[
			-36,
			93
		],
		[
			-54,
			21
		],
		[
			24,
			-125
		],
		[
			-36,
			-20
		],
		[
			-96,
			20
		],
		[
			-54,
			-51
		],
		[
			-55,
			-145
		],
		[
			-54,
			-42
		]
	],
	[
		[
			35720,
			28792
		],
		[
			-6,
			-21
		],
		[
			-6,
			0
		],
		[
			6,
			-72
		],
		[
			-6,
			0
		],
		[
			-12,
			-10
		]
	],
	[
		[
			35696,
			28689
		],
		[
			-54,
			-83
		],
		[
			6,
			-73
		],
		[
			126,
			-217
		],
		[
			24,
			62
		],
		[
			61,
			10
		],
		[
			72,
			52
		],
		[
			186,
			21
		],
		[
			48,
			31
		]
	],
	[
		[
			36165,
			28492
		],
		[
			18,
			-11
		],
		[
			-42,
			-134
		],
		[
			12,
			-93
		],
		[
			-36,
			-62
		],
		[
			-42,
			-187
		],
		[
			-6,
			-62
		],
		[
			-72,
			10
		],
		[
			-48,
			-72
		]
	],
	[
		[
			36532,
			26990
		],
		[
			0,
			-83
		],
		[
			36,
			-31
		],
		[
			-90,
			-145
		],
		[
			24,
			-93
		],
		[
			42,
			0
		],
		[
			60,
			-114
		],
		[
			169,
			-31
		],
		[
			60,
			31
		],
		[
			90,
			0
		],
		[
			42,
			-114
		],
		[
			6,
			-83
		],
		[
			24,
			-62
		],
		[
			-12,
			-186
		],
		[
			-54,
			-73
		],
		[
			-36,
			-134
		],
		[
			-24,
			-42
		],
		[
			-66,
			10
		],
		[
			-37,
			-31
		],
		[
			-204,
			0
		],
		[
			-18,
			63
		],
		[
			-48,
			10
		],
		[
			-24,
			-145
		],
		[
			18,
			-62
		],
		[
			78,
			-21
		],
		[
			60,
			10
		],
		[
			24,
			-62
		],
		[
			78,
			-10
		],
		[
			43,
			-42
		],
		[
			66,
			-103
		],
		[
			0,
			-62
		],
		[
			-48,
			-21
		],
		[
			-49,
			-52
		],
		[
			97,
			-72
		],
		[
			30,
			-52
		],
		[
			-72,
			-104
		],
		[
			42,
			-62
		],
		[
			-48,
			-41
		],
		[
			-121,
			-73
		],
		[
			-60,
			-103
		],
		[
			-30,
			-11
		],
		[
			-36,
			-103
		],
		[
			102,
			-135
		],
		[
			36,
			-124
		]
	],
	[
		[
			36682,
			24432
		],
		[
			12,
			-52
		]
	],
	[
		[
			36694,
			24380
		],
		[
			-96,
			-72
		],
		[
			-48,
			-104
		],
		[
			-78,
			10
		],
		[
			-78,
			-20
		],
		[
			-30,
			31
		],
		[
			-109,
			0
		],
		[
			0,
			-124
		],
		[
			-18,
			-32
		],
		[
			0,
			-155
		],
		[
			-24,
			-41
		],
		[
			163,
			-83
		],
		[
			18,
			-83
		],
		[
			-163,
			41
		],
		[
			-60,
			-51
		],
		[
			-198,
			10
		]
	],
	[
		[
			35973,
			23707
		],
		[
			-18,
			-62
		],
		[
			30,
			-31
		],
		[
			-30,
			-62
		]
	],
	[
		[
			35955,
			23552
		],
		[
			-66,
			-21
		],
		[
			-115,
			21
		],
		[
			-84,
			0
		],
		[
			-78,
			-63
		]
	],
	[
		[
			35612,
			23489
		],
		[
			-54,
			-10
		],
		[
			12,
			-83
		],
		[
			-12,
			-62
		],
		[
			30,
			-62
		],
		[
			-6,
			-52
		],
		[
			-60,
			-31
		],
		[
			-132,
			0
		],
		[
			24,
			52
		],
		[
			-91,
			72
		],
		[
			-54,
			21
		],
		[
			-162,
			-103
		],
		[
			6,
			-73
		],
		[
			-24,
			-62
		],
		[
			-78,
			-21
		],
		[
			-36,
			-41
		],
		[
			-60,
			10
		],
		[
			-60,
			-62
		],
		[
			-73,
			0
		]
	],
	[
		[
			32840,
			23376
		],
		[
			-114,
			51
		],
		[
			-66,
			-31
		],
		[
			-72,
			11
		],
		[
			-36,
			-31
		],
		[
			-211,
			-42
		],
		[
			-66,
			31
		],
		[
			-48,
			0
		],
		[
			-24,
			52
		],
		[
			-72,
			52
		],
		[
			-84,
			31
		],
		[
			-66,
			103
		],
		[
			-43,
			42
		],
		[
			-54,
			0
		],
		[
			-42,
			52
		],
		[
			-114,
			41
		],
		[
			-42,
			0
		],
		[
			-42,
			62
		],
		[
			12,
			42
		],
		[
			-108,
			103
		],
		[
			-79,
			52
		],
		[
			-102,
			41
		],
		[
			-60,
			42
		]
	],
	[
		[
			31307,
			24080
		],
		[
			-60,
			62
		],
		[
			12,
			83
		],
		[
			-30,
			10
		],
		[
			-6,
			83
		],
		[
			66,
			73
		],
		[
			42,
			82
		],
		[
			126,
			104
		],
		[
			91,
			-21
		],
		[
			120,
			104
		],
		[
			102,
			62
		],
		[
			66,
			0
		],
		[
			120,
			72
		],
		[
			301,
			0
		],
		[
			54,
			-10
		],
		[
			66,
			73
		],
		[
			-6,
			82
		],
		[
			66,
			83
		],
		[
			121,
			-41
		],
		[
			-6,
			93
		],
		[
			42,
			176
		],
		[
			-12,
			114
		],
		[
			12,
			31
		],
		[
			-60,
			104
		],
		[
			-36,
			10
		],
		[
			-121,
			-31
		],
		[
			-54,
			-41
		],
		[
			-36,
			-73
		],
		[
			-54,
			-41
		],
		[
			-30,
			10
		],
		[
			-150,
			-83
		],
		[
			0,
			-52
		],
		[
			54,
			-51
		],
		[
			-54,
			-42
		],
		[
			-151,
			-41
		],
		[
			-90,
			-11
		],
		[
			-18,
			73
		],
		[
			84,
			21
		],
		[
			54,
			41
		],
		[
			-30,
			93
		],
		[
			-54,
			114
		],
		[
			-66,
			93
		],
		[
			-12,
			114
		],
		[
			102,
			21
		],
		[
			18,
			-21
		],
		[
			97,
			93
		],
		[
			6,
			0
		],
		[
			36,
			32
		]
	],
	[
		[
			32029,
			25727
		],
		[
			36,
			10
		],
		[
			-24,
			93
		],
		[
			60,
			52
		],
		[
			18,
			83
		],
		[
			66,
			62
		],
		[
			-6,
			62
		],
		[
			-72,
			41
		],
		[
			66,
			42
		],
		[
			108,
			10
		],
		[
			12,
			145
		],
		[
			36,
			52
		],
		[
			12,
			238
		],
		[
			42,
			0
		],
		[
			24,
			93
		],
		[
			49,
			73
		],
		[
			-25,
			52
		],
		[
			43,
			52
		],
		[
			120,
			-11
		],
		[
			60,
			11
		],
		[
			54,
			41
		],
		[
			-6,
			-104
		],
		[
			66,
			-10
		],
		[
			36,
			21
		],
		[
			-6,
			83
		],
		[
			-54,
			93
		]
	],
	[
		[
			32744,
			27011
		],
		[
			-114,
			-11
		],
		[
			-108,
			156
		],
		[
			-6,
			114
		],
		[
			-48,
			52
		],
		[
			-18,
			-32
		],
		[
			-73,
			11
		],
		[
			-138,
			72
		],
		[
			-60,
			11
		],
		[
			-30,
			-52
		],
		[
			-30,
			21
		],
		[
			-72,
			145
		],
		[
			36,
			31
		],
		[
			-24,
			62
		],
		[
			-42,
			-52
		],
		[
			-48,
			21
		],
		[
			-37,
			-73
		],
		[
			-78,
			11
		],
		[
			-192,
			62
		],
		[
			-54,
			248
		],
		[
			60,
			94
		]
	],
	[
		[
			31668,
			27902
		],
		[
			6,
			72
		],
		[
			30,
			52
		],
		[
			-66,
			41
		],
		[
			54,
			73
		],
		[
			54,
			20
		],
		[
			96,
			94
		],
		[
			-144,
			114
		],
		[
			30,
			103
		]
	],
	[
		[
			31728,
			28471
		],
		[
			12,
			31
		],
		[
			66,
			21
		],
		[
			108,
			-10
		],
		[
			-12,
			51
		],
		[
			24,
			62
		],
		[
			18,
			114
		],
		[
			79,
			114
		],
		[
			66,
			-41
		],
		[
			126,
			0
		],
		[
			18,
			31
		],
		[
			66,
			-21
		],
		[
			78,
			21
		],
		[
			79,
			124
		],
		[
			48,
			52
		],
		[
			18,
			73
		],
		[
			36,
			20
		],
		[
			102,
			0
		],
		[
			66,
			104
		],
		[
			42,
			-104
		],
		[
			48,
			-72
		],
		[
			157,
			-104
		],
		[
			72,
			42
		],
		[
			66,
			-21
		],
		[
			54,
			83
		],
		[
			66,
			20
		],
		[
			18,
			-62
		],
		[
			175,
			-20
		],
		[
			60,
			-21
		],
		[
			24,
			-93
		],
		[
			150,
			-156
		],
		[
			84,
			-186
		],
		[
			96,
			124
		],
		[
			151,
			145
		],
		[
			156,
			11
		],
		[
			18,
			41
		],
		[
			-12,
			186
		],
		[
			0,
			166
		],
		[
			-30,
			0
		],
		[
			12,
			104
		]
	],
	[
		[
			34133,
			29300
		],
		[
			24,
			31
		]
	],
	[
		[
			34157,
			29331
		],
		[
			-6,
			20
		]
	],
	[
		[
			21910,
			6225
		],
		[
			0,
			-11
		]
	],
	[
		[
			21910,
			6214
		],
		[
			0,
			11
		]
	],
	[
		[
			24266,
			9601
		],
		[
			103,
			-176
		]
	],
	[
		[
			24369,
			9425
		],
		[
			-66,
			-21
		],
		[
			0,
			-52
		],
		[
			-37,
			-93
		]
	],
	[
		[
			24266,
			9259
		],
		[
			-6,
			-62
		]
	],
	[
		[
			24260,
			9197
		],
		[
			-6,
			-52
		],
		[
			-6,
			0
		],
		[
			0,
			-10
		]
	],
	[
		[
			24248,
			9135
		],
		[
			-6,
			-11
		],
		[
			6,
			0
		],
		[
			0,
			-41
		]
	],
	[
		[
			24248,
			9083
		],
		[
			25,
			-83
		],
		[
			-7,
			0
		]
	],
	[
		[
			24266,
			9000
		],
		[
			-30,
			-114
		],
		[
			-42,
			-52
		]
	],
	[
		[
			24194,
			8834
		],
		[
			-144,
			-51
		],
		[
			-90,
			-62
		],
		[
			96,
			-32
		],
		[
			6,
			-41
		],
		[
			138,
			0
		],
		[
			30,
			-83
		],
		[
			49,
			-21
		]
	],
	[
		[
			24279,
			8544
		],
		[
			18,
			-41
		],
		[
			72,
			-52
		],
		[
			54,
			0
		],
		[
			18,
			42
		]
	],
	[
		[
			24441,
			8493
		],
		[
			-18,
			20
		]
	],
	[
		[
			24423,
			8513
		],
		[
			0,
			42
		],
		[
			108,
			31
		],
		[
			72,
			-73
		],
		[
			-30,
			-62
		],
		[
			30,
			-72
		]
	],
	[
		[
			24603,
			8379
		],
		[
			0,
			-11
		]
	],
	[
		[
			24603,
			8368
		],
		[
			-24,
			-62
		],
		[
			66,
			-103
		],
		[
			30,
			-135
		],
		[
			42,
			-41
		],
		[
			-18,
			-63
		]
	],
	[
		[
			24699,
			7964
		],
		[
			-24,
			-82
		],
		[
			12,
			-52
		],
		[
			79,
			-52
		]
	],
	[
		[
			24766,
			7778
		],
		[
			48,
			-124
		],
		[
			-12,
			-62
		],
		[
			12,
			-94
		],
		[
			42,
			-62
		],
		[
			12,
			-93
		]
	],
	[
		[
			24868,
			7343
		],
		[
			24,
			-62
		],
		[
			66,
			-42
		],
		[
			102,
			0
		],
		[
			0,
			-93
		],
		[
			-30,
			-52
		],
		[
			24,
			-82
		],
		[
			-24,
			-73
		],
		[
			6,
			-83
		],
		[
			-30,
			-31
		],
		[
			0,
			-62
		],
		[
			36,
			-52
		],
		[
			42,
			42
		],
		[
			42,
			0
		],
		[
			12,
			-73
		],
		[
			42,
			11
		],
		[
			-18,
			72
		],
		[
			73,
			-21
		],
		[
			-43,
			-124
		],
		[
			115,
			-166
		],
		[
			0,
			-62
		],
		[
			-66,
			-62
		],
		[
			42,
			-31
		],
		[
			96,
			83
		],
		[
			48,
			-42
		],
		[
			6,
			-51
		],
		[
			66,
			-42
		],
		[
			66,
			42
		],
		[
			48,
			-145
		]
	],
	[
		[
			25613,
			6142
		],
		[
			-18,
			-42
		]
	],
	[
		[
			25595,
			6100
		],
		[
			36,
			-10
		]
	],
	[
		[
			25631,
			6090
		],
		[
			0,
			-83
		]
	],
	[
		[
			25631,
			6007
		],
		[
			6,
			-21
		]
	],
	[
		[
			25637,
			5986
		],
		[
			12,
			0
		]
	],
	[
		[
			25649,
			5986
		],
		[
			36,
			0
		]
	],
	[
		[
			25685,
			5986
		],
		[
			49,
			52
		]
	],
	[
		[
			25734,
			6038
		],
		[
			12,
			0
		]
	],
	[
		[
			25746,
			6038
		],
		[
			18,
			-52
		]
	],
	[
		[
			25764,
			5986
		],
		[
			-55,
			-41
		]
	],
	[
		[
			25709,
			5945
		],
		[
			-18,
			10
		]
	],
	[
		[
			25691,
			5955
		],
		[
			-12,
			-52
		],
		[
			-48,
			-10
		]
	],
	[
		[
			25631,
			5893
		],
		[
			-18,
			31
		],
		[
			-78,
			21
		]
	],
	[
		[
			25535,
			5945
		],
		[
			-6,
			0
		]
	],
	[
		[
			25529,
			5945
		],
		[
			-18,
			-83
		],
		[
			30,
			-52
		],
		[
			0,
			-83
		],
		[
			-60,
			-31
		],
		[
			-60,
			-62
		],
		[
			12,
			-72
		],
		[
			54,
			-21
		],
		[
			42,
			83
		],
		[
			48,
			-52
		],
		[
			18,
			-124
		],
		[
			60,
			-93
		],
		[
			-24,
			-52
		],
		[
			-60,
			0
		],
		[
			12,
			-145
		],
		[
			36,
			-62
		],
		[
			-36,
			-83
		],
		[
			-84,
			-42
		],
		[
			-84,
			-20
		],
		[
			-42,
			-73
		],
		[
			-42,
			-10
		],
		[
			-90,
			20
		],
		[
			-6,
			-82
		],
		[
			36,
			-52
		],
		[
			42,
			52
		],
		[
			42,
			-11
		],
		[
			66,
			42
		],
		[
			48,
			93
		],
		[
			114,
			21
		],
		[
			18,
			-52
		],
		[
			90,
			-104
		],
		[
			-18,
			-41
		],
		[
			-120,
			-31
		],
		[
			6,
			-93
		],
		[
			42,
			31
		],
		[
			66,
			-21
		],
		[
			42,
			-42
		],
		[
			55,
			52
		],
		[
			78,
			-83
		],
		[
			0,
			-51
		],
		[
			-78,
			-52
		],
		[
			-42,
			0
		],
		[
			-67,
			-62
		],
		[
			-12,
			-42
		],
		[
			60,
			-52
		],
		[
			13,
			-62
		],
		[
			-103,
			11
		],
		[
			-84,
			-42
		],
		[
			-30,
			52
		],
		[
			36,
			41
		],
		[
			-84,
			114
		],
		[
			-108,
			73
		],
		[
			-96,
			83
		],
		[
			-223,
			83
		],
		[
			-144,
			0
		],
		[
			-18,
			-21
		],
		[
			-121,
			21
		],
		[
			-24,
			-21
		],
		[
			-150,
			41
		],
		[
			-132,
			0
		],
		[
			-42,
			-20
		],
		[
			-72,
			0
		],
		[
			-55,
			-21
		],
		[
			-54,
			-62
		],
		[
			-18,
			-73
		],
		[
			-120,
			-62
		],
		[
			0,
			-52
		],
		[
			-150,
			31
		],
		[
			-12,
			-51
		],
		[
			-90,
			0
		],
		[
			-97,
			-63
		],
		[
			-108,
			0
		],
		[
			-138,
			73
		],
		[
			-66,
			0
		],
		[
			-54,
			-52
		],
		[
			-79,
			21
		],
		[
			-42,
			-42
		],
		[
			-90,
			0
		],
		[
			24,
			73
		],
		[
			0,
			104
		],
		[
			-42,
			124
		],
		[
			18,
			114
		],
		[
			-18,
			41
		],
		[
			-114,
			114
		],
		[
			0,
			-41
		],
		[
			102,
			-94
		],
		[
			-6,
			-134
		],
		[
			42,
			-166
		],
		[
			-66,
			-103
		],
		[
			-54,
			-42
		],
		[
			-84,
			0
		],
		[
			-30,
			-93
		],
		[
			-54,
			83
		],
		[
			0,
			134
		],
		[
			-43,
			94
		],
		[
			-54,
			10
		],
		[
			-36,
			-62
		],
		[
			-204,
			-52
		],
		[
			-30,
			-31
		],
		[
			-66,
			-10
		],
		[
			-54,
			-73
		],
		[
			18,
			-124
		],
		[
			54,
			-42
		],
		[
			-12,
			-51
		],
		[
			-54,
			0
		],
		[
			-109,
			-145
		],
		[
			30,
			-52
		],
		[
			-30,
			-42
		],
		[
			-6,
			-62
		],
		[
			24,
			-83
		],
		[
			61,
			-10
		],
		[
			-7,
			-72
		],
		[
			-78,
			-52
		],
		[
			-12,
			-93
		],
		[
			-66,
			-63
		],
		[
			12,
			-62
		],
		[
			-48,
			-31
		],
		[
			-48,
			104
		],
		[
			-36,
			20
		],
		[
			-48,
			-20
		],
		[
			-18,
			31
		],
		[
			-181,
			31
		],
		[
			-66,
			-52
		],
		[
			-12,
			-62
		],
		[
			-36,
			0
		],
		[
			-72,
			-104
		],
		[
			-30,
			11
		],
		[
			-36,
			-83
		],
		[
			-54,
			-83
		],
		[
			-96,
			93
		],
		[
			-91,
			-10
		],
		[
			-54,
			-31
		],
		[
			-96,
			-155
		],
		[
			0,
			-187
		],
		[
			-96,
			-145
		],
		[
			-102,
			-103
		],
		[
			-54,
			93
		],
		[
			36,
			41
		],
		[
			24,
			-31
		],
		[
			36,
			42
		],
		[
			0,
			93
		],
		[
			-121,
			-93
		],
		[
			-12,
			82
		],
		[
			25,
			125
		],
		[
			-49,
			83
		],
		[
			-18,
			134
		],
		[
			30,
			73
		],
		[
			-12,
			51
		],
		[
			-48,
			-20
		],
		[
			-24,
			-62
		],
		[
			-42,
			-11
		],
		[
			-42,
			-52
		],
		[
			-114,
			104
		],
		[
			-6,
			-62
		],
		[
			42,
			-31
		],
		[
			72,
			-93
		],
		[
			6,
			-104
		],
		[
			60,
			-41
		],
		[
			-12,
			-52
		],
		[
			-54,
			-62
		],
		[
			-78,
			20
		],
		[
			-6,
			-72
		],
		[
			42,
			-42
		],
		[
			66,
			21
		],
		[
			42,
			-41
		],
		[
			-132,
			-42
		],
		[
			-54,
			-51
		],
		[
			-30,
			-104
		],
		[
			-36,
			-21
		],
		[
			-6,
			-114
		],
		[
			30,
			-41
		],
		[
			-42,
			-62
		],
		[
			-66,
			-31
		],
		[
			-49,
			41
		],
		[
			-72,
			-52
		],
		[
			-72,
			11
		],
		[
			24,
			-73
		],
		[
			42,
			42
		],
		[
			114,
			-21
		],
		[
			37,
			-42
		],
		[
			102,
			-62
		],
		[
			12,
			-145
		],
		[
			54,
			0
		],
		[
			66,
			-145
		],
		[
			-48,
			-41
		],
		[
			-18,
			-124
		],
		[
			-114,
			-42
		],
		[
			-48,
			-52
		],
		[
			18,
			-82
		],
		[
			-36,
			-114
		],
		[
			-67,
			-11
		],
		[
			-66,
			42
		],
		[
			-192,
			0
		],
		[
			-42,
			-21
		],
		[
			-42,
			-62
		],
		[
			-6,
			-93
		],
		[
			-36,
			-31
		],
		[
			-36,
			-94
		],
		[
			0,
			-124
		],
		[
			-79,
			-31
		],
		[
			-102,
			0
		],
		[
			-12,
			114
		],
		[
			-162,
			52
		],
		[
			0,
			62
		],
		[
			-48,
			52
		],
		[
			6,
			72
		],
		[
			-66,
			21
		],
		[
			-12,
			72
		],
		[
			54,
			62
		],
		[
			12,
			94
		],
		[
			-42,
			31
		],
		[
			-24,
			103
		],
		[
			-31,
			42
		],
		[
			-30,
			124
		],
		[
			-30,
			52
		],
		[
			-186,
			207
		],
		[
			-36,
			0
		],
		[
			-60,
			72
		],
		[
			-96,
			21
		],
		[
			-85,
			-31
		],
		[
			-66,
			83
		],
		[
			-96,
			52
		],
		[
			-48,
			-21
		],
		[
			-78,
			31
		],
		[
			-36,
			-52
		],
		[
			-42,
			0
		],
		[
			-12,
			62
		],
		[
			-199,
			166
		],
		[
			-66,
			0
		],
		[
			-54,
			42
		],
		[
			-66,
			10
		],
		[
			-163,
			-21
		],
		[
			-126,
			-155
		],
		[
			-24,
			-62
		],
		[
			60,
			-52
		],
		[
			36,
			-83
		],
		[
			-30,
			-62
		],
		[
			-18,
			-104
		],
		[
			-42,
			-41
		],
		[
			-24,
			-62
		],
		[
			-48,
			21
		],
		[
			-12,
			-42
		],
		[
			-72,
			-62
		],
		[
			-54,
			10
		],
		[
			-90,
			-10
		],
		[
			-25,
			-31
		],
		[
			-120,
			10
		],
		[
			-12,
			-52
		],
		[
			-48,
			-20
		],
		[
			-36,
			31
		],
		[
			-96,
			-62
		],
		[
			-120,
			-31
		],
		[
			-49,
			72
		],
		[
			-24,
			104
		],
		[
			-78,
			10
		],
		[
			-60,
			104
		],
		[
			42,
			51
		],
		[
			0,
			63
		],
		[
			60,
			0
		],
		[
			36,
			41
		],
		[
			24,
			72
		],
		[
			-36,
			42
		],
		[
			-36,
			166
		],
		[
			0,
			72
		],
		[
			-30,
			62
		],
		[
			12,
			52
		],
		[
			60,
			73
		],
		[
			0,
			82
		],
		[
			103,
			114
		],
		[
			18,
			52
		],
		[
			90,
			-21
		],
		[
			36,
			42
		],
		[
			132,
			0
		],
		[
			36,
			83
		],
		[
			103,
			83
		],
		[
			72,
			31
		],
		[
			36,
			62
		],
		[
			42,
			-11
		],
		[
			24,
			62
		],
		[
			30,
			-10
		],
		[
			66,
			31
		],
		[
			60,
			83
		],
		[
			72,
			31
		],
		[
			85,
			-10
		],
		[
			138,
			52
		],
		[
			120,
			-114
		],
		[
			30,
			-73
		],
		[
			84,
			-21
		],
		[
			30,
			-31
		],
		[
			79,
			-10
		],
		[
			162,
			155
		],
		[
			96,
			176
		],
		[
			0,
			52
		],
		[
			78,
			83
		],
		[
			36,
			-62
		],
		[
			78,
			21
		],
		[
			133,
			10
		],
		[
			114,
			93
		],
		[
			30,
			73
		],
		[
			60,
			51
		],
		[
			18,
			-20
		],
		[
			66,
			41
		],
		[
			42,
			83
		],
		[
			79,
			21
		],
		[
			48,
			52
		],
		[
			30,
			0
		],
		[
			48,
			51
		],
		[
			48,
			166
		],
		[
			0,
			135
		],
		[
			90,
			20
		],
		[
			126,
			11
		],
		[
			42,
			52
		],
		[
			6,
			51
		],
		[
			49,
			11
		],
		[
			-6,
			62
		],
		[
			54,
			0
		],
		[
			18,
			31
		],
		[
			72,
			31
		],
		[
			54,
			259
		],
		[
			-42,
			31
		],
		[
			0,
			83
		],
		[
			66,
			83
		],
		[
			-30,
			83
		],
		[
			66,
			-21
		],
		[
			78,
			21
		],
		[
			54,
			82
		],
		[
			73,
			0
		],
		[
			36,
			73
		],
		[
			42,
			0
		],
		[
			12,
			-62
		],
		[
			48,
			10
		],
		[
			66,
			62
		],
		[
			0,
			52
		],
		[
			54,
			21
		],
		[
			36,
			41
		],
		[
			60,
			145
		],
		[
			-24,
			83
		],
		[
			12,
			62
		],
		[
			48,
			21
		],
		[
			-36,
			62
		],
		[
			36,
			93
		],
		[
			0,
			52
		],
		[
			-42,
			104
		],
		[
			48,
			82
		],
		[
			48,
			-10
		],
		[
			-36,
			114
		],
		[
			42,
			114
		],
		[
			-18,
			93
		],
		[
			-48,
			10
		],
		[
			-12,
			63
		],
		[
			84,
			0
		],
		[
			7,
			-42
		],
		[
			84,
			11
		],
		[
			18,
			-52
		],
		[
			90,
			10
		],
		[
			36,
			62
		],
		[
			42,
			31
		],
		[
			18,
			62
		],
		[
			42,
			0
		],
		[
			42,
			83
		],
		[
			66,
			11
		],
		[
			-18,
			-125
		],
		[
			48,
			-10
		],
		[
			31,
			-62
		],
		[
			-12,
			-42
		],
		[
			42,
			-176
		],
		[
			24,
			63
		],
		[
			84,
			-11
		],
		[
			72,
			-41
		],
		[
			54,
			41
		],
		[
			192,
			-10
		],
		[
			115,
			-114
		]
	],
	[
		[
			21982,
			6121
		],
		[
			-72,
			93
		]
	],
	[
		[
			21910,
			6225
		],
		[
			-67,
			82
		],
		[
			-42,
			-31
		],
		[
			-114,
			11
		],
		[
			-90,
			-31
		],
		[
			-66,
			51
		],
		[
			-6,
			62
		],
		[
			-66,
			11
		],
		[
			-18,
			114
		],
		[
			0,
			83
		],
		[
			60,
			134
		],
		[
			-84,
			93
		],
		[
			54,
			11
		],
		[
			78,
			-21
		],
		[
			6,
			-31
		],
		[
			78,
			0
		],
		[
			54,
			-21
		],
		[
			60,
			31
		],
		[
			24,
			73
		],
		[
			84,
			0
		],
		[
			19,
			31
		],
		[
			108,
			-31
		],
		[
			30,
			21
		],
		[
			186,
			10
		],
		[
			54,
			52
		],
		[
			36,
			83
		],
		[
			67,
			103
		],
		[
			-7,
			83
		],
		[
			25,
			104
		],
		[
			42,
			31
		],
		[
			-36,
			83
		],
		[
			54,
			165
		],
		[
			60,
			-10
		],
		[
			78,
			21
		],
		[
			54,
			114
		],
		[
			48,
			-11
		],
		[
			60,
			21
		],
		[
			0,
			41
		],
		[
			48,
			42
		],
		[
			73,
			20
		],
		[
			18,
			73
		],
		[
			78,
			21
		],
		[
			12,
			41
		],
		[
			66,
			52
		],
		[
			30,
			114
		],
		[
			-18,
			83
		],
		[
			66,
			0
		],
		[
			36,
			31
		],
		[
			12,
			83
		],
		[
			72,
			10
		],
		[
			12,
			52
		],
		[
			42,
			52
		],
		[
			109,
			31
		],
		[
			114,
			114
		],
		[
			30,
			0
		],
		[
			48,
			103
		],
		[
			6,
			104
		],
		[
			-12,
			62
		],
		[
			18,
			72
		],
		[
			-12,
			104
		],
		[
			24,
			72
		],
		[
			-12,
			63
		],
		[
			0,
			207
		],
		[
			-18,
			176
		],
		[
			-30,
			134
		],
		[
			-6,
			104
		],
		[
			24,
			124
		],
		[
			54,
			73
		],
		[
			36,
			20
		]
	],
	[
		[
			23653,
			9994
		],
		[
			66,
			-10
		],
		[
			205,
			0
		],
		[
			156,
			41
		],
		[
			78,
			-20
		],
		[
			0,
			-62
		],
		[
			-30,
			-73
		],
		[
			36,
			-72
		],
		[
			66,
			-83
		],
		[
			-6,
			-52
		],
		[
			42,
			-62
		]
	],
	[
		[
			13246,
			300
		],
		[
			12,
			-31
		],
		[
			60,
			-10
		],
		[
			0,
			-73
		],
		[
			-36,
			-20
		],
		[
			-36,
			134
		]
	],
	[
		[
			13528,
			663
		],
		[
			102,
			-62
		],
		[
			30,
			-94
		],
		[
			-18,
			-51
		],
		[
			-48,
			-52
		],
		[
			-72,
			21
		],
		[
			-12,
			-42
		],
		[
			-60,
			52
		],
		[
			-54,
			-52
		],
		[
			-24,
			42
		],
		[
			30,
			51
		],
		[
			54,
			-20
		],
		[
			18,
			72
		],
		[
			-30,
			42
		],
		[
			84,
			93
		]
	],
	[
		[
			13191,
			942
		],
		[
			55,
			-103
		],
		[
			-18,
			-104
		],
		[
			-31,
			0
		],
		[
			-18,
			114
		],
		[
			12,
			93
		]
	],
	[
		[
			13246,
			953
		],
		[
			36,
			0
		],
		[
			66,
			-93
		],
		[
			66,
			-42
		],
		[
			-18,
			-72
		],
		[
			-54,
			-62
		],
		[
			-42,
			62
		],
		[
			0,
			93
		],
		[
			-30,
			10
		],
		[
			-42,
			73
		],
		[
			18,
			31
		]
	],
	[
		[
			13570,
			1067
		],
		[
			18,
			-135
		],
		[
			84,
			0
		],
		[
			73,
			-31
		],
		[
			-127,
			-62
		],
		[
			-60,
			72
		],
		[
			-60,
			31
		],
		[
			78,
			73
		],
		[
			-6,
			52
		]
	],
	[
		[
			40645,
			15556
		],
		[
			30,
			0
		],
		[
			72,
			62
		]
	],
	[
		[
			41246,
			13775
		],
		[
			-102,
			93
		],
		[
			-67,
			-10
		],
		[
			6,
			-63
		],
		[
			-30,
			-31
		],
		[
			-6,
			-114
		],
		[
			49,
			-82
		],
		[
			-19,
			-73
		],
		[
			37,
			-21
		],
		[
			-6,
			-103
		],
		[
			-67,
			0
		],
		[
			-36,
			-238
		],
		[
			60,
			-11
		],
		[
			-36,
			-114
		],
		[
			-42,
			-31
		],
		[
			-198,
			104
		],
		[
			-84,
			-31
		],
		[
			-42,
			10
		],
		[
			-42,
			-41
		],
		[
			-19,
			-63
		],
		[
			-54,
			-10
		],
		[
			-66,
			-166
		],
		[
			-12,
			-62
		],
		[
			-120,
			31
		],
		[
			-114,
			-41
		],
		[
			-90,
			-10
		],
		[
			-31,
			-104
		],
		[
			103,
			-104
		],
		[
			48,
			-20
		],
		[
			-24,
			-114
		],
		[
			108,
			-218
		],
		[
			-36,
			-124
		],
		[
			12,
			-31
		],
		[
			-30,
			-83
		],
		[
			42,
			-31
		],
		[
			90,
			-21
		],
		[
			84,
			-72
		],
		[
			-30,
			-42
		],
		[
			24,
			-93
		],
		[
			-60,
			-103
		],
		[
			48,
			-104
		],
		[
			-6,
			-145
		],
		[
			-24,
			-217
		],
		[
			12,
			-94
		],
		[
			72,
			0
		],
		[
			67,
			-62
		],
		[
			18,
			-93
		],
		[
			42,
			-73
		],
		[
			-115,
			-41
		],
		[
			-66,
			-52
		],
		[
			6,
			0
		],
		[
			42,
			-134
		],
		[
			91,
			-83
		],
		[
			-43,
			-42
		],
		[
			-42,
			-114
		]
	],
	[
		[
			40548,
			10284
		],
		[
			-24,
			-41
		],
		[
			-66,
			41
		],
		[
			-36,
			-62
		],
		[
			-60,
			-52
		],
		[
			-102,
			0
		],
		[
			-114,
			73
		],
		[
			-67,
			72
		],
		[
			-102,
			135
		],
		[
			-210,
			10
		],
		[
			6,
			32
		],
		[
			-175,
			51
		],
		[
			-42,
			31
		],
		[
			-96,
			21
		],
		[
			-42,
			-52
		],
		[
			-72,
			104
		],
		[
			-48,
			114
		],
		[
			-96,
			-42
		],
		[
			-79,
			-134
		],
		[
			-48,
			-31
		],
		[
			0,
			176
		],
		[
			-72,
			-62
		],
		[
			-144,
			0
		],
		[
			-90,
			-21
		],
		[
			-127,
			-145
		],
		[
			-42,
			72
		]
	],
	[
		[
			38600,
			10574
		],
		[
			-48,
			21
		],
		[
			-72,
			-62
		],
		[
			-48,
			-10
		],
		[
			-48,
			-83
		],
		[
			-90,
			0
		],
		[
			-42,
			-31
		],
		[
			-115,
			0
		],
		[
			-24,
			-42
		],
		[
			-72,
			-10
		],
		[
			-78,
			-135
		]
	],
	[
		[
			37963,
			10222
		],
		[
			-156,
			-31
		],
		[
			-36,
			-41
		],
		[
			-61,
			103
		],
		[
			-48,
			42
		],
		[
			-18,
			124
		],
		[
			18,
			41
		],
		[
			-108,
			42
		],
		[
			-126,
			103
		],
		[
			-72,
			83
		],
		[
			-24,
			104
		],
		[
			-66,
			52
		],
		[
			-6,
			114
		],
		[
			-25,
			72
		],
		[
			-78,
			73
		],
		[
			-66,
			82
		],
		[
			-150,
			166
		],
		[
			-138,
			-31
		],
		[
			-85,
			62
		],
		[
			-138,
			42
		],
		[
			-108,
			0
		]
	],
	[
		[
			36472,
			11424
		],
		[
			-18,
			51
		],
		[
			-108,
			32
		],
		[
			-91,
			134
		],
		[
			12,
			52
		],
		[
			-18,
			104
		],
		[
			115,
			51
		],
		[
			-12,
			52
		]
	],
	[
		[
			36352,
			11900
		],
		[
			6,
			31
		],
		[
			78,
			42
		],
		[
			0,
			62
		],
		[
			132,
			228
		],
		[
			60,
			62
		],
		[
			6,
			41
		],
		[
			54,
			73
		],
		[
			42,
			114
		],
		[
			49,
			93
		],
		[
			24,
			134
		],
		[
			42,
			145
		],
		[
			36,
			31
		],
		[
			54,
			104
		],
		[
			-24,
			52
		],
		[
			30,
			41
		],
		[
			-6,
			83
		],
		[
			-30,
			124
		],
		[
			-42,
			63
		],
		[
			-84,
			20
		],
		[
			-43,
			-20
		],
		[
			-6,
			134
		]
	],
	[
		[
			36730,
			13557
		],
		[
			55,
			73
		],
		[
			-25,
			103
		],
		[
			-78,
			0
		]
	],
	[
		[
			36779,
			16115
		],
		[
			30,
			42
		],
		[
			90,
			10
		],
		[
			36,
			-21
		],
		[
			18,
			104
		],
		[
			96,
			31
		],
		[
			102,
			73
		],
		[
			6,
			-73
		],
		[
			151,
			10
		],
		[
			132,
			-31
		],
		[
			30,
			-31
		],
		[
			186,
			290
		],
		[
			367,
			487
		],
		[
			18,
			-31
		],
		[
			169,
			-145
		],
		[
			78,
			-52
		],
		[
			90,
			31
		],
		[
			60,
			-83
		],
		[
			78,
			-31
		],
		[
			120,
			-20
		],
		[
			-60,
			186
		],
		[
			54,
			93
		],
		[
			54,
			31
		],
		[
			127,
			-124
		],
		[
			96,
			-10
		],
		[
			66,
			-52
		],
		[
			48,
			-10
		],
		[
			30,
			51
		],
		[
			-54,
			52
		],
		[
			0,
			42
		]
	],
	[
		[
			38997,
			16934
		],
		[
			-42,
			113
		],
		[
			126,
			52
		],
		[
			6,
			-31
		],
		[
			115,
			-176
		]
	],
	[
		[
			39202,
			16892
		],
		[
			12,
			-41
		],
		[
			96,
			10
		],
		[
			84,
			52
		],
		[
			18,
			52
		],
		[
			-42,
			51
		],
		[
			66,
			114
		],
		[
			-42,
			83
		],
		[
			48,
			31
		],
		[
			84,
			-197
		],
		[
			48,
			-93
		]
	],
	[
		[
			48455,
			21822
		],
		[
			-24,
			21
		],
		[
			-199,
			41
		],
		[
			-30,
			-72
		],
		[
			-48,
			-42
		],
		[
			-6,
			-93
		],
		[
			-102,
			0
		],
		[
			-54,
			-31
		],
		[
			-30,
			-83
		],
		[
			-66,
			-93
		],
		[
			-91,
			-31
		],
		[
			79,
			-156
		],
		[
			24,
			-82
		],
		[
			-18,
			-52
		],
		[
			-133,
			-166
		],
		[
			-60,
			-10
		],
		[
			-12,
			-73
		],
		[
			-36,
			-52
		],
		[
			30,
			-51
		],
		[
			-120,
			-62
		],
		[
			-168,
			-11
		],
		[
			-30,
			-41
		],
		[
			-109,
			103
		],
		[
			-78,
			135
		],
		[
			-84,
			-41
		],
		[
			-78,
			-83
		],
		[
			0,
			-73
		],
		[
			-48,
			-124
		],
		[
			-78,
			145
		],
		[
			-115,
			114
		],
		[
			-48,
			-11
		],
		[
			-66,
			114
		],
		[
			-96,
			11
		],
		[
			-60,
			41
		],
		[
			30,
			62
		],
		[
			-48,
			52
		]
	],
	[
		[
			46044,
			21926
		],
		[
			36,
			124
		],
		[
			72,
			114
		],
		[
			66,
			62
		],
		[
			-36,
			83
		],
		[
			-54,
			290
		],
		[
			36,
			41
		],
		[
			66,
			11
		],
		[
			144,
			72
		]
	],
	[
		[
			46374,
			22723
		],
		[
			49,
			-10
		],
		[
			132,
			-114
		],
		[
			78,
			-125
		],
		[
			60,
			42
		],
		[
			90,
			0
		],
		[
			0,
			83
		],
		[
			48,
			41
		],
		[
			-18,
			93
		],
		[
			-36,
			104
		],
		[
			127,
			186
		],
		[
			66,
			73
		],
		[
			114,
			21
		],
		[
			66,
			-31
		],
		[
			60,
			41
		]
	],
	[
		[
			47210,
			23127
		],
		[
			126,
			-83
		],
		[
			61,
			-21
		],
		[
			-12,
			-145
		],
		[
			72,
			-62
		],
		[
			6,
			-41
		],
		[
			108,
			0
		],
		[
			18,
			-62
		],
		[
			42,
			31
		],
		[
			96,
			-11
		],
		[
			-12,
			-259
		],
		[
			30,
			-186
		],
		[
			103,
			10
		],
		[
			18,
			-31
		],
		[
			48,
			31
		],
		[
			6,
			63
		],
		[
			114,
			20
		],
		[
			54,
			-41
		],
		[
			84,
			21
		],
		[
			78,
			-32
		],
		[
			-84,
			-186
		],
		[
			42,
			-104
		],
		[
			181,
			21
		],
		[
			60,
			-134
		],
		[
			60,
			-42
		],
		[
			-18,
			-72
		],
		[
			-36,
			10
		]
	],
	[
		[
			48455,
			21822
		],
		[
			-60,
			-72
		],
		[
			198,
			-104
		],
		[
			54,
			-62
		]
	],
	[
		[
			48647,
			21584
		],
		[
			-60,
			-104
		],
		[
			48,
			-41
		],
		[
			66,
			10
		],
		[
			151,
			-41
		],
		[
			102,
			0
		],
		[
			24,
			41
		],
		[
			42,
			-10
		],
		[
			42,
			-52
		],
		[
			6,
			-72
		],
		[
			-24,
			-156
		],
		[
			12,
			-72
		],
		[
			-24,
			-83
		],
		[
			6,
			-73
		],
		[
			-48,
			-83
		]
	],
	[
		[
			48990,
			20848
		],
		[
			-42,
			-62
		],
		[
			-60,
			-124
		],
		[
			-115,
			10
		],
		[
			-144,
			-238
		],
		[
			108,
			-248
		],
		[
			-72,
			-21
		],
		[
			-90,
			-52
		],
		[
			-42,
			-41
		],
		[
			-42,
			10
		],
		[
			-6,
			-62
		]
	],
	[
		[
			48485,
			20020
		],
		[
			-18,
			-73
		],
		[
			-54,
			0
		],
		[
			-18,
			-51
		],
		[
			-60,
			0
		],
		[
			-37,
			134
		],
		[
			-60,
			73
		],
		[
			-48,
			10
		],
		[
			6,
			-72
		],
		[
			-60,
			-42
		],
		[
			-36,
			-83
		],
		[
			-114,
			21
		],
		[
			-84,
			-10
		],
		[
			-54,
			20
		],
		[
			-67,
			-10
		],
		[
			30,
			-93
		],
		[
			55,
			0
		],
		[
			12,
			-156
		],
		[
			-139,
			-82
		],
		[
			-54,
			41
		],
		[
			24,
			52
		],
		[
			6,
			124
		],
		[
			-12,
			73
		],
		[
			-60,
			-21
		],
		[
			-24,
			-93
		],
		[
			-24,
			0
		],
		[
			-30,
			-197
		],
		[
			-6,
			0
		],
		[
			-6,
			-52
		],
		[
			24,
			-103
		],
		[
			72,
			-42
		],
		[
			24,
			-93
		]
	],
	[
		[
			47848,
			18901
		],
		[
			0,
			-62
		],
		[
			48,
			-114
		],
		[
			42,
			-51
		]
	],
	[
		[
			47938,
			18674
		],
		[
			-24,
			-42
		],
		[
			-72,
			-41
		],
		[
			-43,
			10
		],
		[
			-30,
			-104
		],
		[
			-30,
			-20
		],
		[
			-180,
			114
		]
	],
	[
		[
			47559,
			18591
		],
		[
			-96,
			83
		],
		[
			-18,
			-32
		],
		[
			-78,
			52
		],
		[
			-55,
			-41
		],
		[
			-36,
			52
		],
		[
			-60,
			-31
		],
		[
			-36,
			51
		],
		[
			-42,
			-20
		],
		[
			42,
			-73
		],
		[
			-48,
			-31
		],
		[
			-66,
			10
		],
		[
			-6,
			-72
		],
		[
			-60,
			10
		],
		[
			-36,
			-114
		],
		[
			36,
			-83
		],
		[
			-126,
			-93
		],
		[
			-49,
			31
		],
		[
			-54,
			94
		],
		[
			-66,
			72
		]
	],
	[
		[
			46705,
			18456
		],
		[
			54,
			-21
		],
		[
			36,
			62
		],
		[
			-60,
			42
		],
		[
			-54,
			93
		],
		[
			-30,
			0
		],
		[
			-54,
			93
		],
		[
			-30,
			104
		],
		[
			-54,
			41
		],
		[
			-132,
			42
		],
		[
			-61,
			103
		],
		[
			-48,
			-41
		],
		[
			-108,
			31
		],
		[
			-72,
			52
		],
		[
			0,
			31
		],
		[
			-78,
			72
		],
		[
			-127,
			-10
		],
		[
			-42,
			83
		],
		[
			55,
			103
		],
		[
			54,
			145
		],
		[
			0,
			62
		],
		[
			78,
			63
		],
		[
			84,
			114
		],
		[
			12,
			82
		]
	],
	[
		[
			40380,
			53846
		],
		[
			18,
			-21
		]
	],
	[
		[
			40398,
			53825
		],
		[
			-18,
			21
		]
	],
	[
		[
			40494,
			54353
		],
		[
			6,
			0
		]
	],
	[
		[
			40500,
			54353
		],
		[
			-6,
			0
		]
	],
	[
		[
			40494,
			54353
		],
		[
			6,
			0
		]
	],
	[
		[
			40602,
			54394
		],
		[
			0,
			11
		]
	],
	[
		[
			40602,
			54405
		],
		[
			0,
			-11
		]
	],
	[
		[
			39508,
			54819
		],
		[
			90,
			-31
		],
		[
			30,
			10
		],
		[
			-18,
			-155
		],
		[
			-66,
			10
		],
		[
			-54,
			-20
		],
		[
			-18,
			93
		],
		[
			-72,
			52
		],
		[
			-96,
			-11
		],
		[
			-30,
			-31
		],
		[
			-66,
			21
		],
		[
			-12,
			62
		],
		[
			78,
			0
		],
		[
			114,
			-31
		],
		[
			72,
			31
		],
		[
			48,
			0
		]
	],
	[
		[
			37662,
			55337
		],
		[
			6,
			-10
		]
	],
	[
		[
			37668,
			55327
		],
		[
			-6,
			10
		]
	],
	[
		[
			37933,
			55513
		],
		[
			-6,
			0
		]
	],
	[
		[
			37927,
			55513
		],
		[
			6,
			0
		]
	],
	[
		[
			39562,
			54436
		],
		[
			36,
			-31
		],
		[
			115,
			-166
		],
		[
			-42,
			-83
		],
		[
			-43,
			-31
		],
		[
			61,
			-93
		],
		[
			60,
			41
		],
		[
			12,
			42
		],
		[
			78,
			52
		],
		[
			72,
			-11
		],
		[
			78,
			-52
		],
		[
			138,
			-51
		],
		[
			25,
			-42
		],
		[
			84,
			-72
		],
		[
			54,
			-73
		],
		[
			54,
			-31
		],
		[
			36,
			11
		]
	],
	[
		[
			40380,
			53846
		],
		[
			18,
			-21
		]
	],
	[
		[
			40398,
			53825
		],
		[
			6,
			-104
		],
		[
			96,
			-155
		],
		[
			-36,
			-52
		],
		[
			-18,
			-83
		],
		[
			24,
			-62
		],
		[
			90,
			-114
		],
		[
			-6,
			-72
		],
		[
			30,
			-42
		],
		[
			-18,
			-83
		],
		[
			36,
			-51
		],
		[
			109,
			-52
		],
		[
			-6,
			-187
		],
		[
			24,
			-72
		],
		[
			-30,
			-41
		],
		[
			30,
			-52
		],
		[
			6,
			-62
		],
		[
			-36,
			-52
		],
		[
			66,
			-73
		],
		[
			30,
			0
		],
		[
			-30,
			-155
		],
		[
			12,
			-93
		],
		[
			-48,
			0
		],
		[
			-48,
			-104
		],
		[
			-66,
			-103
		],
		[
			36,
			-218
		],
		[
			114,
			-207
		],
		[
			60,
			-21
		],
		[
			126,
			-145
		],
		[
			0,
			-93
		],
		[
			-36,
			-21
		],
		[
			-60,
			-114
		],
		[
			-30,
			-103
		],
		[
			0,
			-93
		],
		[
			30,
			-125
		],
		[
			30,
			-72
		],
		[
			96,
			-156
		],
		[
			24,
			-10
		],
		[
			84,
			-103
		],
		[
			-18,
			-52
		],
		[
			31,
			-83
		],
		[
			108,
			-176
		],
		[
			6,
			-83
		],
		[
			-36,
			0
		],
		[
			-30,
			-52
		],
		[
			-6,
			-72
		],
		[
			-48,
			-83
		],
		[
			18,
			-124
		],
		[
			132,
			-218
		],
		[
			12,
			-93
		],
		[
			-12,
			-42
		],
		[
			24,
			-93
		],
		[
			66,
			-124
		],
		[
			78,
			-41
		],
		[
			48,
			-104
		]
	],
	[
		[
			41462,
			49040
		],
		[
			-36,
			10
		],
		[
			-132,
			-114
		],
		[
			18,
			-72
		],
		[
			-126,
			-73
		],
		[
			-6,
			73
		],
		[
			-127,
			-10
		],
		[
			-42,
			72
		],
		[
			-18,
			-31
		],
		[
			-78,
			-41
		],
		[
			-120,
			20
		],
		[
			-12,
			62
		],
		[
			-247,
			31
		],
		[
			-96,
			-10
		]
	],
	[
		[
			40440,
			48957
		],
		[
			-54,
			135
		],
		[
			-42,
			0
		],
		[
			-144,
			-42
		],
		[
			-97,
			-41
		],
		[
			-42,
			-52
		],
		[
			-54,
			0
		],
		[
			18,
			-114
		],
		[
			72,
			-10
		],
		[
			18,
			-83
		],
		[
			-84,
			-10
		],
		[
			-48,
			-31
		],
		[
			-126,
			-125
		],
		[
			-60,
			-20
		],
		[
			-36,
			-73
		],
		[
			-12,
			-124
		],
		[
			-90,
			10
		],
		[
			-13,
			-135
		],
		[
			37,
			-72
		]
	],
	[
		[
			39683,
			48170
		],
		[
			-91,
			31
		]
	],
	[
		[
			39592,
			48201
		],
		[
			-162,
			-83
		],
		[
			6,
			-52
		],
		[
			-54,
			-41
		],
		[
			-12,
			-62
		]
	],
	[
		[
			39370,
			47963
		],
		[
			-60,
			-83
		],
		[
			18,
			-31
		],
		[
			6,
			0
		],
		[
			30,
			-62
		],
		[
			-12,
			-104
		],
		[
			-84,
			0
		],
		[
			-42,
			-145
		],
		[
			126,
			-41
		],
		[
			24,
			-42
		]
	],
	[
		[
			36550,
			46378
		],
		[
			-66,
			31
		],
		[
			-24,
			73
		],
		[
			-54,
			41
		],
		[
			-48,
			-10
		],
		[
			-85,
			103
		],
		[
			-54,
			42
		],
		[
			-18,
			62
		],
		[
			-114,
			52
		],
		[
			-54,
			176
		],
		[
			-60,
			41
		],
		[
			-48,
			-114
		],
		[
			-205,
			-124
		],
		[
			-30,
			21
		],
		[
			-102,
			-135
		],
		[
			-96,
			-83
		],
		[
			-72,
			0
		],
		[
			-90,
			-41
		],
		[
			-61,
			10
		],
		[
			-54,
			52
		],
		[
			-84,
			41
		],
		[
			-60,
			63
		],
		[
			-84,
			207
		]
	],
	[
		[
			34987,
			46886
		],
		[
			54,
			72
		],
		[
			-42,
			104
		],
		[
			-48,
			52
		],
		[
			-90,
			145
		],
		[
			132,
			82
		],
		[
			42,
			52
		],
		[
			42,
			93
		],
		[
			6,
			94
		],
		[
			42,
			51
		],
		[
			72,
			21
		],
		[
			0,
			31
		],
		[
			-78,
			42
		],
		[
			-42,
			62
		],
		[
			-24,
			72
		],
		[
			18,
			93
		],
		[
			-174,
			63
		],
		[
			-12,
			82
		],
		[
			54,
			0
		],
		[
			12,
			63
		],
		[
			54,
			20
		],
		[
			42,
			62
		],
		[
			24,
			104
		],
		[
			-36,
			104
		],
		[
			54,
			82
		],
		[
			54,
			0
		],
		[
			54,
			32
		],
		[
			42,
			51
		],
		[
			60,
			0
		],
		[
			24,
			42
		],
		[
			67,
			0
		],
		[
			42,
			31
		],
		[
			72,
			0
		],
		[
			60,
			31
		],
		[
			-12,
			52
		],
		[
			-90,
			103
		],
		[
			-18,
			62
		],
		[
			60,
			31
		],
		[
			-36,
			63
		],
		[
			18,
			72
		],
		[
			36,
			31
		]
	],
	[
		[
			35522,
			49133
		],
		[
			-30,
			21
		]
	],
	[
		[
			35492,
			49154
		],
		[
			-30,
			41
		],
		[
			-102,
			-51
		],
		[
			-73,
			0
		],
		[
			-150,
			-42
		],
		[
			-18,
			73
		]
	],
	[
		[
			35119,
			49175
		],
		[
			-48,
			72
		],
		[
			-48,
			0
		],
		[
			-36,
			52
		],
		[
			-54,
			21
		],
		[
			-6,
			82
		],
		[
			-36,
			32
		],
		[
			-36,
			93
		],
		[
			-91,
			31
		],
		[
			-66,
			-11
		],
		[
			-138,
			73
		],
		[
			-30,
			104
		],
		[
			-66,
			51
		],
		[
			-54,
			135
		],
		[
			30,
			104
		],
		[
			-72,
			103
		]
	],
	[
		[
			34368,
			50117
		],
		[
			48,
			93
		],
		[
			-6,
			31
		],
		[
			90,
			187
		],
		[
			108,
			-11
		],
		[
			54,
			21
		],
		[
			24,
			83
		]
	],
	[
		[
			34686,
			50521
		],
		[
			42,
			176
		],
		[
			-96,
			73
		],
		[
			18,
			31
		],
		[
			84,
			10
		],
		[
			18,
			72
		],
		[
			84,
			125
		],
		[
			109,
			83
		],
		[
			66,
			20
		],
		[
			30,
			62
		],
		[
			132,
			145
		],
		[
			114,
			63
		],
		[
			61,
			0
		],
		[
			66,
			82
		],
		[
			78,
			156
		],
		[
			42,
			41
		],
		[
			60,
			21
		],
		[
			60,
			-21
		],
		[
			132,
			62
		],
		[
			91,
			-20
		],
		[
			78,
			20
		],
		[
			84,
			-51
		],
		[
			6,
			-52
		],
		[
			84,
			0
		],
		[
			72,
			72
		],
		[
			199,
			114
		],
		[
			-48,
			52
		],
		[
			54,
			31
		],
		[
			12,
			62
		],
		[
			-6,
			93
		],
		[
			-42,
			73
		],
		[
			54,
			10
		],
		[
			-12,
			62
		],
		[
			132,
			-10
		],
		[
			18,
			31
		],
		[
			78,
			42
		],
		[
			12,
			51
		],
		[
			121,
			52
		],
		[
			72,
			62
		],
		[
			108,
			0
		],
		[
			72,
			-20
		],
		[
			150,
			72
		],
		[
			60,
			83
		],
		[
			55,
			166
		],
		[
			102,
			31
		],
		[
			-42,
			41
		],
		[
			-163,
			31
		],
		[
			-24,
			42
		],
		[
			18,
			93
		],
		[
			-96,
			155
		],
		[
			-54,
			31
		],
		[
			24,
			125
		],
		[
			-48,
			62
		],
		[
			6,
			145
		],
		[
			-120,
			155
		],
		[
			-102,
			83
		],
		[
			-55,
			72
		],
		[
			-30,
			0
		],
		[
			-42,
			73
		],
		[
			24,
			62
		],
		[
			0,
			83
		],
		[
			-42,
			72
		],
		[
			-66,
			21
		],
		[
			-54,
			93
		],
		[
			42,
			21
		],
		[
			-12,
			62
		],
		[
			-60,
			-31
		],
		[
			-78,
			52
		],
		[
			90,
			103
		],
		[
			48,
			32
		],
		[
			66,
			10
		],
		[
			60,
			-31
		],
		[
			97,
			-11
		],
		[
			72,
			21
		],
		[
			48,
			-10
		],
		[
			36,
			-42
		],
		[
			48,
			11
		],
		[
			30,
			41
		],
		[
			-90,
			52
		],
		[
			78,
			72
		],
		[
			18,
			42
		],
		[
			60,
			10
		],
		[
			12,
			114
		],
		[
			108,
			114
		],
		[
			91,
			135
		],
		[
			78,
			31
		],
		[
			-30,
			83
		],
		[
			12,
			62
		],
		[
			72,
			21
		],
		[
			42,
			-11
		],
		[
			36,
			52
		],
		[
			-12,
			72
		],
		[
			72,
			52
		]
	],
	[
		[
			37560,
			55316
		],
		[
			66,
			-31
		]
	],
	[
		[
			37626,
			55285
		],
		[
			36,
			0
		],
		[
			30,
			104
		],
		[
			43,
			-11
		],
		[
			-13,
			94
		],
		[
			67,
			51
		],
		[
			186,
			-31
		],
		[
			60,
			-20
		],
		[
			84,
			20
		],
		[
			66,
			83
		],
		[
			91,
			31
		],
		[
			54,
			-93
		],
		[
			48,
			-10
		],
		[
			114,
			-135
		],
		[
			30,
			-52
		],
		[
			42,
			-20
		],
		[
			12,
			-52
		],
		[
			84,
			-62
		],
		[
			49,
			-63
		],
		[
			108,
			-72
		],
		[
			60,
			-73
		],
		[
			144,
			-93
		],
		[
			24,
			-83
		],
		[
			36,
			-20
		],
		[
			0,
			-73
		],
		[
			78,
			-155
		],
		[
			79,
			-62
		],
		[
			84,
			-135
		],
		[
			108,
			-41
		],
		[
			66,
			20
		],
		[
			66,
			104
		]
	],
	[
		[
			37927,
			55513
		],
		[
			-72,
			10
		]
	],
	[
		[
			37855,
			55523
		],
		[
			-6,
			83
		],
		[
			6,
			207
		],
		[
			42,
			0
		],
		[
			78,
			83
		],
		[
			72,
			0
		],
		[
			108,
			83
		]
	],
	[
		[
			38155,
			55979
		],
		[
			12,
			-52
		],
		[
			181,
			-186
		],
		[
			18,
			-93
		],
		[
			36,
			-73
		],
		[
			-72,
			-21
		],
		[
			-60,
			83
		],
		[
			-115,
			-31
		],
		[
			-36,
			-103
		],
		[
			-84,
			-21
		],
		[
			-102,
			31
		]
	],
	[
		[
			46705,
			18456
		],
		[
			-24,
			41
		],
		[
			-30,
			-72
		],
		[
			-66,
			-62
		],
		[
			-48,
			-93
		],
		[
			-54,
			10
		],
		[
			-36,
			62
		],
		[
			-79,
			-21
		],
		[
			-126,
			73
		],
		[
			-66,
			-42
		],
		[
			-132,
			0
		],
		[
			-60,
			94
		],
		[
			-30,
			93
		],
		[
			-42,
			52
		],
		[
			12,
			93
		],
		[
			-24,
			62
		],
		[
			-43,
			10
		],
		[
			-42,
			-41
		],
		[
			-60,
			31
		],
		[
			-90,
			-93
		],
		[
			-18,
			-52
		],
		[
			-48,
			-41
		],
		[
			78,
			-104
		],
		[
			12,
			-41
		],
		[
			60,
			-63
		],
		[
			54,
			42
		],
		[
			78,
			-93
		],
		[
			79,
			-125
		],
		[
			6,
			-82
		],
		[
			42,
			-187
		]
	],
	[
		[
			46008,
			17907
		],
		[
			-108,
			-93
		],
		[
			-13,
			-83
		],
		[
			-102,
			10
		],
		[
			-42,
			-41
		],
		[
			36,
			-218
		],
		[
			-84,
			-41
		],
		[
			-48,
			0
		]
	],
	[
		[
			45647,
			17441
		],
		[
			-54,
			73
		],
		[
			-54,
			155
		],
		[
			-48,
			62
		],
		[
			12,
			83
		],
		[
			-30,
			93
		],
		[
			-42,
			73
		],
		[
			-67,
			-63
		],
		[
			-78,
			114
		],
		[
			-132,
			0
		],
		[
			-60,
			-31
		],
		[
			-18,
			-72
		],
		[
			-30,
			-21
		],
		[
			-90,
			10
		],
		[
			0,
			-82
		],
		[
			-115,
			-114
		],
		[
			-84,
			31
		],
		[
			-78,
			0
		],
		[
			0,
			-52
		],
		[
			-48,
			-83
		]
	],
	[
		[
			44631,
			17617
		],
		[
			-24,
			-10
		]
	],
	[
		[
			44607,
			17607
		],
		[
			-42,
			103
		],
		[
			-24,
			-10
		],
		[
			-48,
			62
		],
		[
			-157,
			62
		],
		[
			-66,
			-10
		],
		[
			-36,
			-52
		],
		[
			-96,
			0
		],
		[
			-84,
			31
		],
		[
			-66,
			-10
		],
		[
			-49,
			-104
		],
		[
			-78,
			21
		],
		[
			-156,
			114
		],
		[
			-48,
			-21
		],
		[
			-12,
			73
		],
		[
			24,
			51
		],
		[
			-6,
			73
		],
		[
			-30,
			41
		],
		[
			-120,
			0
		],
		[
			-55,
			52
		],
		[
			-36,
			0
		],
		[
			-12,
			62
		]
	],
	[
		[
			43410,
			18145
		],
		[
			24,
			62
		],
		[
			-18,
			94
		],
		[
			48,
			72
		],
		[
			-90,
			124
		],
		[
			6,
			73
		],
		[
			42,
			62
		],
		[
			54,
			-41
		],
		[
			49,
			0
		],
		[
			102,
			-94
		],
		[
			60,
			-20
		],
		[
			48,
			52
		],
		[
			108,
			41
		],
		[
			-78,
			52
		],
		[
			6,
			41
		],
		[
			-48,
			249
		],
		[
			-12,
			134
		],
		[
			-30,
			-10
		],
		[
			-90,
			52
		],
		[
			30,
			31
		],
		[
			30,
			145
		],
		[
			6,
			145
		]
	],
	[
		[
			43657,
			19409
		],
		[
			66,
			62
		],
		[
			42,
			10
		],
		[
			36,
			62
		],
		[
			-18,
			73
		],
		[
			-96,
			-62
		],
		[
			-72,
			114
		],
		[
			-42,
			20
		],
		[
			60,
			104
		],
		[
			42,
			114
		],
		[
			132,
			207
		],
		[
			-24,
			52
		],
		[
			-174,
			0
		],
		[
			-48,
			62
		],
		[
			-30,
			-21
		],
		[
			-55,
			42
		],
		[
			-30,
			-11
		]
	],
	[
		[
			43446,
			20237
		],
		[
			-108,
			42
		],
		[
			0,
			31
		],
		[
			60,
			145
		]
	],
	[
		[
			43398,
			20455
		],
		[
			48,
			83
		],
		[
			91,
			0
		],
		[
			36,
			31
		],
		[
			72,
			10
		],
		[
			36,
			62
		],
		[
			84,
			42
		],
		[
			54,
			-31
		],
		[
			72,
			62
		],
		[
			54,
			-31
		],
		[
			12,
			62
		],
		[
			55,
			31
		],
		[
			72,
			-10
		]
	],
	[
		[
			44084,
			20766
		],
		[
			78,
			10
		],
		[
			66,
			-31
		],
		[
			42,
			31
		],
		[
			42,
			-21
		],
		[
			48,
			83
		],
		[
			42,
			21
		],
		[
			42,
			-83
		],
		[
			19,
			-83
		],
		[
			66,
			-135
		],
		[
			18,
			-103
		],
		[
			72,
			-83
		],
		[
			48,
			-83
		],
		[
			36,
			52
		],
		[
			60,
			41
		],
		[
			66,
			-10
		],
		[
			36,
			93
		]
	],
	[
		[
			46008,
			17907
		],
		[
			84,
			-41
		],
		[
			90,
			-94
		],
		[
			120,
			0
		],
		[
			103,
			-41
		],
		[
			24,
			21
		],
		[
			84,
			0
		],
		[
			12,
			-52
		],
		[
			66,
			-104
		],
		[
			36,
			31
		],
		[
			72,
			-62
		],
		[
			24,
			-83
		],
		[
			-36,
			-10
		],
		[
			-42,
			-93
		],
		[
			84,
			-83
		],
		[
			36,
			-93
		],
		[
			-36,
			-62
		],
		[
			18,
			-62
		],
		[
			84,
			0
		],
		[
			43,
			20
		]
	],
	[
		[
			46874,
			17099
		],
		[
			90,
			-41
		],
		[
			0,
			-62
		],
		[
			-36,
			-62
		],
		[
			-36,
			31
		],
		[
			-18,
			-94
		],
		[
			-49,
			42
		],
		[
			-24,
			-93
		],
		[
			30,
			-31
		],
		[
			-48,
			-104
		],
		[
			24,
			-31
		],
		[
			36,
			-187
		],
		[
			37,
			-93
		]
	],
	[
		[
			46880,
			16374
		],
		[
			-85,
			-72
		],
		[
			-30,
			-52
		],
		[
			-36,
			21
		],
		[
			-72,
			-11
		],
		[
			-84,
			-41
		],
		[
			-66,
			21
		],
		[
			-60,
			51
		],
		[
			-60,
			11
		],
		[
			-13,
			134
		],
		[
			-36,
			11
		],
		[
			43,
			145
		],
		[
			-67,
			52
		],
		[
			-6,
			-52
		],
		[
			-78,
			62
		],
		[
			-48,
			-62
		],
		[
			6,
			-93
		],
		[
			-66,
			-11
		],
		[
			-54,
			-72
		],
		[
			-66,
			-21
		]
	],
	[
		[
			46002,
			16395
		],
		[
			-24,
			124
		],
		[
			-54,
			-31
		],
		[
			0,
			114
		],
		[
			-49,
			166
		],
		[
			31,
			72
		],
		[
			-55,
			62
		],
		[
			-30,
			0
		]
	],
	[
		[
			45821,
			16902
		],
		[
			-78,
			114
		],
		[
			-60,
			11
		],
		[
			-36,
			83
		],
		[
			-66,
			10
		],
		[
			-60,
			83
		],
		[
			-12,
			83
		],
		[
			36,
			51
		],
		[
			24,
			-41
		],
		[
			60,
			73
		],
		[
			18,
			72
		]
	],
	[
		[
			46880,
			16374
		],
		[
			30,
			-52
		],
		[
			96,
			0
		]
	],
	[
		[
			47006,
			16322
		],
		[
			12,
			-82
		],
		[
			84,
			-156
		],
		[
			0,
			-72
		],
		[
			42,
			-114
		],
		[
			-60,
			-52
		],
		[
			-24,
			-72
		],
		[
			12,
			-290
		],
		[
			36,
			-31
		]
	],
	[
		[
			47108,
			15453
		],
		[
			-36,
			-125
		]
	],
	[
		[
			45893,
			15970
		],
		[
			91,
			11
		],
		[
			36,
			83
		],
		[
			-30,
			41
		],
		[
			36,
			83
		],
		[
			-6,
			72
		],
		[
			-30,
			62
		],
		[
			12,
			73
		]
	],
	[
		[
			44721,
			15805
		],
		[
			-36,
			10
		],
		[
			6,
			93
		],
		[
			-102,
			52
		],
		[
			-60,
			72
		],
		[
			-48,
			21
		],
		[
			-18,
			135
		],
		[
			96,
			52
		],
		[
			48,
			72
		],
		[
			-18,
			42
		],
		[
			-60,
			10
		],
		[
			-18,
			-31
		],
		[
			-61,
			31
		],
		[
			0,
			62
		],
		[
			31,
			62
		],
		[
			-67,
			31
		],
		[
			6,
			93
		],
		[
			30,
			0
		],
		[
			55,
			52
		],
		[
			-61,
			93
		],
		[
			31,
			73
		],
		[
			48,
			-10
		],
		[
			48,
			41
		],
		[
			-36,
			62
		],
		[
			60,
			73
		],
		[
			66,
			20
		],
		[
			72,
			-51
		],
		[
			60,
			-11
		],
		[
			18,
			52
		],
		[
			-78,
			21
		],
		[
			48,
			62
		],
		[
			6,
			52
		],
		[
			-54,
			51
		],
		[
			48,
			114
		],
		[
			-6,
			135
		],
		[
			-48,
			31
		],
		[
			-30,
			73
		],
		[
			-66,
			72
		]
	],
	[
		[
			50944,
			21853
		],
		[
			6,
			-155
		],
		[
			-114,
			10
		],
		[
			-42,
			-72
		],
		[
			-78,
			62
		],
		[
			-121,
			-52
		],
		[
			-102,
			-73
		],
		[
			24,
			114
		],
		[
			-48,
			11
		],
		[
			12,
			114
		],
		[
			24,
			62
		],
		[
			-42,
			72
		],
		[
			-108,
			62
		],
		[
			-60,
			114
		],
		[
			72,
			21
		],
		[
			156,
			114
		],
		[
			60,
			10
		],
		[
			66,
			42
		],
		[
			103,
			-52
		],
		[
			42,
			62
		],
		[
			66,
			-21
		],
		[
			-66,
			-72
		],
		[
			60,
			-83
		],
		[
			60,
			-10
		],
		[
			-30,
			-73
		],
		[
			72,
			-103
		],
		[
			-12,
			-104
		]
	],
	[
		[
			51317,
			24805
		],
		[
			-607,
			-746
		],
		[
			-97,
			-62
		]
	],
	[
		[
			50613,
			23997
		],
		[
			-48,
			-41
		]
	],
	[
		[
			50565,
			23956
		],
		[
			-90,
			-114
		],
		[
			-36,
			-73
		]
	],
	[
		[
			50439,
			23769
		],
		[
			-247,
			-311
		]
	],
	[
		[
			50192,
			23458
		],
		[
			-6,
			52
		],
		[
			-48,
			166
		],
		[
			-42,
			41
		]
	],
	[
		[
			50096,
			23717
		],
		[
			114,
			94
		],
		[
			-6,
			124
		],
		[
			-66,
			52
		],
		[
			24,
			51
		],
		[
			54,
			-51
		],
		[
			43,
			41
		],
		[
			120,
			52
		],
		[
			24,
			52
		],
		[
			114,
			-42
		],
		[
			78,
			62
		],
		[
			-12,
			-72
		],
		[
			30,
			-31
		],
		[
			157,
			207
		],
		[
			24,
			-21
		],
		[
			138,
			176
		],
		[
			-12,
			21
		],
		[
			343,
			435
		]
	],
	[
		[
			51263,
			24867
		],
		[
			54,
			-62
		]
	],
	[
		[
			52375,
			24194
		],
		[
			-18,
			-52
		],
		[
			-48,
			-21
		],
		[
			-247,
			-176
		],
		[
			54,
			-166
		],
		[
			30,
			-41
		],
		[
			121,
			-259
		],
		[
			54,
			-21
		],
		[
			0,
			-51
		],
		[
			90,
			0
		],
		[
			42,
			-31
		],
		[
			-30,
			-135
		],
		[
			-78,
			-52
		],
		[
			30,
			-52
		],
		[
			12,
			-72
		],
		[
			66,
			10
		]
	],
	[
		[
			52453,
			23075
		],
		[
			96,
			-10
		],
		[
			18,
			-73
		],
		[
			85,
			-51
		]
	],
	[
		[
			52652,
			22941
		],
		[
			114,
			-114
		],
		[
			6,
			-83
		]
	],
	[
		[
			52772,
			22744
		],
		[
			-6,
			-42
		]
	],
	[
		[
			52766,
			22702
		],
		[
			-12,
			-51
		],
		[
			-205,
			-63
		],
		[
			-204,
			-93
		],
		[
			-114,
			176
		],
		[
			-109,
			83
		],
		[
			-12,
			93
		],
		[
			-138,
			42
		],
		[
			0,
			-73
		],
		[
			-48,
			-62
		],
		[
			24,
			-31
		],
		[
			-84,
			-114
		],
		[
			120,
			-176
		],
		[
			-108,
			-62
		],
		[
			168,
			-145
		],
		[
			72,
			62
		],
		[
			61,
			-31
		],
		[
			78,
			83
		],
		[
			78,
			10
		]
	],
	[
		[
			52333,
			22350
		],
		[
			-24,
			62
		],
		[
			54,
			62
		],
		[
			96,
			-103
		],
		[
			72,
			52
		],
		[
			54,
			-73
		],
		[
			30,
			11
		],
		[
			55,
			-83
		],
		[
			54,
			62
		],
		[
			30,
			0
		],
		[
			72,
			-83
		],
		[
			36,
			-21
		],
		[
			-6,
			-124
		]
	],
	[
		[
			52856,
			22112
		],
		[
			-54,
			-73
		],
		[
			-12,
			-134
		],
		[
			-36,
			-42
		],
		[
			0,
			-93
		],
		[
			-42,
			-134
		],
		[
			-60,
			31
		],
		[
			-37,
			-21
		],
		[
			-54,
			62
		],
		[
			-96,
			-10
		],
		[
			-48,
			-104
		],
		[
			-108,
			-10
		]
	],
	[
		[
			52309,
			21584
		],
		[
			-48,
			-21
		],
		[
			-24,
			31
		],
		[
			-60,
			-21
		],
		[
			-31,
			42
		],
		[
			-72,
			21
		]
	],
	[
		[
			52074,
			21636
		],
		[
			-42,
			31
		],
		[
			-102,
			10
		],
		[
			-156,
			93
		],
		[
			-84,
			73
		],
		[
			6,
			41
		],
		[
			-85,
			52
		],
		[
			-54,
			52
		],
		[
			-78,
			31
		],
		[
			-96,
			72
		],
		[
			-138,
			176
		],
		[
			-18,
			52
		],
		[
			-49,
			42
		],
		[
			-36,
			82
		],
		[
			30,
			125
		],
		[
			-54,
			62
		],
		[
			48,
			41
		],
		[
			61,
			83
		],
		[
			0,
			31
		],
		[
			66,
			42
		],
		[
			24,
			93
		],
		[
			24,
			176
		],
		[
			-30,
			52
		],
		[
			-30,
			-42
		],
		[
			-193,
			-31
		],
		[
			-36,
			62
		],
		[
			-126,
			-20
		],
		[
			-60,
			-42
		],
		[
			-30,
			62
		],
		[
			-108,
			0
		],
		[
			-18,
			-31
		],
		[
			-85,
			62
		],
		[
			-90,
			11
		],
		[
			-132,
			72
		],
		[
			-30,
			-10
		],
		[
			-96,
			62
		],
		[
			-121,
			104
		]
	],
	[
		[
			50156,
			23407
		],
		[
			18,
			31
		],
		[
			265,
			331
		]
	],
	[
		[
			50439,
			23769
		],
		[
			30,
			62
		],
		[
			96,
			125
		]
	],
	[
		[
			50613,
			23997
		],
		[
			103,
			62
		],
		[
			601,
			746
		]
	],
	[
		[
			51317,
			24805
		],
		[
			60,
			62
		],
		[
			132,
			10
		],
		[
			175,
			52
		],
		[
			114,
			-41
		],
		[
			120,
			-83
		],
		[
			54,
			0
		],
		[
			48,
			-42
		],
		[
			78,
			-155
		],
		[
			61,
			-41
		],
		[
			60,
			-94
		],
		[
			126,
			-82
		],
		[
			0,
			-114
		],
		[
			30,
			-83
		]
	],
	[
		[
			50096,
			23717
		],
		[
			-30,
			83
		],
		[
			-12,
			114
		],
		[
			-42,
			73
		],
		[
			84,
			124
		],
		[
			-72,
			72
		],
		[
			0,
			83
		],
		[
			-54,
			42
		],
		[
			-18,
			62
		],
		[
			-66,
			0
		],
		[
			-42,
			72
		],
		[
			-127,
			104
		],
		[
			-42,
			0
		],
		[
			-12,
			83
		],
		[
			6,
			186
		],
		[
			-78,
			21
		],
		[
			12,
			52
		],
		[
			-108,
			72
		],
		[
			-6,
			-103
		],
		[
			-114,
			-94
		],
		[
			-42,
			52
		],
		[
			-36,
			-72
		],
		[
			-61,
			-52
		],
		[
			-84,
			114
		],
		[
			-216,
			248
		],
		[
			-24,
			42
		],
		[
			-66,
			20
		],
		[
			-30,
			73
		]
	],
	[
		[
			49182,
			25519
		],
		[
			247,
			63
		]
	],
	[
		[
			49429,
			25582
		],
		[
			312,
			82
		],
		[
			19,
			0
		]
	],
	[
		[
			49826,
			25685
		],
		[
			306,
			73
		],
		[
			127,
			41
		],
		[
			12,
			41
		]
	],
	[
		[
			50271,
			25840
		],
		[
			180,
			166
		],
		[
			114,
			62
		],
		[
			84,
			62
		],
		[
			169,
			239
		]
	],
	[
		[
			50818,
			26369
		],
		[
			0,
			10
		]
	],
	[
		[
			50818,
			26379
		],
		[
			-36,
			73
		]
	],
	[
		[
			50782,
			26452
		],
		[
			6,
			62
		]
	],
	[
		[
			50788,
			26514
		],
		[
			18,
			-21
		],
		[
			120,
			-10
		],
		[
			36,
			-21
		],
		[
			0,
			-197
		],
		[
			-36,
			-31
		],
		[
			-12,
			-72
		],
		[
			42,
			-32
		],
		[
			78,
			-93
		],
		[
			36,
			-10
		],
		[
			84,
			-83
		],
		[
			-36,
			-31
		],
		[
			-54,
			-145
		],
		[
			-60,
			-10
		],
		[
			12,
			-94
		],
		[
			54,
			-114
		],
		[
			72,
			0
		],
		[
			6,
			-103
		],
		[
			-54,
			-10
		],
		[
			-18,
			-177
		],
		[
			54,
			-103
		],
		[
			-12,
			-73
		],
		[
			54,
			-10
		],
		[
			31,
			31
		],
		[
			30,
			-41
		],
		[
			-103,
			-93
		],
		[
			133,
			-104
		]
	],
	[
		[
			50890,
			27042
		],
		[
			-30,
			-135
		],
		[
			-60,
			-155
		],
		[
			-18,
			-300
		]
	],
	[
		[
			50782,
			26452
		],
		[
			36,
			-73
		]
	],
	[
		[
			50818,
			26369
		],
		[
			-48,
			-52
		],
		[
			-67,
			-104
		],
		[
			-90,
			-114
		],
		[
			-108,
			-51
		],
		[
			-66,
			-52
		],
		[
			-168,
			-156
		]
	],
	[
		[
			50271,
			25840
		],
		[
			-18,
			-41
		],
		[
			-127,
			-41
		],
		[
			-300,
			-73
		]
	],
	[
		[
			49717,
			26317
		],
		[
			307,
			31
		],
		[
			150,
			155
		],
		[
			12,
			52
		],
		[
			-30,
			52
		],
		[
			0,
			207
		],
		[
			18,
			41
		],
		[
			97,
			83
		],
		[
			66,
			-31
		],
		[
			78,
			0
		],
		[
			54,
			62
		],
		[
			84,
			-10
		],
		[
			90,
			83
		],
		[
			85,
			21
		],
		[
			30,
			-21
		],
		[
			132,
			0
		]
	],
	[
		[
			50192,
			23458
		],
		[
			-42,
			-41
		],
		[
			-54,
			0
		]
	],
	[
		[
			50096,
			23417
		],
		[
			-24,
			-10
		]
	],
	[
		[
			50072,
			23407
		],
		[
			-120,
			-104
		]
	],
	[
		[
			49952,
			23303
		],
		[
			-6,
			-52
		]
	],
	[
		[
			49946,
			23251
		],
		[
			-72,
			-114
		],
		[
			-18,
			-62
		],
		[
			-42,
			-41
		],
		[
			-97,
			41
		],
		[
			-90,
			-31
		],
		[
			0,
			-52
		],
		[
			-96,
			-196
		],
		[
			-126,
			-145
		],
		[
			-96,
			41
		],
		[
			-127,
			-186
		],
		[
			-108,
			248
		],
		[
			-72,
			10
		],
		[
			-114,
			-41
		],
		[
			-54,
			-176
		],
		[
			42,
			-93
		],
		[
			18,
			41
		],
		[
			96,
			-10
		],
		[
			48,
			-21
		],
		[
			42,
			-62
		],
		[
			54,
			-21
		],
		[
			-42,
			-134
		],
		[
			-108,
			-21
		],
		[
			-102,
			31
		],
		[
			-60,
			-10
		],
		[
			-18,
			-145
		],
		[
			-37,
			-83
		],
		[
			43,
			-42
		],
		[
			60,
			11
		],
		[
			30,
			-42
		],
		[
			114,
			135
		],
		[
			132,
			-42
		],
		[
			78,
			11
		],
		[
			73,
			-52
		],
		[
			0,
			-83
		],
		[
			24,
			-103
		],
		[
			-61,
			-42
		],
		[
			-156,
			52
		],
		[
			-42,
			-10
		],
		[
			-48,
			-83
		],
		[
			-18,
			-62
		],
		[
			-174,
			0
		],
		[
			-24,
			10
		],
		[
			-67,
			-52
		],
		[
			-84,
			-41
		]
	],
	[
		[
			47210,
			23127
		],
		[
			6,
			72
		],
		[
			-18,
			73
		],
		[
			-90,
			31
		],
		[
			36,
			62
		],
		[
			-126,
			114
		],
		[
			-6,
			52
		],
		[
			90,
			155
		],
		[
			84,
			-20
		],
		[
			6,
			31
		],
		[
			132,
			0
		],
		[
			55,
			51
		],
		[
			18,
			73
		],
		[
			66,
			41
		],
		[
			30,
			104
		],
		[
			90,
			31
		],
		[
			126,
			124
		],
		[
			78,
			31
		],
		[
			-24,
			83
		],
		[
			42,
			62
		],
		[
			55,
			125
		],
		[
			48,
			51
		],
		[
			-30,
			156
		],
		[
			-54,
			72
		],
		[
			0,
			62
		],
		[
			30,
			94
		],
		[
			-139,
			41
		],
		[
			-72,
			73
		],
		[
			-90,
			31
		],
		[
			-42,
			41
		],
		[
			18,
			52
		],
		[
			54,
			62
		],
		[
			-12,
			103
		],
		[
			-72,
			21
		],
		[
			-24,
			73
		],
		[
			72,
			62
		],
		[
			-42,
			41
		],
		[
			-6,
			83
		]
	],
	[
		[
			52309,
			21584
		],
		[
			18,
			-21
		],
		[
			-18,
			-217
		],
		[
			-42,
			10
		],
		[
			-30,
			-52
		],
		[
			6,
			-62
		],
		[
			-54,
			0
		],
		[
			-43,
			-52
		],
		[
			-42,
			-134
		],
		[
			61,
			-63
		],
		[
			12,
			-113
		],
		[
			36,
			-21
		]
	],
	[
		[
			52213,
			20859
		],
		[
			0,
			-73
		],
		[
			24,
			-83
		]
	],
	[
		[
			52237,
			20703
		],
		[
			-84,
			-51
		],
		[
			-49,
			-83
		],
		[
			36,
			-73
		],
		[
			6,
			-62
		]
	],
	[
		[
			52146,
			20434
		],
		[
			-84,
			0
		],
		[
			-66,
			73
		],
		[
			-66,
			20
		],
		[
			-48,
			42
		],
		[
			-108,
			207
		],
		[
			-72,
			31
		],
		[
			-18,
			41
		],
		[
			-133,
			94
		],
		[
			-60,
			20
		],
		[
			-42,
			-51
		],
		[
			-96,
			-83
		],
		[
			-96,
			103
		],
		[
			-139,
			11
		],
		[
			-42,
			20
		],
		[
			-60,
			-165
		],
		[
			-60,
			-21
		],
		[
			42,
			-124
		],
		[
			-24,
			-31
		],
		[
			-48,
			10
		],
		[
			-102,
			-52
		],
		[
			-54,
			11
		],
		[
			-121,
			-42
		],
		[
			-42,
			83
		],
		[
			-48,
			31
		],
		[
			-48,
			-10
		],
		[
			0,
			-94
		],
		[
			-30,
			-41
		],
		[
			0,
			-62
		],
		[
			-48,
			-83
		],
		[
			-18,
			-93
		],
		[
			-54,
			-114
		],
		[
			-66,
			-21
		]
	],
	[
		[
			50295,
			20144
		],
		[
			-54,
			83
		],
		[
			6,
			41
		],
		[
			-49,
			52
		],
		[
			-12,
			83
		],
		[
			-42,
			73
		],
		[
			-12,
			114
		],
		[
			-90,
			-21
		],
		[
			-132,
			-11
		],
		[
			-102,
			125
		],
		[
			-79,
			-11
		],
		[
			-126,
			-114
		],
		[
			-30,
			-41
		],
		[
			-325,
			-186
		],
		[
			-48,
			-63
		],
		[
			-30,
			21
		],
		[
			24,
			83
		],
		[
			-66,
			155
		],
		[
			-66,
			0
		],
		[
			-54,
			52
		],
		[
			24,
			83
		],
		[
			12,
			104
		],
		[
			-54,
			82
		]
	],
	[
		[
			49946,
			23251
		],
		[
			6,
			52
		]
	],
	[
		[
			49952,
			23303
		],
		[
			120,
			104
		]
	],
	[
		[
			50072,
			23407
		],
		[
			24,
			10
		]
	],
	[
		[
			50096,
			23417
		],
		[
			60,
			-10
		]
	],
	[
		[
			31896,
			47652
		],
		[
			-6,
			0
		]
	],
	[
		[
			31890,
			47652
		],
		[
			0,
			-10
		]
	],
	[
		[
			31890,
			47642
		],
		[
			-18,
			-31
		],
		[
			42,
			-176
		],
		[
			55,
			51
		],
		[
			24,
			-41
		],
		[
			132,
			-21
		],
		[
			30,
			-31
		],
		[
			12,
			-93
		],
		[
			60,
			-21
		],
		[
			-24,
			-145
		],
		[
			48,
			-10
		],
		[
			-6,
			-73
		],
		[
			-36,
			0
		],
		[
			-6,
			-62
		],
		[
			228,
			-51
		],
		[
			25,
			-32
		],
		[
			-43,
			-72
		],
		[
			-42,
			-31
		],
		[
			42,
			-124
		],
		[
			-12,
			-42
		],
		[
			36,
			-83
		],
		[
			-24,
			-62
		],
		[
			43,
			-41
		],
		[
			54,
			41
		],
		[
			60,
			-31
		],
		[
			-48,
			-62
		],
		[
			30,
			-31
		],
		[
			96,
			21
		],
		[
			18,
			-156
		]
	],
	[
		[
			32666,
			46233
		],
		[
			-18,
			-103
		],
		[
			-72,
			-94
		],
		[
			-120,
			-62
		],
		[
			0,
			-83
		],
		[
			54,
			-51
		],
		[
			72,
			0
		],
		[
			36,
			-31
		],
		[
			36,
			-73
		],
		[
			-18,
			-155
		],
		[
			-36,
			-114
		],
		[
			-126,
			-11
		],
		[
			-91,
			11
		],
		[
			-42,
			31
		],
		[
			-132,
			21
		],
		[
			-54,
			-42
		],
		[
			-48,
			0
		],
		[
			-30,
			-93
		],
		[
			96,
			-10
		],
		[
			60,
			-31
		],
		[
			-24,
			-83
		],
		[
			-114,
			-94
		],
		[
			-48,
			-72
		]
	],
	[
		[
			32047,
			45094
		],
		[
			-12,
			-104
		],
		[
			18,
			-72
		],
		[
			-6,
			-176
		],
		[
			84,
			-62
		],
		[
			54,
			31
		],
		[
			30,
			-21
		],
		[
			48,
			21
		],
		[
			84,
			-11
		],
		[
			36,
			-93
		],
		[
			133,
			-41
		],
		[
			12,
			-52
		],
		[
			-42,
			-41
		],
		[
			-61,
			-21
		],
		[
			-24,
			-104
		],
		[
			61,
			-41
		],
		[
			-37,
			-42
		],
		[
			37,
			-72
		],
		[
			18,
			-104
		],
		[
			-49,
			-72
		],
		[
			0,
			-104
		],
		[
			61,
			-41
		],
		[
			-12,
			-93
		],
		[
			30,
			-73
		],
		[
			-18,
			-72
		]
	],
	[
		[
			32492,
			43634
		],
		[
			-48,
			0
		],
		[
			-121,
			-42
		],
		[
			-36,
			-31
		],
		[
			-66,
			0
		],
		[
			-132,
			-62
		],
		[
			-72,
			-135
		],
		[
			-73,
			21
		],
		[
			-54,
			-124
		],
		[
			-78,
			41
		],
		[
			-24,
			52
		],
		[
			-60,
			-31
		],
		[
			-54,
			-83
		],
		[
			-60,
			-41
		]
	],
	[
		[
			31614,
			43199
		],
		[
			-48,
			10
		],
		[
			-54,
			73
		],
		[
			-73,
			31
		],
		[
			-12,
			72
		],
		[
			-48,
			10
		],
		[
			-60,
			73
		],
		[
			42,
			52
		],
		[
			-18,
			83
		],
		[
			-60,
			51
		],
		[
			-54,
			-10
		]
	],
	[
		[
			31229,
			43644
		],
		[
			-36,
			52
		],
		[
			-102,
			21
		],
		[
			-60,
			62
		],
		[
			-61,
			20
		],
		[
			-120,
			73
		],
		[
			-48,
			41
		],
		[
			-48,
			-20
		],
		[
			-102,
			31
		],
		[
			-36,
			41
		],
		[
			-60,
			-10
		],
		[
			-55,
			31
		],
		[
			-24,
			124
		],
		[
			-42,
			41
		],
		[
			-6,
			63
		],
		[
			-30,
			31
		],
		[
			12,
			62
		],
		[
			-60,
			52
		],
		[
			-42,
			82
		],
		[
			-90,
			11
		],
		[
			-96,
			52
		],
		[
			-48,
			41
		]
	],
	[
		[
			30075,
			44545
		],
		[
			-73,
			-145
		],
		[
			-90,
			21
		],
		[
			-114,
			-21
		],
		[
			-24,
			21
		],
		[
			-18,
			134
		],
		[
			-72,
			11
		],
		[
			-54,
			52
		],
		[
			-151,
			-11
		],
		[
			-30,
			31
		],
		[
			-72,
			-93
		],
		[
			-102,
			41
		]
	],
	[
		[
			29275,
			44586
		],
		[
			24,
			104
		],
		[
			-12,
			114
		],
		[
			-30,
			104
		],
		[
			18,
			124
		],
		[
			60,
			93
		],
		[
			6,
			41
		],
		[
			60,
			63
		],
		[
			42,
			72
		],
		[
			96,
			83
		],
		[
			43,
			62
		],
		[
			66,
			218
		],
		[
			24,
			0
		],
		[
			42,
			82
		],
		[
			180,
			135
		],
		[
			151,
			166
		],
		[
			42,
			155
		],
		[
			0,
			83
		],
		[
			-42,
			176
		],
		[
			48,
			93
		],
		[
			18,
			73
		],
		[
			96,
			207
		],
		[
			36,
			124
		],
		[
			24,
			135
		],
		[
			78,
			72
		],
		[
			114,
			156
		],
		[
			103,
			62
		],
		[
			48,
			-11
		],
		[
			48,
			-51
		],
		[
			120,
			-31
		],
		[
			126,
			-73
		],
		[
			48,
			-41
		],
		[
			-24,
			-73
		],
		[
			18,
			-62
		],
		[
			-42,
			-21
		],
		[
			-12,
			0
		],
		[
			42,
			-10
		],
		[
			0,
			83
		],
		[
			30,
			72
		],
		[
			-24,
			52
		],
		[
			-24,
			114
		],
		[
			133,
			-10
		],
		[
			42,
			62
		],
		[
			18,
			62
		],
		[
			-24,
			62
		],
		[
			-60,
			-72
		],
		[
			-67,
			-11
		],
		[
			-132,
			62
		],
		[
			-60,
			52
		],
		[
			0,
			42
		],
		[
			84,
			93
		],
		[
			54,
			93
		],
		[
			36,
			31
		],
		[
			205,
			21
		],
		[
			96,
			72
		],
		[
			156,
			21
		],
		[
			109,
			-41
		],
		[
			54,
			-73
		],
		[
			114,
			-41
		],
		[
			18,
			-52
		],
		[
			72,
			-42
		],
		[
			114,
			11
		],
		[
			18,
			-21
		]
	],
	[
		[
			31121,
			40340
		],
		[
			-72,
			-21
		],
		[
			18,
			-93
		],
		[
			66,
			-114
		],
		[
			0,
			-93
		],
		[
			24,
			-41
		],
		[
			6,
			-83
		],
		[
			30,
			-145
		],
		[
			60,
			-21
		],
		[
			36,
			-52
		],
		[
			-18,
			-51
		],
		[
			18,
			-73
		],
		[
			78,
			-21
		],
		[
			24,
			-114
		],
		[
			36,
			-31
		],
		[
			85,
			21
		],
		[
			36,
			41
		],
		[
			30,
			-82
		],
		[
			-127,
			-21
		],
		[
			-96,
			41
		],
		[
			-66,
			114
		],
		[
			-138,
			197
		],
		[
			-48,
			83
		],
		[
			-78,
			166
		],
		[
			6,
			41
		],
		[
			-43,
			166
		],
		[
			-6,
			124
		],
		[
			31,
			41
		],
		[
			78,
			42
		],
		[
			30,
			-21
		]
	],
	[
		[
			31716,
			39802
		],
		[
			-90,
			-94
		],
		[
			-48,
			0
		],
		[
			-84,
			83
		],
		[
			18,
			31
		],
		[
			-55,
			83
		],
		[
			-120,
			-62
		],
		[
			-24,
			-41
		],
		[
			-48,
			10
		],
		[
			-48,
			62
		],
		[
			-54,
			155
		],
		[
			0,
			145
		],
		[
			36,
			228
		],
		[
			-102,
			52
		],
		[
			0,
			62
		],
		[
			60,
			31
		],
		[
			102,
			-10
		],
		[
			66,
			62
		],
		[
			6,
			135
		],
		[
			24,
			155
		],
		[
			42,
			62
		]
	],
	[
		[
			31397,
			40951
		],
		[
			12,
			-10
		]
	],
	[
		[
			31409,
			40941
		],
		[
			0,
			-11
		]
	],
	[
		[
			31409,
			40930
		],
		[
			0,
			-10
		]
	],
	[
		[
			31409,
			40920
		],
		[
			127,
			-83
		],
		[
			72,
			0
		],
		[
			48,
			83
		],
		[
			72,
			62
		],
		[
			-12,
			-103
		],
		[
			-54,
			-83
		],
		[
			0,
			-62
		],
		[
			42,
			-114
		],
		[
			36,
			-42
		],
		[
			6,
			-82
		],
		[
			-30,
			-63
		],
		[
			-78,
			-10
		],
		[
			-12,
			-52
		],
		[
			12,
			-93
		],
		[
			-6,
			-207
		],
		[
			-66,
			-62
		],
		[
			186,
			-166
		],
		[
			-36,
			-41
		]
	],
	[
		[
			32582,
			47745
		],
		[
			-12,
			-20
		],
		[
			12,
			20
		]
	],
	[
		[
			34987,
			46886
		],
		[
			-108,
			72
		],
		[
			-241,
			11
		],
		[
			-54,
			-11
		],
		[
			-96,
			-72
		],
		[
			-42,
			-83
		],
		[
			-85,
			10
		],
		[
			-54,
			-62
		],
		[
			61,
			-114
		],
		[
			-91,
			-21
		],
		[
			-90,
			32
		],
		[
			-48,
			-11
		],
		[
			-120,
			93
		],
		[
			-36,
			-51
		],
		[
			-60,
			0
		],
		[
			-36,
			-31
		],
		[
			-55,
			20
		],
		[
			-96,
			-31
		],
		[
			-108,
			83
		],
		[
			-66,
			-21
		],
		[
			-48,
			83
		],
		[
			-102,
			-10
		],
		[
			-43,
			41
		],
		[
			-48,
			-31
		],
		[
			-36,
			-93
		],
		[
			-66,
			-31
		],
		[
			-90,
			0
		],
		[
			0,
			-73
		],
		[
			-96,
			-41
		],
		[
			-78,
			-155
		],
		[
			-61,
			-83
		],
		[
			-36,
			0
		],
		[
			-60,
			-52
		],
		[
			-72,
			0
		],
		[
			-60,
			-21
		]
	],
	[
		[
			31890,
			47642
		],
		[
			0,
			10
		]
	],
	[
		[
			31896,
			47652
		],
		[
			79,
			21
		],
		[
			42,
			31
		],
		[
			138,
			41
		],
		[
			60,
			83
		],
		[
			72,
			11
		],
		[
			120,
			-21
		],
		[
			115,
			21
		],
		[
			48,
			-125
		],
		[
			12,
			31
		]
	],
	[
		[
			32582,
			47745
		],
		[
			-36,
			83
		],
		[
			-60,
			31
		],
		[
			-115,
			-31
		],
		[
			-90,
			31
		],
		[
			-42,
			42
		],
		[
			-78,
			-52
		],
		[
			-60,
			-73
		],
		[
			-169,
			-51
		],
		[
			-72,
			20
		],
		[
			-42,
			83
		],
		[
			30,
			52
		],
		[
			42,
			0
		],
		[
			6,
			72
		],
		[
			85,
			125
		],
		[
			120,
			-42
		],
		[
			42,
			0
		],
		[
			84,
			145
		],
		[
			66,
			-51
		],
		[
			6,
			62
		],
		[
			-54,
			51
		]
	],
	[
		[
			32245,
			48242
		],
		[
			0,
			21
		]
	],
	[
		[
			32245,
			48263
		],
		[
			72,
			62
		],
		[
			-24,
			94
		],
		[
			48,
			82
		],
		[
			36,
			125
		],
		[
			48,
			51
		],
		[
			-54,
			32
		],
		[
			-42,
			82
		],
		[
			0,
			73
		],
		[
			127,
			0
		],
		[
			120,
			-31
		],
		[
			240,
			-31
		],
		[
			18,
			52
		],
		[
			42,
			10
		],
		[
			61,
			145
		],
		[
			66,
			0
		],
		[
			90,
			62
		],
		[
			66,
			0
		],
		[
			42,
			73
		],
		[
			36,
			10
		],
		[
			18,
			72
		],
		[
			66,
			63
		],
		[
			0,
			51
		],
		[
			72,
			21
		]
	],
	[
		[
			33393,
			49361
		],
		[
			37,
			0
		],
		[
			66,
			93
		],
		[
			84,
			83
		],
		[
			-36,
			42
		],
		[
			78,
			72
		],
		[
			36,
			-31
		],
		[
			78,
			21
		],
		[
			259,
			176
		],
		[
			54,
			20
		],
		[
			72,
			83
		],
		[
			186,
			73
		],
		[
			61,
			124
		]
	],
	[
		[
			31109,
			40972
		],
		[
			6,
			21
		]
	],
	[
		[
			31115,
			40993
		],
		[
			6,
			0
		]
	],
	[
		[
			31121,
			40993
		],
		[
			-12,
			-21
		]
	],
	[
		[
			31235,
			41376
		],
		[
			-6,
			0
		]
	],
	[
		[
			31229,
			41376
		],
		[
			6,
			21
		]
	],
	[
		[
			31235,
			41397
		],
		[
			0,
			-21
		]
	],
	[
		[
			31614,
			43199
		],
		[
			36,
			-62
		],
		[
			18,
			-156
		],
		[
			126,
			-83
		],
		[
			42,
			0
		],
		[
			24,
			52
		],
		[
			54,
			-52
		],
		[
			-42,
			-72
		]
	],
	[
		[
			31872,
			42826
		],
		[
			-132,
			-62
		],
		[
			-84,
			0
		],
		[
			-66,
			-73
		],
		[
			-12,
			-103
		],
		[
			-30,
			-31
		],
		[
			-12,
			-94
		],
		[
			-42,
			-51
		],
		[
			-49,
			-135
		],
		[
			-60,
			-31
		],
		[
			-66,
			-73
		],
		[
			0,
			-83
		],
		[
			-72,
			-41
		],
		[
			-60,
			-83
		],
		[
			48,
			-176
		],
		[
			-30,
			-93
		],
		[
			24,
			-104
		],
		[
			36,
			-51
		]
	],
	[
		[
			31265,
			41542
		],
		[
			18,
			-21
		]
	],
	[
		[
			31283,
			41521
		],
		[
			-24,
			-114
		],
		[
			-24,
			-31
		]
	],
	[
		[
			31235,
			41376
		],
		[
			0,
			21
		]
	],
	[
		[
			31229,
			41376
		],
		[
			60,
			-52
		],
		[
			-12,
			-145
		],
		[
			-66,
			-62
		],
		[
			-24,
			-62
		],
		[
			-66,
			-62
		]
	],
	[
		[
			31109,
			40972
		],
		[
			84,
			-135
		],
		[
			-48,
			-72
		],
		[
			-78,
			-52
		],
		[
			-85,
			21
		],
		[
			-24,
			41
		],
		[
			-60,
			-52
		],
		[
			-78,
			-31
		],
		[
			-84,
			11
		],
		[
			-66,
			72
		],
		[
			-126,
			228
		],
		[
			-157,
			217
		],
		[
			-78,
			94
		],
		[
			-162,
			290
		],
		[
			-12,
			83
		],
		[
			42,
			72
		],
		[
			-6,
			124
		],
		[
			-48,
			135
		],
		[
			18,
			104
		],
		[
			42,
			51
		],
		[
			54,
			-51
		],
		[
			0,
			82
		],
		[
			-54,
			83
		],
		[
			-66,
			21
		],
		[
			-12,
			-52
		],
		[
			66,
			0
		],
		[
			-12,
			-52
		],
		[
			-66,
			-62
		],
		[
			-175,
			218
		],
		[
			-72,
			103
		],
		[
			-18,
			104
		],
		[
			-174,
			238
		],
		[
			-109,
			124
		],
		[
			-90,
			125
		],
		[
			-126,
			124
		],
		[
			-72,
			104
		],
		[
			-42,
			93
		],
		[
			-60,
			93
		],
		[
			-85,
			83
		],
		[
			-54,
			-11
		],
		[
			-78,
			135
		],
		[
			-30,
			21
		],
		[
			-18,
			103
		],
		[
			144,
			73
		],
		[
			36,
			52
		],
		[
			43,
			165
		],
		[
			42,
			0
		],
		[
			24,
			125
		],
		[
			48,
			93
		],
		[
			-12,
			62
		],
		[
			6,
			93
		],
		[
			54,
			124
		]
	],
	[
		[
			37368,
			43240
		],
		[
			-42,
			31
		],
		[
			-48,
			-93
		],
		[
			-37,
			-31
		],
		[
			-252,
			0
		],
		[
			-60,
			31
		],
		[
			-126,
			-41
		],
		[
			18,
			-42
		],
		[
			-91,
			-41
		],
		[
			-72,
			10
		],
		[
			6,
			-72
		],
		[
			-66,
			-52
		],
		[
			-24,
			-52
		],
		[
			12,
			-104
		],
		[
			-12,
			-51
		],
		[
			36,
			-73
		],
		[
			60,
			-62
		],
		[
			-36,
			-124
		],
		[
			-114,
			-11
		],
		[
			-48,
			-72
		],
		[
			-108,
			-83
		],
		[
			-97,
			-41
		],
		[
			-36,
			10
		]
	],
	[
		[
			36231,
			42277
		],
		[
			-78,
			93
		],
		[
			-6,
			52
		],
		[
			-66,
			-21
		],
		[
			-78,
			11
		],
		[
			-72,
			-42
		],
		[
			-127,
			73
		],
		[
			-66,
			10
		],
		[
			-60,
			-62
		],
		[
			-66,
			72
		],
		[
			-54,
			11
		],
		[
			-90,
			-42
		],
		[
			-30,
			11
		],
		[
			-54,
			-52
		],
		[
			-54,
			72
		],
		[
			-61,
			52
		],
		[
			-24,
			124
		],
		[
			-66,
			-62
		],
		[
			-42,
			-10
		],
		[
			-96,
			52
		],
		[
			-60,
			-42
		],
		[
			-54,
			73
		],
		[
			-48,
			31
		],
		[
			-12,
			72
		],
		[
			-79,
			21
		],
		[
			-72,
			-10
		],
		[
			-36,
			-31
		],
		[
			-48,
			20
		],
		[
			-12,
			42
		],
		[
			-84,
			31
		],
		[
			-30,
			72
		],
		[
			-72,
			42
		],
		[
			-48,
			0
		],
		[
			-25,
			72
		],
		[
			19,
			93
		],
		[
			-49,
			21
		],
		[
			-30,
			-134
		],
		[
			-102,
			72
		],
		[
			-30,
			0
		],
		[
			-72,
			73
		],
		[
			-60,
			0
		],
		[
			-138,
			155
		],
		[
			-31,
			-42
		],
		[
			-72,
			52
		],
		[
			-42,
			52
		],
		[
			6,
			41
		],
		[
			-66,
			73
		],
		[
			-48,
			-73
		],
		[
			-72,
			52
		],
		[
			-42,
			-41
		],
		[
			-102,
			21
		],
		[
			-12,
			51
		],
		[
			-67,
			52
		],
		[
			-36,
			-62
		],
		[
			-54,
			21
		],
		[
			-96,
			-11
		],
		[
			-48,
			-20
		],
		[
			-72,
			-156
		],
		[
			-72,
			52
		],
		[
			-55,
			0
		],
		[
			-48,
			114
		],
		[
			-36,
			21
		],
		[
			-60,
			-21
		],
		[
			-6,
			41
		],
		[
			-96,
			94
		],
		[
			-72,
			10
		],
		[
			-102,
			-31
		],
		[
			-6,
			52
		]
	],
	[
		[
			32654,
			40319
		],
		[
			66,
			-10
		],
		[
			18,
			-31
		],
		[
			-72,
			-62
		],
		[
			-120,
			-52
		],
		[
			-66,
			21
		],
		[
			60,
			83
		],
		[
			36,
			93
		],
		[
			24,
			-21
		]
	],
	[
		[
			32600,
			40340
		],
		[
			54,
			-21
		]
	],
	[
		[
			36231,
			42277
		],
		[
			42,
			-52
		],
		[
			67,
			-31
		],
		[
			72,
			-62
		],
		[
			6,
			-52
		],
		[
			84,
			-31
		],
		[
			60,
			-72
		],
		[
			-30,
			-104
		],
		[
			-54,
			-93
		],
		[
			0,
			-93
		],
		[
			30,
			-42
		],
		[
			-30,
			-83
		],
		[
			54,
			-93
		],
		[
			-24,
			-124
		]
	],
	[
		[
			36508,
			41345
		],
		[
			-18,
			-114
		],
		[
			-90,
			-73
		],
		[
			-60,
			11
		],
		[
			-79,
			103
		],
		[
			-60,
			-10
		],
		[
			-6,
			-73
		],
		[
			-132,
			-10
		],
		[
			-42,
			-135
		],
		[
			-66,
			11
		],
		[
			-114,
			-31
		],
		[
			-37,
			31
		],
		[
			-114,
			0
		]
	],
	[
		[
			35690,
			41055
		],
		[
			6,
			124
		],
		[
			-72,
			-52
		],
		[
			-42,
			-52
		],
		[
			-66,
			-31
		],
		[
			-48,
			-51
		],
		[
			-108,
			-21
		],
		[
			-18,
			-31
		],
		[
			-85,
			-42
		],
		[
			-84,
			-93
		],
		[
			-210,
			-52
		],
		[
			-48,
			21
		],
		[
			-60,
			-21
		],
		[
			-109,
			11
		],
		[
			-90,
			62
		],
		[
			-24,
			-104
		],
		[
			-48,
			-72
		],
		[
			-102,
			-62
		],
		[
			-54,
			-145
		],
		[
			-48,
			31
		],
		[
			-121,
			-11
		],
		[
			-162,
			52
		],
		[
			12,
			145
		],
		[
			-60,
			11
		],
		[
			-24,
			31
		],
		[
			-108,
			-31
		],
		[
			-181,
			114
		],
		[
			-96,
			-73
		],
		[
			0,
			-72
		],
		[
			-72,
			-32
		],
		[
			-48,
			-41
		],
		[
			-187,
			21
		]
	],
	[
		[
			33333,
			40589
		],
		[
			54,
			165
		],
		[
			25,
			-10
		],
		[
			114,
			83
		],
		[
			48,
			10
		],
		[
			36,
			62
		],
		[
			42,
			21
		],
		[
			36,
			62
		],
		[
			108,
			83
		],
		[
			-48,
			135
		],
		[
			-42,
			-73
		],
		[
			42,
			-72
		],
		[
			-198,
			-62
		],
		[
			-60,
			-135
		],
		[
			-66,
			0
		],
		[
			-85,
			-31
		],
		[
			-60,
			0
		],
		[
			-168,
			-83
		],
		[
			-72,
			-166
		],
		[
			-84,
			-103
		],
		[
			-49,
			-83
		],
		[
			-126,
			-62
		],
		[
			-12,
			-31
		],
		[
			-114,
			20
		]
	],
	[
		[
			32654,
			40319
		],
		[
			-54,
			21
		]
	],
	[
		[
			32600,
			40340
		],
		[
			-54,
			52
		],
		[
			6,
			104
		],
		[
			-54,
			134
		],
		[
			-48,
			42
		],
		[
			-73,
			103
		],
		[
			91,
			31
		],
		[
			30,
			42
		],
		[
			-48,
			72
		],
		[
			-6,
			42
		],
		[
			-67,
			113
		],
		[
			-48,
			-20
		],
		[
			-54,
			52
		],
		[
			-6,
			-104
		],
		[
			84,
			-31
		],
		[
			36,
			-62
		],
		[
			-42,
			-73
		],
		[
			-60,
			-20
		],
		[
			-24,
			-52
		],
		[
			6,
			-62
		],
		[
			-54,
			-94
		],
		[
			24,
			-62
		],
		[
			-12,
			-93
		],
		[
			-54,
			-31
		],
		[
			-78,
			-114
		],
		[
			-6,
			-52
		],
		[
			-60,
			-103
		],
		[
			-30,
			-21
		],
		[
			-43,
			-104
		],
		[
			-78,
			-41
		],
		[
			-60,
			-104
		],
		[
			-102,
			-82
		]
	],
	[
		[
			31409,
			40920
		],
		[
			0,
			10
		]
	],
	[
		[
			31409,
			40930
		],
		[
			0,
			11
		]
	],
	[
		[
			31397,
			40951
		],
		[
			42,
			62
		],
		[
			-18,
			145
		],
		[
			-72,
			114
		],
		[
			-6,
			73
		],
		[
			-42,
			10
		],
		[
			-18,
			62
		],
		[
			0,
			104
		]
	],
	[
		[
			31283,
			41521
		],
		[
			-18,
			21
		]
	],
	[
		[
			41264,
			30770
		],
		[
			30,
			-20
		],
		[
			18,
			-83
		],
		[
			108,
			-42
		],
		[
			18,
			-72
		],
		[
			54,
			-10
		],
		[
			48,
			-63
		],
		[
			163,
			31
		],
		[
			180,
			-10
		],
		[
			48,
			31
		],
		[
			36,
			-10
		]
	],
	[
		[
			41967,
			30522
		],
		[
			48,
			-135
		],
		[
			73,
			-72
		],
		[
			54,
			10
		],
		[
			66,
			-52
		]
	],
	[
		[
			42208,
			30273
		],
		[
			-36,
			-83
		],
		[
			-6,
			0
		],
		[
			-18,
			-20
		]
	],
	[
		[
			42148,
			30170
		],
		[
			-12,
			-42
		]
	],
	[
		[
			42136,
			30128
		],
		[
			18,
			-52
		]
	],
	[
		[
			42154,
			30076
		],
		[
			30,
			-72
		]
	],
	[
		[
			42184,
			30004
		],
		[
			24,
			-207
		],
		[
			36,
			-31
		],
		[
			42,
			-104
		],
		[
			-6,
			-62
		],
		[
			72,
			-62
		]
	],
	[
		[
			42352,
			29538
		],
		[
			-42,
			-21
		],
		[
			-48,
			-62
		],
		[
			0,
			-41
		]
	],
	[
		[
			42262,
			29414
		],
		[
			-60,
			-114
		],
		[
			-144,
			0
		],
		[
			-97,
			-42
		],
		[
			-18,
			31
		],
		[
			-90,
			42
		],
		[
			-96,
			-21
		],
		[
			-96,
			21
		],
		[
			-30,
			-21
		],
		[
			-73,
			0
		],
		[
			-90,
			41
		],
		[
			-78,
			-20
		],
		[
			-18,
			-42
		],
		[
			36,
			-51
		],
		[
			-24,
			-52
		]
	],
	[
		[
			40981,
			28792
		],
		[
			-78,
			83
		],
		[
			-54,
			0
		],
		[
			-144,
			41
		],
		[
			-66,
			0
		],
		[
			-37,
			32
		],
		[
			19,
			62
		]
	],
	[
		[
			40621,
			29010
		],
		[
			-6,
			72
		],
		[
			48,
			73
		],
		[
			84,
			-11
		],
		[
			72,
			52
		],
		[
			0,
			62
		],
		[
			-60,
			62
		],
		[
			-108,
			52
		],
		[
			12,
			124
		],
		[
			42,
			21
		],
		[
			60,
			-10
		],
		[
			36,
			41
		],
		[
			-24,
			62
		],
		[
			48,
			94
		],
		[
			-36,
			31
		],
		[
			-54,
			-11
		],
		[
			-66,
			62
		],
		[
			72,
			94
		],
		[
			12,
			41
		],
		[
			-54,
			42
		],
		[
			12,
			62
		],
		[
			114,
			62
		],
		[
			60,
			62
		],
		[
			72,
			31
		],
		[
			-6,
			52
		],
		[
			60,
			41
		],
		[
			48,
			62
		],
		[
			67,
			-20
		],
		[
			42,
			62
		],
		[
			-30,
			41
		],
		[
			-55,
			-20
		],
		[
			0,
			134
		],
		[
			37,
			73
		],
		[
			0,
			72
		],
		[
			114,
			42
		],
		[
			30,
			51
		]
	],
	[
		[
			42496,
			32417
		],
		[
			49,
			10
		],
		[
			36,
			-41
		],
		[
			78,
			-41
		],
		[
			54,
			0
		],
		[
			78,
			72
		],
		[
			72,
			-52
		],
		[
			90,
			11
		],
		[
			18,
			62
		]
	],
	[
		[
			42971,
			32438
		],
		[
			73,
			-73
		],
		[
			48,
			21
		],
		[
			30,
			-31
		],
		[
			12,
			-73
		],
		[
			-36,
			-103
		],
		[
			54,
			-62
		],
		[
			-72,
			-62
		],
		[
			-36,
			-52
		],
		[
			-91,
			-42
		],
		[
			-60,
			-124
		],
		[
			18,
			-62
		],
		[
			48,
			-52
		],
		[
			-42,
			-103
		],
		[
			0,
			-63
		]
	],
	[
		[
			42917,
			31557
		],
		[
			42,
			-165
		],
		[
			42,
			-104
		],
		[
			-24,
			-62
		],
		[
			-114,
			-31
		],
		[
			-144,
			-21
		],
		[
			-60,
			-114
		],
		[
			-36,
			0
		]
	],
	[
		[
			42623,
			31060
		],
		[
			-48,
			31
		],
		[
			-79,
			-10
		],
		[
			-36,
			42
		],
		[
			-42,
			0
		],
		[
			-30,
			-52
		],
		[
			-132,
			-31
		],
		[
			12,
			-176
		],
		[
			36,
			-73
		],
		[
			-30,
			-72
		],
		[
			36,
			-31
		]
	],
	[
		[
			42310,
			30688
		],
		[
			30,
			-114
		],
		[
			0,
			-52
		],
		[
			48,
			-62
		],
		[
			-48,
			-42
		],
		[
			36,
			-83
		],
		[
			-114,
			-31
		],
		[
			-54,
			-31
		]
	],
	[
		[
			41967,
			30522
		],
		[
			-18,
			103
		],
		[
			24,
			94
		],
		[
			-24,
			82
		],
		[
			84,
			52
		],
		[
			55,
			125
		],
		[
			-12,
			62
		],
		[
			-67,
			72
		],
		[
			-54,
			21
		],
		[
			24,
			72
		],
		[
			42,
			0
		],
		[
			43,
			52
		],
		[
			66,
			-21
		],
		[
			102,
			42
		],
		[
			54,
			-21
		],
		[
			42,
			124
		],
		[
			-18,
			31
		],
		[
			24,
			125
		],
		[
			-24,
			31
		],
		[
			18,
			124
		],
		[
			-48,
			73
		]
	],
	[
		[
			42280,
			31765
		],
		[
			-18,
			10
		],
		[
			-6,
			114
		],
		[
			-42,
			41
		],
		[
			84,
			52
		],
		[
			78,
			0
		],
		[
			6,
			42
		],
		[
			-30,
			72
		],
		[
			-54,
			62
		]
	],
	[
		[
			42298,
			32158
		],
		[
			-42,
			114
		],
		[
			42,
			73
		],
		[
			-30,
			72
		],
		[
			96,
			42
		],
		[
			78,
			-42
		],
		[
			54,
			0
		]
	],
	[
		[
			42280,
			31765
		],
		[
			-72,
			-31
		],
		[
			0,
			51
		],
		[
			-84,
			-20
		],
		[
			-36,
			62
		],
		[
			-139,
			-52
		],
		[
			-18,
			31
		],
		[
			-60,
			-62
		],
		[
			-6,
			0
		],
		[
			-54,
			-31
		],
		[
			30,
			-114
		],
		[
			-36,
			-42
		],
		[
			-108,
			-51
		],
		[
			-48,
			31
		],
		[
			-66,
			-21
		],
		[
			-6,
			73
		],
		[
			-115,
			10
		],
		[
			-84,
			-10
		],
		[
			-48,
			103
		],
		[
			72,
			10
		],
		[
			-60,
			125
		],
		[
			42,
			20
		],
		[
			6,
			83
		],
		[
			-30,
			52
		],
		[
			72,
			42
		],
		[
			6,
			103
		],
		[
			126,
			42
		],
		[
			25,
			-21
		],
		[
			90,
			21
		],
		[
			78,
			41
		],
		[
			48,
			-52
		],
		[
			84,
			42
		],
		[
			6,
			82
		],
		[
			84,
			21
		],
		[
			30,
			-72
		],
		[
			79,
			-31
		],
		[
			60,
			0
		],
		[
			54,
			31
		],
		[
			60,
			-73
		],
		[
			36,
			0
		]
	],
	[
		[
			40669,
			32438
		],
		[
			6,
			-145
		],
		[
			72,
			-42
		],
		[
			36,
			-41
		],
		[
			-60,
			-83
		],
		[
			36,
			-114
		]
	],
	[
		[
			40759,
			32013
		],
		[
			-6,
			-31
		],
		[
			108,
			-10
		],
		[
			48,
			-114
		],
		[
			-66,
			-62
		],
		[
			-12,
			-73
		],
		[
			30,
			-41
		],
		[
			-18,
			-73
		],
		[
			84,
			-72
		],
		[
			108,
			-42
		],
		[
			18,
			-31
		],
		[
			85,
			-20
		],
		[
			0,
			-42
		],
		[
			-181,
			-10
		],
		[
			-24,
			-42
		],
		[
			6,
			-72
		],
		[
			72,
			-155
		],
		[
			175,
			-197
		],
		[
			0,
			-42
		],
		[
			78,
			-114
		]
	],
	[
		[
			40621,
			29010
		],
		[
			-37,
			-31
		],
		[
			-162,
			41
		],
		[
			-48,
			-31
		],
		[
			6,
			-52
		],
		[
			-42,
			-197
		],
		[
			18,
			-93
		],
		[
			-60,
			-62
		],
		[
			-30,
			52
		],
		[
			-12,
			83
		],
		[
			-42,
			51
		],
		[
			-36,
			-31
		],
		[
			-127,
			42
		],
		[
			-24,
			-21
		],
		[
			-24,
			-103
		],
		[
			-48,
			0
		],
		[
			-96,
			31
		],
		[
			-42,
			-21
		],
		[
			24,
			-83
		],
		[
			36,
			-62
		],
		[
			-12,
			-176
		],
		[
			-42,
			-73
		]
	],
	[
		[
			39821,
			28274
		],
		[
			-30,
			42
		],
		[
			-78,
			52
		],
		[
			-60,
			0
		],
		[
			-13,
			41
		],
		[
			-66,
			-31
		],
		[
			-78,
			52
		],
		[
			-60,
			-31
		],
		[
			-66,
			0
		],
		[
			-48,
			62
		],
		[
			-6,
			124
		],
		[
			-72,
			62
		],
		[
			-24,
			114
		],
		[
			-36,
			62
		],
		[
			36,
			73
		],
		[
			120,
			124
		],
		[
			-30,
			52
		],
		[
			48,
			83
		],
		[
			-24,
			51
		],
		[
			6,
			73
		],
		[
			150,
			52
		],
		[
			0,
			41
		],
		[
			66,
			21
		],
		[
			42,
			62
		],
		[
			79,
			10
		],
		[
			36,
			63
		],
		[
			-12,
			62
		],
		[
			42,
			51
		],
		[
			-24,
			63
		],
		[
			36,
			93
		],
		[
			-18,
			72
		],
		[
			-42,
			52
		],
		[
			-67,
			10
		]
	],
	[
		[
			39628,
			29931
		],
		[
			-30,
			52
		],
		[
			36,
			93
		],
		[
			-36,
			42
		],
		[
			-42,
			124
		],
		[
			-18,
			93
		],
		[
			60,
			42
		],
		[
			-30,
			166
		],
		[
			-60,
			41
		],
		[
			-96,
			186
		],
		[
			-30,
			11
		],
		[
			30,
			134
		],
		[
			24,
			42
		],
		[
			-48,
			72
		]
	],
	[
		[
			39388,
			31029
		],
		[
			-132,
			156
		]
	],
	[
		[
			39256,
			31185
		],
		[
			-18,
			0
		],
		[
			-73,
			93
		],
		[
			-66,
			31
		],
		[
			-30,
			41
		],
		[
			-132,
			42
		]
	],
	[
		[
			38937,
			31392
		],
		[
			6,
			145
		],
		[
			54,
			20
		],
		[
			36,
			-93
		],
		[
			24,
			-10
		]
	],
	[
		[
			39057,
			31454
		],
		[
			30,
			83
		],
		[
			54,
			-93
		],
		[
			127,
			-83
		],
		[
			54,
			10
		],
		[
			6,
			124
		],
		[
			-114,
			62
		],
		[
			-85,
			63
		],
		[
			67,
			176
		],
		[
			54,
			20
		],
		[
			0,
			52
		],
		[
			138,
			11
		],
		[
			24,
			62
		],
		[
			102,
			-21
		],
		[
			-6,
			145
		],
		[
			-60,
			31
		],
		[
			-36,
			114
		],
		[
			-30,
			21
		],
		[
			-18,
			93
		],
		[
			108,
			166
		],
		[
			48,
			20
		],
		[
			96,
			73
		],
		[
			121,
			114
		],
		[
			60,
			-31
		],
		[
			108,
			10
		]
	],
	[
		[
			39905,
			32676
		],
		[
			36,
			-52
		],
		[
			-18,
			-114
		],
		[
			42,
			0
		],
		[
			84,
			62
		],
		[
			30,
			-20
		],
		[
			30,
			114
		],
		[
			61,
			0
		],
		[
			48,
			62
		],
		[
			24,
			62
		],
		[
			12,
			155
		],
		[
			-18,
			42
		],
		[
			60,
			103
		],
		[
			6,
			104
		],
		[
			48,
			0
		]
	],
	[
		[
			40350,
			33194
		],
		[
			0,
			-62
		],
		[
			-48,
			-83
		],
		[
			-12,
			-83
		],
		[
			36,
			-31
		],
		[
			156,
			-73
		],
		[
			30,
			-41
		],
		[
			205,
			-52
		],
		[
			-78,
			-41
		],
		[
			-49,
			10
		],
		[
			-12,
			-41
		],
		[
			-72,
			-93
		],
		[
			-36,
			-73
		],
		[
			30,
			-41
		],
		[
			108,
			51
		],
		[
			43,
			-41
		],
		[
			18,
			-62
		]
	],
	[
		[
			42352,
			29538
		],
		[
			18,
			-31
		],
		[
			6,
			0
		],
		[
			0,
			-11
		],
		[
			6,
			0
		],
		[
			6,
			-62
		]
	],
	[
		[
			42388,
			29434
		],
		[
			60,
			-207
		],
		[
			12,
			-10
		]
	],
	[
		[
			42460,
			29217
		],
		[
			-6,
			-31
		]
	],
	[
		[
			42454,
			29186
		],
		[
			-12,
			-93
		],
		[
			54,
			-42
		],
		[
			0,
			-72
		],
		[
			24,
			-73
		],
		[
			-24,
			-135
		],
		[
			0,
			-113
		],
		[
			43,
			-42
		],
		[
			54,
			0
		],
		[
			108,
			-62
		]
	],
	[
		[
			42701,
			28554
		],
		[
			42,
			-62
		]
	],
	[
		[
			42743,
			28492
		],
		[
			-18,
			-124
		],
		[
			-66,
			0
		],
		[
			-78,
			-52
		]
	],
	[
		[
			42581,
			28316
		],
		[
			-79,
			20
		],
		[
			-48,
			-31
		],
		[
			-96,
			42
		],
		[
			-12,
			-31
		],
		[
			-66,
			-11
		]
	],
	[
		[
			42280,
			28305
		],
		[
			-12,
			42
		],
		[
			-78,
			-11
		],
		[
			-66,
			63
		],
		[
			42,
			72
		],
		[
			-90,
			-10
		],
		[
			-12,
			62
		],
		[
			-91,
			-10
		],
		[
			-30,
			62
		],
		[
			-60,
			0
		]
	],
	[
		[
			39376,
			34416
		],
		[
			18,
			-72
		],
		[
			54,
			-21
		],
		[
			0,
			-52
		],
		[
			66,
			-10
		],
		[
			18,
			-104
		],
		[
			-30,
			0
		],
		[
			-6,
			-124
		]
	],
	[
		[
			39496,
			34033
		],
		[
			54,
			-42
		],
		[
			66,
			-10
		],
		[
			30,
			-62
		],
		[
			97,
			-52
		],
		[
			66,
			10
		],
		[
			6,
			-124
		],
		[
			18,
			-52
		],
		[
			-36,
			-51
		],
		[
			30,
			-73
		],
		[
			-12,
			-41
		],
		[
			96,
			-114
		],
		[
			36,
			31
		],
		[
			54,
			0
		],
		[
			60,
			-42
		],
		[
			-6,
			-93
		],
		[
			60,
			-31
		],
		[
			73,
			0
		],
		[
			78,
			-83
		],
		[
			84,
			-10
		]
	],
	[
		[
			38937,
			31392
		],
		[
			-48,
			-21
		],
		[
			-60,
			52
		],
		[
			-30,
			0
		],
		[
			-72,
			72
		],
		[
			-79,
			0
		],
		[
			-48,
			21
		],
		[
			-30,
			124
		],
		[
			-48,
			-51
		],
		[
			-96,
			-73
		]
	],
	[
		[
			38173,
			32997
		],
		[
			43,
			31
		],
		[
			60,
			93
		],
		[
			48,
			21
		],
		[
			0,
			73
		],
		[
			60,
			145
		],
		[
			12,
			62
		],
		[
			-72,
			-11
		],
		[
			-66,
			42
		],
		[
			-18,
			62
		],
		[
			-43,
			41
		]
	],
	[
		[
			38197,
			33556
		],
		[
			55,
			83
		],
		[
			132,
			73
		],
		[
			42,
			72
		],
		[
			-6,
			249
		],
		[
			66,
			52
		],
		[
			36,
			82
		],
		[
			-6,
			94
		],
		[
			48,
			51
		]
	],
	[
		[
			38564,
			34312
		],
		[
			66,
			-62
		],
		[
			54,
			31
		],
		[
			43,
			-10
		],
		[
			78,
			41
		],
		[
			30,
			42
		],
		[
			-42,
			83
		],
		[
			6,
			72
		],
		[
			42,
			21
		],
		[
			30,
			52
		]
	],
	[
		[
			38871,
			34582
		],
		[
			48,
			0
		],
		[
			42,
			-52
		],
		[
			66,
			52
		],
		[
			72,
			0
		],
		[
			66,
			-52
		],
		[
			85,
			-114
		],
		[
			54,
			-10
		],
		[
			36,
			31
		],
		[
			36,
			-21
		]
	],
	[
		[
			41877,
			32676
		],
		[
			-18,
			-135
		],
		[
			24,
			-41
		],
		[
			150,
			-21
		],
		[
			6,
			31
		],
		[
			79,
			0
		],
		[
			60,
			-31
		],
		[
			72,
			125
		]
	],
	[
		[
			42250,
			32604
		],
		[
			36,
			-32
		],
		[
			42,
			42
		],
		[
			72,
			21
		],
		[
			30,
			-31
		]
	],
	[
		[
			42430,
			32604
		],
		[
			-12,
			-63
		],
		[
			12,
			-82
		],
		[
			66,
			-42
		]
	],
	[
		[
			40669,
			32438
		],
		[
			78,
			93
		],
		[
			24,
			-93
		],
		[
			60,
			31
		],
		[
			78,
			-31
		],
		[
			-6,
			-52
		],
		[
			66,
			10
		],
		[
			78,
			-10
		],
		[
			24,
			52
		]
	],
	[
		[
			41071,
			32438
		],
		[
			73,
			10
		],
		[
			180,
			62
		],
		[
			90,
			-20
		],
		[
			72,
			41
		],
		[
			36,
			93
		],
		[
			42,
			62
		],
		[
			61,
			0
		],
		[
			72,
			-31
		],
		[
			54,
			73
		],
		[
			126,
			-52
		]
	],
	[
		[
			42280,
			28305
		],
		[
			-48,
			-62
		],
		[
			-72,
			-10
		],
		[
			-48,
			-52
		],
		[
			-91,
			-52
		],
		[
			-12,
			-31
		],
		[
			-96,
			-51
		],
		[
			-24,
			-63
		],
		[
			-42,
			-10
		],
		[
			12,
			-72
		],
		[
			-72,
			-114
		],
		[
			-72,
			-145
		],
		[
			-138,
			0
		]
	],
	[
		[
			41577,
			27643
		],
		[
			0,
			-83
		],
		[
			-91,
			-42
		],
		[
			-12,
			-83
		]
	],
	[
		[
			41474,
			27435
		],
		[
			-18,
			-82
		],
		[
			-54,
			-52
		],
		[
			-96,
			-31
		],
		[
			-24,
			-31
		],
		[
			-66,
			83
		],
		[
			-102,
			-21
		],
		[
			-49,
			-42
		],
		[
			-66,
			-10
		],
		[
			-66,
			31
		],
		[
			-54,
			-124
		],
		[
			30,
			-93
		],
		[
			66,
			-73
		],
		[
			-42,
			-124
		],
		[
			-78,
			-93
		],
		[
			-66,
			20
		],
		[
			-24,
			-31
		]
	],
	[
		[
			40765,
			26762
		],
		[
			-66,
			-41
		],
		[
			-12,
			-11
		],
		[
			-12,
			-20
		]
	],
	[
		[
			40675,
			26690
		],
		[
			-6,
			-11
		]
	],
	[
		[
			40669,
			26679
		],
		[
			-6,
			-10
		]
	],
	[
		[
			40663,
			26669
		],
		[
			6,
			10
		]
	],
	[
		[
			40669,
			26679
		],
		[
			-6,
			-10
		]
	],
	[
		[
			40663,
			26669
		],
		[
			-24,
			-21
		],
		[
			-67,
			42
		],
		[
			-66,
			-11
		],
		[
			-156,
			0
		],
		[
			0,
			83
		],
		[
			-24,
			21
		],
		[
			6,
			104
		],
		[
			-84,
			20
		],
		[
			-24,
			31
		],
		[
			-121,
			0
		],
		[
			-42,
			42
		]
	],
	[
		[
			40061,
			26980
		],
		[
			36,
			31
		],
		[
			6,
			166
		],
		[
			73,
			82
		],
		[
			-6,
			42
		],
		[
			36,
			62
		],
		[
			42,
			0
		],
		[
			6,
			83
		],
		[
			48,
			41
		],
		[
			72,
			-62
		],
		[
			66,
			73
		],
		[
			66,
			-63
		],
		[
			84,
			94
		],
		[
			49,
			10
		],
		[
			36,
			73
		],
		[
			48,
			10
		],
		[
			-6,
			62
		],
		[
			-115,
			104
		],
		[
			91,
			165
		],
		[
			-72,
			83
		],
		[
			-61,
			11
		],
		[
			-48,
			41
		],
		[
			-6,
			52
		],
		[
			-48,
			-21
		],
		[
			-36,
			31
		],
		[
			-132,
			21
		],
		[
			-36,
			31
		],
		[
			-169,
			10
		],
		[
			-36,
			42
		],
		[
			-60,
			-11
		],
		[
			-30,
			-31
		]
	],
	[
		[
			39959,
			28212
		],
		[
			-54,
			0
		],
		[
			-72,
			31
		],
		[
			-12,
			31
		]
	],
	[
		[
			32275,
			9808
		],
		[
			18,
			-41
		],
		[
			-36,
			-104
		],
		[
			24,
			-93
		],
		[
			-18,
			-83
		],
		[
			96,
			-52
		],
		[
			24,
			-72
		],
		[
			-18,
			-94
		],
		[
			91,
			42
		],
		[
			48,
			0
		],
		[
			84,
			-42
		],
		[
			42,
			42
		],
		[
			102,
			0
		],
		[
			6,
			-93
		],
		[
			54,
			-166
		],
		[
			48,
			-62
		]
	],
	[
		[
			32840,
			8990
		],
		[
			-24,
			-31
		]
	],
	[
		[
			32816,
			8959
		],
		[
			96,
			-62
		],
		[
			6,
			0
		],
		[
			151,
			-63
		],
		[
			126,
			0
		],
		[
			36,
			-72
		],
		[
			-6,
			-41
		],
		[
			-54,
			-63
		],
		[
			-198,
			-41
		],
		[
			-67,
			-52
		],
		[
			-66,
			-83
		],
		[
			-6,
			-41
		],
		[
			121,
			-83
		],
		[
			-18,
			-83
		],
		[
			-91,
			-166
		],
		[
			36,
			-93
		]
	],
	[
		[
			32882,
			8016
		],
		[
			-36,
			-41
		],
		[
			-48,
			0
		],
		[
			-108,
			-83
		],
		[
			-66,
			10
		],
		[
			-54,
			-41
		],
		[
			-157,
			-31
		],
		[
			-174,
			52
		],
		[
			-120,
			-11
		],
		[
			-48,
			-62
		],
		[
			-36,
			-83
		],
		[
			-66,
			-20
		],
		[
			-121,
			20
		],
		[
			-120,
			-20
		],
		[
			-216,
			0
		],
		[
			-127,
			-32
		],
		[
			-144,
			-20
		],
		[
			-156,
			-62
		],
		[
			-103,
			-104
		],
		[
			-102,
			-249
		],
		[
			-66,
			-62
		],
		[
			-48,
			11
		],
		[
			-114,
			-42
		],
		[
			-90,
			-52
		],
		[
			-85,
			-93
		],
		[
			-126,
			-31
		],
		[
			-12,
			21
		],
		[
			-120,
			21
		],
		[
			-42,
			41
		],
		[
			0,
			124
		],
		[
			-54,
			114
		],
		[
			-30,
			21
		],
		[
			-30,
			124
		],
		[
			-55,
			125
		],
		[
			-30,
			41
		],
		[
			-24,
			93
		]
	],
	[
		[
			29954,
			7695
		],
		[
			-24,
			42
		]
	],
	[
		[
			29930,
			7737
		],
		[
			-6,
			10
		]
	],
	[
		[
			29924,
			7747
		],
		[
			-6,
			21
		]
	],
	[
		[
			29918,
			7768
		],
		[
			12,
			10
		]
	],
	[
		[
			29930,
			7778
		],
		[
			-12,
			10
		]
	],
	[
		[
			29918,
			7788
		],
		[
			0,
			11
		]
	],
	[
		[
			29918,
			7799
		],
		[
			12,
			-21
		]
	],
	[
		[
			29930,
			7778
		],
		[
			-12,
			21
		]
	],
	[
		[
			29918,
			7799
		],
		[
			-60,
			31
		],
		[
			54,
			176
		],
		[
			-6,
			207
		],
		[
			-24,
			52
		],
		[
			-78,
			21
		],
		[
			-78,
			72
		],
		[
			-36,
			0
		],
		[
			-42,
			62
		],
		[
			-84,
			-31
		],
		[
			-25,
			10
		],
		[
			-90,
			-62
		],
		[
			-60,
			-62
		],
		[
			-102,
			-10
		]
	],
	[
		[
			29287,
			8265
		],
		[
			-72,
			-31
		],
		[
			-18,
			20
		]
	],
	[
		[
			29197,
			8254
		],
		[
			66,
			83
		],
		[
			24,
			73
		],
		[
			48,
			-11
		],
		[
			66,
			73
		],
		[
			-12,
			83
		],
		[
			-66,
			0
		],
		[
			-48,
			124
		],
		[
			102,
			31
		],
		[
			102,
			0
		],
		[
			72,
			-41
		],
		[
			-12,
			72
		]
	],
	[
		[
			29539,
			8741
		],
		[
			73,
			62
		],
		[
			24,
			145
		]
	],
	[
		[
			29636,
			8948
		],
		[
			24,
			83
		],
		[
			36,
			-10
		],
		[
			12,
			-62
		],
		[
			-6,
			-93
		],
		[
			-24,
			-83
		],
		[
			126,
			0
		],
		[
			60,
			-42
		]
	],
	[
		[
			29864,
			8741
		],
		[
			24,
			52
		],
		[
			42,
			21
		],
		[
			6,
			0
		],
		[
			66,
			-31
		],
		[
			37,
			62
		],
		[
			60,
			52
		],
		[
			60,
			0
		],
		[
			48,
			-63
		]
	],
	[
		[
			30207,
			8834
		],
		[
			66,
			11
		],
		[
			90,
			41
		],
		[
			90,
			0
		],
		[
			48,
			42
		],
		[
			-42,
			51
		],
		[
			0,
			83
		],
		[
			67,
			42
		],
		[
			-6,
			-62
		],
		[
			78,
			-11
		],
		[
			6,
			135
		],
		[
			-36,
			41
		],
		[
			156,
			125
		],
		[
			18,
			-31
		],
		[
			198,
			0
		],
		[
			0,
			82
		],
		[
			109,
			83
		],
		[
			120,
			166
		],
		[
			66,
			52
		],
		[
			90,
			-21
		],
		[
			0,
			-93
		],
		[
			48,
			-52
		],
		[
			96,
			10
		],
		[
			61,
			-20
		],
		[
			66,
			20
		],
		[
			30,
			52
		],
		[
			78,
			21
		],
		[
			42,
			52
		]
	],
	[
		[
			31746,
			9653
		],
		[
			30,
			0
		],
		[
			66,
			72
		],
		[
			30,
			-10
		],
		[
			60,
			41
		],
		[
			133,
			31
		],
		[
			60,
			-10
		],
		[
			150,
			31
		]
	],
	[
		[
			29918,
			7799
		],
		[
			0,
			-11
		]
	],
	[
		[
			29918,
			7788
		],
		[
			12,
			-10
		]
	],
	[
		[
			29918,
			7768
		],
		[
			6,
			-21
		]
	],
	[
		[
			29930,
			7737
		],
		[
			24,
			-42
		]
	],
	[
		[
			29954,
			7695
		],
		[
			-24,
			-83
		],
		[
			-84,
			114
		],
		[
			-54,
			42
		],
		[
			-66,
			10
		]
	],
	[
		[
			29726,
			7778
		],
		[
			18,
			0
		],
		[
			120,
			-104
		]
	],
	[
		[
			29864,
			7674
		],
		[
			-42,
			11
		],
		[
			-96,
			93
		]
	],
	[
		[
			29726,
			7778
		],
		[
			-42,
			10
		],
		[
			-30,
			-31
		],
		[
			-66,
			21
		],
		[
			-121,
			0
		],
		[
			-60,
			104
		],
		[
			-60,
			20
		],
		[
			-42,
			73
		],
		[
			6,
			93
		],
		[
			24,
			83
		],
		[
			-48,
			114
		]
	],
	[
		[
			30177,
			10937
		],
		[
			0,
			-42
		],
		[
			48,
			-41
		],
		[
			156,
			-10
		],
		[
			-6,
			-207
		],
		[
			-12,
			-21
		],
		[
			30,
			-156
		],
		[
			229,
			32
		],
		[
			24,
			20
		],
		[
			66,
			-62
		]
	],
	[
		[
			30712,
			10450
		],
		[
			0,
			-21
		],
		[
			102,
			-93
		],
		[
			24,
			-41
		],
		[
			217,
			-125
		],
		[
			54,
			-51
		],
		[
			126,
			31
		],
		[
			84,
			-11
		],
		[
			169,
			52
		],
		[
			132,
			-10
		],
		[
			-24,
			-73
		],
		[
			-18,
			-124
		],
		[
			-84,
			-155
		],
		[
			72,
			-31
		],
		[
			30,
			-63
		],
		[
			84,
			-10
		],
		[
			18,
			-52
		],
		[
			48,
			-20
		]
	],
	[
		[
			29197,
			8254
		],
		[
			-60,
			42
		],
		[
			-61,
			10
		],
		[
			-12,
			52
		],
		[
			-66,
			-31
		],
		[
			-12,
			41
		],
		[
			-54,
			-10
		],
		[
			-138,
			21
		],
		[
			-60,
			31
		],
		[
			-54,
			0
		]
	],
	[
		[
			28680,
			8410
		],
		[
			0,
			-11
		]
	],
	[
		[
			28680,
			8399
		],
		[
			0,
			-10
		],
		[
			-6,
			0
		],
		[
			-18,
			-72
		],
		[
			-73,
			31
		],
		[
			-96,
			-42
		],
		[
			-6,
			-62
		],
		[
			-48,
			-52
		],
		[
			-48,
			-83
		],
		[
			-48,
			-41
		],
		[
			30,
			-83
		],
		[
			-24,
			-31
		],
		[
			-12,
			-83
		]
	],
	[
		[
			28331,
			7871
		],
		[
			-84,
			62
		],
		[
			-42,
			125
		],
		[
			-48,
			51
		],
		[
			-199,
			-103
		],
		[
			-108,
			0
		],
		[
			-54,
			176
		],
		[
			24,
			52
		]
	],
	[
		[
			27820,
			8234
		],
		[
			30,
			124
		],
		[
			6,
			0
		],
		[
			30,
			31
		],
		[
			6,
			10
		],
		[
			-66,
			156
		],
		[
			6,
			52
		],
		[
			-132,
			0
		],
		[
			24,
			51
		]
	],
	[
		[
			27724,
			8658
		],
		[
			12,
			42
		]
	],
	[
		[
			27736,
			8700
		],
		[
			-24,
			93
		],
		[
			-6,
			114
		],
		[
			-36,
			52
		],
		[
			-55,
			31
		],
		[
			-102,
			-21
		],
		[
			-30,
			52
		],
		[
			-96,
			93
		]
	],
	[
		[
			27387,
			9114
		],
		[
			18,
			21
		]
	],
	[
		[
			27405,
			9135
		],
		[
			60,
			83
		]
	],
	[
		[
			27465,
			9218
		],
		[
			-102,
			20
		],
		[
			-6,
			73
		],
		[
			-30,
			52
		],
		[
			-54,
			20
		],
		[
			-42,
			62
		],
		[
			108,
			32
		],
		[
			54,
			41
		],
		[
			-24,
			83
		],
		[
			-30,
			-11
		],
		[
			-42,
			94
		],
		[
			18,
			83
		],
		[
			42,
			10
		]
	],
	[
		[
			27357,
			9777
		],
		[
			72,
			31
		],
		[
			96,
			-21
		],
		[
			48,
			31
		],
		[
			229,
			-20
		],
		[
			36,
			62
		],
		[
			54,
			-21
		],
		[
			-6,
			-62
		],
		[
			84,
			-42
		],
		[
			30,
			32
		],
		[
			48,
			-21
		],
		[
			60,
			-114
		],
		[
			43,
			-10
		],
		[
			42,
			-83
		],
		[
			54,
			10
		],
		[
			96,
			104
		],
		[
			-18,
			82
		],
		[
			42,
			94
		],
		[
			96,
			10
		],
		[
			84,
			-10
		],
		[
			145,
			83
		],
		[
			174,
			20
		],
		[
			12,
			-31
		],
		[
			78,
			11
		],
		[
			72,
			51
		],
		[
			103,
			166
		],
		[
			-24,
			197
		],
		[
			-24,
			41
		],
		[
			-85,
			0
		],
		[
			0,
			104
		],
		[
			-48,
			103
		],
		[
			0,
			156
		],
		[
			30,
			-11
		],
		[
			103,
			-145
		],
		[
			36,
			52
		]
	],
	[
		[
			29119,
			10626
		],
		[
			-24,
			114
		]
	],
	[
		[
			29095,
			10740
		],
		[
			144,
			-21
		],
		[
			174,
			0
		],
		[
			84,
			-10
		],
		[
			85,
			104
		],
		[
			0,
			93
		],
		[
			78,
			52
		],
		[
			126,
			31
		],
		[
			114,
			-83
		],
		[
			54,
			21
		],
		[
			48,
			-11
		],
		[
			55,
			42
		],
		[
			72,
			10
		],
		[
			48,
			-31
		]
	],
	[
		[
			28415,
			12863
		],
		[
			-30,
			-62
		],
		[
			-42,
			-31
		],
		[
			36,
			-135
		],
		[
			6,
			-82
		],
		[
			-36,
			-83
		],
		[
			48,
			-62
		],
		[
			-6,
			-52
		],
		[
			-120,
			-31
		],
		[
			-66,
			20
		],
		[
			-145,
			-51
		],
		[
			-60,
			0
		],
		[
			-78,
			51
		],
		[
			-66,
			11
		],
		[
			-36,
			-31
		],
		[
			-84,
			10
		],
		[
			18,
			-217
		],
		[
			18,
			-21
		],
		[
			-12,
			-124
		],
		[
			54,
			-63
		],
		[
			66,
			-103
		],
		[
			192,
			-124
		],
		[
			79,
			-11
		],
		[
			90,
			-103
		],
		[
			72,
			-62
		],
		[
			96,
			-52
		],
		[
			24,
			-31
		],
		[
			150,
			10
		],
		[
			73,
			-83
		],
		[
			78,
			-21
		],
		[
			72,
			-51
		],
		[
			6,
			-42
		],
		[
			84,
			-31
		],
		[
			78,
			42
		],
		[
			121,
			-52
		],
		[
			18,
			-42
		],
		[
			12,
			-134
		],
		[
			-24,
			-62
		],
		[
			-49,
			-52
		],
		[
			-24,
			-93
		],
		[
			30,
			-63
		],
		[
			37,
			-10
		]
	],
	[
		[
			27357,
			9777
		],
		[
			-6,
			103
		],
		[
			24,
			73
		],
		[
			-24,
			31
		]
	],
	[
		[
			27351,
			9984
		],
		[
			-102,
			-41
		]
	],
	[
		[
			27249,
			9943
		],
		[
			-54,
			0
		],
		[
			-79,
			-42
		],
		[
			-42,
			0
		],
		[
			-78,
			52
		],
		[
			-60,
			21
		],
		[
			-114,
			0
		],
		[
			24,
			103
		],
		[
			-6,
			104
		],
		[
			78,
			52
		],
		[
			78,
			10
		],
		[
			18,
			93
		],
		[
			36,
			21
		],
		[
			18,
			103
		],
		[
			-66,
			32
		],
		[
			-102,
			10
		],
		[
			-42,
			-62
		],
		[
			-114,
			-73
		],
		[
			-48,
			11
		],
		[
			-103,
			124
		]
	],
	[
		[
			26593,
			10502
		],
		[
			6,
			93
		],
		[
			0,
			10
		],
		[
			18,
			94
		],
		[
			-12,
			41
		],
		[
			-54,
			10
		],
		[
			-204,
			0
		],
		[
			0,
			-51
		]
	],
	[
		[
			26347,
			10699
		],
		[
			-84,
			10
		],
		[
			-24,
			52
		],
		[
			-127,
			21
		]
	],
	[
		[
			26112,
			10782
		],
		[
			24,
			72
		],
		[
			-114,
			10
		],
		[
			-24,
			-31
		],
		[
			-48,
			11
		],
		[
			-42,
			-42
		],
		[
			-72,
			11
		],
		[
			-36,
			72
		],
		[
			-139,
			-10
		]
	],
	[
		[
			25661,
			10875
		],
		[
			6,
			124
		],
		[
			30,
			10
		],
		[
			73,
			114
		],
		[
			-18,
			73
		],
		[
			6,
			103
		],
		[
			96,
			73
		],
		[
			78,
			-10
		],
		[
			-24,
			62
		],
		[
			90,
			0
		],
		[
			60,
			-21
		],
		[
			66,
			31
		],
		[
			-6,
			73
		],
		[
			42,
			0
		],
		[
			49,
			-52
		],
		[
			72,
			-11
		],
		[
			6,
			31
		],
		[
			-109,
			83
		],
		[
			-114,
			-10
		],
		[
			-30,
			-73
		],
		[
			-72,
			-10
		],
		[
			-78,
			10
		],
		[
			-48,
			-41
		],
		[
			-102,
			-41
		],
		[
			-43,
			-94
		],
		[
			-60,
			31
		],
		[
			-84,
			73
		],
		[
			-24,
			62
		],
		[
			-6,
			311
		],
		[
			-90,
			21
		],
		[
			-18,
			51
		],
		[
			12,
			83
		],
		[
			-96,
			52
		],
		[
			-6,
			72
		],
		[
			108,
			-20
		],
		[
			96,
			0
		],
		[
			42,
			83
		],
		[
			30,
			155
		],
		[
			-30,
			93
		],
		[
			-48,
			93
		],
		[
			66,
			0
		],
		[
			42,
			94
		],
		[
			187,
			-11
		],
		[
			36,
			42
		],
		[
			114,
			10
		],
		[
			24,
			31
		],
		[
			78,
			31
		],
		[
			133,
			-10
		],
		[
			90,
			41
		],
		[
			54,
			42
		],
		[
			54,
			-42
		],
		[
			78,
			-10
		],
		[
			36,
			-52
		],
		[
			102,
			21
		],
		[
			30,
			62
		],
		[
			115,
			0
		],
		[
			42,
			21
		],
		[
			114,
			10
		],
		[
			144,
			0
		],
		[
			66,
			31
		],
		[
			30,
			52
		],
		[
			103,
			21
		],
		[
			108,
			-11
		],
		[
			42,
			-52
		],
		[
			72,
			11
		],
		[
			18,
			41
		],
		[
			48,
			-21
		],
		[
			18,
			32
		],
		[
			115,
			41
		],
		[
			60,
			0
		],
		[
			36,
			-31
		],
		[
			138,
			0
		],
		[
			114,
			135
		],
		[
			109,
			-83
		],
		[
			102,
			0
		],
		[
			180,
			-42
		]
	],
	[
		[
			28036,
			5707
		],
		[
			30,
			-11
		],
		[
			30,
			-72
		],
		[
			49,
			31
		],
		[
			54,
			-10
		],
		[
			6,
			72
		],
		[
			-66,
			114
		],
		[
			18,
			62
		],
		[
			-6,
			114
		],
		[
			60,
			52
		],
		[
			84,
			-21
		],
		[
			36,
			-52
		],
		[
			96,
			-93
		],
		[
			18,
			-72
		],
		[
			42,
			-42
		],
		[
			84,
			-21
		],
		[
			43,
			-82
		],
		[
			90,
			-52
		],
		[
			78,
			72
		],
		[
			24,
			-72
		],
		[
			48,
			-31
		],
		[
			42,
			62
		],
		[
			84,
			-10
		],
		[
			60,
			31
		],
		[
			18,
			103
		],
		[
			61,
			42
		],
		[
			84,
			-73
		]
	],
	[
		[
			29648,
			4826
		],
		[
			-48,
			-62
		],
		[
			-30,
			-155
		],
		[
			36,
			-52
		],
		[
			-49,
			-62
		],
		[
			-48,
			0
		],
		[
			-24,
			-73
		],
		[
			-48,
			-10
		],
		[
			-150,
			104
		],
		[
			0,
			93
		],
		[
			-36,
			62
		],
		[
			6,
			52
		],
		[
			-30,
			93
		],
		[
			-42,
			31
		],
		[
			42,
			73
		],
		[
			-42,
			51
		],
		[
			-84,
			0
		],
		[
			-31,
			-20
		],
		[
			-48,
			41
		],
		[
			-96,
			31
		],
		[
			36,
			-83
		],
		[
			84,
			-20
		],
		[
			30,
			-42
		],
		[
			37,
			62
		],
		[
			30,
			-103
		],
		[
			84,
			-83
		],
		[
			-30,
			-83
		],
		[
			54,
			-62
		],
		[
			-6,
			-73
		],
		[
			54,
			-51
		],
		[
			18,
			-83
		],
		[
			-48,
			-73
		],
		[
			-78,
			0
		],
		[
			-48,
			-62
		],
		[
			-97,
			-10
		],
		[
			-60,
			-94
		],
		[
			-66,
			-72
		],
		[
			-42,
			-83
		],
		[
			-54,
			-186
		],
		[
			-48,
			-290
		],
		[
			0,
			-83
		],
		[
			54,
			-83
		],
		[
			-42,
			-62
		],
		[
			-30,
			31
		],
		[
			-48,
			-10
		],
		[
			-66,
			20
		],
		[
			-42,
			-52
		],
		[
			-85,
			-51
		],
		[
			-30,
			-52
		],
		[
			-60,
			-31
		],
		[
			-72,
			41
		],
		[
			-30,
			73
		],
		[
			-66,
			41
		],
		[
			-102,
			11
		],
		[
			-43,
			31
		],
		[
			13,
			51
		],
		[
			90,
			104
		],
		[
			18,
			62
		],
		[
			-24,
			42
		],
		[
			108,
			82
		],
		[
			-6,
			42
		],
		[
			-126,
			-31
		],
		[
			6,
			72
		],
		[
			-72,
			62
		],
		[
			18,
			-134
		],
		[
			48,
			-156
		],
		[
			-30,
			-72
		],
		[
			-91,
			-124
		],
		[
			0,
			-63
		],
		[
			-30,
			-62
		],
		[
			-72,
			42
		],
		[
			-72,
			0
		],
		[
			-48,
			20
		],
		[
			-42,
			63
		],
		[
			-144,
			103
		],
		[
			-91,
			42
		],
		[
			48,
			62
		],
		[
			12,
			103
		],
		[
			-24,
			73
		],
		[
			-102,
			72
		],
		[
			-6,
			125
		],
		[
			-54,
			-31
		],
		[
			-42,
			51
		],
		[
			-54,
			31
		],
		[
			-18,
			42
		],
		[
			-66,
			21
		],
		[
			-72,
			-21
		],
		[
			-55,
			21
		],
		[
			-24,
			41
		],
		[
			-6,
			83
		],
		[
			-48,
			-42
		],
		[
			-204,
			21
		],
		[
			-66,
			-62
		],
		[
			-48,
			21
		],
		[
			-42,
			-83
		],
		[
			-79,
			0
		],
		[
			-18,
			-21
		],
		[
			-90,
			21
		],
		[
			-108,
			83
		],
		[
			-12,
			51
		],
		[
			-78,
			83
		],
		[
			-151,
			-20
		],
		[
			-60,
			82
		],
		[
			12,
			114
		],
		[
			-36,
			0
		],
		[
			-12,
			63
		],
		[
			30,
			31
		]
	],
	[
		[
			25860,
			5282
		],
		[
			-72,
			-52
		]
	],
	[
		[
			25788,
			5230
		],
		[
			-72,
			52
		],
		[
			78,
			62
		],
		[
			54,
			73
		],
		[
			18,
			72
		],
		[
			36,
			31
		],
		[
			-6,
			83
		]
	],
	[
		[
			25896,
			5603
		],
		[
			30,
			21
		]
	],
	[
		[
			25926,
			5624
		],
		[
			54,
			-21
		],
		[
			36,
			31
		],
		[
			162,
			-21
		],
		[
			-12,
			-82
		],
		[
			18,
			-31
		],
		[
			49,
			93
		],
		[
			114,
			72
		],
		[
			90,
			-134
		],
		[
			114,
			51
		],
		[
			48,
			42
		],
		[
			36,
			-11
		]
	],
	[
		[
			26635,
			5613
		],
		[
			36,
			52
		],
		[
			91,
			11
		],
		[
			36,
			72
		],
		[
			36,
			0
		],
		[
			72,
			83
		],
		[
			72,
			21
		],
		[
			54,
			103
		],
		[
			66,
			-10
		],
		[
			0,
			-52
		],
		[
			61,
			-83
		],
		[
			84,
			-41
		],
		[
			60,
			21
		],
		[
			90,
			-63
		],
		[
			108,
			114
		],
		[
			-30,
			135
		],
		[
			-36,
			41
		],
		[
			-12,
			73
		],
		[
			12,
			93
		],
		[
			30,
			10
		],
		[
			-12,
			83
		],
		[
			30,
			62
		],
		[
			42,
			21
		]
	],
	[
		[
			27525,
			6359
		],
		[
			18,
			-72
		],
		[
			78,
			-21
		],
		[
			43,
			41
		],
		[
			36,
			-20
		],
		[
			48,
			-104
		],
		[
			54,
			-62
		],
		[
			30,
			0
		],
		[
			42,
			114
		],
		[
			72,
			72
		],
		[
			24,
			-62
		],
		[
			-6,
			-83
		],
		[
			54,
			0
		],
		[
			30,
			-31
		],
		[
			-24,
			-176
		],
		[
			-48,
			-114
		],
		[
			60,
			-83
		],
		[
			0,
			-51
		]
	],
	[
		[
			29864,
			7674
		],
		[
			24,
			-207
		],
		[
			48,
			-20
		],
		[
			36,
			-104
		],
		[
			-6,
			-41
		],
		[
			36,
			-166
		],
		[
			12,
			-218
		],
		[
			73,
			63
		],
		[
			12,
			-32
		],
		[
			-79,
			-82
		],
		[
			-6,
			-42
		],
		[
			-84,
			-62
		],
		[
			-60,
			-104
		],
		[
			6,
			-72
		],
		[
			-42,
			-41
		],
		[
			-120,
			-187
		],
		[
			-36,
			42
		],
		[
			-96,
			-11
		],
		[
			-61,
			21
		],
		[
			-54,
			-21
		],
		[
			-114,
			0
		],
		[
			-84,
			-21
		],
		[
			-18,
			-41
		],
		[
			282,
			10
		],
		[
			115,
			21
		],
		[
			42,
			-83
		],
		[
			-54,
			-155
		]
	],
	[
		[
			27525,
			6359
		],
		[
			-12,
			73
		],
		[
			12,
			134
		],
		[
			30,
			73
		],
		[
			-60,
			114
		],
		[
			-12,
			124
		],
		[
			18,
			21
		],
		[
			36,
			145
		],
		[
			90,
			134
		],
		[
			67,
			62
		],
		[
			12,
			104
		],
		[
			36,
			31
		],
		[
			48,
			-21
		],
		[
			18,
			42
		],
		[
			54,
			-11
		],
		[
			36,
			42
		],
		[
			6,
			83
		],
		[
			36,
			20
		],
		[
			30,
			104
		],
		[
			-54,
			41
		],
		[
			-24,
			83
		],
		[
			24,
			42
		],
		[
			48,
			-21
		],
		[
			90,
			21
		],
		[
			54,
			-21
		],
		[
			73,
			0
		],
		[
			72,
			41
		],
		[
			84,
			-10
		],
		[
			0,
			52
		]
	],
	[
		[
			28337,
			7861
		],
		[
			-6,
			10
		]
	],
	[
		[
			27387,
			9114
		],
		[
			-36,
			-52
		],
		[
			-72,
			11
		],
		[
			-42,
			-31
		],
		[
			-78,
			-11
		],
		[
			-25,
			104
		],
		[
			-108,
			114
		],
		[
			18,
			52
		],
		[
			-72,
			20
		],
		[
			-96,
			-62
		],
		[
			-54,
			42
		],
		[
			6,
			134
		],
		[
			-84,
			-52
		],
		[
			-73,
			31
		],
		[
			-6,
			-62
		],
		[
			-72,
			-10
		],
		[
			-24,
			41
		],
		[
			-66,
			-10
		],
		[
			-36,
			83
		],
		[
			-60,
			31
		],
		[
			-120,
			-62
		],
		[
			24,
			-93
		],
		[
			-102,
			-73
		],
		[
			6,
			-103
		],
		[
			-97,
			-11
		],
		[
			-48,
			62
		],
		[
			-60,
			-41
		],
		[
			-6,
			-62
		],
		[
			-138,
			-42
		],
		[
			24,
			-51
		],
		[
			0,
			-73
		],
		[
			-72,
			-41
		],
		[
			-36,
			-42
		],
		[
			-6,
			-93
		],
		[
			-36,
			-73
		],
		[
			90,
			21
		],
		[
			-6,
			-52
		],
		[
			-121,
			-41
		],
		[
			-84,
			-62
		],
		[
			24,
			-93
		],
		[
			42,
			-73
		],
		[
			-96,
			-52
		],
		[
			-96,
			-93
		],
		[
			6,
			-103
		],
		[
			-36,
			-83
		],
		[
			-12,
			-94
		],
		[
			36,
			-62
		],
		[
			0,
			-83
		],
		[
			24,
			-51
		],
		[
			54,
			-21
		],
		[
			30,
			-73
		],
		[
			-72,
			-103
		],
		[
			-90,
			10
		],
		[
			-36,
			21
		],
		[
			-54,
			-62
		],
		[
			-139,
			10
		],
		[
			-210,
			-62
		],
		[
			-18,
			-62
		]
	],
	[
		[
			24976,
			7426
		],
		[
			-84,
			-62
		]
	],
	[
		[
			24892,
			7364
		],
		[
			-24,
			-21
		]
	],
	[
		[
			23653,
			9994
		],
		[
			-12,
			114
		],
		[
			30,
			42
		],
		[
			-6,
			83
		],
		[
			36,
			51
		],
		[
			30,
			94
		],
		[
			0,
			114
		],
		[
			18,
			51
		],
		[
			-24,
			73
		],
		[
			18,
			31
		],
		[
			-12,
			114
		],
		[
			30,
			83
		],
		[
			61,
			41
		],
		[
			90,
			-41
		],
		[
			24,
			31
		],
		[
			156,
			0
		],
		[
			42,
			-11
		],
		[
			78,
			-62
		],
		[
			36,
			11
		],
		[
			145,
			-42
		],
		[
			84,
			-62
		],
		[
			42,
			-72
		],
		[
			120,
			-63
		],
		[
			175,
			-10
		],
		[
			210,
			62
		],
		[
			102,
			104
		],
		[
			66,
			93
		],
		[
			121,
			207
		],
		[
			114,
			31
		],
		[
			78,
			207
		],
		[
			36,
			21
		],
		[
			42,
			-41
		],
		[
			6,
			-83
		],
		[
			60,
			52
		],
		[
			54,
			-32
		],
		[
			0,
			-93
		],
		[
			-72,
			-103
		],
		[
			6,
			-94
		],
		[
			24,
			-20
		]
	],
	[
		[
			22902,
			12573
		],
		[
			30,
			-10
		],
		[
			48,
			-124
		],
		[
			0,
			-176
		],
		[
			24,
			-63
		],
		[
			-54,
			-31
		],
		[
			-48,
			42
		],
		[
			-24,
			103
		],
		[
			36,
			52
		],
		[
			0,
			52
		],
		[
			-30,
			72
		],
		[
			18,
			83
		]
	],
	[
		[
			25926,
			5624
		],
		[
			-30,
			-21
		]
	],
	[
		[
			25896,
			5603
		],
		[
			6,
			-31
		],
		[
			-84,
			-72
		],
		[
			-30,
			-94
		],
		[
			-54,
			-62
		],
		[
			-73,
			124
		],
		[
			-24,
			83
		],
		[
			-78,
			114
		],
		[
			-42,
			0
		],
		[
			-30,
			-103
		],
		[
			-42,
			10
		],
		[
			6,
			83
		],
		[
			90,
			62
		],
		[
			12,
			83
		],
		[
			-36,
			62
		],
		[
			12,
			83
		]
	],
	[
		[
			25529,
			5945
		],
		[
			6,
			0
		]
	],
	[
		[
			25535,
			5945
		],
		[
			96,
			-52
		]
	],
	[
		[
			25631,
			5893
		],
		[
			48,
			0
		],
		[
			12,
			62
		]
	],
	[
		[
			25709,
			5945
		],
		[
			55,
			41
		]
	],
	[
		[
			25764,
			5986
		],
		[
			-18,
			52
		]
	],
	[
		[
			25734,
			6038
		],
		[
			-49,
			-52
		]
	],
	[
		[
			25685,
			5986
		],
		[
			-36,
			0
		]
	],
	[
		[
			25637,
			5986
		],
		[
			-6,
			21
		]
	],
	[
		[
			25631,
			6007
		],
		[
			0,
			83
		]
	],
	[
		[
			25595,
			6100
		],
		[
			18,
			42
		]
	],
	[
		[
			39839,
			8047
		],
		[
			6,
			0
		]
	],
	[
		[
			39683,
			8141
		],
		[
			-24,
			31
		]
	],
	[
		[
			39659,
			8172
		],
		[
			0,
			10
		]
	],
	[
		[
			39659,
			8182
		],
		[
			12,
			10
		]
	],
	[
		[
			39671,
			8192
		],
		[
			12,
			-51
		]
	],
	[
		[
			39484,
			8223
		],
		[
			18,
			-10
		]
	],
	[
		[
			39484,
			8752
		],
		[
			0,
			-42
		]
	],
	[
		[
			39484,
			8710
		],
		[
			78,
			-145
		],
		[
			6,
			-83
		],
		[
			36,
			-31
		],
		[
			85,
			52
		],
		[
			66,
			83
		],
		[
			48,
			10
		],
		[
			54,
			-134
		],
		[
			-30,
			-166
		],
		[
			150,
			41
		],
		[
			163,
			-10
		],
		[
			48,
			10
		],
		[
			-18,
			-83
		],
		[
			-43,
			-62
		]
	],
	[
		[
			40127,
			8192
		],
		[
			-84,
			0
		],
		[
			-132,
			-41
		],
		[
			-66,
			-83
		],
		[
			-12,
			41
		],
		[
			-78,
			-10
		],
		[
			-42,
			-31
		],
		[
			-30,
			73
		]
	],
	[
		[
			39683,
			8141
		],
		[
			-12,
			51
		]
	],
	[
		[
			39671,
			8192
		],
		[
			-12,
			-10
		]
	],
	[
		[
			39659,
			8172
		],
		[
			-13,
			-42
		]
	],
	[
		[
			39646,
			8130
		],
		[
			-48,
			0
		]
	],
	[
		[
			39598,
			8130
		],
		[
			-48,
			0
		]
	],
	[
		[
			39550,
			8130
		],
		[
			-12,
			11
		]
	],
	[
		[
			39538,
			8141
		],
		[
			18,
			10
		]
	],
	[
		[
			39556,
			8151
		],
		[
			-12,
			41
		]
	],
	[
		[
			39544,
			8192
		],
		[
			-18,
			21
		]
	],
	[
		[
			39514,
			8213
		],
		[
			-30,
			21
		]
	],
	[
		[
			39484,
			8234
		],
		[
			-12,
			0
		]
	],
	[
		[
			39081,
			8441
		],
		[
			48,
			103
		],
		[
			6,
			218
		],
		[
			-12,
			52
		],
		[
			121,
			62
		],
		[
			66,
			-93
		],
		[
			174,
			-31
		]
	],
	[
		[
			38600,
			10574
		],
		[
			6,
			-103
		],
		[
			66,
			-31
		],
		[
			31,
			-52
		],
		[
			54,
			-21
		],
		[
			54,
			-62
		],
		[
			24,
			-72
		],
		[
			102,
			-166
		],
		[
			108,
			-104
		],
		[
			36,
			-72
		],
		[
			72,
			31
		],
		[
			31,
			52
		]
	],
	[
		[
			39184,
			9974
		],
		[
			78,
			51
		],
		[
			72,
			-41
		],
		[
			114,
			0
		],
		[
			-60,
			-145
		],
		[
			24,
			-72
		],
		[
			-48,
			-73
		],
		[
			-96,
			10
		],
		[
			-18,
			-41
		],
		[
			-18,
			-218
		],
		[
			-36,
			-31
		],
		[
			18,
			-72
		],
		[
			120,
			-31
		],
		[
			84,
			31
		],
		[
			42,
			52
		],
		[
			48,
			-218
		]
	],
	[
		[
			39508,
			9176
		],
		[
			30,
			-41
		],
		[
			-54,
			-62
		],
		[
			0,
			-156
		],
		[
			-18,
			-93
		],
		[
			18,
			-72
		]
	],
	[
		[
			38276,
			8296
		],
		[
			-66,
			-52
		],
		[
			-55,
			124
		],
		[
			-78,
			63
		],
		[
			-42,
			-52
		],
		[
			-18,
			93
		],
		[
			-54,
			124
		],
		[
			-30,
			-83
		],
		[
			-36,
			42
		],
		[
			-48,
			-11
		],
		[
			-6,
			52
		],
		[
			90,
			21
		],
		[
			-24,
			52
		],
		[
			-138,
			-11
		],
		[
			-36,
			63
		],
		[
			-73,
			-21
		],
		[
			-72,
			-83
		],
		[
			-18,
			-73
		]
	],
	[
		[
			37572,
			8544
		],
		[
			-12,
			94
		],
		[
			-126,
			72
		],
		[
			-24,
			93
		],
		[
			198,
			31
		],
		[
			84,
			73
		],
		[
			97,
			166
		],
		[
			96,
			41
		],
		[
			48,
			42
		]
	],
	[
		[
			37933,
			9156
		],
		[
			108,
			103
		],
		[
			-30,
			62
		],
		[
			84,
			73
		],
		[
			0,
			83
		],
		[
			-78,
			93
		],
		[
			-30,
			62
		],
		[
			24,
			93
		],
		[
			-30,
			73
		],
		[
			12,
			41
		],
		[
			60,
			62
		],
		[
			-30,
			83
		],
		[
			-6,
			155
		],
		[
			-54,
			83
		]
	],
	[
		[
			37572,
			8544
		],
		[
			-102,
			-72
		],
		[
			-42,
			10
		],
		[
			-6,
			62
		],
		[
			-162,
			-72
		],
		[
			-115,
			21
		],
		[
			-138,
			114
		],
		[
			-48,
			-42
		],
		[
			-96,
			11
		],
		[
			-6,
			-73
		],
		[
			-42,
			-104
		]
	],
	[
		[
			36815,
			8399
		],
		[
			-30,
			32
		],
		[
			-199,
			10
		],
		[
			-6,
			52
		],
		[
			42,
			20
		],
		[
			18,
			73
		],
		[
			-54,
			21
		],
		[
			36,
			72
		],
		[
			-78,
			124
		],
		[
			42,
			63
		],
		[
			-30,
			41
		],
		[
			-54,
			-31
		],
		[
			-18,
			103
		],
		[
			-42,
			32
		],
		[
			-54,
			-11
		],
		[
			-84,
			62
		],
		[
			18,
			83
		],
		[
			-30,
			52
		],
		[
			-55,
			31
		],
		[
			-48,
			-21
		],
		[
			-48,
			21
		],
		[
			-96,
			-93
		],
		[
			-12,
			52
		],
		[
			36,
			186
		],
		[
			-90,
			-10
		],
		[
			-72,
			-31
		],
		[
			-24,
			103
		],
		[
			-60,
			0
		],
		[
			-37,
			-62
		],
		[
			-72,
			0
		],
		[
			-42,
			62
		]
	],
	[
		[
			35672,
			9435
		],
		[
			-24,
			42
		]
	],
	[
		[
			35648,
			9477
		],
		[
			-66,
			20
		],
		[
			48,
			73
		],
		[
			36,
			-11
		],
		[
			24,
			52
		]
	],
	[
		[
			35690,
			9611
		],
		[
			0,
			11
		]
	],
	[
		[
			35690,
			9622
		],
		[
			24,
			41
		],
		[
			48,
			-62
		],
		[
			55,
			10
		],
		[
			102,
			-21
		],
		[
			108,
			73
		],
		[
			18,
			124
		],
		[
			-60,
			135
		],
		[
			-42,
			-10
		],
		[
			-42,
			41
		],
		[
			-127,
			52
		],
		[
			12,
			72
		],
		[
			73,
			52
		],
		[
			36,
			73
		],
		[
			6,
			82
		],
		[
			54,
			11
		]
	],
	[
		[
			35955,
			10295
		],
		[
			102,
			83
		],
		[
			96,
			41
		],
		[
			36,
			0
		],
		[
			96,
			41
		],
		[
			79,
			11
		],
		[
			-6,
			52
		],
		[
			-54,
			62
		],
		[
			-133,
			10
		]
	],
	[
		[
			36171,
			10595
		],
		[
			-24,
			124
		],
		[
			30,
			42
		]
	],
	[
		[
			36177,
			10761
		],
		[
			78,
			93
		],
		[
			12,
			52
		],
		[
			97,
			72
		],
		[
			84,
			83
		],
		[
			-18,
			93
		],
		[
			-66,
			42
		],
		[
			-30,
			52
		],
		[
			0,
			93
		],
		[
			48,
			41
		],
		[
			66,
			11
		],
		[
			24,
			31
		]
	],
	[
		[
			37049,
			7063
		],
		[
			0,
			-10
		]
	],
	[
		[
			37049,
			7053
		],
		[
			0,
			10
		]
	],
	[
		[
			37049,
			7053
		],
		[
			0,
			10
		]
	],
	[
		[
			38402,
			7633
		],
		[
			-18,
			0
		]
	],
	[
		[
			38384,
			7633
		],
		[
			18,
			0
		]
	],
	[
		[
			38402,
			7633
		],
		[
			-18,
			0
		]
	],
	[
		[
			38384,
			7633
		],
		[
			18,
			0
		]
	],
	[
		[
			38300,
			7695
		],
		[
			-6,
			-10
		]
	],
	[
		[
			38294,
			7685
		],
		[
			6,
			10
		]
	],
	[
		[
			38516,
			7809
		],
		[
			78,
			-10
		],
		[
			-18,
			-83
		],
		[
			-132,
			10
		],
		[
			-24,
			52
		],
		[
			54,
			41
		],
		[
			42,
			-10
		]
	],
	[
		[
			38197,
			8120
		],
		[
			-96,
			-21
		],
		[
			18,
			-62
		]
	],
	[
		[
			38119,
			8037
		],
		[
			-36,
			-31
		],
		[
			-96,
			0
		],
		[
			-84,
			-197
		],
		[
			-6,
			-72
		],
		[
			78,
			-21
		],
		[
			54,
			124
		],
		[
			42,
			11
		],
		[
			48,
			62
		],
		[
			36,
			10
		],
		[
			12,
			-93
		],
		[
			36,
			0
		],
		[
			7,
			-104
		],
		[
			36,
			-62
		],
		[
			48,
			21
		]
	],
	[
		[
			38294,
			7685
		],
		[
			48,
			-114
		],
		[
			48,
			-10
		],
		[
			54,
			20
		],
		[
			18,
			-62
		]
	],
	[
		[
			38462,
			7519
		],
		[
			66,
			-21
		],
		[
			6,
			73
		],
		[
			60,
			10
		],
		[
			48,
			73
		],
		[
			42,
			-83
		],
		[
			-60,
			-135
		],
		[
			18,
			-103
		],
		[
			73,
			-42
		],
		[
			78,
			11
		],
		[
			-54,
			-104
		],
		[
			-103,
			-52
		],
		[
			-42,
			-114
		],
		[
			42,
			-186
		],
		[
			-60,
			-31
		],
		[
			-192,
			0
		],
		[
			-54,
			10
		],
		[
			-145,
			-31
		],
		[
			-18,
			-41
		],
		[
			-60,
			-42
		],
		[
			-90,
			-20
		],
		[
			-36,
			103
		],
		[
			-60,
			42
		],
		[
			-138,
			51
		],
		[
			-36,
			-10
		],
		[
			-133,
			62
		],
		[
			-54,
			83
		],
		[
			-60,
			-21
		],
		[
			-60,
			52
		],
		[
			-72,
			-21
		],
		[
			-72,
			21
		],
		[
			-24,
			41
		],
		[
			-67,
			32
		],
		[
			-36,
			-21
		],
		[
			-90,
			-11
		],
		[
			-42,
			-41
		],
		[
			-186,
			21
		],
		[
			-78,
			41
		],
		[
			-103,
			0
		],
		[
			-42,
			21
		],
		[
			-150,
			10
		]
	],
	[
		[
			36478,
			7146
		],
		[
			12,
			166
		],
		[
			0,
			124
		],
		[
			96,
			0
		],
		[
			6,
			83
		],
		[
			48,
			197
		],
		[
			-30,
			83
		],
		[
			-96,
			10
		],
		[
			42,
			135
		],
		[
			6,
			114
		],
		[
			36,
			72
		],
		[
			24,
			-10
		],
		[
			54,
			155
		],
		[
			30,
			31
		],
		[
			109,
			31
		],
		[
			0,
			62
		]
	],
	[
		[
			35360,
			10616
		],
		[
			90,
			0
		],
		[
			60,
			-145
		],
		[
			72,
			-124
		],
		[
			30,
			-73
		],
		[
			42,
			21
		],
		[
			84,
			-93
		],
		[
			60,
			103
		],
		[
			-30,
			62
		],
		[
			91,
			31
		],
		[
			42,
			-10
		],
		[
			54,
			-93
		]
	],
	[
		[
			36478,
			7146
		],
		[
			-60,
			52
		],
		[
			-181,
			0
		],
		[
			-78,
			41
		],
		[
			-108,
			11
		],
		[
			-72,
			-21
		]
	],
	[
		[
			35979,
			7229
		],
		[
			24,
			83
		],
		[
			6,
			155
		],
		[
			-54,
			21
		],
		[
			-54,
			-21
		],
		[
			-48,
			-72
		],
		[
			0,
			-52
		],
		[
			-61,
			0
		],
		[
			-102,
			52
		],
		[
			-36,
			0
		],
		[
			18,
			186
		],
		[
			-84,
			52
		],
		[
			-90,
			10
		],
		[
			-18,
			-114
		],
		[
			42,
			-10
		],
		[
			-12,
			-83
		],
		[
			24,
			-72
		],
		[
			6,
			-104
		],
		[
			42,
			-145
		],
		[
			-24,
			-31
		],
		[
			6,
			-155
		],
		[
			-30,
			-114
		]
	],
	[
		[
			35534,
			6815
		],
		[
			-60,
			52
		],
		[
			-18,
			103
		],
		[
			-90,
			104
		],
		[
			-85,
			-11
		],
		[
			-48,
			52
		],
		[
			-48,
			21
		],
		[
			-78,
			124
		],
		[
			-54,
			0
		],
		[
			-96,
			83
		],
		[
			-60,
			21
		],
		[
			6,
			41
		],
		[
			-85,
			11
		],
		[
			265,
			-208
		],
		[
			162,
			-145
		],
		[
			72,
			-51
		],
		[
			133,
			-135
		]
	],
	[
		[
			35450,
			6877
		],
		[
			-6,
			-10
		]
	],
	[
		[
			35444,
			6867
		],
		[
			-241,
			217
		],
		[
			-270,
			228
		],
		[
			-205,
			155
		],
		[
			-559,
			352
		],
		[
			-204,
			114
		],
		[
			-193,
			83
		],
		[
			-120,
			0
		],
		[
			-72,
			42
		],
		[
			-78,
			0
		],
		[
			-127,
			51
		],
		[
			-186,
			42
		],
		[
			-90,
			10
		],
		[
			-60,
			-10
		],
		[
			-114,
			-114
		],
		[
			-43,
			-21
		]
	],
	[
		[
			32840,
			8990
		],
		[
			30,
			10
		],
		[
			30,
			83
		],
		[
			0,
			10
		],
		[
			91,
			73
		]
	],
	[
		[
			32991,
			9166
		],
		[
			48,
			0
		],
		[
			48,
			41
		],
		[
			54,
			0
		]
	],
	[
		[
			33141,
			9207
		],
		[
			72,
			52
		],
		[
			162,
			-10
		],
		[
			97,
			20
		],
		[
			12,
			-31
		],
		[
			84,
			31
		]
	],
	[
		[
			33568,
			9269
		],
		[
			126,
			73
		],
		[
			72,
			-52
		],
		[
			36,
			0
		],
		[
			30,
			62
		],
		[
			127,
			11
		],
		[
			36,
			51
		],
		[
			24,
			-31
		],
		[
			156,
			31
		],
		[
			54,
			-20
		],
		[
			108,
			114
		],
		[
			97,
			10
		],
		[
			114,
			83
		],
		[
			48,
			-31
		],
		[
			24,
			41
		],
		[
			90,
			-21
		],
		[
			18,
			-51
		],
		[
			66,
			20
		],
		[
			24,
			31
		]
	],
	[
		[
			34818,
			9590
		],
		[
			12,
			63
		],
		[
			-36,
			41
		]
	],
	[
		[
			34794,
			9694
		],
		[
			-6,
			52
		],
		[
			-42,
			52
		],
		[
			54,
			93
		]
	],
	[
		[
			34800,
			9891
		],
		[
			0,
			62
		],
		[
			61,
			31
		],
		[
			6,
			41
		],
		[
			-49,
			83
		],
		[
			31,
			52
		],
		[
			42,
			21
		],
		[
			6,
			238
		],
		[
			18,
			73
		],
		[
			36,
			-42
		],
		[
			114,
			83
		],
		[
			42,
			-73
		],
		[
			48,
			52
		],
		[
			48,
			21
		],
		[
			-36,
			83
		],
		[
			24,
			52
		],
		[
			72,
			0
		],
		[
			-6,
			-52
		],
		[
			73,
			-21
		],
		[
			30,
			21
		]
	],
	[
		[
			35450,
			6877
		],
		[
			174,
			-166
		],
		[
			18,
			31
		],
		[
			54,
			-114
		],
		[
			72,
			-20
		],
		[
			79,
			10
		],
		[
			72,
			-93
		],
		[
			36,
			-104
		],
		[
			-30,
			-72
		],
		[
			-48,
			-31
		],
		[
			-48,
			-73
		],
		[
			-37,
			-93
		],
		[
			-78,
			-62
		],
		[
			-12,
			83
		],
		[
			18,
			31
		],
		[
			12,
			124
		],
		[
			30,
			176
		],
		[
			-18,
			42
		],
		[
			-156,
			176
		],
		[
			-144,
			145
		]
	],
	[
		[
			35979,
			7229
		],
		[
			-84,
			10
		],
		[
			-109,
			-103
		],
		[
			-48,
			-104
		],
		[
			18,
			-114
		],
		[
			-96,
			-93
		],
		[
			-24,
			-62
		],
		[
			-78,
			62
		],
		[
			-24,
			-10
		]
	],
	[
		[
			51858,
			8783
		],
		[
			-60,
			-135
		],
		[
			-108,
			-52
		],
		[
			-85,
			-83
		],
		[
			-54,
			-103
		],
		[
			-54,
			-42
		],
		[
			-66,
			-82
		],
		[
			-30,
			-83
		],
		[
			-114,
			-31
		],
		[
			-175,
			31
		]
	],
	[
		[
			51112,
			8203
		],
		[
			30,
			20
		],
		[
			-36,
			104
		],
		[
			48,
			52
		],
		[
			-12,
			62
		],
		[
			18,
			124
		],
		[
			55,
			62
		],
		[
			36,
			125
		],
		[
			60,
			82
		],
		[
			36,
			-62
		],
		[
			60,
			31
		],
		[
			0,
			42
		],
		[
			60,
			41
		],
		[
			24,
			-52
		],
		[
			54,
			73
		],
		[
			84,
			0
		],
		[
			0,
			-31
		],
		[
			139,
			-21
		],
		[
			90,
			-72
		]
	],
	[
		[
			53704,
			9445
		],
		[
			-108,
			-20
		],
		[
			-67,
			-52
		],
		[
			-114,
			-21
		],
		[
			-96,
			-51
		],
		[
			-120,
			-11
		],
		[
			-78,
			-31
		],
		[
			-133,
			0
		],
		[
			-186,
			-62
		]
	],
	[
		[
			52802,
			9197
		],
		[
			30,
			72
		],
		[
			24,
			-20
		],
		[
			48,
			31
		],
		[
			-18,
			83
		],
		[
			24,
			51
		],
		[
			-12,
			104
		],
		[
			54,
			114
		],
		[
			48,
			52
		],
		[
			139,
			-62
		],
		[
			42,
			0
		],
		[
			72,
			-52
		],
		[
			108,
			10
		],
		[
			24,
			-52
		],
		[
			54,
			21
		],
		[
			24,
			41
		],
		[
			60,
			-51
		],
		[
			60,
			-21
		],
		[
			49,
			-62
		],
		[
			54,
			21
		],
		[
			18,
			-32
		]
	],
	[
		[
			50764,
			8472
		],
		[
			-18,
			62
		]
	],
	[
		[
			50746,
			8534
		],
		[
			18,
			-62
		]
	],
	[
		[
			50728,
			8596
		],
		[
			0,
			11
		]
	],
	[
		[
			50728,
			8607
		],
		[
			0,
			-11
		]
	],
	[
		[
			50740,
			8627
		],
		[
			-6,
			-10
		]
	],
	[
		[
			50734,
			8617
		],
		[
			6,
			10
		]
	],
	[
		[
			49994,
			9622
		],
		[
			-6,
			-11
		]
	],
	[
		[
			49988,
			9611
		],
		[
			-24,
			-10
		]
	],
	[
		[
			49964,
			9601
		],
		[
			-12,
			21
		]
	],
	[
		[
			49952,
			9622
		],
		[
			-48,
			0
		]
	],
	[
		[
			49904,
			9622
		],
		[
			54,
			41
		]
	],
	[
		[
			49958,
			9663
		],
		[
			36,
			-41
		]
	],
	[
		[
			50072,
			10471
		],
		[
			48,
			-42
		],
		[
			6,
			-72
		],
		[
			78,
			21
		],
		[
			-12,
			-135
		]
	],
	[
		[
			50192,
			10243
		],
		[
			-6,
			-21
		]
	],
	[
		[
			50186,
			10222
		],
		[
			-12,
			-52
		],
		[
			42,
			-72
		],
		[
			6,
			-93
		]
	],
	[
		[
			50222,
			10005
		],
		[
			7,
			-31
		],
		[
			180,
			-73
		],
		[
			42,
			42
		],
		[
			138,
			-94
		],
		[
			-48,
			-51
		],
		[
			-48,
			-104
		],
		[
			-66,
			-104
		],
		[
			36,
			-31
		],
		[
			-6,
			-93
		],
		[
			24,
			-21
		],
		[
			78,
			11
		],
		[
			12,
			-52
		],
		[
			42,
			-31
		],
		[
			-48,
			-114
		],
		[
			54,
			-31
		],
		[
			-48,
			-72
		],
		[
			-30,
			-83
		],
		[
			-60,
			-42
		],
		[
			-18,
			-52
		],
		[
			66,
			-72
		],
		[
			12,
			-104
		],
		[
			60,
			-82
		],
		[
			133,
			-21
		]
	],
	[
		[
			50734,
			8700
		],
		[
			0,
			-11
		]
	],
	[
		[
			50734,
			8689
		],
		[
			12,
			-31
		]
	],
	[
		[
			50746,
			8658
		],
		[
			-6,
			-31
		]
	],
	[
		[
			50740,
			8627
		],
		[
			-24,
			-41
		]
	],
	[
		[
			50716,
			8586
		],
		[
			6,
			-10
		]
	],
	[
		[
			50722,
			8576
		],
		[
			6,
			-21
		]
	],
	[
		[
			50728,
			8555
		],
		[
			12,
			-11
		]
	],
	[
		[
			50740,
			8544
		],
		[
			24,
			-72
		]
	],
	[
		[
			50764,
			8472
		],
		[
			-12,
			-52
		]
	],
	[
		[
			50752,
			8420
		],
		[
			6,
			-21
		]
	],
	[
		[
			50758,
			8399
		],
		[
			-67,
			-31
		],
		[
			-102,
			31
		],
		[
			-162,
			135
		],
		[
			-114,
			83
		],
		[
			-78,
			10
		],
		[
			-85,
			249
		],
		[
			-54,
			10
		],
		[
			-42,
			42
		],
		[
			12,
			62
		],
		[
			-18,
			93
		],
		[
			42,
			114
		],
		[
			30,
			31
		],
		[
			-66,
			104
		],
		[
			-24,
			134
		],
		[
			-126,
			114
		],
		[
			0,
			42
		]
	],
	[
		[
			49904,
			9622
		],
		[
			48,
			0
		]
	],
	[
		[
			49964,
			9601
		],
		[
			24,
			10
		]
	],
	[
		[
			49994,
			9622
		],
		[
			-36,
			41
		]
	],
	[
		[
			49958,
			9663
		],
		[
			-66,
			-31
		],
		[
			42,
			-93
		],
		[
			96,
			-73
		],
		[
			-18,
			-72
		],
		[
			84,
			-125
		],
		[
			-6,
			-93
		],
		[
			-42,
			-72
		],
		[
			12,
			-114
		],
		[
			-12,
			-62
		],
		[
			48,
			-52
		],
		[
			54,
			0
		],
		[
			18,
			-114
		],
		[
			30,
			-21
		],
		[
			18,
			-93
		],
		[
			-12,
			-52
		],
		[
			-96,
			11
		],
		[
			-312,
			114
		],
		[
			-121,
			62
		]
	],
	[
		[
			49116,
			9601
		],
		[
			24,
			93
		],
		[
			18,
			218
		],
		[
			48,
			124
		],
		[
			12,
			124
		],
		[
			36,
			-21
		],
		[
			43,
			21
		],
		[
			-37,
			207
		],
		[
			-36,
			52
		],
		[
			49,
			62
		],
		[
			84,
			0
		],
		[
			60,
			104
		],
		[
			54,
			10
		],
		[
			42,
			-31
		],
		[
			18,
			-93
		],
		[
			24,
			10
		],
		[
			205,
			0
		],
		[
			24,
			52
		],
		[
			18,
			166
		]
	],
	[
		[
			49802,
			10699
		],
		[
			54,
			-21
		],
		[
			66,
			-62
		],
		[
			30,
			-62
		],
		[
			-6,
			-62
		],
		[
			114,
			0
		],
		[
			12,
			-21
		]
	],
	[
		[
			53391,
			10782
		],
		[
			36,
			0
		],
		[
			96,
			62
		],
		[
			48,
			-62
		],
		[
			67,
			51
		],
		[
			48,
			-20
		],
		[
			54,
			10
		],
		[
			66,
			-124
		],
		[
			30,
			-21
		],
		[
			102,
			-21
		],
		[
			36,
			-31
		],
		[
			30,
			31
		],
		[
			169,
			21
		],
		[
			96,
			-52
		],
		[
			90,
			-21
		],
		[
			36,
			-31
		]
	],
	[
		[
			54395,
			10574
		],
		[
			-12,
			-41
		],
		[
			144,
			-259
		],
		[
			103,
			-114
		],
		[
			60,
			0
		],
		[
			42,
			42
		],
		[
			24,
			72
		],
		[
			30,
			-52
		]
	],
	[
		[
			54786,
			10222
		],
		[
			54,
			11
		],
		[
			54,
			-228
		],
		[
			-60,
			-52
		]
	],
	[
		[
			54834,
			9953
		],
		[
			-385,
			93
		],
		[
			-84,
			-10
		],
		[
			6,
			-52
		],
		[
			-60,
			0
		],
		[
			-84,
			-41
		],
		[
			-102,
			-73
		],
		[
			-127,
			-124
		],
		[
			-102,
			-83
		],
		[
			-54,
			-62
		],
		[
			-18,
			-52
		],
		[
			-60,
			-72
		],
		[
			-60,
			-32
		]
	],
	[
		[
			52802,
			9197
		],
		[
			-156,
			-62
		],
		[
			-163,
			-21
		],
		[
			-204,
			-41
		],
		[
			-199,
			-94
		]
	],
	[
		[
			52080,
			8979
		],
		[
			-18,
			104
		],
		[
			6,
			93
		],
		[
			175,
			83
		],
		[
			102,
			124
		],
		[
			96,
			42
		],
		[
			42,
			41
		],
		[
			6,
			62
		],
		[
			-42,
			52
		],
		[
			-12,
			52
		],
		[
			-48,
			10
		],
		[
			-12,
			42
		],
		[
			-72,
			20
		],
		[
			-120,
			-51
		],
		[
			-18,
			-31
		],
		[
			-103,
			-52
		],
		[
			-48,
			52
		],
		[
			48,
			93
		],
		[
			-60,
			41
		],
		[
			-36,
			104
		],
		[
			0,
			72
		],
		[
			48,
			83
		],
		[
			-30,
			52
		],
		[
			-54,
			31
		],
		[
			-84,
			83
		],
		[
			18,
			124
		],
		[
			-78,
			0
		],
		[
			18,
			114
		],
		[
			-18,
			114
		],
		[
			-30,
			104
		],
		[
			48,
			93
		]
	],
	[
		[
			51804,
			10730
		],
		[
			6,
			72
		],
		[
			78,
			11
		],
		[
			42,
			31
		],
		[
			-24,
			51
		]
	],
	[
		[
			51906,
			10895
		],
		[
			48,
			83
		],
		[
			12,
			114
		],
		[
			-6,
			125
		],
		[
			24,
			72
		],
		[
			78,
			62
		],
		[
			109,
			11
		],
		[
			18,
			93
		]
	],
	[
		[
			52189,
			11455
		],
		[
			60,
			-31
		],
		[
			-36,
			-73
		],
		[
			102,
			-93
		],
		[
			42,
			21
		],
		[
			84,
			-62
		],
		[
			132,
			-32
		],
		[
			48,
			-51
		],
		[
			-30,
			-62
		],
		[
			6,
			-94
		],
		[
			55,
			-31
		],
		[
			96,
			21
		],
		[
			66,
			-31
		],
		[
			18,
			-42
		],
		[
			168,
			-20
		],
		[
			24,
			-104
		],
		[
			127,
			-31
		],
		[
			48,
			-41
		],
		[
			48,
			10
		],
		[
			42,
			41
		],
		[
			60,
			0
		],
		[
			42,
			32
		]
	],
	[
		[
			50824,
			11962
		],
		[
			-54,
			-52
		]
	],
	[
		[
			50770,
			11910
		],
		[
			6,
			-82
		],
		[
			36,
			-52
		],
		[
			78,
			-21
		],
		[
			78,
			21
		],
		[
			96,
			0
		],
		[
			90,
			31
		]
	],
	[
		[
			51154,
			11807
		],
		[
			61,
			31
		],
		[
			138,
			-83
		]
	],
	[
		[
			51353,
			11755
		],
		[
			84,
			0
		],
		[
			54,
			-31
		],
		[
			66,
			62
		],
		[
			157,
			11
		],
		[
			36,
			31
		],
		[
			54,
			-31
		],
		[
			-18,
			-83
		],
		[
			48,
			-52
		],
		[
			132,
			0
		],
		[
			-42,
			-52
		],
		[
			18,
			-62
		],
		[
			-18,
			-83
		],
		[
			36,
			-10
		],
		[
			54,
			52
		],
		[
			96,
			-11
		],
		[
			79,
			-41
		]
	],
	[
		[
			52080,
			8979
		],
		[
			-84,
			-41
		],
		[
			-78,
			-62
		],
		[
			-60,
			-93
		]
	],
	[
		[
			51112,
			8203
		],
		[
			-126,
			93
		],
		[
			-228,
			103
		]
	],
	[
		[
			50758,
			8399
		],
		[
			-6,
			21
		]
	],
	[
		[
			50752,
			8420
		],
		[
			12,
			52
		]
	],
	[
		[
			50746,
			8534
		],
		[
			-6,
			10
		]
	],
	[
		[
			50728,
			8555
		],
		[
			-6,
			21
		]
	],
	[
		[
			50722,
			8576
		],
		[
			-6,
			10
		]
	],
	[
		[
			50716,
			8586
		],
		[
			12,
			10
		]
	],
	[
		[
			50728,
			8607
		],
		[
			6,
			10
		]
	],
	[
		[
			50746,
			8658
		],
		[
			-12,
			31
		]
	],
	[
		[
			49802,
			10699
		],
		[
			-18,
			72
		],
		[
			18,
			42
		],
		[
			-24,
			72
		],
		[
			12,
			42
		],
		[
			96,
			72
		],
		[
			0,
			124
		],
		[
			60,
			31
		],
		[
			-36,
			63
		],
		[
			-60,
			-11
		],
		[
			-30,
			166
		],
		[
			-79,
			10
		],
		[
			-24,
			114
		],
		[
			55,
			83
		],
		[
			66,
			0
		],
		[
			102,
			83
		],
		[
			48,
			-10
		],
		[
			60,
			41
		],
		[
			90,
			21
		]
	],
	[
		[
			50138,
			11714
		],
		[
			-78,
			62
		],
		[
			-18,
			62
		],
		[
			12,
			145
		]
	],
	[
		[
			50054,
			11983
		],
		[
			132,
			31
		]
	],
	[
		[
			50186,
			12014
		],
		[
			121,
			-31
		],
		[
			144,
			31
		]
	],
	[
		[
			50451,
			12014
		],
		[
			48,
			0
		],
		[
			102,
			41
		],
		[
			102,
			0
		],
		[
			49,
			-41
		],
		[
			72,
			-10
		],
		[
			0,
			-42
		]
	],
	[
		[
			53084,
			16488
		],
		[
			12,
			-10
		]
	],
	[
		[
			53096,
			16478
		],
		[
			-12,
			10
		]
	],
	[
		[
			53096,
			16478
		],
		[
			6,
			0
		],
		[
			7,
			0
		]
	],
	[
		[
			53109,
			16478
		],
		[
			36,
			10
		]
	],
	[
		[
			53145,
			16488
		],
		[
			6,
			0
		]
	],
	[
		[
			53151,
			16488
		],
		[
			6,
			-10
		]
	],
	[
		[
			53157,
			16478
		],
		[
			-6,
			-21
		]
	],
	[
		[
			53151,
			16457
		],
		[
			-67,
			-52
		],
		[
			-12,
			-103
		],
		[
			91,
			-42
		],
		[
			6,
			-51
		]
	],
	[
		[
			53169,
			16209
		],
		[
			-48,
			-73
		],
		[
			-73,
			-52
		],
		[
			-36,
			-134
		],
		[
			-6,
			-73
		],
		[
			36,
			-62
		]
	],
	[
		[
			53042,
			15815
		],
		[
			-6,
			-21
		]
	],
	[
		[
			53036,
			15794
		],
		[
			0,
			-52
		]
	],
	[
		[
			53036,
			15742
		],
		[
			-6,
			-41
		]
	],
	[
		[
			53030,
			15701
		],
		[
			-18,
			0
		]
	],
	[
		[
			53012,
			15701
		],
		[
			-36,
			-31
		]
	],
	[
		[
			52976,
			15670
		],
		[
			-60,
			21
		],
		[
			-54,
			-11
		]
	],
	[
		[
			52838,
			15711
		],
		[
			-12,
			21
		]
	],
	[
		[
			52820,
			15742
		],
		[
			-54,
			0
		]
	],
	[
		[
			52110,
			16001
		],
		[
			-12,
			176
		],
		[
			30,
			11
		],
		[
			-42,
			166
		],
		[
			-12,
			113
		],
		[
			42,
			42
		],
		[
			18,
			62
		],
		[
			0,
			104
		],
		[
			43,
			31
		],
		[
			42,
			93
		]
	],
	[
		[
			52219,
			16799
		],
		[
			186,
			-10
		],
		[
			72,
			-73
		],
		[
			-24,
			-41
		],
		[
			24,
			-104
		],
		[
			108,
			-31
		],
		[
			91,
			21
		],
		[
			138,
			-31
		],
		[
			12,
			31
		],
		[
			78,
			0
		],
		[
			0,
			-62
		],
		[
			126,
			20
		],
		[
			54,
			-31
		]
	],
	[
		[
			54413,
			19771
		],
		[
			-24,
			-51
		],
		[
			-42,
			20
		],
		[
			-24,
			-72
		],
		[
			-60,
			-21
		],
		[
			-36,
			21
		],
		[
			-30,
			-114
		],
		[
			-24,
			-31
		],
		[
			0,
			-83
		],
		[
			-36,
			-62
		],
		[
			-42,
			-114
		],
		[
			-6,
			-73
		],
		[
			-151,
			-10
		],
		[
			0,
			-41
		],
		[
			54,
			-42
		],
		[
			24,
			-72
		],
		[
			55,
			-83
		],
		[
			0,
			-83
		],
		[
			48,
			-21
		],
		[
			30,
			42
		],
		[
			66,
			-31
		],
		[
			6,
			-73
		],
		[
			-24,
			-83
		],
		[
			-48,
			-41
		],
		[
			18,
			-42
		]
	],
	[
		[
			54167,
			18611
		],
		[
			-115,
			-51
		],
		[
			12,
			-73
		],
		[
			-72,
			-103
		]
	],
	[
		[
			53992,
			18384
		],
		[
			-60,
			93
		],
		[
			-42,
			-21
		],
		[
			-84,
			-155
		],
		[
			-96,
			-62
		],
		[
			-36,
			-52
		],
		[
			12,
			-73
		],
		[
			-30,
			-52
		],
		[
			-79,
			-72
		],
		[
			-24,
			-52
		],
		[
			61,
			-41
		],
		[
			-31,
			-73
		],
		[
			-90,
			21
		],
		[
			-24,
			-31
		],
		[
			-42,
			21
		],
		[
			-36,
			-31
		]
	],
	[
		[
			53391,
			17804
		],
		[
			-36,
			-63
		],
		[
			-30,
			42
		]
	],
	[
		[
			53325,
			17783
		],
		[
			-54,
			-42
		],
		[
			-66,
			11
		]
	],
	[
		[
			53205,
			17752
		],
		[
			-36,
			62
		],
		[
			-48,
			166
		],
		[
			-55,
			51
		],
		[
			-36,
			63
		],
		[
			-66,
			62
		],
		[
			-36,
			93
		],
		[
			42,
			52
		],
		[
			-12,
			124
		],
		[
			0,
			124
		],
		[
			-54,
			73
		],
		[
			-6,
			62
		]
	],
	[
		[
			52898,
			18684
		],
		[
			-48,
			41
		],
		[
			12,
			83
		],
		[
			-72,
			11
		],
		[
			-60,
			51
		],
		[
			-96,
			52
		],
		[
			-67,
			104
		],
		[
			-42,
			41
		],
		[
			-36,
			93
		],
		[
			-48,
			62
		],
		[
			-18,
			104
		],
		[
			-24,
			52
		],
		[
			-66,
			20
		],
		[
			-6,
			166
		],
		[
			24,
			31
		],
		[
			6,
			104
		],
		[
			-42,
			0
		],
		[
			-30,
			145
		],
		[
			60,
			41
		]
	],
	[
		[
			52345,
			19885
		],
		[
			18,
			83
		],
		[
			-24,
			104
		],
		[
			-48,
			124
		],
		[
			36,
			31
		]
	],
	[
		[
			52327,
			20227
		],
		[
			96,
			-10
		],
		[
			-42,
			62
		],
		[
			18,
			114
		],
		[
			-12,
			62
		],
		[
			-102,
			-10
		],
		[
			-108,
			-52
		],
		[
			-31,
			41
		]
	],
	[
		[
			52237,
			20703
		],
		[
			78,
			0
		],
		[
			114,
			63
		],
		[
			48,
			-31
		]
	],
	[
		[
			52477,
			20735
		],
		[
			90,
			31
		],
		[
			24,
			62
		],
		[
			55,
			-52
		],
		[
			84,
			-52
		],
		[
			-12,
			-52
		],
		[
			72,
			-72
		],
		[
			60,
			52
		],
		[
			66,
			-31
		],
		[
			42,
			31
		],
		[
			48,
			-21
		],
		[
			48,
			21
		],
		[
			30,
			83
		],
		[
			85,
			20
		]
	],
	[
		[
			53169,
			20755
		],
		[
			186,
			42
		],
		[
			42,
			51
		],
		[
			72,
			-31
		],
		[
			90,
			83
		],
		[
			109,
			-31
		],
		[
			24,
			21
		]
	],
	[
		[
			53692,
			20890
		],
		[
			90,
			10
		],
		[
			36,
			-20
		],
		[
			30,
			31
		],
		[
			36,
			-73
		],
		[
			84,
			-10
		],
		[
			30,
			-104
		],
		[
			-36,
			-10
		],
		[
			24,
			-83
		],
		[
			48,
			-83
		],
		[
			-90,
			-10
		],
		[
			-24,
			-42
		],
		[
			42,
			-62
		],
		[
			18,
			-72
		],
		[
			42,
			-21
		],
		[
			121,
			52
		],
		[
			36,
			-11
		],
		[
			6,
			-134
		],
		[
			-24,
			-62
		],
		[
			66,
			-42
		],
		[
			18,
			-72
		],
		[
			42,
			0
		],
		[
			18,
			-73
		],
		[
			-6,
			-62
		],
		[
			54,
			-21
		],
		[
			24,
			-134
		],
		[
			36,
			-11
		]
	],
	[
		[
			52195,
			16830
		],
		[
			24,
			-31
		]
	],
	[
		[
			51708,
			16001
		],
		[
			-133,
			-20
		],
		[
			-48,
			145
		],
		[
			-60,
			83
		],
		[
			-12,
			113
		],
		[
			-66,
			11
		],
		[
			30,
			72
		],
		[
			-60,
			83
		],
		[
			-90,
			62
		],
		[
			-78,
			73
		],
		[
			-13,
			-21
		],
		[
			-126,
			-41
		]
	],
	[
		[
			51052,
			16561
		],
		[
			0,
			51
		],
		[
			-36,
			104
		],
		[
			-66,
			104
		],
		[
			60,
			0
		],
		[
			6,
			72
		],
		[
			84,
			0
		],
		[
			30,
			52
		],
		[
			12,
			83
		],
		[
			79,
			0
		],
		[
			102,
			134
		],
		[
			48,
			11
		],
		[
			48,
			83
		],
		[
			60,
			-21
		],
		[
			84,
			-62
		],
		[
			78,
			-83
		],
		[
			31,
			124
		],
		[
			36,
			73
		],
		[
			48,
			51
		],
		[
			0,
			42
		],
		[
			72,
			41
		]
	],
	[
		[
			51828,
			17420
		],
		[
			36,
			-145
		],
		[
			36,
			-72
		],
		[
			78,
			-31
		],
		[
			48,
			20
		],
		[
			48,
			52
		],
		[
			66,
			-62
		],
		[
			97,
			-124
		],
		[
			36,
			-73
		],
		[
			-66,
			-72
		],
		[
			-12,
			-83
		]
	],
	[
		[
			53247,
			15722
		],
		[
			-6,
			0
		],
		[
			6,
			0
		]
	],
	[
		[
			53343,
			15701
		],
		[
			-60,
			21
		]
	],
	[
		[
			53283,
			15722
		],
		[
			-6,
			10
		]
	],
	[
		[
			53277,
			15732
		],
		[
			12,
			0
		]
	],
	[
		[
			53289,
			15732
		],
		[
			78,
			-21
		]
	],
	[
		[
			53367,
			15711
		],
		[
			-24,
			-10
		]
	],
	[
		[
			53517,
			15680
		],
		[
			-96,
			31
		]
	],
	[
		[
			53421,
			15711
		],
		[
			66,
			11
		]
	],
	[
		[
			53487,
			15722
		],
		[
			18,
			0
		]
	],
	[
		[
			53283,
			15722
		],
		[
			-18,
			0
		],
		[
			-6,
			0
		],
		[
			-12,
			0
		]
	],
	[
		[
			53247,
			15722
		],
		[
			6,
			0
		]
	],
	[
		[
			53253,
			15722
		],
		[
			-18,
			0
		]
	],
	[
		[
			53235,
			15722
		],
		[
			12,
			0
		]
	],
	[
		[
			53253,
			15722
		],
		[
			30,
			0
		]
	],
	[
		[
			53283,
			15722
		],
		[
			60,
			-21
		]
	],
	[
		[
			53343,
			15701
		],
		[
			24,
			10
		]
	],
	[
		[
			53367,
			15711
		],
		[
			54,
			-62
		],
		[
			60,
			11
		],
		[
			96,
			-62
		],
		[
			-72,
			-63
		],
		[
			-294,
			-82
		],
		[
			-121,
			31
		],
		[
			-72,
			93
		],
		[
			-78,
			-21
		],
		[
			-48,
			104
		],
		[
			30,
			31
		],
		[
			54,
			-21
		]
	],
	[
		[
			52976,
			15670
		],
		[
			36,
			31
		]
	],
	[
		[
			53030,
			15701
		],
		[
			6,
			41
		]
	],
	[
		[
			53036,
			15742
		],
		[
			0,
			52
		]
	],
	[
		[
			53042,
			15815
		],
		[
			6,
			10
		]
	],
	[
		[
			53048,
			15825
		],
		[
			12,
			0
		]
	],
	[
		[
			53060,
			15825
		],
		[
			169,
			-83
		],
		[
			48,
			-10
		]
	],
	[
		[
			53517,
			15742
		],
		[
			-30,
			-20
		]
	],
	[
		[
			53487,
			15722
		],
		[
			-66,
			-11
		]
	],
	[
		[
			53421,
			15711
		],
		[
			-150,
			31
		]
	],
	[
		[
			53271,
			15742
		],
		[
			-108,
			32
		],
		[
			-103,
			51
		]
	],
	[
		[
			53048,
			15825
		],
		[
			-6,
			-10
		]
	],
	[
		[
			53169,
			16209
		],
		[
			24,
			0
		],
		[
			108,
			-94
		],
		[
			138,
			-20
		],
		[
			108,
			-52
		]
	],
	[
		[
			52357,
			18601
		],
		[
			30,
			-93
		],
		[
			90,
			-31
		],
		[
			30,
			52
		],
		[
			60,
			0
		],
		[
			30,
			51
		],
		[
			109,
			0
		],
		[
			120,
			83
		],
		[
			72,
			21
		]
	],
	[
		[
			53325,
			17783
		],
		[
			-12,
			-93
		],
		[
			24,
			-104
		],
		[
			0,
			-83
		],
		[
			90,
			-21
		],
		[
			-54,
			-113
		],
		[
			18,
			-104
		],
		[
			30,
			0
		],
		[
			0,
			-93
		],
		[
			18,
			-93
		],
		[
			36,
			-52
		],
		[
			24,
			-83
		],
		[
			30,
			-228
		]
	],
	[
		[
			53529,
			16716
		],
		[
			67,
			-31
		],
		[
			12,
			-52
		],
		[
			-115,
			0
		],
		[
			-66,
			-31
		],
		[
			-108,
			21
		],
		[
			-36,
			-62
		]
	],
	[
		[
			53283,
			16561
		],
		[
			-6,
			-21
		]
	],
	[
		[
			53277,
			16540
		],
		[
			-12,
			10
		]
	],
	[
		[
			53265,
			16550
		],
		[
			-12,
			0
		]
	],
	[
		[
			53253,
			16550
		],
		[
			-36,
			0
		]
	],
	[
		[
			53217,
			16550
		],
		[
			-48,
			-20
		]
	],
	[
		[
			53169,
			16530
		],
		[
			-6,
			0
		]
	],
	[
		[
			53163,
			16530
		],
		[
			-6,
			-11
		]
	],
	[
		[
			53157,
			16519
		],
		[
			0,
			-10
		]
	],
	[
		[
			53157,
			16509
		],
		[
			-12,
			-21
		]
	],
	[
		[
			53145,
			16488
		],
		[
			-36,
			-10
		]
	],
	[
		[
			53109,
			16478
		],
		[
			-13,
			0
		]
	],
	[
		[
			51828,
			17420
		],
		[
			72,
			114
		],
		[
			-6,
			125
		],
		[
			-24,
			93
		],
		[
			30,
			145
		]
	],
	[
		[
			51900,
			17897
		],
		[
			6,
			41
		],
		[
			-72,
			42
		],
		[
			0,
			93
		],
		[
			42,
			72
		],
		[
			96,
			0
		],
		[
			0,
			42
		],
		[
			90,
			31
		],
		[
			54,
			-42
		],
		[
			43,
			83
		],
		[
			90,
			21
		],
		[
			42,
			72
		],
		[
			-42,
			94
		],
		[
			18,
			103
		],
		[
			-36,
			62
		],
		[
			54,
			52
		],
		[
			30,
			83
		],
		[
			30,
			-31
		],
		[
			12,
			-114
		]
	],
	[
		[
			55526,
			18249
		],
		[
			144,
			-21
		],
		[
			30,
			-52
		],
		[
			-90,
			-93
		],
		[
			-157,
			-62
		],
		[
			-66,
			-41
		],
		[
			-138,
			-31
		],
		[
			-138,
			10
		],
		[
			-18,
			83
		],
		[
			42,
			72
		],
		[
			72,
			31
		],
		[
			6,
			42
		],
		[
			126,
			83
		],
		[
			144,
			20
		],
		[
			43,
			-41
		]
	],
	[
		[
			55814,
			19668
		],
		[
			6,
			-42
		],
		[
			-42,
			-72
		],
		[
			-96,
			-73
		],
		[
			-96,
			42
		],
		[
			-91,
			0
		],
		[
			-84,
			-31
		],
		[
			-72,
			-62
		],
		[
			-24,
			-73
		],
		[
			-36,
			-41
		]
	],
	[
		[
			55279,
			19316
		],
		[
			90,
			-73
		],
		[
			42,
			-52
		],
		[
			-36,
			-72
		],
		[
			78,
			-52
		],
		[
			-24,
			-93
		],
		[
			12,
			-42
		],
		[
			91,
			-31
		],
		[
			18,
			-51
		],
		[
			-18,
			-83
		],
		[
			12,
			-52
		],
		[
			-67,
			-21
		]
	],
	[
		[
			55477,
			18694
		],
		[
			61,
			-52
		],
		[
			12,
			-82
		],
		[
			-24,
			-42
		],
		[
			12,
			-186
		],
		[
			-187,
			-31
		],
		[
			-60,
			-31
		],
		[
			-174,
			-156
		],
		[
			-48,
			-20
		],
		[
			-24,
			-83
		],
		[
			-67,
			41
		],
		[
			-114,
			21
		],
		[
			-48,
			-11
		],
		[
			-48,
			-41
		]
	],
	[
		[
			54768,
			18021
		],
		[
			-229,
			83
		],
		[
			49,
			93
		],
		[
			-67,
			21
		],
		[
			-126,
			93
		],
		[
			-36,
			-41
		],
		[
			-150,
			-73
		],
		[
			-24,
			10
		],
		[
			-90,
			-31
		],
		[
			-49,
			0
		],
		[
			-6,
			145
		],
		[
			-48,
			63
		]
	],
	[
		[
			54413,
			19771
		],
		[
			30,
			-31
		],
		[
			157,
			-10
		],
		[
			6,
			52
		],
		[
			54,
			10
		],
		[
			102,
			-62
		],
		[
			90,
			10
		],
		[
			30,
			52
		],
		[
			42,
			10
		],
		[
			30,
			-31
		],
		[
			60,
			21
		],
		[
			19,
			41
		],
		[
			126,
			0
		],
		[
			84,
			32
		],
		[
			12,
			-42
		],
		[
			84,
			-10
		],
		[
			96,
			62
		],
		[
			79,
			-83
		],
		[
			18,
			-72
		],
		[
			96,
			10
		],
		[
			36,
			21
		],
		[
			72,
			-83
		],
		[
			42,
			-21
		],
		[
			36,
			21
		]
	],
	[
		[
			51052,
			16561
		],
		[
			-102,
			0
		],
		[
			-78,
			-42
		],
		[
			-78,
			21
		],
		[
			-97,
			0
		]
	],
	[
		[
			50697,
			16540
		],
		[
			-198,
			-104
		],
		[
			-36,
			31
		],
		[
			-30,
			-82
		],
		[
			-30,
			-21
		],
		[
			-54,
			21
		],
		[
			-30,
			-21
		],
		[
			-60,
			21
		],
		[
			-73,
			93
		],
		[
			-54,
			0
		],
		[
			-54,
			62
		]
	],
	[
		[
			50078,
			16540
		],
		[
			-54,
			52
		]
	],
	[
		[
			50024,
			16592
		],
		[
			24,
			52
		],
		[
			-18,
			62
		],
		[
			-126,
			10
		],
		[
			-78,
			41
		]
	],
	[
		[
			49826,
			16757
		],
		[
			24,
			135
		],
		[
			-18,
			31
		],
		[
			0,
			156
		]
	],
	[
		[
			49832,
			17079
		],
		[
			-48,
			217
		],
		[
			36,
			186
		],
		[
			0,
			177
		],
		[
			48,
			0
		],
		[
			42,
			41
		],
		[
			6,
			72
		],
		[
			60,
			32
		],
		[
			6,
			62
		]
	],
	[
		[
			49982,
			17866
		],
		[
			18,
			51
		],
		[
			108,
			63
		],
		[
			60,
			-11
		],
		[
			67,
			42
		]
	],
	[
		[
			50235,
			18011
		],
		[
			-25,
			-31
		],
		[
			6,
			-94
		],
		[
			31,
			-41
		],
		[
			42,
			0
		],
		[
			-12,
			-73
		],
		[
			24,
			-62
		],
		[
			66,
			-62
		],
		[
			18,
			-62
		],
		[
			138,
			104
		],
		[
			108,
			41
		],
		[
			36,
			41
		],
		[
			85,
			32
		],
		[
			18,
			62
		],
		[
			66,
			93
		],
		[
			30,
			83
		],
		[
			-66,
			20
		],
		[
			-12,
			73
		],
		[
			-48,
			31
		]
	],
	[
		[
			50740,
			18166
		],
		[
			96,
			176
		],
		[
			24,
			73
		]
	],
	[
		[
			50860,
			18415
		],
		[
			48,
			-21
		],
		[
			78,
			0
		],
		[
			24,
			-73
		],
		[
			0,
			-72
		],
		[
			84,
			-114
		],
		[
			36,
			41
		],
		[
			48,
			11
		],
		[
			67,
			-42
		],
		[
			24,
			-62
		],
		[
			0,
			-72
		],
		[
			114,
			20
		],
		[
			6,
			21
		],
		[
			114,
			52
		],
		[
			102,
			10
		],
		[
			42,
			-124
		],
		[
			-18,
			-52
		],
		[
			79,
			-31
		],
		[
			36,
			42
		],
		[
			42,
			-32
		],
		[
			114,
			-20
		]
	],
	[
		[
			50235,
			18011
		],
		[
			18,
			41
		],
		[
			228,
			0
		],
		[
			36,
			42
		],
		[
			78,
			20
		],
		[
			48,
			52
		],
		[
			97,
			0
		]
	],
	[
		[
			54167,
			16654
		],
		[
			-12,
			0
		]
	],
	[
		[
			54155,
			16654
		],
		[
			12,
			0
		]
	],
	[
		[
			54233,
			16716
		],
		[
			-78,
			-62
		]
	],
	[
		[
			54155,
			16654
		],
		[
			12,
			52
		]
	],
	[
		[
			54167,
			16706
		],
		[
			18,
			0
		]
	],
	[
		[
			54185,
			16706
		],
		[
			48,
			10
		]
	],
	[
		[
			54816,
			17420
		],
		[
			-6,
			0
		]
	],
	[
		[
			54810,
			17420
		],
		[
			-12,
			-10
		]
	],
	[
		[
			54798,
			17410
		],
		[
			18,
			10
		]
	],
	[
		[
			54395,
			17514
		],
		[
			24,
			-63
		],
		[
			-78,
			-10
		],
		[
			-72,
			31
		],
		[
			-6,
			42
		],
		[
			132,
			0
		]
	],
	[
		[
			54064,
			17555
		],
		[
			49,
			-93
		],
		[
			-18,
			-42
		],
		[
			-55,
			21
		],
		[
			0,
			93
		],
		[
			24,
			21
		]
	],
	[
		[
			54756,
			17627
		],
		[
			6,
			11
		]
	],
	[
		[
			54762,
			17638
		],
		[
			-6,
			-11
		]
	],
	[
		[
			54768,
			18021
		],
		[
			84,
			31
		],
		[
			144,
			-72
		],
		[
			49,
			-73
		],
		[
			-49,
			-41
		],
		[
			-72,
			41
		],
		[
			-60,
			0
		],
		[
			-48,
			52
		],
		[
			-18,
			-52
		],
		[
			114,
			-72
		],
		[
			12,
			-73
		],
		[
			-60,
			-72
		],
		[
			-102,
			-52
		]
	],
	[
		[
			54756,
			17627
		],
		[
			-174,
			0
		],
		[
			-85,
			32
		],
		[
			-48,
			-52
		],
		[
			-84,
			62
		],
		[
			-12,
			-31
		],
		[
			-78,
			-21
		],
		[
			-108,
			-72
		],
		[
			-48,
			10
		],
		[
			-55,
			52
		],
		[
			-36,
			0
		],
		[
			-42,
			-114
		],
		[
			-42,
			41
		],
		[
			-72,
			0
		],
		[
			144,
			-124
		],
		[
			157,
			-31
		],
		[
			90,
			-83
		],
		[
			-48,
			-104
		],
		[
			24,
			-41
		],
		[
			42,
			52
		],
		[
			0,
			62
		],
		[
			78,
			10
		],
		[
			6,
			-93
		],
		[
			30,
			10
		]
	],
	[
		[
			54395,
			17192
		],
		[
			0,
			11
		],
		[
			-24,
			103
		],
		[
			102,
			52
		],
		[
			12,
			83
		],
		[
			67,
			-10
		],
		[
			78,
			31
		],
		[
			84,
			-62
		],
		[
			84,
			10
		]
	],
	[
		[
			54810,
			17420
		],
		[
			6,
			0
		]
	],
	[
		[
			54816,
			17420
		],
		[
			102,
			52
		],
		[
			48,
			52
		],
		[
			73,
			124
		],
		[
			54,
			42
		],
		[
			108,
			20
		],
		[
			72,
			0
		],
		[
			96,
			-114
		],
		[
			18,
			-124
		],
		[
			-42,
			-103
		],
		[
			-12,
			-156
		],
		[
			48,
			-93
		],
		[
			-12,
			-93
		],
		[
			-36,
			-73
		],
		[
			6,
			-62
		],
		[
			-36,
			-93
		],
		[
			6,
			-93
		],
		[
			-12,
			-73
		],
		[
			-48,
			-41
		],
		[
			-126,
			-62
		],
		[
			-30,
			10
		],
		[
			-169,
			0
		],
		[
			-60,
			-21
		],
		[
			-108,
			21
		],
		[
			-48,
			-10
		],
		[
			-163,
			41
		],
		[
			-54,
			-10
		],
		[
			-42,
			20
		],
		[
			-66,
			83
		],
		[
			-90,
			62
		],
		[
			-72,
			11
		],
		[
			-36,
			-31
		]
	],
	[
		[
			54185,
			16706
		],
		[
			-18,
			0
		]
	],
	[
		[
			54167,
			16706
		],
		[
			-24,
			20
		],
		[
			-103,
			0
		],
		[
			-48,
			-62
		],
		[
			-96,
			11
		],
		[
			-162,
			-11
		],
		[
			-30,
			21
		],
		[
			-169,
			10
		],
		[
			-6,
			21
		]
	],
	[
		[
			54720,
			16229
		],
		[
			12,
			-62
		],
		[
			-42,
			-93
		],
		[
			-60,
			-42
		],
		[
			-66,
			156
		],
		[
			60,
			83
		],
		[
			66,
			10
		],
		[
			30,
			-52
		]
	],
	[
		[
			53151,
			16499
		],
		[
			0,
			-11
		]
	],
	[
		[
			53145,
			16488
		],
		[
			6,
			11
		]
	],
	[
		[
			53163,
			16530
		],
		[
			0,
			-11
		]
	],
	[
		[
			53163,
			16519
		],
		[
			-6,
			0
		]
	],
	[
		[
			55429,
			16509
		],
		[
			-18,
			-73
		],
		[
			-114,
			-134
		],
		[
			-30,
			-52
		],
		[
			-253,
			-218
		],
		[
			-42,
			0
		],
		[
			-66,
			-93
		],
		[
			-78,
			-20
		],
		[
			-72,
			31
		],
		[
			-48,
			145
		],
		[
			42,
			62
		],
		[
			-12,
			114
		],
		[
			120,
			-21
		],
		[
			48,
			31
		],
		[
			24,
			52
		],
		[
			0,
			93
		],
		[
			66,
			52
		],
		[
			103,
			-31
		],
		[
			126,
			41
		],
		[
			132,
			31
		],
		[
			72,
			-10
		]
	],
	[
		[
			54750,
			15950
		],
		[
			54,
			-31
		],
		[
			-30,
			-73
		],
		[
			-132,
			-83
		]
	],
	[
		[
			53151,
			16457
		],
		[
			6,
			21
		]
	],
	[
		[
			53157,
			16478
		],
		[
			-6,
			21
		]
	],
	[
		[
			53151,
			16499
		],
		[
			6,
			10
		]
	],
	[
		[
			53163,
			16519
		],
		[
			6,
			11
		]
	],
	[
		[
			53169,
			16530
		],
		[
			48,
			20
		]
	],
	[
		[
			53217,
			16550
		],
		[
			36,
			0
		]
	],
	[
		[
			53253,
			16550
		],
		[
			12,
			0
		]
	],
	[
		[
			53277,
			16540
		],
		[
			6,
			21
		]
	],
	[
		[
			53283,
			16561
		],
		[
			12,
			51
		],
		[
			96,
			-20
		],
		[
			126,
			31
		],
		[
			85,
			-21
		],
		[
			60,
			62
		],
		[
			36,
			-20
		],
		[
			156,
			0
		],
		[
			126,
			-11
		],
		[
			109,
			21
		],
		[
			36,
			-42
		],
		[
			114,
			11
		],
		[
			72,
			41
		],
		[
			66,
			-41
		],
		[
			48,
			-83
		],
		[
			157,
			-10
		],
		[
			48,
			-31
		],
		[
			72,
			0
		],
		[
			192,
			-32
		],
		[
			-12,
			-51
		],
		[
			18,
			-104
		],
		[
			-66,
			-31
		],
		[
			-150,
			31
		],
		[
			-48,
			0
		],
		[
			-84,
			-83
		],
		[
			12,
			-103
		],
		[
			60,
			-94
		],
		[
			0,
			-31
		],
		[
			90,
			-62
		],
		[
			36,
			11
		]
	],
	[
		[
			57221,
			18767
		],
		[
			6,
			0
		]
	],
	[
		[
			57227,
			18767
		],
		[
			6,
			0
		]
	],
	[
		[
			57233,
			18767
		],
		[
			-6,
			-11
		]
	],
	[
		[
			57227,
			18756
		],
		[
			-6,
			11
		]
	],
	[
		[
			57143,
			18901
		],
		[
			72,
			-41
		],
		[
			-12,
			-52
		],
		[
			-60,
			93
		]
	],
	[
		[
			57155,
			18995
		],
		[
			-18,
			-63
		],
		[
			-78,
			-72
		],
		[
			-36,
			41
		],
		[
			-24,
			73
		],
		[
			102,
			0
		],
		[
			54,
			21
		]
	],
	[
		[
			57017,
			19160
		],
		[
			66,
			-52
		],
		[
			0,
			-72
		],
		[
			-72,
			-10
		],
		[
			6,
			134
		]
	],
	[
		[
			55970,
			19678
		],
		[
			12,
			-21
		],
		[
			0,
			-10
		]
	],
	[
		[
			55982,
			19647
		],
		[
			49,
			-62
		],
		[
			96,
			0
		],
		[
			234,
			-62
		],
		[
			151,
			20
		],
		[
			18,
			32
		],
		[
			126,
			20
		],
		[
			30,
			-41
		],
		[
			72,
			-21
		],
		[
			102,
			21
		],
		[
			72,
			-31
		],
		[
			79,
			0
		],
		[
			78,
			83
		],
		[
			90,
			-11
		],
		[
			78,
			-72
		],
		[
			84,
			93
		],
		[
			6,
			-114
		],
		[
			-54,
			-31
		],
		[
			-126,
			-176
		],
		[
			-36,
			-135
		],
		[
			-36,
			-52
		],
		[
			-78,
			52
		]
	],
	[
		[
			57017,
			19160
		],
		[
			-36,
			21
		],
		[
			-49,
			-62
		]
	],
	[
		[
			56932,
			19119
		],
		[
			43,
			-73
		]
	],
	[
		[
			56975,
			19046
		],
		[
			-55,
			0
		],
		[
			-96,
			-51
		],
		[
			-42,
			-114
		],
		[
			90,
			-11
		],
		[
			36,
			62
		],
		[
			61,
			31
		],
		[
			24,
			-72
		],
		[
			0,
			-72
		],
		[
			102,
			-52
		],
		[
			36,
			41
		],
		[
			66,
			-10
		],
		[
			36,
			-31
		]
	],
	[
		[
			57227,
			18767
		],
		[
			-12,
			10
		],
		[
			6,
			-10
		]
	],
	[
		[
			57221,
			18767
		],
		[
			6,
			-11
		]
	],
	[
		[
			57227,
			18756
		],
		[
			24,
			31
		],
		[
			-36,
			114
		],
		[
			30,
			83
		],
		[
			108,
			-83
		],
		[
			-6,
			-103
		],
		[
			-312,
			-414
		],
		[
			-181,
			-145
		],
		[
			-180,
			-83
		],
		[
			-235,
			-166
		],
		[
			-114,
			-41
		],
		[
			-126,
			0
		],
		[
			-138,
			-32
		],
		[
			-145,
			0
		],
		[
			-54,
			83
		],
		[
			-6,
			73
		],
		[
			24,
			52
		],
		[
			-60,
			62
		],
		[
			90,
			41
		],
		[
			-12,
			31
		],
		[
			-126,
			11
		],
		[
			-24,
			-21
		],
		[
			-114,
			114
		],
		[
			-54,
			103
		],
		[
			12,
			94
		],
		[
			-30,
			93
		],
		[
			-85,
			41
		]
	],
	[
		[
			55814,
			19668
		],
		[
			24,
			20
		],
		[
			132,
			-10
		]
	],
	[
		[
			50860,
			18415
		],
		[
			-30,
			124
		],
		[
			18,
			135
		],
		[
			36,
			0
		],
		[
			24,
			113
		],
		[
			114,
			42
		],
		[
			-12,
			62
		],
		[
			-72,
			72
		],
		[
			-18,
			52
		]
	],
	[
		[
			50920,
			19015
		],
		[
			30,
			42
		],
		[
			-18,
			51
		],
		[
			-96,
			-31
		],
		[
			-133,
			-72
		],
		[
			-84,
			0
		],
		[
			-6,
			176
		],
		[
			-12,
			72
		],
		[
			18,
			125
		],
		[
			-36,
			93
		],
		[
			0,
			124
		],
		[
			-30,
			93
		],
		[
			-54,
			73
		],
		[
			18,
			62
		],
		[
			-60,
			114
		],
		[
			-114,
			-31
		],
		[
			-48,
			31
		]
	],
	[
		[
			50295,
			19937
		],
		[
			24,
			31
		],
		[
			12,
			124
		],
		[
			-36,
			52
		]
	],
	[
		[
			38294,
			19171
		],
		[
			-18,
			-42
		],
		[
			-12,
			-145
		],
		[
			-36,
			-62
		],
		[
			-37,
			-103
		],
		[
			-114,
			-63
		],
		[
			-84,
			63
		],
		[
			-48,
			0
		]
	],
	[
		[
			37945,
			18819
		],
		[
			-60,
			62
		]
	],
	[
		[
			37885,
			18881
		],
		[
			-66,
			20
		],
		[
			-30,
			42
		],
		[
			-151,
			41
		],
		[
			-12,
			42
		],
		[
			-96,
			-21
		],
		[
			-6,
			41
		],
		[
			108,
			280
		],
		[
			84,
			-31
		],
		[
			31,
			83
		],
		[
			-18,
			93
		],
		[
			72,
			21
		],
		[
			24,
			-42
		],
		[
			84,
			0
		],
		[
			210,
			-93
		],
		[
			0,
			-72
		],
		[
			36,
			-21
		],
		[
			0,
			-73
		],
		[
			55,
			-20
		],
		[
			84,
			0
		]
	],
	[
		[
			40134,
			20465
		],
		[
			12,
			-20
		],
		[
			120,
			-11
		],
		[
			24,
			-52
		],
		[
			72,
			42
		],
		[
			0,
			-11
		],
		[
			12,
			0
		]
	],
	[
		[
			40374,
			20413
		],
		[
			30,
			11
		],
		[
			6,
			0
		],
		[
			108,
			10
		]
	],
	[
		[
			40518,
			20434
		],
		[
			24,
			-21
		]
	],
	[
		[
			40542,
			20413
		],
		[
			-36,
			-62
		],
		[
			-78,
			-83
		],
		[
			-24,
			-93
		],
		[
			-42,
			-31
		],
		[
			-102,
			-124
		],
		[
			24,
			-52
		]
	],
	[
		[
			40284,
			19968
		],
		[
			-18,
			-114
		],
		[
			42,
			-114
		],
		[
			72,
			-41
		],
		[
			78,
			-21
		],
		[
			36,
			-31
		],
		[
			54,
			-145
		],
		[
			-138,
			-135
		],
		[
			-6,
			-51
		]
	],
	[
		[
			40404,
			19316
		],
		[
			0,
			-11
		]
	],
	[
		[
			40404,
			19305
		],
		[
			24,
			-41
		]
	],
	[
		[
			40428,
			19264
		],
		[
			24,
			-21
		],
		[
			6,
			0
		],
		[
			6,
			-114
		],
		[
			-60,
			-31
		],
		[
			-84,
			21
		],
		[
			-48,
			-187
		],
		[
			-66,
			-72
		],
		[
			-42,
			-21
		],
		[
			54,
			-155
		],
		[
			-54,
			-155
		],
		[
			36,
			-259
		],
		[
			-42,
			-83
		],
		[
			-187,
			-135
		],
		[
			66,
			-62
		],
		[
			42,
			-62
		],
		[
			36,
			-207
		],
		[
			37,
			-62
		],
		[
			18,
			-104
		],
		[
			-61,
			-73
		],
		[
			37,
			-72
		]
	],
	[
		[
			40146,
			17410
		],
		[
			6,
			-10
		],
		[
			6,
			-11
		],
		[
			66,
			-93
		],
		[
			66,
			-62
		],
		[
			42,
			0
		],
		[
			6,
			-52
		],
		[
			42,
			-72
		]
	],
	[
		[
			40380,
			17110
		],
		[
			-24,
			-21
		],
		[
			-108,
			0
		],
		[
			-24,
			62
		],
		[
			-42,
			21
		]
	],
	[
		[
			36670,
			16260
		],
		[
			72,
			187
		],
		[
			12,
			52
		],
		[
			-96,
			124
		],
		[
			-90,
			-42
		]
	],
	[
		[
			36568,
			16581
		],
		[
			-66,
			0
		],
		[
			-18,
			52
		],
		[
			72,
			52
		],
		[
			-24,
			72
		],
		[
			126,
			94
		],
		[
			12,
			31
		]
	],
	[
		[
			36670,
			16882
		],
		[
			42,
			72
		],
		[
			-6,
			135
		],
		[
			48,
			-10
		]
	],
	[
		[
			36754,
			17079
		],
		[
			31,
			20
		],
		[
			36,
			-41
		],
		[
			102,
			-21
		],
		[
			84,
			-145
		],
		[
			234,
			-10
		],
		[
			25,
			103
		]
	],
	[
		[
			37266,
			16985
		],
		[
			-67,
			31
		],
		[
			-30,
			73
		],
		[
			0,
			72
		],
		[
			48,
			31
		],
		[
			55,
			-41
		],
		[
			132,
			21
		],
		[
			30,
			-42
		],
		[
			102,
			125
		],
		[
			66,
			-21
		],
		[
			36,
			72
		],
		[
			-54,
			42
		],
		[
			-6,
			134
		],
		[
			132,
			32
		],
		[
			49,
			-11
		],
		[
			108,
			31
		],
		[
			0,
			62
		],
		[
			36,
			11
		],
		[
			-12,
			72
		],
		[
			-78,
			21
		],
		[
			-48,
			-52
		],
		[
			-24,
			31
		],
		[
			-6,
			104
		],
		[
			18,
			103
		],
		[
			114,
			0
		],
		[
			60,
			21
		],
		[
			-54,
			93
		],
		[
			-6,
			104
		],
		[
			-102,
			62
		],
		[
			-79,
			31
		],
		[
			-48,
			104
		],
		[
			-60,
			93
		]
	],
	[
		[
			37578,
			18394
		],
		[
			72,
			0
		],
		[
			36,
			21
		],
		[
			24,
			103
		],
		[
			55,
			42
		],
		[
			-6,
			72
		],
		[
			36,
			52
		],
		[
			-12,
			52
		],
		[
			84,
			-21
		],
		[
			54,
			41
		],
		[
			24,
			63
		]
	],
	[
		[
			38294,
			19171
		],
		[
			54,
			10
		],
		[
			36,
			104
		],
		[
			108,
			-83
		],
		[
			78,
			-31
		],
		[
			133,
			41
		],
		[
			54,
			-31
		],
		[
			12,
			-73
		],
		[
			90,
			-82
		],
		[
			60,
			0
		],
		[
			36,
			72
		],
		[
			78,
			0
		],
		[
			6,
			-41
		],
		[
			66,
			10
		],
		[
			42,
			-21
		],
		[
			31,
			73
		],
		[
			-139,
			0
		],
		[
			72,
			103
		],
		[
			-114,
			42
		],
		[
			-24,
			72
		],
		[
			18,
			62
		],
		[
			-42,
			32
		],
		[
			-126,
			51
		],
		[
			-36,
			42
		],
		[
			-42,
			165
		],
		[
			54,
			52
		],
		[
			36,
			0
		],
		[
			18,
			52
		],
		[
			54,
			10
		],
		[
			6,
			-72
		],
		[
			60,
			-21
		],
		[
			60,
			52
		],
		[
			78,
			145
		],
		[
			-84,
			31
		],
		[
			48,
			73
		],
		[
			54,
			31
		],
		[
			103,
			-63
		],
		[
			132,
			11
		],
		[
			72,
			-11
		],
		[
			30,
			135
		],
		[
			-84,
			10
		],
		[
			-102,
			32
		]
	],
	[
		[
			39280,
			20155
		],
		[
			30,
			93
		],
		[
			-12,
			52
		],
		[
			60,
			62
		],
		[
			-18,
			72
		],
		[
			-36,
			62
		],
		[
			-72,
			31
		],
		[
			-54,
			52
		],
		[
			-73,
			207
		],
		[
			109,
			0
		],
		[
			24,
			52
		],
		[
			84,
			-62
		],
		[
			78,
			114
		],
		[
			12,
			-52
		],
		[
			84,
			166
		],
		[
			72,
			83
		],
		[
			127,
			62
		]
	],
	[
		[
			39695,
			21149
		],
		[
			48,
			-62
		],
		[
			30,
			-83
		],
		[
			90,
			-52
		],
		[
			54,
			0
		],
		[
			6,
			-93
		],
		[
			-18,
			-83
		],
		[
			108,
			-62
		],
		[
			12,
			62
		],
		[
			48,
			0
		],
		[
			-18,
			-124
		],
		[
			30,
			-52
		],
		[
			55,
			0
		],
		[
			-25,
			-104
		],
		[
			19,
			-31
		]
	],
	[
		[
			36322,
			20289
		],
		[
			0,
			-52
		],
		[
			66,
			-82
		],
		[
			84,
			-11
		],
		[
			18,
			-155
		],
		[
			-6,
			-135
		],
		[
			60,
			11
		],
		[
			72,
			-94
		],
		[
			42,
			31
		],
		[
			72,
			11
		],
		[
			61,
			-21
		]
	],
	[
		[
			36791,
			19792
		],
		[
			-6,
			-72
		],
		[
			24,
			-73
		],
		[
			-73,
			0
		],
		[
			-72,
			-114
		],
		[
			-18,
			-72
		],
		[
			42,
			-73
		],
		[
			18,
			-135
		],
		[
			-72,
			-82
		],
		[
			12,
			-83
		],
		[
			-72,
			-52
		],
		[
			-66,
			0
		],
		[
			-90,
			-114
		],
		[
			102,
			-124
		],
		[
			-36,
			-62
		],
		[
			-120,
			-11
		],
		[
			-48,
			-83
		]
	],
	[
		[
			36316,
			18642
		],
		[
			-24,
			-62
		],
		[
			24,
			-103
		],
		[
			-61,
			-31
		],
		[
			6,
			-135
		],
		[
			18,
			-52
		],
		[
			67,
			-41
		],
		[
			-42,
			-52
		],
		[
			-67,
			-21
		],
		[
			-90,
			62
		],
		[
			-114,
			42
		],
		[
			-72,
			114
		],
		[
			-36,
			21
		],
		[
			-60,
			-11
		],
		[
			-79,
			-83
		],
		[
			-48,
			-124
		],
		[
			12,
			-83
		],
		[
			54,
			-52
		],
		[
			67,
			11
		],
		[
			138,
			-42
		],
		[
			6,
			-51
		],
		[
			-36,
			-42
		],
		[
			-156,
			-83
		],
		[
			-127,
			-114
		],
		[
			-78,
			-41
		],
		[
			-30,
			-73
		],
		[
			-90,
			-62
		],
		[
			-24,
			-41
		],
		[
			-42,
			-135
		],
		[
			-78,
			-21
		],
		[
			-43,
			-51
		],
		[
			-120,
			-42
		],
		[
			-30,
			-52
		],
		[
			-42,
			11
		],
		[
			-84,
			-73
		],
		[
			-132,
			-72
		],
		[
			-67,
			-52
		],
		[
			-96,
			-114
		],
		[
			12,
			-62
		],
		[
			-48,
			-62
		],
		[
			-54,
			-114
		],
		[
			-48,
			-52
		],
		[
			-6,
			-83
		],
		[
			18,
			-72
		],
		[
			-30,
			-42
		],
		[
			-42,
			62
		],
		[
			30,
			63
		],
		[
			-66,
			93
		],
		[
			6,
			83
		],
		[
			-24,
			51
		],
		[
			-60,
			11
		],
		[
			84,
			145
		],
		[
			-102,
			-21
		],
		[
			12,
			83
		],
		[
			54,
			-10
		],
		[
			66,
			20
		],
		[
			-12,
			73
		],
		[
			-60,
			31
		],
		[
			24,
			114
		],
		[
			-78,
			93
		]
	],
	[
		[
			34416,
			17296
		],
		[
			36,
			-31
		]
	],
	[
		[
			34452,
			17265
		],
		[
			12,
			0
		]
	],
	[
		[
			34464,
			17265
		],
		[
			30,
			62
		],
		[
			-60,
			73
		],
		[
			-18,
			62
		]
	],
	[
		[
			34416,
			17462
		],
		[
			6,
			31
		]
	],
	[
		[
			34422,
			17493
		],
		[
			-30,
			72
		],
		[
			78,
			42
		]
	],
	[
		[
			34470,
			17607
		],
		[
			18,
			62
		]
	],
	[
		[
			34488,
			17669
		],
		[
			36,
			114
		],
		[
			-48,
			31
		],
		[
			-48,
			83
		],
		[
			48,
			259
		],
		[
			-42,
			83
		],
		[
			36,
			51
		],
		[
			72,
			11
		],
		[
			-6,
			114
		],
		[
			60,
			41
		]
	],
	[
		[
			37266,
			18632
		],
		[
			-79,
			-83
		],
		[
			-42,
			-72
		],
		[
			-84,
			-73
		],
		[
			-42,
			52
		],
		[
			-108,
			-10
		],
		[
			-42,
			-42
		],
		[
			-36,
			-124
		],
		[
			-109,
			72
		],
		[
			-48,
			63
		],
		[
			-54,
			20
		],
		[
			6,
			73
		]
	],
	[
		[
			36628,
			18508
		],
		[
			18,
			0
		]
	],
	[
		[
			36646,
			18508
		],
		[
			36,
			62
		],
		[
			60,
			62
		],
		[
			-48,
			124
		],
		[
			54,
			31
		]
	],
	[
		[
			36748,
			18787
		],
		[
			49,
			63
		],
		[
			12,
			62
		]
	],
	[
		[
			36809,
			18912
		],
		[
			102,
			31
		],
		[
			36,
			41
		],
		[
			84,
			-10
		],
		[
			60,
			31
		],
		[
			54,
			0
		],
		[
			54,
			-62
		],
		[
			18,
			-124
		],
		[
			109,
			-83
		],
		[
			-60,
			-104
		]
	],
	[
		[
			37266,
			18632
		],
		[
			6,
			-10
		]
	],
	[
		[
			37272,
			18622
		],
		[
			84,
			-83
		],
		[
			6,
			-31
		],
		[
			84,
			-83
		],
		[
			132,
			-31
		]
	],
	[
		[
			35263,
			17047
		],
		[
			151,
			83
		],
		[
			66,
			73
		],
		[
			66,
			103
		],
		[
			18,
			187
		],
		[
			60,
			10
		],
		[
			120,
			135
		],
		[
			115,
			-31
		],
		[
			90,
			62
		],
		[
			36,
			52
		],
		[
			60,
			20
		],
		[
			96,
			73
		],
		[
			18,
			41
		],
		[
			-30,
			114
		],
		[
			-162,
			104
		],
		[
			-96,
			0
		],
		[
			-91,
			41
		],
		[
			-12,
			52
		],
		[
			55,
			104
		],
		[
			60,
			72
		],
		[
			138,
			-124
		],
		[
			78,
			-21
		],
		[
			90,
			-62
		],
		[
			42,
			-10
		],
		[
			79,
			20
		],
		[
			36,
			42
		],
		[
			-6,
			83
		],
		[
			-61,
			41
		],
		[
			-18,
			104
		],
		[
			24,
			51
		],
		[
			37,
			176
		]
	],
	[
		[
			36322,
			18642
		],
		[
			84,
			32
		]
	],
	[
		[
			36406,
			18674
		],
		[
			84,
			-21
		]
	],
	[
		[
			36490,
			18653
		],
		[
			60,
			0
		],
		[
			42,
			-31
		],
		[
			36,
			-114
		]
	],
	[
		[
			37584,
			20113
		],
		[
			84,
			114
		],
		[
			121,
			-10
		],
		[
			60,
			-31
		],
		[
			90,
			10
		],
		[
			66,
			31
		],
		[
			60,
			-104
		],
		[
			66,
			11
		],
		[
			121,
			145
		],
		[
			54,
			31
		],
		[
			54,
			62
		],
		[
			18,
			-31
		],
		[
			66,
			83
		],
		[
			120,
			0
		],
		[
			66,
			21
		],
		[
			36,
			-63
		],
		[
			85,
			-10
		],
		[
			102,
			135
		],
		[
			162,
			-145
		],
		[
			66,
			-42
		],
		[
			54,
			-93
		],
		[
			79,
			-62
		],
		[
			66,
			-10
		]
	],
	[
		[
			36809,
			18912
		],
		[
			-18,
			-62
		],
		[
			-43,
			-63
		]
	],
	[
		[
			36748,
			18787
		],
		[
			-66,
			-31
		],
		[
			48,
			-134
		],
		[
			-60,
			-52
		],
		[
			-24,
			-62
		]
	],
	[
		[
			36646,
			18508
		],
		[
			-30,
			21
		],
		[
			-24,
			113
		],
		[
			-102,
			11
		]
	],
	[
		[
			36490,
			18653
		],
		[
			-84,
			21
		]
	],
	[
		[
			36322,
			18642
		],
		[
			-6,
			0
		]
	],
	[
		[
			36791,
			19792
		],
		[
			108,
			-21
		],
		[
			108,
			197
		],
		[
			30,
			10
		],
		[
			42,
			73
		],
		[
			126,
			0
		],
		[
			79,
			-52
		],
		[
			30,
			42
		],
		[
			90,
			10
		],
		[
			6,
			52
		],
		[
			-120,
			114
		],
		[
			-24,
			51
		],
		[
			66,
			32
		],
		[
			-24,
			124
		],
		[
			0,
			62
		],
		[
			54,
			52
		]
	],
	[
		[
			37362,
			20538
		],
		[
			54,
			31
		],
		[
			72,
			-42
		],
		[
			90,
			0
		],
		[
			90,
			-41
		],
		[
			18,
			-52
		],
		[
			-60,
			-62
		],
		[
			-60,
			-10
		],
		[
			-30,
			-42
		],
		[
			-24,
			-103
		],
		[
			-30,
			-62
		],
		[
			90,
			-73
		],
		[
			12,
			31
		]
	],
	[
		[
			44204,
			14065
		],
		[
			-12,
			-83
		],
		[
			-36,
			-42
		],
		[
			18,
			-82
		],
		[
			60,
			-11
		],
		[
			-36,
			-134
		],
		[
			18,
			-125
		],
		[
			-66,
			-103
		],
		[
			-36,
			-31
		],
		[
			12,
			-63
		],
		[
			102,
			-20
		],
		[
			-6,
			-62
		],
		[
			30,
			-52
		],
		[
			-18,
			-124
		],
		[
			-48,
			-83
		],
		[
			-24,
			-73
		],
		[
			96,
			-31
		],
		[
			-36,
			-62
		],
		[
			36,
			-41
		],
		[
			-6,
			-94
		],
		[
			-30,
			-51
		],
		[
			-18,
			-114
		],
		[
			0,
			-125
		]
	],
	[
		[
			44204,
			12459
		],
		[
			-156,
			-20
		],
		[
			-127,
			31
		],
		[
			-204,
			-31
		],
		[
			-18,
			-21
		],
		[
			-18,
			-124
		],
		[
			18,
			-73
		],
		[
			-78,
			31
		],
		[
			-66,
			-41
		],
		[
			-36,
			0
		],
		[
			-37,
			-73
		],
		[
			-120,
			-114
		]
	],
	[
		[
			43362,
			12024
		],
		[
			-60,
			-20
		],
		[
			-102,
			-62
		],
		[
			-102,
			-11
		],
		[
			-48,
			42
		],
		[
			12,
			62
		],
		[
			-85,
			52
		],
		[
			-84,
			10
		],
		[
			-6,
			72
		],
		[
			102,
			21
		],
		[
			55,
			31
		],
		[
			30,
			104
		],
		[
			-42,
			62
		],
		[
			-73,
			31
		],
		[
			-24,
			-41
		],
		[
			-66,
			31
		],
		[
			-60,
			62
		],
		[
			-144,
			0
		],
		[
			-241,
			52
		],
		[
			-84,
			-21
		]
	],
	[
		[
			42340,
			12501
		],
		[
			-132,
			-62
		],
		[
			-54,
			-11
		],
		[
			12,
			94
		],
		[
			-12,
			82
		],
		[
			-96,
			62
		],
		[
			-13,
			-72
		],
		[
			-48,
			-21
		],
		[
			-90,
			125
		],
		[
			-72,
			20
		],
		[
			-180,
			73
		],
		[
			0,
			83
		],
		[
			-36,
			31
		],
		[
			-73,
			124
		],
		[
			-66,
			31
		],
		[
			6,
			73
		],
		[
			109,
			113
		],
		[
			96,
			42
		],
		[
			30,
			72
		],
		[
			-24,
			83
		],
		[
			-24,
			11
		]
	],
	[
		[
			41673,
			13454
		],
		[
			-6,
			165
		],
		[
			24,
			31
		],
		[
			18,
			94
		],
		[
			-66,
			93
		]
	],
	[
		[
			44998,
			12656
		],
		[
			36,
			-103
		],
		[
			72,
			-104
		],
		[
			30,
			-72
		],
		[
			-54,
			-301
		],
		[
			36,
			-41
		],
		[
			60,
			31
		],
		[
			60,
			62
		],
		[
			60,
			-31
		],
		[
			30,
			-114
		],
		[
			60,
			-41
		],
		[
			18,
			-73
		],
		[
			79,
			-114
		],
		[
			108,
			-31
		],
		[
			-18,
			-83
		],
		[
			-54,
			-103
		],
		[
			30,
			-52
		]
	],
	[
		[
			45551,
			11486
		],
		[
			-66,
			-11
		],
		[
			-97,
			-62
		],
		[
			-90,
			-145
		],
		[
			-36,
			11
		],
		[
			-96,
			-31
		],
		[
			-60,
			20
		],
		[
			-6,
			52
		],
		[
			-42,
			0
		],
		[
			-66,
			-93
		],
		[
			-18,
			-135
		],
		[
			-79,
			-62
		],
		[
			-102,
			-114
		],
		[
			-66,
			-21
		],
		[
			-18,
			-62
		],
		[
			24,
			-93
		],
		[
			-6,
			-62
		],
		[
			-36,
			0
		],
		[
			-36,
			-62
		],
		[
			-54,
			-145
		],
		[
			12,
			-73
		],
		[
			-78,
			-124
		],
		[
			-6,
			-93
		],
		[
			-42,
			-31
		],
		[
			54,
			-156
		],
		[
			24,
			-41
		],
		[
			-72,
			-41
		],
		[
			-79,
			-135
		],
		[
			0,
			-62
		],
		[
			-30,
			-73
		],
		[
			48,
			-62
		],
		[
			49,
			-103
		]
	],
	[
		[
			44481,
			9477
		],
		[
			-85,
			-52
		],
		[
			-60,
			0
		],
		[
			-30,
			93
		],
		[
			-60,
			10
		],
		[
			-132,
			197
		],
		[
			-54,
			42
		],
		[
			-72,
			20
		],
		[
			-61,
			-20
		]
	],
	[
		[
			43927,
			9767
		],
		[
			-84,
			-11
		],
		[
			18,
			104
		],
		[
			54,
			72
		],
		[
			-18,
			62
		],
		[
			18,
			94
		],
		[
			-24,
			124
		],
		[
			-36,
			31
		],
		[
			6,
			135
		],
		[
			-48,
			20
		],
		[
			-6,
			62
		],
		[
			-48,
			0
		],
		[
			-36,
			208
		],
		[
			42,
			196
		],
		[
			-18,
			94
		],
		[
			-48,
			31
		],
		[
			54,
			83
		],
		[
			-30,
			41
		],
		[
			-90,
			31
		],
		[
			-54,
			114
		],
		[
			0,
			52
		],
		[
			-72,
			103
		],
		[
			-6,
			94
		],
		[
			144,
			93
		],
		[
			0,
			41
		],
		[
			48,
			42
		]
	],
	[
		[
			43693,
			11683
		],
		[
			-96,
			20
		],
		[
			0,
			104
		],
		[
			-18,
			52
		],
		[
			0,
			134
		],
		[
			-85,
			-31
		],
		[
			-90,
			21
		],
		[
			-42,
			41
		]
	],
	[
		[
			44204,
			12459
		],
		[
			72,
			-41
		],
		[
			54,
			41
		],
		[
			12,
			52
		],
		[
			169,
			73
		],
		[
			66,
			0
		],
		[
			96,
			31
		],
		[
			6,
			31
		],
		[
			114,
			0
		],
		[
			72,
			31
		],
		[
			133,
			-21
		]
	],
	[
		[
			41859,
			10709
		],
		[
			48,
			0
		],
		[
			175,
			-52
		],
		[
			66,
			-124
		],
		[
			84,
			-52
		],
		[
			48,
			73
		],
		[
			42,
			-31
		],
		[
			126,
			-21
		],
		[
			-30,
			-73
		],
		[
			114,
			0
		],
		[
			25,
			42
		],
		[
			78,
			0
		],
		[
			-78,
			-156
		],
		[
			-61,
			-31
		],
		[
			-60,
			-103
		],
		[
			42,
			-104
		],
		[
			67,
			-10
		],
		[
			54,
			-124
		],
		[
			-18,
			-63
		]
	],
	[
		[
			42581,
			9880
		],
		[
			0,
			-20
		]
	],
	[
		[
			42581,
			9860
		],
		[
			-6,
			-11
		]
	],
	[
		[
			42575,
			9849
		],
		[
			0,
			-10
		]
	],
	[
		[
			42575,
			9839
		],
		[
			0,
			-10
		]
	],
	[
		[
			42575,
			9829
		],
		[
			0,
			-11
		]
	],
	[
		[
			42575,
			9818
		],
		[
			6,
			0
		]
	],
	[
		[
			42581,
			9818
		],
		[
			12,
			-10
		]
	],
	[
		[
			42593,
			9808
		],
		[
			-6,
			0
		]
	],
	[
		[
			42587,
			9808
		],
		[
			12,
			-10
		]
	],
	[
		[
			42599,
			9798
		],
		[
			0,
			-21
		]
	],
	[
		[
			42599,
			9777
		],
		[
			0,
			-62
		],
		[
			-42,
			0
		]
	],
	[
		[
			42557,
			9715
		],
		[
			-103,
			-42
		],
		[
			-78,
			-83
		],
		[
			-6,
			-72
		],
		[
			-54,
			-10
		],
		[
			24,
			-73
		],
		[
			-24,
			-83
		],
		[
			18,
			-103
		],
		[
			-66,
			20
		],
		[
			-60,
			52
		],
		[
			-42,
			62
		],
		[
			-72,
			62
		],
		[
			-79,
			94
		]
	],
	[
		[
			41931,
			10181
		],
		[
			0,
			83
		],
		[
			-78,
			72
		],
		[
			-12,
			52
		],
		[
			18,
			62
		],
		[
			6,
			104
		],
		[
			-42,
			83
		],
		[
			36,
			72
		]
	],
	[
		[
			42593,
			9704
		],
		[
			60,
			-82
		],
		[
			6,
			-156
		],
		[
			114,
			-93
		],
		[
			30,
			-10
		],
		[
			78,
			134
		],
		[
			102,
			0
		],
		[
			0,
			83
		],
		[
			55,
			0
		],
		[
			18,
			42
		],
		[
			60,
			-11
		],
		[
			42,
			21
		],
		[
			72,
			-62
		],
		[
			30,
			-52
		],
		[
			-12,
			-73
		],
		[
			42,
			-31
		],
		[
			6,
			-72
		],
		[
			162,
			-10
		]
	],
	[
		[
			43446,
			9207
		],
		[
			24,
			-83
		],
		[
			-54,
			0
		],
		[
			-72,
			32
		],
		[
			-48,
			0
		],
		[
			-96,
			62
		],
		[
			-42,
			-52
		],
		[
			-48,
			10
		],
		[
			-18,
			-41
		]
	],
	[
		[
			43092,
			9135
		],
		[
			-30,
			-62
		],
		[
			-12,
			-104
		],
		[
			42,
			-41
		],
		[
			-85,
			-42
		],
		[
			-96,
			11
		],
		[
			-24,
			-21
		]
	],
	[
		[
			42887,
			8876
		],
		[
			-138,
			83
		],
		[
			-42,
			-11
		],
		[
			-108,
			94
		],
		[
			-187,
			82
		],
		[
			-54,
			42
		],
		[
			18,
			83
		],
		[
			-30,
			41
		],
		[
			0,
			93
		],
		[
			18,
			114
		],
		[
			48,
			31
		],
		[
			-18,
			62
		],
		[
			90,
			94
		],
		[
			73,
			31
		]
	],
	[
		[
			42557,
			9715
		],
		[
			36,
			-11
		]
	],
	[
		[
			43092,
			9135
		],
		[
			18,
			21
		],
		[
			150,
			-52
		],
		[
			48,
			-156
		],
		[
			78,
			-72
		],
		[
			24,
			-104
		],
		[
			42,
			-20
		],
		[
			0,
			-73
		],
		[
			-102,
			-124
		],
		[
			-30,
			-21
		],
		[
			-90,
			83
		],
		[
			-66,
			31
		],
		[
			-108,
			21
		],
		[
			-67,
			62
		],
		[
			-102,
			145
		]
	],
	[
		[
			45425,
			13795
		],
		[
			60,
			-62
		],
		[
			12,
			-62
		],
		[
			-6,
			0
		]
	],
	[
		[
			45491,
			13671
		],
		[
			-91,
			-10
		],
		[
			-72,
			-73
		],
		[
			-30,
			-52
		],
		[
			-30,
			-113
		],
		[
			66,
			-94
		],
		[
			-96,
			-62
		],
		[
			18,
			-134
		],
		[
			-12,
			-32
		],
		[
			6,
			-124
		]
	],
	[
		[
			45250,
			12977
		],
		[
			-90,
			-52
		],
		[
			-42,
			-62
		],
		[
			-6,
			-72
		],
		[
			-66,
			-93
		],
		[
			-48,
			-42
		]
	],
	[
		[
			44306,
			9104
		],
		[
			78,
			-31
		],
		[
			24,
			-62
		],
		[
			-24,
			-63
		],
		[
			-18,
			-114
		],
		[
			18,
			-51
		],
		[
			-24,
			-83
		],
		[
			127,
			-73
		],
		[
			-12,
			-62
		],
		[
			-73,
			11
		],
		[
			-108,
			41
		],
		[
			-294,
			41
		],
		[
			-18,
			52
		],
		[
			144,
			31
		],
		[
			54,
			62
		],
		[
			6,
			83
		],
		[
			36,
			104
		],
		[
			-18,
			52
		],
		[
			48,
			51
		],
		[
			54,
			11
		]
	],
	[
		[
			44000,
			9135
		],
		[
			0,
			-11
		]
	],
	[
		[
			44481,
			9477
		],
		[
			72,
			-83
		],
		[
			-42,
			-93
		],
		[
			6,
			-83
		]
	],
	[
		[
			44517,
			9218
		],
		[
			0,
			-21
		]
	],
	[
		[
			44517,
			9197
		],
		[
			-109,
			0
		],
		[
			-48,
			-41
		],
		[
			-66,
			31
		],
		[
			-42,
			-31
		],
		[
			-66,
			-11
		],
		[
			-132,
			62
		],
		[
			-54,
			-20
		]
	],
	[
		[
			44000,
			9187
		],
		[
			6,
			-31
		]
	],
	[
		[
			43813,
			9321
		],
		[
			24,
			31
		],
		[
			30,
			125
		],
		[
			48,
			82
		],
		[
			-48,
			11
		],
		[
			-24,
			83
		],
		[
			84,
			114
		]
	],
	[
		[
			41348,
			10005
		],
		[
			18,
			0
		]
	],
	[
		[
			41366,
			10005
		],
		[
			12,
			-11
		]
	],
	[
		[
			41366,
			9974
		],
		[
			-6,
			0
		]
	],
	[
		[
			41360,
			9974
		],
		[
			-18,
			20
		]
	],
	[
		[
			41342,
			9994
		],
		[
			6,
			0
		]
	],
	[
		[
			41348,
			9994
		],
		[
			-12,
			11
		]
	],
	[
		[
			41336,
			10005
		],
		[
			12,
			0
		]
	],
	[
		[
			40548,
			10284
		],
		[
			67,
			-41
		],
		[
			120,
			0
		],
		[
			18,
			72
		],
		[
			48,
			-10
		],
		[
			174,
			73
		],
		[
			24,
			-31
		]
	],
	[
		[
			40999,
			10347
		],
		[
			42,
			-83
		]
	],
	[
		[
			41041,
			10264
		],
		[
			30,
			-62
		],
		[
			97,
			10
		],
		[
			36,
			-104
		],
		[
			36,
			-51
		],
		[
			78,
			-11
		]
	],
	[
		[
			41318,
			10046
		],
		[
			0,
			-10
		]
	],
	[
		[
			41318,
			10036
		],
		[
			18,
			-42
		]
	],
	[
		[
			41336,
			9994
		],
		[
			6,
			0
		]
	],
	[
		[
			41360,
			9974
		],
		[
			0,
			-11
		]
	],
	[
		[
			41360,
			9963
		],
		[
			42,
			-165
		],
		[
			72,
			-52
		],
		[
			103,
			0
		],
		[
			84,
			-52
		],
		[
			114,
			-155
		],
		[
			54,
			-52
		],
		[
			54,
			-83
		],
		[
			120,
			-114
		],
		[
			127,
			-83
		],
		[
			60,
			-62
		],
		[
			-30,
			-52
		],
		[
			48,
			-62
		],
		[
			72,
			-10
		],
		[
			42,
			-62
		],
		[
			-6,
			-42
		],
		[
			-138,
			-186
		],
		[
			-36,
			-83
		],
		[
			-54,
			-10
		],
		[
			-205,
			20
		],
		[
			-72,
			-20
		],
		[
			36,
			-94
		],
		[
			-144,
			-72
		],
		[
			-211,
			-41
		],
		[
			-168,
			-63
		],
		[
			-162,
			-20
		],
		[
			-79,
			41
		],
		[
			-24,
			-197
		],
		[
			-84,
			-93
		],
		[
			-42,
			10
		],
		[
			-18,
			-51
		],
		[
			-54,
			-11
		],
		[
			-66,
			-51
		],
		[
			-42,
			31
		],
		[
			-265,
			93
		],
		[
			-96,
			41
		],
		[
			-246,
			42
		],
		[
			-19,
			-11
		]
	],
	[
		[
			45491,
			13671
		],
		[
			48,
			-52
		],
		[
			48,
			-20
		],
		[
			42,
			-94
		],
		[
			0,
			-62
		],
		[
			48,
			-134
		]
	],
	[
		[
			45677,
			13309
		],
		[
			6,
			-63
		],
		[
			-18,
			-134
		],
		[
			12,
			-73
		],
		[
			-42,
			-103
		],
		[
			18,
			-31
		],
		[
			-60,
			-62
		]
	],
	[
		[
			45593,
			12843
		],
		[
			-138,
			51
		],
		[
			-49,
			62
		],
		[
			-72,
			0
		],
		[
			-66,
			-31
		],
		[
			-18,
			52
		]
	],
	[
		[
			41318,
			10036
		],
		[
			6,
			-11
		]
	],
	[
		[
			41324,
			10025
		],
		[
			24,
			-20
		]
	],
	[
		[
			41348,
			10005
		],
		[
			-12,
			0
		]
	],
	[
		[
			41336,
			10005
		],
		[
			0,
			-11
		]
	],
	[
		[
			41336,
			9994
		],
		[
			12,
			0
		]
	],
	[
		[
			42340,
			12501
		],
		[
			-6,
			-31
		],
		[
			-90,
			-104
		],
		[
			-18,
			-83
		],
		[
			-36,
			-72
		]
	],
	[
		[
			42190,
			12211
		],
		[
			-12,
			-42
		],
		[
			-127,
			-62
		],
		[
			-60,
			-72
		],
		[
			-48,
			-83
		],
		[
			42,
			-62
		],
		[
			-54,
			-52
		],
		[
			-48,
			10
		],
		[
			-108,
			-41
		],
		[
			18,
			-73
		],
		[
			-78,
			-31
		],
		[
			-78,
			73
		],
		[
			-30,
			-93
		],
		[
			36,
			-125
		],
		[
			90,
			11
		],
		[
			24,
			-166
		],
		[
			-6,
			-73
		],
		[
			-30,
			-62
		],
		[
			-138,
			-51
		],
		[
			-91,
			-166
		],
		[
			54,
			-52
		],
		[
			0,
			-41
		],
		[
			49,
			-63
		],
		[
			30,
			21
		],
		[
			72,
			-114
		],
		[
			54,
			0
		],
		[
			108,
			-93
		]
	],
	[
		[
			41372,
			9994
		],
		[
			-6,
			11
		]
	],
	[
		[
			41324,
			10025
		],
		[
			0,
			11
		],
		[
			-6,
			10
		]
	],
	[
		[
			42593,
			9704
		],
		[
			6,
			73
		]
	],
	[
		[
			42599,
			9777
		],
		[
			0,
			21
		]
	],
	[
		[
			42599,
			9798
		],
		[
			-6,
			10
		]
	],
	[
		[
			42587,
			9808
		],
		[
			-6,
			10
		]
	],
	[
		[
			42575,
			9818
		],
		[
			0,
			11
		]
	],
	[
		[
			42575,
			9839
		],
		[
			0,
			10
		]
	],
	[
		[
			42575,
			9849
		],
		[
			6,
			11
		]
	],
	[
		[
			42581,
			9860
		],
		[
			0,
			20
		]
	],
	[
		[
			49832,
			17079
		],
		[
			-97,
			20
		],
		[
			-162,
			0
		],
		[
			-60,
			11
		],
		[
			-96,
			62
		],
		[
			-126,
			10
		]
	],
	[
		[
			49291,
			17182
		],
		[
			-18,
			218
		],
		[
			-37,
			51
		],
		[
			73,
			94
		],
		[
			18,
			62
		]
	],
	[
		[
			49327,
			17607
		],
		[
			102,
			-21
		],
		[
			132,
			0
		],
		[
			36,
			73
		],
		[
			24,
			248
		],
		[
			54,
			42
		],
		[
			103,
			10
		],
		[
			6,
			52
		],
		[
			114,
			0
		],
		[
			30,
			-83
		],
		[
			54,
			-62
		]
	],
	[
		[
			47559,
			18591
		],
		[
			-66,
			-52
		],
		[
			-12,
			-124
		],
		[
			24,
			-31
		],
		[
			-72,
			-73
		],
		[
			-6,
			-41
		],
		[
			96,
			-63
		],
		[
			-12,
			-82
		],
		[
			-78,
			10
		],
		[
			-78,
			-52
		],
		[
			54,
			-93
		],
		[
			6,
			-83
		],
		[
			42,
			-21
		],
		[
			12,
			-165
		],
		[
			-6,
			-73
		]
	],
	[
		[
			47463,
			17648
		],
		[
			-72,
			-41
		],
		[
			-91,
			-104
		],
		[
			43,
			-124
		],
		[
			12,
			-104
		],
		[
			-49,
			-31
		],
		[
			-102,
			-20
		],
		[
			-54,
			31
		],
		[
			-78,
			-11
		],
		[
			-78,
			21
		],
		[
			-72,
			62
		],
		[
			-18,
			-21
		],
		[
			-36,
			-155
		],
		[
			6,
			-52
		]
	],
	[
		[
			48425,
			17545
		],
		[
			84,
			-135
		],
		[
			0,
			-52
		],
		[
			126,
			31
		],
		[
			48,
			-31
		],
		[
			66,
			0
		],
		[
			49,
			-31
		],
		[
			162,
			-62
		],
		[
			-6,
			-114
		]
	],
	[
		[
			48954,
			17151
		],
		[
			0,
			-52
		],
		[
			-66,
			-93
		],
		[
			-6,
			0
		],
		[
			-36,
			-41
		]
	],
	[
		[
			48846,
			16965
		],
		[
			-133,
			0
		],
		[
			-120,
			-104
		],
		[
			-18,
			21
		],
		[
			-120,
			-42
		],
		[
			-6,
			-62
		],
		[
			-42,
			-62
		],
		[
			-30,
			31
		],
		[
			-60,
			-62
		],
		[
			-121,
			-31
		],
		[
			-54,
			10
		]
	],
	[
		[
			48142,
			16664
		],
		[
			-72,
			42
		],
		[
			-186,
			-135
		],
		[
			-79,
			-31
		]
	],
	[
		[
			47805,
			16540
		],
		[
			-84,
			135
		]
	],
	[
		[
			47721,
			16675
		],
		[
			12,
			41
		],
		[
			-66,
			145
		],
		[
			0,
			62
		],
		[
			102,
			135
		],
		[
			-36,
			134
		]
	],
	[
		[
			47733,
			17192
		],
		[
			30,
			-41
		],
		[
			85,
			31
		]
	],
	[
		[
			47848,
			17182
		],
		[
			0,
			62
		],
		[
			120,
			0
		],
		[
			48,
			42
		],
		[
			24,
			-83
		],
		[
			72,
			41
		],
		[
			54,
			-10
		],
		[
			-12,
			103
		],
		[
			108,
			63
		],
		[
			36,
			62
		],
		[
			-72,
			62
		],
		[
			30,
			52
		],
		[
			109,
			51
		],
		[
			60,
			-82
		]
	],
	[
		[
			50295,
			19937
		],
		[
			-12,
			-41
		],
		[
			-127,
			72
		],
		[
			-36,
			-10
		],
		[
			-90,
			20
		],
		[
			0,
			-41
		],
		[
			-132,
			0
		],
		[
			-18,
			93
		],
		[
			-120,
			31
		],
		[
			-12,
			-93
		],
		[
			-109,
			-83
		],
		[
			36,
			-62
		],
		[
			-18,
			-41
		],
		[
			-96,
			-94
		],
		[
			-42,
			-10
		],
		[
			-30,
			145
		],
		[
			-36,
			-21
		],
		[
			-90,
			-124
		],
		[
			-84,
			-21
		],
		[
			0,
			-93
		],
		[
			-73,
			-21
		],
		[
			6,
			-134
		],
		[
			-150,
			62
		],
		[
			-60,
			-41
		],
		[
			0,
			-63
		],
		[
			-42,
			-31
		]
	],
	[
		[
			48960,
			19336
		],
		[
			-12,
			62
		],
		[
			-114,
			52
		],
		[
			-48,
			-41
		],
		[
			-139,
			31
		],
		[
			-48,
			-21
		],
		[
			0,
			-62
		],
		[
			-42,
			-176
		],
		[
			42,
			-73
		],
		[
			72,
			-20
		],
		[
			48,
			-125
		],
		[
			73,
			21
		],
		[
			36,
			-41
		],
		[
			66,
			-31
		]
	],
	[
		[
			48894,
			18912
		],
		[
			36,
			-62
		],
		[
			12,
			-73
		],
		[
			-42,
			-41
		]
	],
	[
		[
			48900,
			18736
		],
		[
			-72,
			41
		],
		[
			-24,
			-31
		],
		[
			-43,
			21
		],
		[
			-42,
			-42
		],
		[
			42,
			-62
		],
		[
			-12,
			-41
		],
		[
			-78,
			72
		],
		[
			-90,
			-145
		],
		[
			-54,
			0
		],
		[
			-60,
			93
		],
		[
			-144,
			-51
		],
		[
			-6,
			-52
		]
	],
	[
		[
			48317,
			18539
		],
		[
			-193,
			0
		],
		[
			-72,
			10
		],
		[
			-18,
			83
		],
		[
			-96,
			42
		]
	],
	[
		[
			47733,
			17192
		],
		[
			-156,
			94
		],
		[
			-78,
			-145
		],
		[
			-66,
			-11
		],
		[
			-18,
			-83
		],
		[
			-48,
			-124
		],
		[
			12,
			-41
		],
		[
			72,
			-42
		],
		[
			-36,
			-62
		],
		[
			6,
			-72
		],
		[
			96,
			0
		],
		[
			54,
			31
		],
		[
			54,
			-62
		],
		[
			18,
			20
		],
		[
			78,
			-20
		]
	],
	[
		[
			47805,
			16540
		],
		[
			-90,
			-52
		],
		[
			-150,
			-41
		]
	],
	[
		[
			47565,
			16447
		],
		[
			-72,
			31
		],
		[
			-54,
			0
		],
		[
			-115,
			31
		],
		[
			-12,
			-42
		],
		[
			-54,
			-31
		],
		[
			-66,
			42
		],
		[
			-108,
			93
		],
		[
			-24,
			41
		],
		[
			-42,
			0
		],
		[
			0,
			-186
		],
		[
			18,
			-83
		],
		[
			-30,
			-21
		]
	],
	[
		[
			47463,
			17648
		],
		[
			36,
			-83
		],
		[
			24,
			0
		],
		[
			30,
			-176
		],
		[
			72,
			-41
		],
		[
			78,
			-21
		],
		[
			30,
			-135
		]
	],
	[
		[
			55520,
			13205
		],
		[
			30,
			-62
		],
		[
			102,
			-104
		],
		[
			-36,
			-51
		],
		[
			-24,
			-94
		],
		[
			30,
			-51
		],
		[
			84,
			-208
		],
		[
			-18,
			-103
		],
		[
			-72,
			-93
		],
		[
			78,
			-73
		]
	],
	[
		[
			55694,
			12366
		],
		[
			-30,
			-145
		],
		[
			108,
			-31
		],
		[
			-42,
			-72
		],
		[
			-6,
			-73
		],
		[
			42,
			-31
		],
		[
			24,
			-72
		],
		[
			48,
			-21
		],
		[
			-66,
			-124
		],
		[
			-48,
			-32
		],
		[
			-48,
			52
		],
		[
			-96,
			-72
		]
	],
	[
		[
			55580,
			11745
		],
		[
			-30,
			-73
		],
		[
			36,
			-62
		],
		[
			-54,
			-197
		],
		[
			-49,
			-20
		],
		[
			12,
			-125
		],
		[
			-90,
			-62
		],
		[
			-54,
			-21
		],
		[
			-60,
			63
		],
		[
			-66,
			-83
		],
		[
			-90,
			-11
		],
		[
			-96,
			-93
		],
		[
			-43,
			11
		],
		[
			-30,
			82
		],
		[
			-42,
			11
		],
		[
			-6,
			-83
		],
		[
			-78,
			10
		],
		[
			0,
			-83
		],
		[
			-90,
			-41
		],
		[
			0,
			72
		],
		[
			-54,
			21
		],
		[
			0,
			73
		],
		[
			-259,
			-487
		],
		[
			-42,
			-73
		]
	],
	[
		[
			53391,
			10782
		],
		[
			6,
			72
		],
		[
			-48,
			10
		],
		[
			0,
			94
		],
		[
			-30,
			93
		],
		[
			42,
			52
		],
		[
			60,
			145
		],
		[
			48,
			41
		],
		[
			48,
			10
		],
		[
			42,
			42
		],
		[
			49,
			114
		],
		[
			-79,
			62
		],
		[
			-186,
			10
		],
		[
			-6,
			166
		],
		[
			-18,
			31
		],
		[
			96,
			62
		],
		[
			-12,
			135
		],
		[
			30,
			0
		]
	],
	[
		[
			53433,
			11921
		],
		[
			6,
			-11
		]
	],
	[
		[
			53439,
			11910
		],
		[
			48,
			11
		],
		[
			103,
			83
		]
	],
	[
		[
			53590,
			12004
		],
		[
			60,
			62
		],
		[
			-12,
			41
		],
		[
			60,
			52
		],
		[
			6,
			52
		],
		[
			42,
			62
		],
		[
			66,
			21
		],
		[
			6,
			62
		],
		[
			36,
			0
		],
		[
			-6,
			114
		],
		[
			72,
			31
		],
		[
			36,
			62
		],
		[
			42,
			31
		],
		[
			36,
			62
		],
		[
			43,
			10
		],
		[
			60,
			-31
		],
		[
			54,
			0
		],
		[
			6,
			63
		],
		[
			60,
			31
		],
		[
			36,
			51
		],
		[
			48,
			21
		],
		[
			48,
			52
		],
		[
			24,
			72
		],
		[
			60,
			-10
		]
	],
	[
		[
			54473,
			12915
		],
		[
			18,
			-93
		],
		[
			97,
			0
		],
		[
			60,
			-42
		],
		[
			18,
			42
		],
		[
			54,
			31
		],
		[
			36,
			52
		],
		[
			78,
			-62
		],
		[
			30,
			0
		],
		[
			18,
			82
		],
		[
			102,
			21
		],
		[
			61,
			52
		],
		[
			66,
			-21
		],
		[
			42,
			52
		],
		[
			54,
			10
		],
		[
			24,
			73
		],
		[
			84,
			-52
		],
		[
			66,
			21
		],
		[
			6,
			62
		],
		[
			42,
			52
		],
		[
			91,
			10
		]
	],
	[
		[
			56379,
			13464
		],
		[
			18,
			-10
		]
	],
	[
		[
			56397,
			13454
		],
		[
			-12,
			0
		]
	],
	[
		[
			56385,
			13454
		],
		[
			-6,
			0
		]
	],
	[
		[
			56379,
			13454
		],
		[
			0,
			10
		]
	],
	[
		[
			57011,
			13764
		],
		[
			6,
			0
		]
	],
	[
		[
			57017,
			13764
		],
		[
			-6,
			0
		]
	],
	[
		[
			57113,
			13775
		],
		[
			-6,
			-11
		]
	],
	[
		[
			57107,
			13764
		],
		[
			-18,
			0
		]
	],
	[
		[
			57089,
			13764
		],
		[
			-66,
			31
		]
	],
	[
		[
			57023,
			13795
		],
		[
			-18,
			0
		]
	],
	[
		[
			57005,
			13795
		],
		[
			6,
			-10
		]
	],
	[
		[
			57011,
			13785
		],
		[
			0,
			-21
		]
	],
	[
		[
			57011,
			13764
		],
		[
			-6,
			0
		]
	],
	[
		[
			57005,
			13764
		],
		[
			-6,
			-20
		]
	],
	[
		[
			56999,
			13744
		],
		[
			-30,
			-11
		]
	],
	[
		[
			56969,
			13733
		],
		[
			-25,
			-10
		]
	],
	[
		[
			56944,
			13723
		],
		[
			0,
			-10
		]
	],
	[
		[
			56944,
			13713
		],
		[
			-114,
			0
		],
		[
			-72,
			-83
		],
		[
			-96,
			-21
		],
		[
			-42,
			-83
		],
		[
			-78,
			-31
		],
		[
			-54,
			0
		],
		[
			-91,
			-41
		]
	],
	[
		[
			56379,
			13464
		],
		[
			0,
			-10
		]
	],
	[
		[
			56385,
			13454
		],
		[
			109,
			41
		],
		[
			54,
			0
		],
		[
			72,
			31
		],
		[
			12,
			42
		],
		[
			102,
			72
		],
		[
			30,
			-10
		],
		[
			78,
			83
		],
		[
			102,
			0
		]
	],
	[
		[
			56944,
			13713
		],
		[
			49,
			-63
		],
		[
			-43,
			-31
		],
		[
			-96,
			-114
		],
		[
			0,
			-62
		],
		[
			-30,
			-31
		],
		[
			72,
			-83
		],
		[
			-102,
			-124
		],
		[
			0,
			-62
		],
		[
			102,
			-93
		],
		[
			-84,
			-145
		],
		[
			-48,
			-135
		],
		[
			114,
			-93
		],
		[
			60,
			-31
		],
		[
			0,
			-52
		],
		[
			-156,
			-197
		],
		[
			-48,
			62
		],
		[
			-78,
			-51
		],
		[
			-72,
			62
		],
		[
			-48,
			-52
		],
		[
			-12,
			-83
		]
	],
	[
		[
			56524,
			12335
		],
		[
			-55,
			62
		],
		[
			-126,
			42
		],
		[
			-42,
			-11
		],
		[
			-138,
			31
		],
		[
			-84,
			94
		],
		[
			-72,
			51
		],
		[
			-19,
			-155
		],
		[
			-84,
			-62
		],
		[
			-108,
			-31
		],
		[
			-42,
			21
		],
		[
			-60,
			-11
		]
	],
	[
		[
			55520,
			13205
		],
		[
			48,
			83
		],
		[
			138,
			52
		],
		[
			-12,
			41
		],
		[
			42,
			145
		],
		[
			-24,
			62
		],
		[
			42,
			21
		],
		[
			-12,
			62
		],
		[
			-66,
			0
		],
		[
			-156,
			155
		],
		[
			-91,
			32
		],
		[
			-42,
			72
		]
	],
	[
		[
			55387,
			13930
		],
		[
			48,
			-10
		],
		[
			121,
			20
		],
		[
			102,
			0
		],
		[
			90,
			52
		],
		[
			72,
			104
		],
		[
			42,
			20
		],
		[
			84,
			-10
		],
		[
			91,
			10
		],
		[
			36,
			32
		],
		[
			126,
			-11
		],
		[
			42,
			42
		],
		[
			222,
			0
		],
		[
			187,
			20
		],
		[
			174,
			52
		],
		[
			145,
			-10
		]
	],
	[
		[
			56969,
			14241
		],
		[
			6,
			-93
		],
		[
			-79,
			-32
		],
		[
			12,
			-82
		],
		[
			67,
			-73
		],
		[
			36,
			-93
		],
		[
			102,
			-93
		]
	],
	[
		[
			51720,
			15049
		],
		[
			-30,
			-114
		],
		[
			54,
			-11
		],
		[
			12,
			-51
		]
	],
	[
		[
			51756,
			14873
		],
		[
			30,
			-32
		],
		[
			-12,
			-124
		],
		[
			48,
			-41
		],
		[
			-12,
			-104
		],
		[
			24,
			-145
		],
		[
			48,
			-31
		],
		[
			-42,
			-83
		]
	],
	[
		[
			51840,
			14313
		],
		[
			-301,
			125
		],
		[
			-36,
			62
		],
		[
			-186,
			10
		],
		[
			-36,
			-104
		],
		[
			-115,
			-10
		],
		[
			-72,
			10
		],
		[
			-6,
			125
		],
		[
			-36,
			72
		],
		[
			-126,
			-20
		],
		[
			-102,
			-63
		],
		[
			-42,
			0
		]
	],
	[
		[
			50782,
			14520
		],
		[
			-24,
			31
		],
		[
			42,
			177
		],
		[
			48,
			-21
		]
	],
	[
		[
			50848,
			14707
		],
		[
			36,
			124
		],
		[
			78,
			31
		],
		[
			66,
			62
		]
	],
	[
		[
			51028,
			14924
		],
		[
			42,
			62
		]
	],
	[
		[
			51070,
			14986
		],
		[
			42,
			42
		]
	],
	[
		[
			51112,
			15028
		],
		[
			0,
			31
		]
	],
	[
		[
			51112,
			15059
		],
		[
			-6,
			52
		]
	],
	[
		[
			51106,
			15111
		],
		[
			18,
			41
		]
	],
	[
		[
			51124,
			15152
		],
		[
			24,
			11
		]
	],
	[
		[
			51148,
			15163
		],
		[
			24,
			20
		],
		[
			49,
			-31
		],
		[
			60,
			-72
		],
		[
			126,
			-73
		],
		[
			78,
			-62
		],
		[
			60,
			0
		],
		[
			84,
			41
		],
		[
			61,
			83
		],
		[
			30,
			-20
		]
	],
	[
		[
			57720,
			13485
		],
		[
			6,
			-21
		]
	],
	[
		[
			57726,
			13464
		],
		[
			-24,
			10
		]
	],
	[
		[
			57702,
			13474
		],
		[
			-12,
			-10
		]
	],
	[
		[
			57690,
			13464
		],
		[
			-6,
			0
		]
	],
	[
		[
			57684,
			13464
		],
		[
			12,
			-62
		]
	],
	[
		[
			57696,
			13402
		],
		[
			24,
			-11
		]
	],
	[
		[
			57720,
			13391
		],
		[
			-6,
			-10
		]
	],
	[
		[
			57714,
			13381
		],
		[
			-12,
			10
		]
	],
	[
		[
			57702,
			13391
		],
		[
			-12,
			-10
		]
	],
	[
		[
			57690,
			13381
		],
		[
			18,
			-31
		]
	],
	[
		[
			57708,
			13350
		],
		[
			-12,
			-31
		]
	],
	[
		[
			57696,
			13319
		],
		[
			6,
			-10
		]
	],
	[
		[
			57702,
			13309
		],
		[
			24,
			-11
		]
	],
	[
		[
			57726,
			13298
		],
		[
			6,
			-10
		]
	],
	[
		[
			57732,
			13288
		],
		[
			-18,
			0
		]
	],
	[
		[
			57714,
			13288
		],
		[
			-12,
			-10
		]
	],
	[
		[
			57702,
			13278
		],
		[
			-36,
			-11
		]
	],
	[
		[
			57666,
			13267
		],
		[
			-18,
			0
		]
	],
	[
		[
			57648,
			13267
		],
		[
			-18,
			21
		]
	],
	[
		[
			57630,
			13288
		],
		[
			6,
			21
		]
	],
	[
		[
			57636,
			13309
		],
		[
			-24,
			20
		]
	],
	[
		[
			57612,
			13329
		],
		[
			-12,
			-10
		]
	],
	[
		[
			57600,
			13319
		],
		[
			-12,
			0
		]
	],
	[
		[
			57588,
			13319
		],
		[
			0,
			31
		]
	],
	[
		[
			57588,
			13350
		],
		[
			-18,
			21
		]
	],
	[
		[
			57570,
			13371
		],
		[
			6,
			20
		]
	],
	[
		[
			57576,
			13391
		],
		[
			30,
			42
		]
	],
	[
		[
			57606,
			13433
		],
		[
			18,
			-10
		]
	],
	[
		[
			57624,
			13423
		],
		[
			42,
			93
		]
	],
	[
		[
			57666,
			13516
		],
		[
			54,
			-31
		]
	],
	[
		[
			57666,
			13568
		],
		[
			36,
			51
		],
		[
			36,
			-10
		]
	],
	[
		[
			57738,
			13609
		],
		[
			-54,
			-93
		],
		[
			-18,
			52
		]
	],
	[
		[
			57023,
			13795
		],
		[
			66,
			-31
		]
	],
	[
		[
			57107,
			13764
		],
		[
			12,
			11
		]
	],
	[
		[
			57119,
			13775
		],
		[
			12,
			-31
		]
	],
	[
		[
			57131,
			13744
		],
		[
			30,
			-31
		],
		[
			60,
			-11
		]
	],
	[
		[
			57221,
			13702
		],
		[
			12,
			0
		]
	],
	[
		[
			57233,
			13702
		],
		[
			18,
			-10
		]
	],
	[
		[
			57251,
			13692
		],
		[
			18,
			-11
		]
	],
	[
		[
			57269,
			13681
		],
		[
			108,
			11
		],
		[
			24,
			-21
		]
	],
	[
		[
			57401,
			13671
		],
		[
			67,
			-21
		],
		[
			84,
			0
		],
		[
			36,
			-31
		]
	],
	[
		[
			57588,
			13619
		],
		[
			18,
			11
		]
	],
	[
		[
			57606,
			13630
		],
		[
			48,
			-31
		]
	],
	[
		[
			57654,
			13599
		],
		[
			12,
			-83
		]
	],
	[
		[
			57624,
			13423
		],
		[
			-18,
			10
		]
	],
	[
		[
			57606,
			13433
		],
		[
			-30,
			-42
		]
	],
	[
		[
			57576,
			13391
		],
		[
			-6,
			-20
		]
	],
	[
		[
			57570,
			13371
		],
		[
			18,
			-21
		]
	],
	[
		[
			57588,
			13319
		],
		[
			12,
			0
		]
	],
	[
		[
			57612,
			13329
		],
		[
			24,
			-20
		]
	],
	[
		[
			57636,
			13309
		],
		[
			-6,
			-21
		]
	],
	[
		[
			57630,
			13288
		],
		[
			18,
			-21
		]
	],
	[
		[
			57666,
			13267
		],
		[
			36,
			11
		]
	],
	[
		[
			57702,
			13278
		],
		[
			12,
			10
		]
	],
	[
		[
			57732,
			13288
		],
		[
			-6,
			10
		]
	],
	[
		[
			57726,
			13298
		],
		[
			-24,
			11
		]
	],
	[
		[
			57696,
			13319
		],
		[
			12,
			31
		]
	],
	[
		[
			57708,
			13350
		],
		[
			-18,
			31
		]
	],
	[
		[
			57690,
			13381
		],
		[
			12,
			10
		]
	],
	[
		[
			57702,
			13391
		],
		[
			12,
			-10
		]
	],
	[
		[
			57720,
			13391
		],
		[
			-24,
			11
		]
	],
	[
		[
			57696,
			13402
		],
		[
			-12,
			62
		]
	],
	[
		[
			57690,
			13464
		],
		[
			12,
			10
		]
	],
	[
		[
			57702,
			13474
		],
		[
			24,
			-10
		]
	],
	[
		[
			57720,
			13485
		],
		[
			-30,
			20
		],
		[
			36,
			83
		],
		[
			60,
			31
		]
	],
	[
		[
			57786,
			13619
		],
		[
			6,
			0
		]
	],
	[
		[
			57792,
			13619
		],
		[
			30,
			-31
		],
		[
			30,
			-207
		],
		[
			97,
			-290
		],
		[
			48,
			-176
		],
		[
			12,
			-83
		],
		[
			-6,
			-155
		],
		[
			12,
			-228
		],
		[
			-18,
			-207
		],
		[
			-54,
			-114
		],
		[
			-97,
			-135
		],
		[
			-66,
			-41
		],
		[
			-126,
			-42
		],
		[
			-84,
			-82
		],
		[
			-12,
			31
		],
		[
			-78,
			-62
		],
		[
			0,
			-52
		],
		[
			-97,
			-21
		],
		[
			-84,
			-62
		],
		[
			-84,
			-31
		],
		[
			-36,
			10
		],
		[
			-72,
			-21
		],
		[
			-72,
			0
		],
		[
			-85,
			-20
		]
	],
	[
		[
			56950,
			11600
		],
		[
			-42,
			20
		],
		[
			-48,
			-31
		],
		[
			-60,
			52
		],
		[
			0,
			124
		],
		[
			-54,
			52
		],
		[
			-30,
			-20
		],
		[
			-42,
			72
		]
	],
	[
		[
			56674,
			11869
		],
		[
			30,
			73
		],
		[
			42,
			-11
		],
		[
			72,
			104
		],
		[
			72,
			62
		],
		[
			-18,
			52
		],
		[
			-102,
			-31
		],
		[
			-78,
			82
		],
		[
			-36,
			11
		],
		[
			-48,
			-52
		],
		[
			-108,
			73
		],
		[
			24,
			103
		]
	],
	[
		[
			56944,
			13723
		],
		[
			25,
			10
		]
	],
	[
		[
			56999,
			13744
		],
		[
			6,
			20
		]
	],
	[
		[
			57017,
			13764
		],
		[
			-6,
			21
		]
	],
	[
		[
			57005,
			13795
		],
		[
			18,
			0
		]
	],
	[
		[
			52213,
			13992
		],
		[
			-54,
			-52
		],
		[
			-13,
			-82
		],
		[
			-30,
			0
		],
		[
			-18,
			-73
		],
		[
			-84,
			-21
		],
		[
			-48,
			11
		],
		[
			-96,
			-42
		],
		[
			0,
			42
		]
	],
	[
		[
			51870,
			13775
		],
		[
			0,
			238
		],
		[
			-36,
			52
		],
		[
			0,
			83
		],
		[
			-24,
			20
		],
		[
			30,
			145
		]
	],
	[
		[
			51720,
			15049
		],
		[
			30,
			-73
		],
		[
			48,
			-62
		],
		[
			54,
			-31
		],
		[
			361,
			-42
		],
		[
			78,
			11
		],
		[
			84,
			31
		],
		[
			66,
			0
		],
		[
			42,
			52
		],
		[
			66,
			20
		]
	],
	[
		[
			53373,
			13806
		],
		[
			30,
			-21
		],
		[
			36,
			41
		],
		[
			60,
			-31
		],
		[
			91,
			52
		],
		[
			144,
			-83
		],
		[
			-30,
			-41
		],
		[
			96,
			-187
		],
		[
			-24,
			-41
		],
		[
			12,
			-62
		],
		[
			42,
			-21
		],
		[
			66,
			62
		],
		[
			120,
			11
		],
		[
			48,
			-83
		],
		[
			67,
			-42
		],
		[
			60,
			-62
		],
		[
			78,
			-10
		],
		[
			24,
			-31
		],
		[
			-60,
			-135
		],
		[
			66,
			-41
		],
		[
			42,
			62
		],
		[
			78,
			21
		],
		[
			60,
			-73
		],
		[
			-24,
			-83
		],
		[
			30,
			-31
		],
		[
			-12,
			-62
		]
	],
	[
		[
			53590,
			12004
		],
		[
			6,
			103
		],
		[
			-85,
			0
		],
		[
			-48,
			-31
		]
	],
	[
		[
			53463,
			12076
		],
		[
			-12,
			11
		]
	],
	[
		[
			53451,
			12087
		],
		[
			-66,
			10
		],
		[
			-30,
			62
		],
		[
			-30,
			-41
		],
		[
			-108,
			20
		],
		[
			18,
			-114
		],
		[
			-54,
			-72
		],
		[
			-36,
			72
		],
		[
			-36,
			-51
		],
		[
			-79,
			-31
		],
		[
			-78,
			-11
		],
		[
			-24,
			21
		],
		[
			-90,
			10
		],
		[
			-36,
			42
		],
		[
			-66,
			31
		],
		[
			-84,
			-31
		],
		[
			-43,
			41
		]
	],
	[
		[
			52609,
			12045
		],
		[
			0,
			73
		],
		[
			-54,
			82
		],
		[
			-114,
			135
		],
		[
			-54,
			31
		],
		[
			-84,
			0
		],
		[
			-72,
			104
		],
		[
			-103,
			31
		],
		[
			-12,
			41
		]
	],
	[
		[
			52116,
			12542
		],
		[
			24,
			31
		],
		[
			73,
			-31
		],
		[
			18,
			114
		],
		[
			30,
			104
		],
		[
			-60,
			10
		],
		[
			-121,
			104
		],
		[
			97,
			72
		],
		[
			72,
			104
		],
		[
			78,
			-31
		],
		[
			54,
			0
		]
	],
	[
		[
			52381,
			13019
		],
		[
			18,
			82
		],
		[
			-6,
			114
		],
		[
			228,
			11
		],
		[
			49,
			62
		],
		[
			108,
			176
		]
	],
	[
		[
			52778,
			13464
		],
		[
			-36,
			41
		]
	],
	[
		[
			52742,
			13505
		],
		[
			30,
			52
		],
		[
			84,
			11
		],
		[
			12,
			62
		],
		[
			72,
			103
		],
		[
			-30,
			42
		],
		[
			24,
			51
		]
	],
	[
		[
			51870,
			13775
		],
		[
			-24,
			0
		],
		[
			-168,
			124
		],
		[
			-19,
			72
		],
		[
			-48,
			11
		],
		[
			-66,
			-104
		],
		[
			18,
			-41
		],
		[
			-24,
			-104
		],
		[
			-42,
			-62
		],
		[
			-66,
			-41
		],
		[
			-12,
			-62
		],
		[
			6,
			-104
		],
		[
			-54,
			-186
		],
		[
			60,
			-83
		],
		[
			-6,
			-104
		],
		[
			-18,
			-21
		],
		[
			-78,
			0
		],
		[
			18,
			-72
		],
		[
			-24,
			-93
		],
		[
			-30,
			0
		],
		[
			-60,
			-52
		],
		[
			-49,
			124
		],
		[
			-84,
			-83
		],
		[
			-42,
			-20
		],
		[
			18,
			-63
		],
		[
			-12,
			-93
		],
		[
			54,
			-83
		],
		[
			48,
			-31
		],
		[
			37,
			21
		],
		[
			18,
			-52
		],
		[
			42,
			0
		],
		[
			54,
			-93
		],
		[
			-96,
			0
		],
		[
			-12,
			-72
		]
	],
	[
		[
			51209,
			12408
		],
		[
			-139,
			-125
		],
		[
			-30,
			42
		],
		[
			-42,
			-73
		],
		[
			48,
			-62
		],
		[
			96,
			-72
		],
		[
			-54,
			-21
		],
		[
			-72,
			-114
		],
		[
			-78,
			-73
		],
		[
			-90,
			11
		],
		[
			-24,
			41
		]
	],
	[
		[
			50186,
			12014
		],
		[
			12,
			135
		],
		[
			-18,
			20
		],
		[
			-18,
			125
		],
		[
			36,
			83
		],
		[
			-78,
			165
		],
		[
			-30,
			145
		],
		[
			48,
			21
		],
		[
			6,
			124
		],
		[
			60,
			62
		],
		[
			31,
			114
		],
		[
			-73,
			270
		],
		[
			12,
			82
		],
		[
			-30,
			63
		]
	],
	[
		[
			50144,
			13423
		],
		[
			48,
			20
		],
		[
			43,
			-52
		],
		[
			156,
			42
		],
		[
			24,
			31
		],
		[
			-36,
			83
		],
		[
			24,
			124
		],
		[
			132,
			73
		],
		[
			60,
			51
		],
		[
			-24,
			94
		],
		[
			48,
			41
		],
		[
			72,
			-21
		],
		[
			6,
			31
		]
	],
	[
		[
			50697,
			13940
		],
		[
			25,
			31
		],
		[
			12,
			114
		],
		[
			24,
			31
		],
		[
			18,
			94
		],
		[
			-24,
			165
		],
		[
			66,
			21
		],
		[
			-36,
			104
		],
		[
			-24,
			20
		]
	],
	[
		[
			50758,
			14520
		],
		[
			24,
			0
		]
	],
	[
		[
			56950,
			11600
		],
		[
			-90,
			-52
		],
		[
			-36,
			-93
		],
		[
			-54,
			-52
		],
		[
			-120,
			-41
		],
		[
			-120,
			0
		],
		[
			-313,
			-52
		],
		[
			-108,
			-42
		],
		[
			-139,
			-72
		],
		[
			-258,
			-228
		],
		[
			-84,
			-104
		],
		[
			-90,
			-165
		],
		[
			-18,
			-62
		],
		[
			-55,
			-270
		],
		[
			12,
			-155
		],
		[
			85,
			-311
		],
		[
			-12,
			-52
		],
		[
			-43,
			-20
		],
		[
			-96,
			0
		],
		[
			-324,
			62
		],
		[
			-253,
			62
		]
	],
	[
		[
			53842,
			14562
		],
		[
			42,
			-21
		],
		[
			0,
			-135
		],
		[
			-96,
			42
		],
		[
			-24,
			83
		],
		[
			72,
			-11
		],
		[
			6,
			42
		]
	],
	[
		[
			53782,
			14665
		],
		[
			48,
			-41
		],
		[
			-60,
			-52
		],
		[
			12,
			93
		]
	],
	[
		[
			53517,
			14199
		],
		[
			48,
			73
		],
		[
			73,
			145
		],
		[
			156,
			-207
		],
		[
			42,
			51
		],
		[
			30,
			104
		],
		[
			66,
			21
		],
		[
			-18,
			-135
		],
		[
			108,
			42
		],
		[
			-12,
			62
		],
		[
			-60,
			41
		],
		[
			-36,
			114
		],
		[
			18,
			21
		],
		[
			-12,
			93
		],
		[
			66,
			0
		],
		[
			115,
			31
		],
		[
			-61,
			-83
		],
		[
			49,
			-134
		],
		[
			60,
			-52
		],
		[
			54,
			-11
		],
		[
			24,
			-41
		],
		[
			78,
			-41
		],
		[
			-24,
			-135
		],
		[
			36,
			-73
		],
		[
			96,
			-20
		],
		[
			139,
			0
		],
		[
			96,
			-52
		],
		[
			84,
			-10
		],
		[
			168,
			20
		],
		[
			72,
			-31
		],
		[
			103,
			-83
		],
		[
			234,
			31
		],
		[
			78,
			-10
		]
	],
	[
		[
			54816,
			14106
		],
		[
			-84,
			-10
		],
		[
			-84,
			41
		],
		[
			-78,
			21
		],
		[
			-73,
			-21
		],
		[
			-36,
			52
		],
		[
			-72,
			-52
		],
		[
			-72,
			21
		],
		[
			24,
			103
		],
		[
			-36,
			63
		],
		[
			-36,
			0
		],
		[
			-30,
			51
		],
		[
			-120,
			73
		],
		[
			6,
			72
		],
		[
			60,
			52
		],
		[
			-36,
			62
		],
		[
			0,
			83
		],
		[
			48,
			104
		],
		[
			-6,
			62
		],
		[
			150,
			-62
		],
		[
			126,
			-11
		],
		[
			145,
			-114
		],
		[
			54,
			-20
		],
		[
			252,
			-42
		],
		[
			48,
			11
		],
		[
			109,
			-31
		],
		[
			48,
			-42
		],
		[
			36,
			-72
		],
		[
			156,
			-156
		],
		[
			72,
			-155
		],
		[
			-30,
			-52
		],
		[
			-48,
			21
		],
		[
			-120,
			-114
		],
		[
			-42,
			-21
		],
		[
			-114,
			-10
		],
		[
			-79,
			52
		],
		[
			-24,
			41
		],
		[
			-114,
			0
		]
	],
	[
		[
			57786,
			13619
		],
		[
			6,
			0
		]
	],
	[
		[
			57666,
			13568
		],
		[
			-12,
			31
		]
	],
	[
		[
			57654,
			13599
		],
		[
			-48,
			31
		]
	],
	[
		[
			57588,
			13619
		],
		[
			-36,
			42
		],
		[
			-151,
			10
		]
	],
	[
		[
			57401,
			13671
		],
		[
			-54,
			31
		],
		[
			-78,
			-21
		]
	],
	[
		[
			57251,
			13692
		],
		[
			-18,
			10
		]
	],
	[
		[
			57221,
			13702
		],
		[
			-90,
			42
		]
	],
	[
		[
			57119,
			13775
		],
		[
			-6,
			0
		]
	],
	[
		[
			56969,
			14241
		],
		[
			156,
			-21
		],
		[
			162,
			10
		],
		[
			42,
			42
		],
		[
			96,
			-11
		],
		[
			157,
			11
		],
		[
			24,
			41
		],
		[
			36,
			-20
		],
		[
			54,
			20
		],
		[
			90,
			-10
		],
		[
			72,
			21
		],
		[
			18,
			31
		],
		[
			61,
			10
		],
		[
			156,
			-10
		],
		[
			42,
			20
		],
		[
			90,
			-62
		],
		[
			42,
			-83
		],
		[
			-6,
			-82
		],
		[
			-42,
			-197
		],
		[
			-48,
			-93
		],
		[
			-84,
			-94
		],
		[
			-78,
			-20
		],
		[
			-72,
			0
		],
		[
			-73,
			31
		],
		[
			-72,
			-42
		],
		[
			-54,
			-124
		]
	],
	[
		[
			52519,
			13878
		],
		[
			18,
			-52
		]
	],
	[
		[
			52537,
			13826
		],
		[
			12,
			-51
		]
	],
	[
		[
			52549,
			13775
		],
		[
			6,
			-31
		]
	],
	[
		[
			52555,
			13744
		],
		[
			-24,
			-73
		],
		[
			42,
			-145
		],
		[
			18,
			0
		]
	],
	[
		[
			52591,
			13526
		],
		[
			24,
			-10
		]
	],
	[
		[
			52615,
			13516
		],
		[
			43,
			10
		]
	],
	[
		[
			52658,
			13526
		],
		[
			12,
			0
		]
	],
	[
		[
			52670,
			13526
		],
		[
			36,
			-31
		]
	],
	[
		[
			52706,
			13495
		],
		[
			30,
			10
		]
	],
	[
		[
			52736,
			13505
		],
		[
			6,
			0
		]
	],
	[
		[
			52742,
			13505
		],
		[
			36,
			-41
		]
	],
	[
		[
			52116,
			12542
		],
		[
			-84,
			31
		],
		[
			-12,
			-62
		],
		[
			-78,
			11
		],
		[
			-54,
			-32
		],
		[
			-60,
			21
		]
	],
	[
		[
			51828,
			12511
		],
		[
			-18,
			31
		],
		[
			-126,
			0
		],
		[
			-55,
			-20
		],
		[
			-54,
			-125
		],
		[
			-78,
			-83
		],
		[
			-66,
			52
		],
		[
			-66,
			-10
		],
		[
			-78,
			21
		],
		[
			-42,
			41
		],
		[
			-36,
			-10
		]
	],
	[
		[
			52778,
			13464
		],
		[
			-42,
			41
		]
	],
	[
		[
			52706,
			13495
		],
		[
			-36,
			31
		]
	],
	[
		[
			52670,
			13526
		],
		[
			-12,
			0
		]
	],
	[
		[
			52658,
			13526
		],
		[
			-43,
			-10
		]
	],
	[
		[
			52615,
			13516
		],
		[
			-24,
			10
		]
	],
	[
		[
			52591,
			13526
		],
		[
			-30,
			42
		],
		[
			-24,
			103
		],
		[
			18,
			73
		]
	],
	[
		[
			52555,
			13744
		],
		[
			-6,
			31
		]
	],
	[
		[
			52549,
			13775
		],
		[
			-12,
			51
		]
	],
	[
		[
			52537,
			13826
		],
		[
			-18,
			94
		],
		[
			24,
			72
		],
		[
			-48,
			104
		],
		[
			42,
			41
		]
	],
	[
		[
			37704,
			37098
		],
		[
			-84,
			-62
		],
		[
			-24,
			-134
		],
		[
			-30,
			-52
		],
		[
			30,
			-52
		],
		[
			0,
			-217
		],
		[
			-60,
			-52
		],
		[
			-12,
			-83
		],
		[
			-120,
			-52
		],
		[
			-54,
			-83
		]
	],
	[
		[
			37350,
			36311
		],
		[
			-66,
			83
		],
		[
			-109,
			11
		],
		[
			-96,
			62
		],
		[
			-72,
			-11
		],
		[
			-42,
			94
		],
		[
			-66,
			72
		],
		[
			-90,
			-124
		],
		[
			-85,
			20
		],
		[
			-78,
			73
		],
		[
			-108,
			-52
		]
	],
	[
		[
			36538,
			36539
		],
		[
			0,
			42
		],
		[
			-78,
			82
		],
		[
			-24,
			166
		],
		[
			-60,
			166
		]
	],
	[
		[
			36376,
			36995
		],
		[
			108,
			145
		],
		[
			60,
			21
		]
	],
	[
		[
			36544,
			37161
		],
		[
			24,
			51
		],
		[
			36,
			0
		],
		[
			42,
			-93
		],
		[
			90,
			0
		],
		[
			18,
			42
		],
		[
			49,
			20
		],
		[
			42,
			-72
		],
		[
			60,
			41
		],
		[
			126,
			31
		],
		[
			30,
			31
		],
		[
			60,
			-41
		],
		[
			36,
			0
		],
		[
			66,
			72
		],
		[
			253,
			21
		],
		[
			96,
			-72
		],
		[
			36,
			31
		],
		[
			96,
			-125
		]
	],
	[
		[
			33682,
			35659
		],
		[
			-12,
			-52
		]
	],
	[
		[
			33670,
			35607
		],
		[
			24,
			-62
		]
	],
	[
		[
			33694,
			35545
		],
		[
			-42,
			72
		],
		[
			-6,
			114
		],
		[
			-36,
			11
		],
		[
			-6,
			62
		],
		[
			36,
			41
		]
	],
	[
		[
			33640,
			35845
		],
		[
			42,
			-124
		],
		[
			0,
			-62
		]
	],
	[
		[
			35402,
			35410
		],
		[
			-157,
			-145
		],
		[
			-102,
			-62
		],
		[
			-36,
			-62
		],
		[
			-72,
			-41
		],
		[
			-36,
			72
		]
	],
	[
		[
			34999,
			35172
		],
		[
			-12,
			21
		]
	],
	[
		[
			34987,
			35193
		],
		[
			-12,
			10
		]
	],
	[
		[
			34975,
			35203
		],
		[
			-48,
			52
		],
		[
			-127,
			-73
		],
		[
			-30,
			-82
		],
		[
			-30,
			0
		]
	],
	[
		[
			34740,
			35100
		],
		[
			-36,
			51
		],
		[
			-6,
			73
		]
	],
	[
		[
			34698,
			35224
		],
		[
			-84,
			0
		],
		[
			-66,
			-31
		],
		[
			-114,
			10
		],
		[
			-60,
			-10
		]
	],
	[
		[
			34374,
			35193
		],
		[
			-43,
			10
		],
		[
			-12,
			93
		],
		[
			42,
			52
		],
		[
			-18,
			62
		],
		[
			-60,
			-72
		],
		[
			-96,
			0
		],
		[
			-84,
			41
		],
		[
			-42,
			-10
		],
		[
			-90,
			-73
		],
		[
			-36,
			42
		],
		[
			-91,
			10
		],
		[
			0,
			31
		],
		[
			-120,
			11
		]
	],
	[
		[
			33724,
			35390
		],
		[
			-6,
			20
		]
	],
	[
		[
			33718,
			35410
		],
		[
			-18,
			11
		]
	],
	[
		[
			33700,
			35421
		],
		[
			-12,
			20
		]
	],
	[
		[
			33688,
			35441
		],
		[
			12,
			21
		]
	],
	[
		[
			33700,
			35462
		],
		[
			-6,
			73
		]
	],
	[
		[
			33694,
			35535
		],
		[
			6,
			10
		]
	],
	[
		[
			33700,
			35545
		],
		[
			-30,
			62
		]
	],
	[
		[
			33670,
			35607
		],
		[
			12,
			52
		]
	],
	[
		[
			33682,
			35659
		],
		[
			-6,
			83
		],
		[
			-42,
			114
		]
	],
	[
		[
			33634,
			35856
		],
		[
			-6,
			41
		]
	],
	[
		[
			33628,
			35897
		],
		[
			-30,
			10
		]
	],
	[
		[
			33598,
			35907
		],
		[
			-6,
			11
		]
	],
	[
		[
			33592,
			35918
		],
		[
			18,
			41
		]
	],
	[
		[
			33610,
			35959
		],
		[
			18,
			0
		]
	],
	[
		[
			33628,
			35959
		],
		[
			-6,
			21
		]
	],
	[
		[
			33622,
			35980
		],
		[
			132,
			0
		],
		[
			54,
			41
		],
		[
			60,
			-10
		],
		[
			55,
			21
		],
		[
			120,
			0
		],
		[
			30,
			-42
		],
		[
			66,
			-41
		],
		[
			-24,
			-83
		],
		[
			126,
			-31
		],
		[
			18,
			83
		],
		[
			78,
			-11
		],
		[
			157,
			0
		],
		[
			54,
			11
		],
		[
			6,
			93
		],
		[
			-114,
			31
		],
		[
			0,
			73
		],
		[
			48,
			103
		],
		[
			66,
			42
		]
	],
	[
		[
			34554,
			36260
		],
		[
			6,
			-32
		]
	],
	[
		[
			34560,
			36228
		],
		[
			156,
			52
		],
		[
			30,
			93
		],
		[
			78,
			73
		],
		[
			97,
			62
		],
		[
			60,
			10
		],
		[
			42,
			63
		],
		[
			84,
			-42
		]
	],
	[
		[
			33201,
			37637
		],
		[
			30,
			0
		]
	],
	[
		[
			33231,
			37637
		],
		[
			48,
			-21
		]
	],
	[
		[
			33279,
			37616
		],
		[
			-54,
			-62
		],
		[
			-12,
			-83
		],
		[
			36,
			-20
		],
		[
			90,
			20
		],
		[
			60,
			-31
		],
		[
			-42,
			-124
		],
		[
			61,
			21
		],
		[
			78,
			0
		],
		[
			30,
			-62
		],
		[
			54,
			-42
		]
	],
	[
		[
			33580,
			37233
		],
		[
			84,
			-114
		],
		[
			168,
			-176
		],
		[
			-90,
			-166
		],
		[
			18,
			-82
		]
	],
	[
		[
			33760,
			36695
		],
		[
			0,
			-11
		]
	],
	[
		[
			33760,
			36684
		],
		[
			6,
			-10
		]
	],
	[
		[
			33766,
			36674
		],
		[
			18,
			-21
		]
	],
	[
		[
			33784,
			36653
		],
		[
			6,
			-21
		]
	],
	[
		[
			33790,
			36632
		],
		[
			-24,
			-41
		]
	],
	[
		[
			33766,
			36591
		],
		[
			-312,
			-114
		],
		[
			-301,
			-72
		],
		[
			-108,
			-11
		],
		[
			-175,
			11
		],
		[
			-78,
			20
		],
		[
			-66,
			-10
		],
		[
			-114,
			41
		],
		[
			-60,
			-10
		],
		[
			-102,
			41
		],
		[
			-73,
			63
		],
		[
			-18,
			-11
		],
		[
			-102,
			156
		],
		[
			-6,
			124
		]
	],
	[
		[
			32516,
			37285
		],
		[
			48,
			31
		],
		[
			96,
			-10
		],
		[
			90,
			10
		],
		[
			6,
			93
		],
		[
			24,
			73
		],
		[
			-72,
			51
		],
		[
			-6,
			52
		]
	],
	[
		[
			32702,
			37585
		],
		[
			-18,
			0
		]
	],
	[
		[
			32684,
			37585
		],
		[
			12,
			11
		]
	],
	[
		[
			32696,
			37596
		],
		[
			0,
			10
		]
	],
	[
		[
			32696,
			37606
		],
		[
			6,
			10
		]
	],
	[
		[
			32702,
			37616
		],
		[
			12,
			11
		]
	],
	[
		[
			32714,
			37627
		],
		[
			18,
			-21
		],
		[
			84,
			10
		],
		[
			42,
			-83
		],
		[
			79,
			-10
		],
		[
			24,
			42
		],
		[
			54,
			0
		],
		[
			132,
			82
		]
	],
	[
		[
			33147,
			37647
		],
		[
			54,
			-10
		]
	],
	[
		[
			36538,
			36539
		],
		[
			-72,
			11
		],
		[
			18,
			-94
		],
		[
			-48,
			-62
		],
		[
			-132,
			-83
		],
		[
			-37,
			-62
		],
		[
			-198,
			-62
		],
		[
			-90,
			-41
		]
	],
	[
		[
			35660,
			36860
		],
		[
			36,
			0
		],
		[
			72,
			62
		],
		[
			61,
			94
		],
		[
			90,
			62
		],
		[
			90,
			93
		],
		[
			36,
			-41
		],
		[
			12,
			-63
		],
		[
			162,
			-10
		],
		[
			24,
			-83
		],
		[
			61,
			42
		],
		[
			72,
			-21
		]
	],
	[
		[
			33249,
			38414
		],
		[
			-30,
			10
		]
	],
	[
		[
			33219,
			38424
		],
		[
			30,
			-10
		]
	],
	[
		[
			33502,
			39139
		],
		[
			18,
			0
		]
	],
	[
		[
			33520,
			39139
		],
		[
			6,
			0
		]
	],
	[
		[
			33526,
			39139
		],
		[
			12,
			0
		]
	],
	[
		[
			33538,
			39139
		],
		[
			-36,
			-21
		]
	],
	[
		[
			33502,
			39118
		],
		[
			0,
			10
		]
	],
	[
		[
			33502,
			39128
		],
		[
			-6,
			0
		]
	],
	[
		[
			33496,
			39128
		],
		[
			6,
			11
		]
	],
	[
		[
			33574,
			40247
		],
		[
			-6,
			0
		]
	],
	[
		[
			33568,
			40247
		],
		[
			-12,
			0
		]
	],
	[
		[
			33556,
			40247
		],
		[
			12,
			10
		]
	],
	[
		[
			33568,
			40257
		],
		[
			6,
			-10
		]
	],
	[
		[
			35690,
			41055
		],
		[
			-78,
			-114
		],
		[
			-30,
			-114
		],
		[
			-180,
			-218
		],
		[
			-42,
			-20
		],
		[
			-109,
			-187
		],
		[
			-60,
			-31
		],
		[
			-60,
			0
		],
		[
			0,
			-103
		],
		[
			-30,
			-21
		],
		[
			0,
			-166
		],
		[
			108,
			-52
		],
		[
			54,
			-134
		],
		[
			42,
			0
		],
		[
			18,
			-83
		],
		[
			85,
			10
		],
		[
			18,
			-41
		],
		[
			84,
			-10
		],
		[
			66,
			-42
		],
		[
			90,
			-124
		],
		[
			6,
			-104
		],
		[
			-30,
			-62
		],
		[
			0,
			-83
		]
	],
	[
		[
			35642,
			39356
		],
		[
			-132,
			-52
		],
		[
			-6,
			-72
		],
		[
			-60,
			-114
		],
		[
			-84,
			10
		],
		[
			-55,
			42
		],
		[
			-66,
			-31
		],
		[
			-36,
			-73
		],
		[
			-156,
			0
		],
		[
			-42,
			-72
		],
		[
			-6,
			-73
		],
		[
			54,
			-93
		],
		[
			-12,
			-41
		],
		[
			42,
			-63
		],
		[
			-48,
			-51
		],
		[
			-42,
			-83
		],
		[
			-42,
			-42
		],
		[
			-78,
			-31
		],
		[
			-49,
			0
		],
		[
			-54,
			-41
		],
		[
			-60,
			52
		],
		[
			-72,
			0
		],
		[
			-30,
			-83
		]
	],
	[
		[
			34608,
			38445
		],
		[
			-90,
			-21
		],
		[
			-54,
			31
		],
		[
			-151,
			-31
		],
		[
			-72,
			176
		],
		[
			6,
			73
		],
		[
			-30,
			62
		],
		[
			-66,
			-11
		],
		[
			-36,
			-51
		],
		[
			-48,
			-166
		],
		[
			-60,
			-21
		],
		[
			-30,
			93
		],
		[
			-48,
			21
		],
		[
			-49,
			-21
		],
		[
			-138,
			83
		],
		[
			-54,
			-93
		],
		[
			18,
			-41
		],
		[
			-12,
			-94
		],
		[
			18,
			-41
		],
		[
			-6,
			-83
		],
		[
			-120,
			-10
		],
		[
			-223,
			-145
		],
		[
			-102,
			155
		],
		[
			18,
			42
		]
	],
	[
		[
			33279,
			38352
		],
		[
			-6,
			41
		]
	],
	[
		[
			33273,
			38393
		],
		[
			-18,
			21
		]
	],
	[
		[
			33255,
			38414
		],
		[
			48,
			72
		],
		[
			96,
			114
		],
		[
			-102,
			62
		],
		[
			-18,
			73
		],
		[
			54,
			31
		],
		[
			-6,
			83
		],
		[
			60,
			31
		],
		[
			43,
			52
		],
		[
			66,
			-31
		],
		[
			48,
			0
		],
		[
			18,
			134
		],
		[
			-24,
			104
		]
	],
	[
		[
			33538,
			39139
		],
		[
			-12,
			0
		]
	],
	[
		[
			33526,
			39139
		],
		[
			-6,
			0
		]
	],
	[
		[
			33520,
			39139
		],
		[
			-18,
			0
		]
	],
	[
		[
			33502,
			39128
		],
		[
			0,
			-10
		]
	],
	[
		[
			33502,
			39118
		],
		[
			30,
			-93
		],
		[
			-42,
			-42
		],
		[
			-97,
			-20
		],
		[
			-24,
			10
		],
		[
			-78,
			-31
		],
		[
			0,
			-73
		],
		[
			-24,
			-41
		],
		[
			-102,
			10
		],
		[
			-12,
			83
		],
		[
			-36,
			62
		],
		[
			12,
			145
		],
		[
			-84,
			52
		],
		[
			78,
			114
		],
		[
			0,
			83
		],
		[
			42,
			0
		],
		[
			36,
			114
		],
		[
			84,
			83
		],
		[
			6,
			41
		],
		[
			60,
			0
		],
		[
			55,
			42
		],
		[
			90,
			10
		],
		[
			48,
			62
		],
		[
			30,
			124
		],
		[
			42,
			52
		],
		[
			42,
			11
		],
		[
			66,
			93
		],
		[
			18,
			72
		],
		[
			-72,
			-20
		],
		[
			-54,
			20
		],
		[
			-60,
			114
		],
		[
			0,
			52
		]
	],
	[
		[
			33568,
			40247
		],
		[
			6,
			0
		]
	],
	[
		[
			33568,
			40257
		],
		[
			-42,
			0
		],
		[
			-36,
			52
		],
		[
			-6,
			62
		],
		[
			-91,
			0
		],
		[
			-42,
			62
		],
		[
			12,
			104
		],
		[
			-30,
			52
		]
	],
	[
		[
			38083,
			37513
		],
		[
			0,
			-197
		],
		[
			-84,
			-31
		]
	],
	[
		[
			37999,
			37285
		],
		[
			-138,
			-73
		],
		[
			-42,
			-41
		],
		[
			-115,
			-73
		]
	],
	[
		[
			36544,
			37161
		],
		[
			-24,
			41
		],
		[
			0,
			104
		],
		[
			54,
			10
		],
		[
			30,
			72
		],
		[
			-66,
			21
		],
		[
			-48,
			-10
		],
		[
			-60,
			31
		]
	],
	[
		[
			36430,
			37430
		],
		[
			84,
			52
		],
		[
			12,
			72
		],
		[
			-24,
			52
		],
		[
			90,
			103
		],
		[
			108,
			32
		],
		[
			79,
			41
		],
		[
			18,
			-31
		],
		[
			60,
			21
		],
		[
			0,
			41
		],
		[
			120,
			41
		],
		[
			84,
			42
		],
		[
			-18,
			72
		],
		[
			-48,
			94
		],
		[
			-54,
			165
		],
		[
			-6,
			73
		],
		[
			90,
			52
		],
		[
			42,
			41
		],
		[
			42,
			-10
		],
		[
			175,
			93
		]
	],
	[
		[
			37284,
			38476
		],
		[
			6,
			-145
		],
		[
			48,
			-21
		],
		[
			24,
			31
		],
		[
			42,
			-31
		],
		[
			24,
			-62
		],
		[
			60,
			-21
		],
		[
			66,
			21
		],
		[
			66,
			-41
		],
		[
			30,
			-63
		],
		[
			30,
			0
		],
		[
			49,
			-82
		],
		[
			-31,
			-31
		],
		[
			61,
			-135
		],
		[
			120,
			-135
		],
		[
			-12,
			-41
		],
		[
			54,
			-93
		],
		[
			72,
			-31
		],
		[
			90,
			-83
		]
	],
	[
		[
			33802,
			36601
		],
		[
			-36,
			-10
		]
	],
	[
		[
			33790,
			36632
		],
		[
			12,
			-31
		]
	],
	[
		[
			34169,
			36632
		],
		[
			30,
			-20
		]
	],
	[
		[
			34199,
			36612
		],
		[
			-30,
			20
		]
	],
	[
		[
			34169,
			36632
		],
		[
			-78,
			11
		],
		[
			-108,
			-11
		]
	],
	[
		[
			33983,
			36632
		],
		[
			72,
			11
		],
		[
			114,
			-11
		]
	],
	[
		[
			34626,
			37927
		],
		[
			60,
			-52
		],
		[
			-6,
			-52
		],
		[
			60,
			-31
		],
		[
			0,
			-124
		],
		[
			-18,
			-72
		],
		[
			48,
			-21
		],
		[
			24,
			-52
		],
		[
			-24,
			-52
		],
		[
			72,
			-62
		],
		[
			-12,
			-114
		],
		[
			-42,
			-72
		],
		[
			-42,
			-31
		],
		[
			24,
			-52
		],
		[
			127,
			-124
		],
		[
			-18,
			-73
		],
		[
			12,
			-72
		]
	],
	[
		[
			34891,
			36871
		],
		[
			-36,
			-31
		],
		[
			-163,
			10
		],
		[
			66,
			-52
		],
		[
			6,
			-31
		],
		[
			-84,
			-52
		],
		[
			-48,
			0
		],
		[
			-12,
			-52
		],
		[
			-54,
			11
		],
		[
			-36,
			-104
		]
	],
	[
		[
			34530,
			36570
		],
		[
			-42,
			-10
		],
		[
			-60,
			41
		],
		[
			-42,
			-41
		],
		[
			-85,
			31
		],
		[
			-48,
			-41
		]
	],
	[
		[
			34253,
			36550
		],
		[
			-54,
			82
		],
		[
			-66,
			21
		],
		[
			-192,
			-21
		],
		[
			-139,
			-31
		]
	],
	[
		[
			33802,
			36601
		],
		[
			-12,
			31
		]
	],
	[
		[
			33790,
			36632
		],
		[
			-6,
			21
		]
	],
	[
		[
			33766,
			36674
		],
		[
			-6,
			10
		]
	],
	[
		[
			33760,
			36684
		],
		[
			0,
			11
		]
	],
	[
		[
			33580,
			37233
		],
		[
			162,
			52
		],
		[
			-12,
			72
		],
		[
			78,
			-10
		],
		[
			97,
			73
		],
		[
			54,
			-125
		],
		[
			42,
			-31
		],
		[
			102,
			0
		],
		[
			-42,
			218
		],
		[
			30,
			41
		],
		[
			108,
			-10
		],
		[
			90,
			134
		],
		[
			-6,
			62
		],
		[
			78,
			32
		],
		[
			25,
			72
		],
		[
			6,
			83
		],
		[
			102,
			10
		],
		[
			36,
			31
		],
		[
			60,
			11
		],
		[
			36,
			-21
		]
	],
	[
		[
			35167,
			36632
		],
		[
			-72,
			11
		],
		[
			0,
			41
		],
		[
			108,
			62
		],
		[
			-12,
			62
		],
		[
			-114,
			21
		],
		[
			-78,
			-21
		],
		[
			-24,
			73
		],
		[
			-42,
			-31
		],
		[
			-42,
			21
		]
	],
	[
		[
			34626,
			37927
		],
		[
			114,
			0
		],
		[
			54,
			52
		],
		[
			18,
			83
		],
		[
			-30,
			82
		],
		[
			24,
			21
		],
		[
			-48,
			93
		],
		[
			-42,
			11
		],
		[
			18,
			72
		],
		[
			-126,
			104
		]
	],
	[
		[
			35642,
			39356
		],
		[
			60,
			-52
		],
		[
			78,
			21
		],
		[
			73,
			-10
		],
		[
			42,
			-31
		],
		[
			66,
			41
		],
		[
			96,
			21
		],
		[
			36,
			-10
		],
		[
			42,
			41
		],
		[
			54,
			10
		],
		[
			72,
			-83
		],
		[
			0,
			-124
		],
		[
			31,
			-72
		],
		[
			66,
			-11
		],
		[
			24,
			-103
		],
		[
			-66,
			31
		],
		[
			0,
			-156
		],
		[
			72,
			-41
		],
		[
			78,
			41
		],
		[
			48,
			0
		],
		[
			150,
			-176
		],
		[
			42,
			-20
		],
		[
			211,
			51
		],
		[
			18,
			21
		],
		[
			84,
			0
		],
		[
			36,
			-41
		],
		[
			-6,
			-145
		],
		[
			66,
			41
		],
		[
			24,
			-21
		],
		[
			78,
			63
		],
		[
			30,
			-114
		],
		[
			37,
			-52
		]
	],
	[
		[
			37350,
			36311
		],
		[
			12,
			-51
		],
		[
			54,
			-94
		],
		[
			6,
			-93
		],
		[
			90,
			-52
		],
		[
			-6,
			-93
		]
	],
	[
		[
			37506,
			35928
		],
		[
			-12,
			-72
		],
		[
			-36,
			-94
		],
		[
			-54,
			-93
		],
		[
			18,
			-124
		],
		[
			-114,
			0
		],
		[
			-24,
			62
		],
		[
			-127,
			83
		],
		[
			0,
			41
		],
		[
			-60,
			73
		],
		[
			-48,
			21
		],
		[
			-114,
			-73
		],
		[
			-84,
			-72
		],
		[
			-54,
			-83
		],
		[
			24,
			-73
		],
		[
			6,
			-83
		],
		[
			24,
			-51
		],
		[
			-6,
			-83
		],
		[
			-60,
			-11
		]
	],
	[
		[
			36785,
			35296
		],
		[
			-79,
			104
		],
		[
			-6,
			41
		],
		[
			-54,
			94
		],
		[
			-12,
			113
		],
		[
			24,
			52
		],
		[
			-42,
			93
		],
		[
			-84,
			-113
		],
		[
			-102,
			0
		],
		[
			-120,
			31
		],
		[
			-12,
			51
		],
		[
			-91,
			31
		]
	],
	[
		[
			33622,
			35980
		],
		[
			-18,
			0
		]
	],
	[
		[
			33604,
			35980
		],
		[
			-18,
			0
		]
	],
	[
		[
			33586,
			35980
		],
		[
			-24,
			62
		]
	],
	[
		[
			33562,
			36042
		],
		[
			-18,
			52
		]
	],
	[
		[
			33544,
			36094
		],
		[
			42,
			10
		]
	],
	[
		[
			33586,
			36104
		],
		[
			-6,
			145
		],
		[
			-54,
			83
		],
		[
			-102,
			83
		],
		[
			-6,
			21
		],
		[
			168,
			72
		],
		[
			246,
			93
		],
		[
			109,
			11
		],
		[
			42,
			20
		]
	],
	[
		[
			34199,
			36612
		],
		[
			6,
			-11
		],
		[
			48,
			-51
		]
	],
	[
		[
			34253,
			36550
		],
		[
			48,
			31
		],
		[
			97,
			-21
		],
		[
			30,
			31
		],
		[
			78,
			-41
		],
		[
			24,
			20
		]
	],
	[
		[
			33694,
			35535
		],
		[
			6,
			10
		]
	],
	[
		[
			33586,
			36104
		],
		[
			-42,
			-10
		]
	],
	[
		[
			33544,
			36094
		],
		[
			18,
			-52
		]
	],
	[
		[
			33562,
			36042
		],
		[
			24,
			-62
		]
	],
	[
		[
			33604,
			35980
		],
		[
			24,
			-21
		]
	],
	[
		[
			33628,
			35959
		],
		[
			-18,
			0
		]
	],
	[
		[
			33610,
			35959
		],
		[
			-18,
			-41
		]
	],
	[
		[
			33598,
			35907
		],
		[
			30,
			-10
		]
	],
	[
		[
			33628,
			35897
		],
		[
			6,
			-41
		]
	],
	[
		[
			33634,
			35856
		],
		[
			6,
			-11
		]
	],
	[
		[
			33694,
			35545
		],
		[
			0,
			-10
		]
	],
	[
		[
			33700,
			35462
		],
		[
			-12,
			-10
		],
		[
			0,
			-11
		]
	],
	[
		[
			33700,
			35421
		],
		[
			18,
			-11
		]
	],
	[
		[
			34374,
			35193
		],
		[
			-31,
			-135
		],
		[
			-96,
			-41
		],
		[
			-36,
			-62
		],
		[
			6,
			-73
		],
		[
			60,
			-93
		],
		[
			-24,
			-93
		],
		[
			-48,
			-63
		],
		[
			12,
			-41
		],
		[
			-12,
			-124
		],
		[
			-72,
			-62
		]
	],
	[
		[
			34133,
			34406
		],
		[
			-126,
			-42
		],
		[
			-42,
			-31
		],
		[
			-60,
			11
		],
		[
			-25,
			93
		],
		[
			-48,
			72
		],
		[
			-66,
			-93
		],
		[
			-132,
			-83
		],
		[
			-24,
			-72
		],
		[
			6,
			-94
		],
		[
			-30,
			-93
		]
	],
	[
		[
			33586,
			34074
		],
		[
			-108,
			-10
		],
		[
			-30,
			83
		],
		[
			-73,
			-11
		],
		[
			-60,
			42
		],
		[
			-6,
			41
		],
		[
			-84,
			31
		]
	],
	[
		[
			33225,
			34250
		],
		[
			-24,
			73
		],
		[
			42,
			72
		],
		[
			-24,
			31
		],
		[
			-96,
			-10
		],
		[
			-114,
			52
		],
		[
			-48,
			62
		],
		[
			-12,
			52
		],
		[
			-109,
			72
		],
		[
			-120,
			11
		],
		[
			-18,
			-42
		],
		[
			90,
			-176
		],
		[
			-6,
			-52
		],
		[
			-72,
			-31
		],
		[
			-48,
			52
		],
		[
			-114,
			73
		],
		[
			-84,
			72
		],
		[
			-91,
			10
		],
		[
			-60,
			52
		],
		[
			36,
			83
		],
		[
			-6,
			124
		],
		[
			103,
			42
		],
		[
			6,
			124
		],
		[
			-73,
			52
		],
		[
			30,
			134
		],
		[
			97,
			94
		],
		[
			66,
			114
		],
		[
			42,
			20
		],
		[
			66,
			-41
		],
		[
			90,
			93
		],
		[
			90,
			186
		],
		[
			61,
			63
		],
		[
			-43,
			82
		],
		[
			12,
			104
		]
	],
	[
		[
			32894,
			35897
		],
		[
			6,
			0
		]
	],
	[
		[
			32900,
			35897
		],
		[
			-48,
			31
		],
		[
			12,
			93
		]
	],
	[
		[
			32864,
			36021
		],
		[
			-30,
			42
		]
	],
	[
		[
			32834,
			36063
		],
		[
			0,
			10
		],
		[
			-6,
			0
		]
	],
	[
		[
			32828,
			36073
		],
		[
			84,
			114
		],
		[
			-36,
			41
		],
		[
			73,
			114
		],
		[
			120,
			0
		],
		[
			60,
			31
		],
		[
			258,
			42
		],
		[
			49,
			-21
		],
		[
			120,
			-114
		],
		[
			24,
			-62
		],
		[
			6,
			-114
		]
	],
	[
		[
			32714,
			37627
		],
		[
			-12,
			-11
		]
	],
	[
		[
			32696,
			37606
		],
		[
			0,
			-10
		]
	],
	[
		[
			32696,
			37596
		],
		[
			-12,
			-11
		]
	],
	[
		[
			32299,
			37751
		],
		[
			6,
			114
		],
		[
			-24,
			269
		],
		[
			18,
			52
		],
		[
			84,
			41
		],
		[
			61,
			0
		],
		[
			78,
			31
		],
		[
			36,
			-51
		],
		[
			-18,
			-42
		],
		[
			12,
			-207
		],
		[
			24,
			-62
		],
		[
			66,
			-73
		],
		[
			48,
			-10
		],
		[
			60,
			-52
		],
		[
			-48,
			-52
		],
		[
			12,
			-82
		]
	],
	[
		[
			33279,
			37616
		],
		[
			-48,
			21
		]
	],
	[
		[
			33231,
			37637
		],
		[
			-30,
			0
		]
	],
	[
		[
			33201,
			37637
		],
		[
			-54,
			10
		]
	],
	[
		[
			33147,
			37647
		],
		[
			-60,
			0
		],
		[
			-12,
			-41
		],
		[
			-60,
			-31
		],
		[
			-72,
			10
		],
		[
			-6,
			-31
		]
	],
	[
		[
			32937,
			37554
		],
		[
			-43,
			-21
		],
		[
			-54,
			83
		],
		[
			-102,
			42
		],
		[
			48,
			62
		],
		[
			-12,
			52
		],
		[
			-138,
			155
		],
		[
			-30,
			72
		],
		[
			18,
			52
		],
		[
			-30,
			83
		],
		[
			-6,
			104
		],
		[
			18,
			41
		],
		[
			60,
			31
		],
		[
			331,
			145
		],
		[
			72,
			11
		],
		[
			0,
			-52
		],
		[
			48,
			-52
		],
		[
			84,
			21
		],
		[
			18,
			41
		]
	],
	[
		[
			33249,
			38414
		],
		[
			6,
			0
		]
	],
	[
		[
			42971,
			26348
		],
		[
			18,
			-31
		],
		[
			67,
			-10
		]
	],
	[
		[
			43296,
			25623
		],
		[
			96,
			-238
		],
		[
			18,
			52
		]
	],
	[
		[
			43410,
			25437
		],
		[
			18,
			-11
		]
	],
	[
		[
			43428,
			25426
		],
		[
			30,
			-10
		]
	],
	[
		[
			43458,
			25416
		],
		[
			121,
			-21
		]
	],
	[
		[
			43579,
			25395
		],
		[
			66,
			-62
		]
	],
	[
		[
			43645,
			25333
		],
		[
			54,
			0
		],
		[
			54,
			52
		],
		[
			0,
			-93
		],
		[
			-30,
			-83
		],
		[
			-36,
			-42
		],
		[
			-126,
			31
		],
		[
			-24,
			-41
		],
		[
			-127,
			62
		],
		[
			-90,
			-10
		],
		[
			-18,
			-83
		],
		[
			-168,
			0
		],
		[
			-18,
			-73
		],
		[
			-42,
			21
		],
		[
			-115,
			-21
		],
		[
			-18,
			73
		],
		[
			-48,
			93
		],
		[
			-108,
			104
		],
		[
			-349,
			-497
		],
		[
			-78,
			-94
		]
	],
	[
		[
			42358,
			24732
		],
		[
			-108,
			73
		]
	],
	[
		[
			42250,
			24805
		],
		[
			36,
			93
		],
		[
			-24,
			83
		],
		[
			-42,
			52
		],
		[
			-30,
			72
		],
		[
			18,
			52
		],
		[
			-42,
			135
		],
		[
			24,
			72
		],
		[
			66,
			73
		],
		[
			66,
			-52
		],
		[
			60,
			-11
		],
		[
			36,
			21
		],
		[
			90,
			10
		]
	],
	[
		[
			42508,
			25405
		],
		[
			31,
			0
		],
		[
			24,
			94
		],
		[
			-61,
			10
		],
		[
			-90,
			41
		],
		[
			-12,
			52
		],
		[
			42,
			62
		],
		[
			97,
			83
		],
		[
			-31,
			62
		],
		[
			49,
			63
		],
		[
			84,
			20
		],
		[
			-30,
			104
		],
		[
			78,
			52
		],
		[
			-60,
			41
		]
	],
	[
		[
			42629,
			26089
		],
		[
			90,
			41
		],
		[
			36,
			0
		],
		[
			6,
			0
		],
		[
			6,
			0
		]
	],
	[
		[
			42767,
			26130
		],
		[
			60,
			21
		],
		[
			-24,
			52
		],
		[
			108,
			52
		],
		[
			12,
			52
		],
		[
			48,
			41
		]
	],
	[
		[
			43723,
			27808
		],
		[
			114,
			-51
		]
	],
	[
		[
			43837,
			27757
		],
		[
			78,
			20
		]
	],
	[
		[
			43915,
			27777
		],
		[
			-36,
			-145
		],
		[
			-24,
			-186
		],
		[
			48,
			-62
		],
		[
			-42,
			-73
		],
		[
			42,
			-31
		],
		[
			54,
			-176
		],
		[
			55,
			-72
		],
		[
			-43,
			-21
		],
		[
			55,
			-104
		],
		[
			96,
			0
		],
		[
			-84,
			-124
		],
		[
			60,
			-62
		],
		[
			-6,
			-52
		]
	],
	[
		[
			44090,
			26669
		],
		[
			204,
			-72
		],
		[
			54,
			-63
		],
		[
			72,
			-41
		]
	],
	[
		[
			44420,
			26493
		],
		[
			-66,
			-62
		],
		[
			-108,
			83
		],
		[
			-54,
			-94
		],
		[
			-42,
			-20
		],
		[
			-24,
			-73
		],
		[
			-78,
			-72
		],
		[
			-145,
			41
		],
		[
			6,
			-52
		],
		[
			-66,
			11
		]
	],
	[
		[
			42971,
			26348
		],
		[
			-12,
			41
		],
		[
			-60,
			31
		],
		[
			-84,
			-20
		],
		[
			-54,
			72
		]
	],
	[
		[
			42761,
			26472
		],
		[
			-48,
			62
		],
		[
			-72,
			0
		],
		[
			-139,
			73
		],
		[
			6,
			62
		],
		[
			-36,
			62
		],
		[
			18,
			83
		]
	],
	[
		[
			42490,
			26814
		],
		[
			97,
			83
		],
		[
			0,
			52
		],
		[
			90,
			72
		],
		[
			-42,
			83
		],
		[
			-54,
			10
		]
	],
	[
		[
			42581,
			27114
		],
		[
			-42,
			-62
		],
		[
			-73,
			-52
		],
		[
			-60,
			63
		],
		[
			-18,
			62
		],
		[
			-162,
			52
		],
		[
			-30,
			41
		],
		[
			0,
			62
		],
		[
			30,
			31
		],
		[
			6,
			83
		],
		[
			54,
			93
		],
		[
			228,
			-20
		],
		[
			-6,
			82
		],
		[
			18,
			73
		],
		[
			85,
			103
		]
	],
	[
		[
			42611,
			27725
		],
		[
			42,
			-62
		],
		[
			54,
			21
		],
		[
			78,
			-52
		],
		[
			36,
			-93
		],
		[
			60,
			31
		],
		[
			96,
			-10
		],
		[
			6,
			-31
		]
	],
	[
		[
			42983,
			27529
		],
		[
			37,
			41
		]
	],
	[
		[
			43020,
			27570
		],
		[
			78,
			73
		],
		[
			84,
			41
		],
		[
			114,
			-21
		],
		[
			72,
			11
		],
		[
			84,
			134
		],
		[
			145,
			0
		],
		[
			96,
			52
		],
		[
			30,
			-52
		]
	],
	[
		[
			45779,
			25033
		],
		[
			-12,
			-21
		],
		[
			-84,
			-10
		]
	],
	[
		[
			45683,
			25002
		],
		[
			-150,
			-104
		],
		[
			-60,
			21
		],
		[
			-73,
			52
		],
		[
			-48,
			-32
		]
	],
	[
		[
			45352,
			24939
		],
		[
			-48,
			11
		]
	],
	[
		[
			45304,
			24950
		],
		[
			-30,
			10
		]
	],
	[
		[
			45274,
			24960
		],
		[
			-18,
			0
		]
	],
	[
		[
			45256,
			24960
		],
		[
			-90,
			-21
		],
		[
			-60,
			42
		]
	],
	[
		[
			45106,
			24981
		],
		[
			-6,
			-10
		]
	],
	[
		[
			45100,
			24971
		],
		[
			6,
			10
		]
	],
	[
		[
			45106,
			24981
		],
		[
			-6,
			-10
		]
	],
	[
		[
			45100,
			24971
		],
		[
			-66,
			10
		]
	],
	[
		[
			45034,
			24981
		],
		[
			-90,
			62
		]
	],
	[
		[
			44944,
			25043
		],
		[
			-55,
			10
		],
		[
			-24,
			-72
		],
		[
			-60,
			-42
		],
		[
			6,
			-134
		]
	],
	[
		[
			44811,
			24805
		],
		[
			-12,
			-83
		],
		[
			-72,
			0
		],
		[
			-12,
			-52
		]
	],
	[
		[
			44715,
			24670
		],
		[
			78,
			-52
		],
		[
			12,
			-93
		],
		[
			-42,
			-10
		],
		[
			-66,
			-93
		]
	],
	[
		[
			44697,
			24422
		],
		[
			-60,
			31
		],
		[
			-30,
			-11
		],
		[
			-151,
			52
		],
		[
			-24,
			62
		]
	],
	[
		[
			44432,
			24556
		],
		[
			-30,
			31
		],
		[
			-42,
			-20
		],
		[
			-48,
			20
		],
		[
			-72,
			-72
		],
		[
			-120,
			0
		],
		[
			-60,
			-52
		],
		[
			-97,
			-52
		],
		[
			-96,
			-124
		],
		[
			54,
			-21
		],
		[
			6,
			-72
		],
		[
			-30,
			-52
		],
		[
			-114,
			-73
		],
		[
			-54,
			94
		]
	],
	[
		[
			43729,
			24163
		],
		[
			-54,
			31
		],
		[
			-72,
			-21
		],
		[
			-42,
			-83
		],
		[
			-30,
			0
		]
	],
	[
		[
			43531,
			24090
		],
		[
			-79,
			-31
		],
		[
			-108,
			-93
		],
		[
			-6,
			-52
		],
		[
			-48,
			-72
		],
		[
			-120,
			0
		]
	],
	[
		[
			43170,
			23842
		],
		[
			-48,
			-31
		]
	],
	[
		[
			43122,
			23811
		],
		[
			-60,
			-32
		],
		[
			-55,
			42
		],
		[
			-48,
			0
		]
	],
	[
		[
			42959,
			23821
		],
		[
			-198,
			373
		],
		[
			-36,
			31
		],
		[
			-295,
			424
		],
		[
			-72,
			83
		]
	],
	[
		[
			43645,
			25333
		],
		[
			54,
			176
		],
		[
			30,
			21
		],
		[
			156,
			186
		],
		[
			-120,
			62
		],
		[
			18,
			42
		],
		[
			-66,
			52
		],
		[
			0,
			41
		]
	],
	[
		[
			44420,
			26493
		],
		[
			85,
			-52
		],
		[
			108,
			-31
		],
		[
			12,
			21
		]
	],
	[
		[
			44625,
			26431
		],
		[
			150,
			10
		],
		[
			84,
			62
		],
		[
			0,
			31
		],
		[
			103,
			0
		],
		[
			-25,
			-82
		],
		[
			25,
			-21
		],
		[
			78,
			21
		],
		[
			66,
			-73
		],
		[
			0,
			-72
		],
		[
			78,
			-32
		],
		[
			48,
			-103
		]
	],
	[
		[
			42250,
			24805
		],
		[
			-78,
			52
		],
		[
			-457,
			269
		]
	],
	[
		[
			41715,
			25126
		],
		[
			-6,
			31
		],
		[
			-235,
			135
		],
		[
			-6,
			-11
		]
	],
	[
		[
			41468,
			25281
		],
		[
			-24,
			21
		],
		[
			-336,
			155
		],
		[
			-49,
			125
		],
		[
			-36,
			62
		],
		[
			-42,
			0
		],
		[
			-78,
			62
		],
		[
			6,
			124
		],
		[
			18,
			42
		],
		[
			-78,
			82
		],
		[
			12,
			125
		],
		[
			120,
			72
		],
		[
			-6,
			145
		],
		[
			-36,
			83
		]
	],
	[
		[
			40939,
			26379
		],
		[
			84,
			-21
		],
		[
			169,
			83
		],
		[
			30,
			31
		],
		[
			54,
			-83
		],
		[
			96,
			83
		],
		[
			18,
			-62
		],
		[
			96,
			-62
		],
		[
			66,
			-10
		],
		[
			49,
			62
		],
		[
			-12,
			41
		],
		[
			90,
			93
		],
		[
			30,
			-62
		],
		[
			54,
			-41
		],
		[
			60,
			-11
		],
		[
			222,
			73
		],
		[
			67,
			52
		],
		[
			24,
			83
		],
		[
			126,
			51
		],
		[
			78,
			63
		],
		[
			60,
			10
		],
		[
			90,
			62
		]
	],
	[
		[
			45406,
			29289
		],
		[
			0,
			-165
		],
		[
			133,
			-83
		]
	],
	[
		[
			45539,
			29041
		],
		[
			-36,
			-156
		],
		[
			-24,
			-41
		],
		[
			-18,
			-124
		],
		[
			-36,
			-83
		],
		[
			6,
			-52
		],
		[
			60,
			10
		],
		[
			30,
			-31
		],
		[
			-48,
			-103
		],
		[
			120,
			-62
		],
		[
			18,
			10
		],
		[
			36,
			-124
		],
		[
			162,
			-249
		],
		[
			24,
			-93
		],
		[
			48,
			-93
		],
		[
			49,
			-52
		],
		[
			42,
			-104
		],
		[
			-18,
			-114
		],
		[
			36,
			-93
		],
		[
			6,
			-72
		],
		[
			66,
			-197
		]
	],
	[
		[
			43915,
			27777
		],
		[
			85,
			52
		],
		[
			162,
			-10
		],
		[
			24,
			-21
		],
		[
			66,
			52
		],
		[
			18,
			52
		]
	],
	[
		[
			44270,
			27902
		],
		[
			-12,
			103
		],
		[
			36,
			42
		],
		[
			66,
			-11
		],
		[
			48,
			73
		],
		[
			67,
			51
		]
	],
	[
		[
			44475,
			28160
		],
		[
			-6,
			32
		]
	],
	[
		[
			44469,
			28192
		],
		[
			72,
			51
		],
		[
			-48,
			52
		],
		[
			36,
			73
		],
		[
			90,
			20
		],
		[
			150,
			93
		],
		[
			181,
			135
		],
		[
			-37,
			52
		],
		[
			37,
			72
		],
		[
			54,
			42
		],
		[
			72,
			134
		],
		[
			12,
			114
		],
		[
			78,
			104
		]
	],
	[
		[
			45166,
			29134
		],
		[
			36,
			-31
		],
		[
			18,
			72
		],
		[
			84,
			114
		],
		[
			102,
			0
		]
	],
	[
		[
			42581,
			28316
		],
		[
			-36,
			-135
		],
		[
			6,
			-93
		],
		[
			36,
			-73
		],
		[
			-30,
			-165
		],
		[
			66,
			-52
		],
		[
			-12,
			-73
		]
	],
	[
		[
			40939,
			26379
		],
		[
			-84,
			62
		],
		[
			-24,
			52
		],
		[
			-36,
			-21
		],
		[
			-72,
			93
		]
	],
	[
		[
			40723,
			26565
		],
		[
			12,
			63
		],
		[
			-60,
			62
		]
	],
	[
		[
			49501,
			28223
		],
		[
			42,
			31
		],
		[
			144,
			51
		]
	],
	[
		[
			49687,
			28305
		],
		[
			-24,
			-41
		],
		[
			-144,
			-52
		],
		[
			-18,
			11
		]
	],
	[
		[
			51052,
			29818
		],
		[
			-42,
			-52
		],
		[
			-228,
			-176
		],
		[
			-109,
			-166
		],
		[
			-36,
			-31
		],
		[
			-120,
			-187
		],
		[
			-54,
			-51
		],
		[
			-96,
			-156
		],
		[
			-24,
			-93
		],
		[
			-84,
			-135
		],
		[
			-49,
			-20
		],
		[
			-120,
			-176
		],
		[
			-144,
			-83
		],
		[
			-211,
			-156
		],
		[
			-240,
			-103
		]
	],
	[
		[
			49495,
			28233
		],
		[
			-60,
			21
		],
		[
			-24,
			-21
		],
		[
			-60,
			21
		],
		[
			-48,
			93
		],
		[
			-55,
			10
		],
		[
			-36,
			42
		],
		[
			-48,
			-21
		]
	],
	[
		[
			49164,
			28378
		],
		[
			-36,
			52
		],
		[
			-54,
			-11
		],
		[
			-36,
			125
		]
	],
	[
		[
			49038,
			28544
		],
		[
			-6,
			72
		],
		[
			-36,
			62
		],
		[
			-66,
			0
		],
		[
			-30,
			52
		],
		[
			-72,
			-31
		],
		[
			-133,
			83
		],
		[
			-180,
			31
		],
		[
			-42,
			21
		]
	],
	[
		[
			48473,
			28834
		],
		[
			132,
			259
		],
		[
			48,
			41
		],
		[
			84,
			155
		],
		[
			12,
			83
		],
		[
			55,
			104
		],
		[
			-61,
			62
		],
		[
			-84,
			145
		],
		[
			-12,
			52
		],
		[
			-48,
			41
		],
		[
			42,
			145
		],
		[
			-12,
			42
		],
		[
			54,
			207
		],
		[
			84,
			-11
		]
	],
	[
		[
			48767,
			30159
		],
		[
			43,
			-62
		],
		[
			138,
			-124
		],
		[
			156,
			-187
		],
		[
			108,
			-165
		],
		[
			36,
			-21
		],
		[
			283,
			-21
		],
		[
			72,
			-31
		],
		[
			211,
			0
		],
		[
			42,
			-31
		],
		[
			48,
			73
		],
		[
			126,
			83
		],
		[
			72,
			82
		],
		[
			54,
			31
		],
		[
			12,
			52
		],
		[
			-60,
			321
		],
		[
			24,
			11
		],
		[
			247,
			0
		],
		[
			204,
			93
		],
		[
			108,
			62
		],
		[
			25,
			-41
		],
		[
			18,
			-176
		],
		[
			30,
			-63
		],
		[
			84,
			-31
		],
		[
			204,
			-196
		]
	],
	[
		[
			50499,
			34085
		],
		[
			6,
			20
		]
	],
	[
		[
			50505,
			34105
		],
		[
			0,
			11
		]
	],
	[
		[
			50505,
			34116
		],
		[
			6,
			-11
		]
	],
	[
		[
			50511,
			34105
		],
		[
			-12,
			-20
		]
	],
	[
		[
			50505,
			34116
		],
		[
			0,
			-11
		]
	],
	[
		[
			50505,
			34105
		],
		[
			-6,
			-20
		]
	],
	[
		[
			50511,
			34105
		],
		[
			66,
			62
		],
		[
			-36,
			83
		],
		[
			126,
			-72
		],
		[
			-30,
			-52
		],
		[
			6,
			-52
		],
		[
			85,
			-31
		],
		[
			24,
			62
		],
		[
			36,
			21
		],
		[
			12,
			-93
		],
		[
			60,
			-93
		],
		[
			30,
			10
		],
		[
			66,
			-114
		],
		[
			6,
			-83
		],
		[
			42,
			-21
		],
		[
			-42,
			-41
		],
		[
			60,
			-135
		],
		[
			36,
			11
		],
		[
			54,
			-52
		],
		[
			-6,
			-145
		],
		[
			78,
			10
		],
		[
			37,
			-62
		],
		[
			-18,
			-52
		],
		[
			30,
			-82
		],
		[
			42,
			-52
		],
		[
			0,
			-52
		],
		[
			96,
			-207
		],
		[
			30,
			-83
		],
		[
			78,
			-155
		],
		[
			90,
			-249
		],
		[
			169,
			-300
		],
		[
			48,
			-156
		],
		[
			60,
			-155
		],
		[
			18,
			-186
		],
		[
			72,
			-228
		],
		[
			18,
			-104
		],
		[
			-42,
			-342
		],
		[
			6,
			-114
		],
		[
			-18,
			-124
		],
		[
			12,
			-145
		],
		[
			-60,
			-83
		],
		[
			-12,
			-103
		],
		[
			-96,
			20
		],
		[
			-127,
			-93
		],
		[
			-228,
			-238
		],
		[
			-48,
			-21
		],
		[
			-48,
			-72
		],
		[
			-66,
			-21
		],
		[
			-121,
			-93
		],
		[
			-54,
			-10
		]
	],
	[
		[
			48767,
			30159
		],
		[
			-24,
			156
		],
		[
			-84,
			31
		],
		[
			-60,
			186
		],
		[
			-6,
			145
		],
		[
			-72,
			93
		],
		[
			-48,
			135
		],
		[
			-102,
			124
		],
		[
			-60,
			114
		],
		[
			-37,
			0
		],
		[
			-48,
			52
		]
	],
	[
		[
			48226,
			31195
		],
		[
			12,
			52
		],
		[
			-18,
			93
		],
		[
			-66,
			145
		],
		[
			18,
			52
		],
		[
			66,
			52
		],
		[
			54,
			72
		],
		[
			13,
			52
		],
		[
			-31,
			62
		],
		[
			6,
			83
		],
		[
			-42,
			72
		],
		[
			-72,
			73
		]
	],
	[
		[
			48166,
			32003
		],
		[
			-18,
			93
		],
		[
			-72,
			41
		],
		[
			24,
			83
		],
		[
			-36,
			94
		],
		[
			72,
			41
		],
		[
			54,
			0
		],
		[
			-24,
			72
		],
		[
			-48,
			83
		],
		[
			42,
			42
		],
		[
			18,
			72
		],
		[
			30,
			31
		],
		[
			103,
			-114
		],
		[
			132,
			83
		],
		[
			-24,
			125
		],
		[
			60,
			20
		],
		[
			132,
			104
		],
		[
			12,
			41
		],
		[
			84,
			114
		],
		[
			-96,
			114
		],
		[
			-36,
			114
		],
		[
			132,
			93
		],
		[
			-24,
			42
		],
		[
			-24,
			145
		],
		[
			72,
			20
		],
		[
			67,
			42
		],
		[
			60,
			62
		],
		[
			42,
			-31
		],
		[
			180,
			-31
		],
		[
			60,
			10
		]
	],
	[
		[
			50000,
			34457
		],
		[
			24,
			-51
		],
		[
			60,
			-21
		],
		[
			36,
			-41
		],
		[
			54,
			10
		],
		[
			42,
			52
		],
		[
			67,
			-21
		],
		[
			66,
			-104
		],
		[
			24,
			-72
		],
		[
			42,
			-52
		],
		[
			42,
			0
		],
		[
			48,
			-41
		]
	],
	[
		[
			47042,
			31630
		],
		[
			-84,
			-73
		],
		[
			-78,
			21
		],
		[
			-43,
			-21
		],
		[
			-48,
			-72
		],
		[
			-6,
			-62
		],
		[
			-54,
			21
		],
		[
			-24,
			-187
		],
		[
			-66,
			11
		],
		[
			-54,
			62
		]
	],
	[
		[
			46585,
			31330
		],
		[
			-36,
			41
		],
		[
			-114,
			52
		],
		[
			-79,
			-11
		],
		[
			-24,
			52
		],
		[
			12,
			135
		],
		[
			43,
			0
		],
		[
			66,
			72
		],
		[
			24,
			-10
		],
		[
			102,
			31
		],
		[
			18,
			42
		],
		[
			-132,
			82
		]
	],
	[
		[
			46465,
			31816
		],
		[
			234,
			63
		],
		[
			54,
			20
		],
		[
			175,
			0
		],
		[
			48,
			-41
		],
		[
			60,
			-21
		],
		[
			-6,
			-135
		],
		[
			12,
			-72
		]
	],
	[
		[
			47042,
			31630
		],
		[
			108,
			21
		],
		[
			78,
			0
		],
		[
			181,
			31
		],
		[
			102,
			-11
		],
		[
			186,
			21
		],
		[
			84,
			-62
		],
		[
			91,
			21
		],
		[
			24,
			-125
		],
		[
			60,
			-51
		],
		[
			-6,
			-52
		],
		[
			42,
			-21
		],
		[
			30,
			-103
		],
		[
			36,
			-52
		],
		[
			54,
			-31
		],
		[
			78,
			0
		],
		[
			36,
			-21
		]
	],
	[
		[
			48473,
			28834
		],
		[
			-54,
			-218
		]
	],
	[
		[
			48419,
			28616
		],
		[
			-108,
			42
		],
		[
			-103,
			10
		],
		[
			-174,
			62
		],
		[
			-204,
			-21
		],
		[
			-13,
			-124
		],
		[
			-30,
			-41
		],
		[
			-102,
			10
		],
		[
			-180,
			-73
		],
		[
			-72,
			-10
		],
		[
			-60,
			-31
		],
		[
			-43,
			135
		],
		[
			-144,
			0
		],
		[
			-12,
			41
		],
		[
			-48,
			10
		],
		[
			-54,
			63
		],
		[
			18,
			145
		],
		[
			30,
			0
		],
		[
			-12,
			103
		],
		[
			-24,
			0
		],
		[
			-36,
			135
		],
		[
			-96,
			-62
		],
		[
			-42,
			124
		],
		[
			-55,
			-41
		],
		[
			-78,
			-21
		],
		[
			-78,
			10
		],
		[
			66,
			156
		],
		[
			12,
			-42
		],
		[
			85,
			21
		],
		[
			-13,
			134
		],
		[
			-24,
			63
		],
		[
			55,
			559
		],
		[
			-295,
			0
		],
		[
			-66,
			-42
		],
		[
			-108,
			63
		],
		[
			-193,
			31
		],
		[
			0,
			-21
		],
		[
			-144,
			21
		],
		[
			-42,
			31
		],
		[
			-139,
			-11
		],
		[
			-24,
			-41
		],
		[
			-48,
			-10
		],
		[
			-60,
			72
		]
	],
	[
		[
			45761,
			30066
		],
		[
			18,
			52
		],
		[
			90,
			10
		],
		[
			-6,
			93
		],
		[
			-48,
			32
		],
		[
			-12,
			62
		],
		[
			-36,
			10
		],
		[
			-78,
			83
		],
		[
			48,
			83
		],
		[
			24,
			145
		],
		[
			-60,
			20
		],
		[
			-30,
			52
		],
		[
			96,
			83
		],
		[
			-30,
			73
		],
		[
			-12,
			103
		],
		[
			42,
			145
		],
		[
			-18,
			62
		],
		[
			-192,
			42
		],
		[
			-72,
			0
		],
		[
			12,
			62
		],
		[
			48,
			0
		],
		[
			66,
			93
		],
		[
			72,
			124
		],
		[
			90,
			-31
		],
		[
			96,
			114
		],
		[
			127,
			-21
		],
		[
			54,
			145
		],
		[
			0,
			63
		]
	],
	[
		[
			46050,
			31765
		],
		[
			102,
			31
		],
		[
			6,
			93
		],
		[
			96,
			21
		],
		[
			48,
			31
		],
		[
			66,
			-21
		],
		[
			97,
			-104
		]
	],
	[
		[
			51449,
			27767
		],
		[
			-36,
			-114
		],
		[
			-54,
			-52
		],
		[
			-6,
			-52
		],
		[
			-42,
			-72
		],
		[
			162,
			-114
		],
		[
			-42,
			-10
		],
		[
			-96,
			-63
		],
		[
			-90,
			-41
		],
		[
			-91,
			-62
		],
		[
			-30,
			-42
		],
		[
			-90,
			-62
		],
		[
			-60,
			-72
		],
		[
			-84,
			31
		]
	],
	[
		[
			50890,
			27042
		],
		[
			138,
			259
		],
		[
			66,
			207
		],
		[
			54,
			311
		],
		[
			73,
			31
		],
		[
			96,
			-21
		],
		[
			66,
			-52
		],
		[
			66,
			-10
		]
	],
	[
		[
			51136,
			27850
		],
		[
			-6,
			20
		]
	],
	[
		[
			51130,
			27870
		],
		[
			6,
			-20
		]
	],
	[
		[
			49495,
			28233
		],
		[
			6,
			-10
		]
	],
	[
		[
			49687,
			28305
		],
		[
			73,
			42
		],
		[
			168,
			124
		],
		[
			132,
			73
		],
		[
			66,
			51
		],
		[
			115,
			125
		],
		[
			36,
			20
		],
		[
			6,
			-114
		],
		[
			66,
			-31
		],
		[
			84,
			-82
		],
		[
			138,
			-11
		],
		[
			120,
			-62
		],
		[
			55,
			-41
		],
		[
			144,
			-52
		],
		[
			42,
			-62
		],
		[
			36,
			-135
		],
		[
			60,
			-62
		],
		[
			12,
			-62
		],
		[
			90,
			-156
		]
	],
	[
		[
			51136,
			27850
		],
		[
			6,
			-11
		],
		[
			-54,
			-331
		],
		[
			-36,
			-124
		],
		[
			-66,
			-156
		],
		[
			-96,
			-186
		]
	],
	[
		[
			48671,
			26369
		],
		[
			-60,
			0
		],
		[
			-144,
			248
		],
		[
			-42,
			-10
		],
		[
			-48,
			83
		],
		[
			-18,
			-21
		],
		[
			-85,
			145
		],
		[
			18,
			21
		],
		[
			-162,
			269
		],
		[
			265,
			249
		],
		[
			0,
			82
		],
		[
			-36,
			156
		],
		[
			-30,
			342
		],
		[
			-18,
			72
		],
		[
			-6,
			197
		],
		[
			36,
			145
		],
		[
			78,
			269
		]
	],
	[
		[
			45406,
			29289
		],
		[
			6,
			62
		],
		[
			-66,
			73
		],
		[
			-90,
			145
		],
		[
			0,
			62
		],
		[
			48,
			-21
		],
		[
			42,
			135
		],
		[
			48,
			-10
		],
		[
			115,
			51
		],
		[
			24,
			135
		],
		[
			36,
			104
		],
		[
			66,
			0
		]
	],
	[
		[
			45635,
			30025
		],
		[
			72,
			10
		],
		[
			54,
			31
		]
	],
	[
		[
			46050,
			31765
		],
		[
			-126,
			176
		],
		[
			-139,
			0
		],
		[
			-126,
			-42
		],
		[
			-6,
			-93
		],
		[
			-162,
			21
		],
		[
			-72,
			0
		]
	],
	[
		[
			45419,
			31827
		],
		[
			-7,
			62
		],
		[
			31,
			31
		]
	],
	[
		[
			45443,
			31920
		],
		[
			-6,
			21
		]
	],
	[
		[
			45437,
			31941
		],
		[
			48,
			103
		],
		[
			0,
			42
		],
		[
			-73,
			93
		],
		[
			73,
			93
		],
		[
			24,
			52
		]
	],
	[
		[
			45509,
			32324
		],
		[
			6,
			-10
		]
	],
	[
		[
			45515,
			32314
		],
		[
			18,
			-52
		]
	],
	[
		[
			45533,
			32262
		],
		[
			36,
			10
		],
		[
			24,
			93
		],
		[
			-42,
			73
		],
		[
			18,
			124
		]
	],
	[
		[
			45569,
			32562
		],
		[
			-48,
			0
		],
		[
			-18,
			73
		],
		[
			30,
			72
		],
		[
			-42,
			42
		]
	],
	[
		[
			45491,
			32749
		],
		[
			0,
			103
		]
	],
	[
		[
			45491,
			32852
		],
		[
			-54,
			83
		],
		[
			-37,
			-21
		]
	],
	[
		[
			45400,
			32914
		],
		[
			-66,
			11
		]
	],
	[
		[
			45334,
			32925
		],
		[
			30,
			114
		],
		[
			55,
			41
		],
		[
			-25,
			31
		],
		[
			25,
			135
		],
		[
			-19,
			20
		]
	],
	[
		[
			45400,
			33266
		],
		[
			-48,
			52
		],
		[
			-36,
			93
		],
		[
			-60,
			31
		],
		[
			-78,
			83
		],
		[
			12,
			52
		],
		[
			-18,
			83
		],
		[
			42,
			10
		],
		[
			36,
			52
		]
	],
	[
		[
			45250,
			33722
		],
		[
			126,
			155
		],
		[
			-12,
			94
		],
		[
			36,
			41
		],
		[
			43,
			0
		],
		[
			-18,
			83
		],
		[
			42,
			62
		],
		[
			12,
			62
		]
	],
	[
		[
			45479,
			34219
		],
		[
			66,
			-10
		],
		[
			72,
			103
		],
		[
			18,
			94
		]
	],
	[
		[
			55237,
			27612
		],
		[
			0,
			-11
		]
	],
	[
		[
			55237,
			27601
		],
		[
			36,
			-83
		],
		[
			36,
			62
		],
		[
			78,
			83
		],
		[
			90,
			-10
		],
		[
			43,
			41
		],
		[
			42,
			-62
		],
		[
			72,
			-20
		]
	],
	[
		[
			55634,
			27612
		],
		[
			18,
			-73
		],
		[
			-24,
			-104
		],
		[
			42,
			-10
		],
		[
			6,
			-124
		],
		[
			60,
			-31
		],
		[
			96,
			62
		],
		[
			84,
			10
		],
		[
			66,
			-83
		],
		[
			-18,
			-103
		],
		[
			55,
			-52
		],
		[
			120,
			-41
		],
		[
			12,
			-104
		],
		[
			30,
			-62
		],
		[
			66,
			-62
		],
		[
			0,
			-42
		],
		[
			-90,
			-93
		],
		[
			18,
			-41
		],
		[
			78,
			-73
		],
		[
			36,
			-93
		],
		[
			-42,
			-73
		],
		[
			6,
			-72
		],
		[
			-18,
			-145
		]
	],
	[
		[
			56235,
			26203
		],
		[
			-48,
			-21
		],
		[
			-60,
			21
		],
		[
			-30,
			-52
		],
		[
			-30,
			11
		],
		[
			-30,
			82
		],
		[
			-55,
			52
		],
		[
			-60,
			-114
		],
		[
			-102,
			-52
		],
		[
			0,
			-103
		],
		[
			-36,
			-135
		],
		[
			96,
			-10
		],
		[
			18,
			-259
		],
		[
			-72,
			21
		],
		[
			-30,
			-31
		],
		[
			-66,
			10
		],
		[
			-60,
			41
		],
		[
			-114,
			11
		],
		[
			-49,
			20
		],
		[
			-60,
			-41
		],
		[
			-6,
			-104
		],
		[
			-60,
			-20
		],
		[
			18,
			-93
		],
		[
			84,
			-73
		],
		[
			37,
			-52
		],
		[
			162,
			-52
		],
		[
			60,
			-62
		],
		[
			66,
			0
		],
		[
			30,
			-31
		],
		[
			78,
			-31
		],
		[
			115,
			11
		],
		[
			96,
			-83
		],
		[
			36,
			-52
		],
		[
			60,
			-41
		],
		[
			-84,
			-94
		],
		[
			-6,
			-83
		],
		[
			36,
			-269
		],
		[
			54,
			-10
		],
		[
			-6,
			-93
		],
		[
			-120,
			-52
		],
		[
			-54,
			-114
		],
		[
			-6,
			-83
		],
		[
			-36,
			-124
		],
		[
			-67,
			0
		],
		[
			-18,
			52
		],
		[
			-42,
			-42
		],
		[
			-66,
			-124
		],
		[
			-18,
			-124
		],
		[
			54,
			-156
		]
	],
	[
		[
			55844,
			23655
		],
		[
			-132,
			-31
		],
		[
			-54,
			-41
		],
		[
			-175,
			-11
		]
	],
	[
		[
			55483,
			23572
		],
		[
			-60,
			21
		],
		[
			-90,
			73
		],
		[
			-36,
			72
		],
		[
			-84,
			21
		]
	],
	[
		[
			55213,
			23759
		],
		[
			-90,
			-42
		],
		[
			-72,
			52
		],
		[
			-67,
			10
		],
		[
			-36,
			-20
		],
		[
			-66,
			10
		],
		[
			-42,
			83
		],
		[
			-102,
			10
		],
		[
			-78,
			-62
		],
		[
			-66,
			-31
		],
		[
			-109,
			0
		],
		[
			-48,
			-41
		],
		[
			-78,
			0
		],
		[
			-36,
			41
		],
		[
			-84,
			-72
		],
		[
			-30,
			0
		],
		[
			-54,
			114
		],
		[
			-145,
			-11
		]
	],
	[
		[
			54010,
			23800
		],
		[
			-24,
			21
		],
		[
			-102,
			10
		],
		[
			-102,
			73
		],
		[
			-24,
			41
		],
		[
			96,
			145
		],
		[
			66,
			83
		],
		[
			114,
			114
		],
		[
			-48,
			62
		],
		[
			-78,
			-10
		],
		[
			-90,
			31
		],
		[
			-60,
			72
		],
		[
			-30,
			0
		],
		[
			-78,
			-62
		],
		[
			-12,
			-31
		],
		[
			-163,
			-31
		],
		[
			-138,
			52
		],
		[
			-78,
			-21
		]
	],
	[
		[
			53259,
			24349
		],
		[
			12,
			145
		],
		[
			36,
			155
		],
		[
			36,
			104
		],
		[
			66,
			300
		],
		[
			30,
			42
		],
		[
			-48,
			114
		],
		[
			-54,
			0
		],
		[
			-90,
			145
		],
		[
			-102,
			62
		],
		[
			-151,
			0
		],
		[
			-18,
			83
		],
		[
			30,
			114
		],
		[
			84,
			20
		],
		[
			73,
			83
		],
		[
			12,
			156
		],
		[
			-36,
			-11
		],
		[
			84,
			301
		],
		[
			18,
			82
		],
		[
			-96,
			21
		],
		[
			18,
			124
		],
		[
			-12,
			42
		],
		[
			-73,
			62
		],
		[
			115,
			83
		],
		[
			126,
			52
		],
		[
			54,
			10
		],
		[
			60,
			41
		],
		[
			78,
			21
		],
		[
			54,
			-83
		],
		[
			73,
			-20
		],
		[
			12,
			93
		],
		[
			54,
			41
		],
		[
			72,
			-21
		],
		[
			6,
			-31
		],
		[
			90,
			-20
		],
		[
			60,
			41
		],
		[
			0,
			42
		],
		[
			84,
			103
		],
		[
			12,
			73
		],
		[
			-84,
			103
		],
		[
			-120,
			11
		],
		[
			-66,
			31
		],
		[
			30,
			51
		],
		[
			84,
			52
		],
		[
			18,
			73
		],
		[
			-6,
			103
		],
		[
			54,
			31
		],
		[
			0,
			125
		],
		[
			48,
			20
		]
	],
	[
		[
			53986,
			27518
		],
		[
			54,
			-62
		],
		[
			199,
			-31
		],
		[
			6,
			-31
		],
		[
			96,
			21
		],
		[
			60,
			-83
		],
		[
			90,
			0
		],
		[
			42,
			114
		],
		[
			49,
			52
		],
		[
			48,
			-11
		],
		[
			-6,
			83
		],
		[
			78,
			42
		],
		[
			-12,
			51
		],
		[
			54,
			62
		],
		[
			18,
			-20
		],
		[
			132,
			-11
		],
		[
			36,
			-93
		],
		[
			115,
			-62
		],
		[
			12,
			31
		],
		[
			114,
			52
		],
		[
			24,
			31
		],
		[
			42,
			-41
		]
	],
	[
		[
			57576,
			25965
		],
		[
			24,
			20
		]
	],
	[
		[
			57600,
			25985
		],
		[
			54,
			-10
		]
	],
	[
		[
			57654,
			25975
		],
		[
			-78,
			-10
		]
	],
	[
		[
			56969,
			27870
		],
		[
			78,
			-51
		],
		[
			72,
			0
		],
		[
			18,
			-73
		],
		[
			48,
			0
		],
		[
			48,
			62
		],
		[
			36,
			-20
		],
		[
			42,
			-94
		],
		[
			30,
			-31
		],
		[
			36,
			21
		],
		[
			115,
			-52
		],
		[
			-24,
			-52
		],
		[
			18,
			-51
		],
		[
			6,
			-104
		],
		[
			66,
			-114
		],
		[
			66,
			11
		],
		[
			6,
			-42
		],
		[
			54,
			-103
		],
		[
			48,
			-11
		],
		[
			0,
			-52
		],
		[
			199,
			-72
		],
		[
			6,
			-52
		],
		[
			72,
			-41
		],
		[
			-6,
			-125
		],
		[
			30,
			-62
		],
		[
			84,
			-62
		]
	],
	[
		[
			58117,
			26700
		],
		[
			-30,
			-62
		]
	],
	[
		[
			58087,
			26638
		],
		[
			-12,
			-10
		]
	],
	[
		[
			58075,
			26628
		],
		[
			36,
			-31
		]
	],
	[
		[
			58111,
			26597
		],
		[
			54,
			-11
		]
	],
	[
		[
			58165,
			26586
		],
		[
			12,
			0
		]
	],
	[
		[
			58177,
			26586
		],
		[
			30,
			31
		]
	],
	[
		[
			58207,
			26617
		],
		[
			12,
			73
		]
	],
	[
		[
			58219,
			26690
		],
		[
			90,
			20
		]
	],
	[
		[
			58309,
			26710
		],
		[
			24,
			21
		],
		[
			36,
			-93
		]
	],
	[
		[
			58369,
			26638
		],
		[
			43,
			-62
		],
		[
			54,
			41
		]
	],
	[
		[
			58466,
			26617
		],
		[
			30,
			0
		]
	],
	[
		[
			58496,
			26617
		],
		[
			12,
			-52
		]
	],
	[
		[
			58508,
			26565
		],
		[
			54,
			21
		]
	],
	[
		[
			58562,
			26586
		],
		[
			24,
			-10
		]
	],
	[
		[
			58586,
			26576
		],
		[
			6,
			0
		]
	],
	[
		[
			58592,
			26576
		],
		[
			42,
			0
		]
	],
	[
		[
			58634,
			26576
		],
		[
			-24,
			-42
		]
	],
	[
		[
			58610,
			26534
		],
		[
			42,
			-20
		]
	],
	[
		[
			58652,
			26514
		],
		[
			6,
			20
		]
	],
	[
		[
			58658,
			26534
		],
		[
			36,
			11
		]
	],
	[
		[
			58694,
			26545
		],
		[
			6,
			-21
		]
	],
	[
		[
			58700,
			26524
		],
		[
			48,
			0
		]
	],
	[
		[
			58748,
			26524
		],
		[
			24,
			0
		]
	],
	[
		[
			58772,
			26524
		],
		[
			18,
			-21
		]
	],
	[
		[
			58790,
			26503
		],
		[
			54,
			0
		],
		[
			24,
			-72
		]
	],
	[
		[
			58868,
			26431
		],
		[
			37,
			-31
		]
	],
	[
		[
			58905,
			26400
		],
		[
			12,
			-42
		]
	],
	[
		[
			58917,
			26358
		],
		[
			-6,
			-31
		]
	],
	[
		[
			58911,
			26327
		],
		[
			-24,
			-83
		]
	],
	[
		[
			58887,
			26244
		],
		[
			54,
			-41
		]
	],
	[
		[
			58941,
			26203
		],
		[
			6,
			-41
		]
	],
	[
		[
			58947,
			26162
		],
		[
			12,
			-73
		]
	],
	[
		[
			58959,
			26089
		],
		[
			12,
			0
		]
	],
	[
		[
			58971,
			26089
		],
		[
			18,
			21
		]
	],
	[
		[
			58989,
			26110
		],
		[
			18,
			-21
		]
	],
	[
		[
			59007,
			26089
		],
		[
			48,
			0
		]
	],
	[
		[
			59055,
			26089
		],
		[
			24,
			10
		]
	],
	[
		[
			59079,
			26099
		],
		[
			12,
			-10
		]
	],
	[
		[
			59091,
			26089
		],
		[
			36,
			-104
		]
	],
	[
		[
			59127,
			25985
		],
		[
			6,
			-10
		]
	],
	[
		[
			59133,
			25975
		],
		[
			66,
			0
		]
	],
	[
		[
			59199,
			25975
		],
		[
			18,
			21
		]
	],
	[
		[
			59217,
			25996
		],
		[
			12,
			10
		]
	],
	[
		[
			59229,
			26006
		],
		[
			12,
			0
		]
	],
	[
		[
			59241,
			26006
		],
		[
			12,
			-41
		],
		[
			54,
			31
		],
		[
			24,
			52
		]
	],
	[
		[
			59331,
			26048
		],
		[
			61,
			-21
		]
	],
	[
		[
			59392,
			26027
		],
		[
			-18,
			-42
		],
		[
			84,
			-20
		],
		[
			120,
			-93
		],
		[
			-102,
			-63
		],
		[
			-48,
			-51
		],
		[
			-42,
			20
		],
		[
			-49,
			-103
		],
		[
			61,
			-31
		]
	],
	[
		[
			59398,
			25644
		],
		[
			-43,
			-62
		],
		[
			-48,
			-21
		]
	],
	[
		[
			59307,
			25561
		],
		[
			-18,
			-42
		]
	],
	[
		[
			59289,
			25519
		],
		[
			-18,
			-20
		]
	],
	[
		[
			59271,
			25499
		],
		[
			-18,
			-11
		]
	],
	[
		[
			59253,
			25488
		],
		[
			-54,
			21
		],
		[
			-12,
			-52
		]
	],
	[
		[
			59187,
			25457
		],
		[
			-30,
			-20
		]
	],
	[
		[
			59157,
			25437
		],
		[
			-48,
			-73
		]
	],
	[
		[
			59109,
			25364
		],
		[
			-30,
			-21
		]
	],
	[
		[
			59079,
			25343
		],
		[
			-72,
			-10
		],
		[
			-66,
			21
		]
	],
	[
		[
			58941,
			25354
		],
		[
			-67,
			10
		],
		[
			-84,
			-41
		]
	],
	[
		[
			58790,
			25323
		],
		[
			-12,
			41
		]
	],
	[
		[
			58778,
			25364
		],
		[
			-18,
			21
		]
	],
	[
		[
			58760,
			25385
		],
		[
			-36,
			-31
		]
	],
	[
		[
			58724,
			25354
		],
		[
			-36,
			31
		],
		[
			6,
			103
		],
		[
			-30,
			21
		]
	],
	[
		[
			58664,
			25509
		],
		[
			-18,
			10
		],
		[
			-102,
			-51
		]
	],
	[
		[
			58544,
			25468
		],
		[
			-54,
			124
		]
	],
	[
		[
			58490,
			25592
		],
		[
			-24,
			31
		]
	],
	[
		[
			58466,
			25623
		],
		[
			-85,
			-10
		]
	],
	[
		[
			58381,
			25613
		],
		[
			-12,
			10
		]
	],
	[
		[
			58369,
			25623
		],
		[
			-36,
			62
		]
	],
	[
		[
			58333,
			25685
		],
		[
			-36,
			0
		],
		[
			-6,
			62
		]
	],
	[
		[
			58291,
			25747
		],
		[
			-54,
			31
		]
	],
	[
		[
			58237,
			25778
		],
		[
			-36,
			52
		]
	],
	[
		[
			58201,
			25830
		],
		[
			-42,
			83
		]
	],
	[
		[
			58159,
			25913
		],
		[
			-60,
			31
		]
	],
	[
		[
			58099,
			25944
		],
		[
			-12,
			-10
		]
	],
	[
		[
			58087,
			25934
		],
		[
			-48,
			-11
		]
	],
	[
		[
			58039,
			25923
		],
		[
			-30,
			-51
		]
	],
	[
		[
			58009,
			25872
		],
		[
			-36,
			-52
		],
		[
			-61,
			-42
		]
	],
	[
		[
			57912,
			25778
		],
		[
			-36,
			21
		],
		[
			-36,
			135
		]
	],
	[
		[
			57840,
			25934
		],
		[
			-30,
			31
		],
		[
			-60,
			-11
		]
	],
	[
		[
			57750,
			25954
		],
		[
			-72,
			11
		]
	],
	[
		[
			57678,
			25965
		],
		[
			-18,
			0
		]
	],
	[
		[
			57660,
			25965
		],
		[
			-6,
			10
		]
	],
	[
		[
			57654,
			25975
		],
		[
			-54,
			10
		]
	],
	[
		[
			57600,
			25985
		],
		[
			-48,
			-31
		]
	],
	[
		[
			57552,
			25954
		],
		[
			24,
			135
		],
		[
			72,
			41
		],
		[
			-12,
			73
		],
		[
			-96,
			-41
		],
		[
			-84,
			72
		],
		[
			-97,
			21
		],
		[
			6,
			155
		],
		[
			18,
			93
		],
		[
			-24,
			31
		],
		[
			-54,
			-62
		],
		[
			-114,
			0
		],
		[
			54,
			-103
		],
		[
			30,
			-94
		],
		[
			-168,
			-82
		]
	],
	[
		[
			57107,
			26193
		],
		[
			-6,
			51
		],
		[
			-78,
			52
		],
		[
			6,
			73
		],
		[
			-79,
			62
		],
		[
			-48,
			-104
		],
		[
			-60,
			-10
		],
		[
			-6,
			114
		],
		[
			-66,
			52
		],
		[
			-48,
			-73
		],
		[
			-84,
			-62
		],
		[
			-126,
			31
		],
		[
			6,
			-72
		],
		[
			-49,
			0
		],
		[
			7,
			-63
		],
		[
			-43,
			-72
		],
		[
			-42,
			-10
		],
		[
			-156,
			41
		]
	],
	[
		[
			55634,
			27612
		],
		[
			12,
			20
		],
		[
			84,
			11
		],
		[
			42,
			-21
		],
		[
			30,
			72
		],
		[
			48,
			0
		],
		[
			24,
			42
		],
		[
			54,
			0
		],
		[
			91,
			31
		],
		[
			174,
			10
		],
		[
			66,
			125
		],
		[
			96,
			-94
		],
		[
			78,
			-41
		],
		[
			103,
			-31
		],
		[
			-12,
			83
		],
		[
			54,
			10
		],
		[
			102,
			83
		],
		[
			36,
			-31
		],
		[
			0,
			-62
		],
		[
			54,
			-11
		],
		[
			18,
			-41
		],
		[
			54,
			10
		],
		[
			24,
			93
		]
	],
	[
		[
			56866,
			27870
		],
		[
			84,
			21
		],
		[
			19,
			-21
		]
	],
	[
		[
			59945,
			25095
		],
		[
			-78,
			-11
		],
		[
			-12,
			31
		],
		[
			-85,
			42
		],
		[
			-42,
			62
		],
		[
			-36,
			-10
		],
		[
			-66,
			62
		],
		[
			-36,
			-21
		],
		[
			-60,
			21
		],
		[
			-54,
			-73
		],
		[
			-121,
			-51
		]
	],
	[
		[
			59355,
			25147
		],
		[
			-6,
			-83
		],
		[
			-48,
			-21
		]
	],
	[
		[
			59301,
			25043
		],
		[
			-48,
			72
		],
		[
			0,
			63
		]
	],
	[
		[
			59253,
			25178
		],
		[
			-6,
			0
		]
	],
	[
		[
			59247,
			25178
		],
		[
			-78,
			31
		]
	],
	[
		[
			59169,
			25209
		],
		[
			12,
			41
		]
	],
	[
		[
			59181,
			25250
		],
		[
			36,
			31
		]
	],
	[
		[
			59217,
			25281
		],
		[
			36,
			0
		],
		[
			78,
			93
		],
		[
			0,
			104
		],
		[
			61,
			21
		]
	],
	[
		[
			59392,
			25499
		],
		[
			18,
			10
		]
	],
	[
		[
			59410,
			25509
		],
		[
			12,
			166
		],
		[
			90,
			41
		],
		[
			108,
			31
		],
		[
			78,
			62
		],
		[
			90,
			42
		],
		[
			61,
			-52
		],
		[
			12,
			-124
		],
		[
			36,
			-125
		],
		[
			0,
			-145
		],
		[
			12,
			-145
		],
		[
			36,
			-165
		]
	],
	[
		[
			59277,
			26037
		],
		[
			54,
			11
		]
	],
	[
		[
			59241,
			26006
		],
		[
			24,
			52
		]
	],
	[
		[
			59265,
			26058
		],
		[
			12,
			-21
		]
	],
	[
		[
			59843,
			25923
		],
		[
			6,
			-51
		]
	],
	[
		[
			59849,
			25872
		],
		[
			-6,
			-21
		]
	],
	[
		[
			59843,
			25851
		],
		[
			-37,
			52
		],
		[
			-66,
			20
		],
		[
			-54,
			-10
		],
		[
			-78,
			-93
		],
		[
			-108,
			-21
		],
		[
			-48,
			-52
		],
		[
			-54,
			-103
		]
	],
	[
		[
			59392,
			26027
		],
		[
			30,
			0
		]
	],
	[
		[
			59422,
			26027
		],
		[
			102,
			0
		]
	],
	[
		[
			59524,
			26027
		],
		[
			72,
			-10
		]
	],
	[
		[
			59596,
			26017
		],
		[
			36,
			-11
		]
	],
	[
		[
			59632,
			26006
		],
		[
			18,
			-52
		]
	],
	[
		[
			59650,
			25954
		],
		[
			30,
			-10
		]
	],
	[
		[
			59680,
			25944
		],
		[
			24,
			31
		]
	],
	[
		[
			59704,
			25975
		],
		[
			24,
			10
		]
	],
	[
		[
			59728,
			25985
		],
		[
			6,
			0
		]
	],
	[
		[
			59734,
			25985
		],
		[
			12,
			32
		]
	],
	[
		[
			59746,
			26017
		],
		[
			24,
			10
		]
	],
	[
		[
			59770,
			26027
		],
		[
			60,
			0
		],
		[
			37,
			-62
		],
		[
			-24,
			-42
		]
	],
	[
		[
			59843,
			25851
		],
		[
			6,
			21
		]
	],
	[
		[
			59849,
			25872
		],
		[
			-6,
			51
		]
	],
	[
		[
			59843,
			25923
		],
		[
			24,
			62
		],
		[
			-55,
			52
		],
		[
			-42,
			-10
		]
	],
	[
		[
			59770,
			26027
		],
		[
			-24,
			-10
		]
	],
	[
		[
			59746,
			26017
		],
		[
			-12,
			-32
		]
	],
	[
		[
			59728,
			25985
		],
		[
			-24,
			-10
		]
	],
	[
		[
			59704,
			25975
		],
		[
			-24,
			-31
		]
	],
	[
		[
			59680,
			25944
		],
		[
			-30,
			10
		]
	],
	[
		[
			59650,
			25954
		],
		[
			-18,
			52
		]
	],
	[
		[
			59632,
			26006
		],
		[
			-36,
			11
		]
	],
	[
		[
			59596,
			26017
		],
		[
			-72,
			10
		]
	],
	[
		[
			59524,
			26027
		],
		[
			-102,
			0
		]
	],
	[
		[
			59422,
			26027
		],
		[
			-91,
			21
		]
	],
	[
		[
			59331,
			26048
		],
		[
			-54,
			-11
		]
	],
	[
		[
			59277,
			26037
		],
		[
			-12,
			21
		]
	],
	[
		[
			59265,
			26058
		],
		[
			-36,
			-52
		]
	],
	[
		[
			59217,
			25996
		],
		[
			-18,
			-21
		]
	],
	[
		[
			59199,
			25975
		],
		[
			-66,
			0
		]
	],
	[
		[
			59127,
			25985
		],
		[
			-36,
			104
		]
	],
	[
		[
			59079,
			26099
		],
		[
			-24,
			-10
		]
	],
	[
		[
			59055,
			26089
		],
		[
			-48,
			0
		]
	],
	[
		[
			58989,
			26110
		],
		[
			-18,
			-21
		]
	],
	[
		[
			58959,
			26089
		],
		[
			-12,
			73
		]
	],
	[
		[
			58947,
			26162
		],
		[
			-6,
			41
		]
	],
	[
		[
			58941,
			26203
		],
		[
			-54,
			41
		]
	],
	[
		[
			58887,
			26244
		],
		[
			24,
			83
		]
	],
	[
		[
			58917,
			26358
		],
		[
			-12,
			42
		]
	],
	[
		[
			58905,
			26400
		],
		[
			-37,
			31
		]
	],
	[
		[
			58868,
			26431
		],
		[
			-24,
			83
		],
		[
			6,
			51
		],
		[
			-30,
			73
		],
		[
			61,
			52
		],
		[
			72,
			0
		]
	],
	[
		[
			58953,
			26690
		],
		[
			48,
			31
		]
	],
	[
		[
			59001,
			26721
		],
		[
			6,
			10
		]
	],
	[
		[
			59007,
			26731
		],
		[
			18,
			42
		]
	],
	[
		[
			59025,
			26773
		],
		[
			126,
			51
		],
		[
			54,
			0
		]
	],
	[
		[
			59205,
			26824
		],
		[
			42,
			21
		]
	],
	[
		[
			59247,
			26845
		],
		[
			48,
			62
		]
	],
	[
		[
			59295,
			26907
		],
		[
			60,
			93
		],
		[
			79,
			42
		],
		[
			138,
			41
		]
	],
	[
		[
			59572,
			27083
		],
		[
			54,
			-72
		],
		[
			84,
			-145
		],
		[
			42,
			-176
		],
		[
			60,
			-176
		],
		[
			55,
			-125
		],
		[
			18,
			-103
		],
		[
			42,
			-104
		],
		[
			48,
			-197
		],
		[
			-18,
			-62
		],
		[
			-24,
			-259
		],
		[
			6,
			-165
		],
		[
			-24,
			-11
		],
		[
			-72,
			363
		]
	],
	[
		[
			51870,
			25654
		],
		[
			0,
			-62
		],
		[
			-241,
			-352
		]
	],
	[
		[
			51629,
			25240
		],
		[
			-228,
			-332
		],
		[
			-84,
			-103
		]
	],
	[
		[
			50788,
			26514
		],
		[
			18,
			248
		],
		[
			54,
			114
		],
		[
			30,
			166
		]
	],
	[
		[
			51449,
			27767
		],
		[
			102,
			31
		],
		[
			241,
			0
		],
		[
			96,
			-41
		],
		[
			42,
			-42
		],
		[
			96,
			-197
		],
		[
			114,
			-279
		],
		[
			25,
			-104
		],
		[
			-43,
			-72
		],
		[
			-180,
			-218
		],
		[
			0,
			-103
		],
		[
			42,
			-73
		],
		[
			60,
			-62
		],
		[
			0,
			-52
		],
		[
			-48,
			-114
		],
		[
			-18,
			-83
		],
		[
			30,
			-114
		],
		[
			12,
			-176
		],
		[
			-30,
			-124
		],
		[
			12,
			-104
		],
		[
			-36,
			-82
		],
		[
			-96,
			-104
		]
	],
	[
		[
			54137,
			29165
		],
		[
			-12,
			-21
		]
	],
	[
		[
			54125,
			29144
		],
		[
			-12,
			0
		]
	],
	[
		[
			54113,
			29144
		],
		[
			30,
			52
		]
	],
	[
		[
			54143,
			29196
		],
		[
			6,
			0
		]
	],
	[
		[
			54149,
			29196
		],
		[
			-12,
			-31
		]
	],
	[
		[
			54089,
			29300
		],
		[
			30,
			-42
		]
	],
	[
		[
			54119,
			29258
		],
		[
			-42,
			11
		]
	],
	[
		[
			54077,
			29269
		],
		[
			-37,
			-21
		]
	],
	[
		[
			54040,
			29248
		],
		[
			-6,
			0
		]
	],
	[
		[
			54034,
			29248
		],
		[
			55,
			52
		]
	],
	[
		[
			54407,
			29289
		],
		[
			-6,
			-93
		],
		[
			12,
			-72
		],
		[
			-18,
			-73
		],
		[
			24,
			-145
		],
		[
			18,
			-207
		],
		[
			24,
			-135
		],
		[
			109,
			11
		],
		[
			42,
			-21
		],
		[
			0,
			-104
		],
		[
			-54,
			-82
		],
		[
			-55,
			62
		],
		[
			-18,
			-52
		],
		[
			18,
			-145
		],
		[
			-36,
			-41
		],
		[
			-150,
			-42
		],
		[
			-132,
			0
		],
		[
			-60,
			21
		],
		[
			-42,
			-73
		],
		[
			0,
			-72
		],
		[
			114,
			-135
		],
		[
			30,
			-114
		],
		[
			-66,
			-72
		],
		[
			-72,
			-125
		],
		[
			-103,
			-62
		]
	],
	[
		[
			53259,
			24349
		],
		[
			-187,
			21
		],
		[
			-42,
			-42
		],
		[
			-84,
			21
		],
		[
			-24,
			-41
		],
		[
			-42,
			20
		],
		[
			-96,
			0
		],
		[
			-126,
			-41
		],
		[
			-163,
			21
		],
		[
			-60,
			-42
		],
		[
			-60,
			-72
		]
	],
	[
		[
			51317,
			24805
		],
		[
			90,
			103
		],
		[
			222,
			332
		]
	],
	[
		[
			51629,
			25240
		],
		[
			235,
			331
		],
		[
			6,
			83
		]
	],
	[
		[
			51870,
			25654
		],
		[
			72,
			62
		],
		[
			66,
			114
		],
		[
			-12,
			114
		],
		[
			30,
			124
		],
		[
			-12,
			187
		],
		[
			-30,
			93
		],
		[
			6,
			52
		],
		[
			66,
			165
		],
		[
			-6,
			52
		],
		[
			-48,
			42
		],
		[
			-60,
			124
		],
		[
			24,
			83
		],
		[
			114,
			124
		],
		[
			91,
			114
		],
		[
			-12,
			124
		],
		[
			-163,
			415
		],
		[
			-30,
			103
		],
		[
			90,
			52
		],
		[
			169,
			176
		],
		[
			66,
			31
		],
		[
			24,
			52
		],
		[
			162,
			114
		],
		[
			-18,
			83
		],
		[
			18,
			82
		],
		[
			36,
			83
		],
		[
			72,
			125
		],
		[
			61,
			186
		],
		[
			24,
			135
		],
		[
			54,
			145
		],
		[
			48,
			62
		],
		[
			42,
			21
		],
		[
			114,
			124
		],
		[
			108,
			62
		],
		[
			109,
			10
		],
		[
			6,
			-62
		],
		[
			42,
			-21
		],
		[
			42,
			21
		],
		[
			90,
			0
		],
		[
			-18,
			62
		],
		[
			144,
			-31
		],
		[
			265,
			42
		],
		[
			54,
			0
		],
		[
			-6,
			-104
		],
		[
			72,
			42
		],
		[
			54,
			51
		],
		[
			54,
			11
		],
		[
			18,
			-42
		],
		[
			72,
			-10
		]
	],
	[
		[
			54034,
			29248
		],
		[
			6,
			0
		]
	],
	[
		[
			54077,
			29269
		],
		[
			42,
			-11
		]
	],
	[
		[
			54119,
			29258
		],
		[
			30,
			21
		],
		[
			78,
			-21
		],
		[
			-42,
			-83
		],
		[
			-36,
			21
		]
	],
	[
		[
			54149,
			29196
		],
		[
			-6,
			0
		]
	],
	[
		[
			54143,
			29196
		],
		[
			-30,
			-52
		]
	],
	[
		[
			54113,
			29144
		],
		[
			12,
			0
		]
	],
	[
		[
			54125,
			29144
		],
		[
			12,
			21
		]
	],
	[
		[
			54137,
			29165
		],
		[
			48,
			0
		],
		[
			72,
			62
		],
		[
			-12,
			62
		],
		[
			126,
			21
		],
		[
			36,
			-21
		]
	],
	[
		[
			54089,
			29300
		],
		[
			-67,
			-11
		],
		[
			-96,
			52
		],
		[
			-60,
			-21
		],
		[
			-48,
			11
		],
		[
			12,
			62
		],
		[
			90,
			0
		],
		[
			241,
			-52
		],
		[
			12,
			-52
		],
		[
			-84,
			11
		]
	],
	[
		[
			58652,
			26514
		],
		[
			-42,
			20
		]
	],
	[
		[
			58634,
			26576
		],
		[
			24,
			-42
		]
	],
	[
		[
			58658,
			26534
		],
		[
			-6,
			-20
		]
	],
	[
		[
			58460,
			26617
		],
		[
			-6,
			0
		]
	],
	[
		[
			58454,
			26617
		],
		[
			6,
			11
		]
	],
	[
		[
			58460,
			26628
		],
		[
			0,
			-11
		]
	],
	[
		[
			58796,
			26721
		],
		[
			-6,
			0
		]
	],
	[
		[
			58790,
			26721
		],
		[
			0,
			10
		]
	],
	[
		[
			58790,
			26731
		],
		[
			6,
			-10
		]
	],
	[
		[
			54888,
			29144
		],
		[
			12,
			-10
		]
	],
	[
		[
			54900,
			29134
		],
		[
			24,
			0
		]
	],
	[
		[
			54924,
			29134
		],
		[
			6,
			0
		]
	],
	[
		[
			54930,
			29134
		],
		[
			0,
			-10
		]
	],
	[
		[
			54930,
			29124
		],
		[
			-6,
			-11
		]
	],
	[
		[
			54924,
			29113
		],
		[
			-6,
			-10
		]
	],
	[
		[
			54918,
			29103
		],
		[
			-36,
			41
		]
	],
	[
		[
			54882,
			29144
		],
		[
			6,
			0
		]
	],
	[
		[
			55658,
			29113
		],
		[
			6,
			0
		]
	],
	[
		[
			55664,
			29113
		],
		[
			0,
			-20
		]
	],
	[
		[
			55664,
			29093
		],
		[
			-36,
			10
		]
	],
	[
		[
			55628,
			29103
		],
		[
			18,
			21
		]
	],
	[
		[
			55646,
			29124
		],
		[
			6,
			0
		]
	],
	[
		[
			55652,
			29124
		],
		[
			6,
			-11
		]
	],
	[
		[
			55453,
			29124
		],
		[
			-6,
			0
		]
	],
	[
		[
			55447,
			29124
		],
		[
			-6,
			0
		]
	],
	[
		[
			55441,
			29124
		],
		[
			-6,
			10
		]
	],
	[
		[
			55435,
			29134
		],
		[
			-12,
			0
		]
	],
	[
		[
			55423,
			29134
		],
		[
			-12,
			-10
		]
	],
	[
		[
			55411,
			29124
		],
		[
			-48,
			0
		]
	],
	[
		[
			55363,
			29124
		],
		[
			0,
			10
		]
	],
	[
		[
			55363,
			29134
		],
		[
			0,
			10
		]
	],
	[
		[
			55363,
			29144
		],
		[
			-6,
			21
		]
	],
	[
		[
			55357,
			29165
		],
		[
			96,
			-41
		]
	],
	[
		[
			55766,
			29124
		],
		[
			6,
			-31
		]
	],
	[
		[
			55772,
			29093
		],
		[
			-24,
			10
		]
	],
	[
		[
			55748,
			29103
		],
		[
			-6,
			0
		]
	],
	[
		[
			55742,
			29103
		],
		[
			-12,
			0
		]
	],
	[
		[
			55730,
			29103
		],
		[
			0,
			10
		]
	],
	[
		[
			55730,
			29113
		],
		[
			-12,
			-20
		]
	],
	[
		[
			55718,
			29093
		],
		[
			-6,
			0
		]
	],
	[
		[
			55712,
			29093
		],
		[
			-18,
			10
		]
	],
	[
		[
			55694,
			29103
		],
		[
			-6,
			10
		]
	],
	[
		[
			55688,
			29113
		],
		[
			-12,
			-10
		]
	],
	[
		[
			55676,
			29103
		],
		[
			-6,
			10
		]
	],
	[
		[
			55670,
			29113
		],
		[
			-12,
			0
		]
	],
	[
		[
			55658,
			29113
		],
		[
			-6,
			11
		]
	],
	[
		[
			55646,
			29124
		],
		[
			18,
			51
		],
		[
			96,
			-20
		],
		[
			6,
			-31
		]
	],
	[
		[
			54912,
			29206
		],
		[
			42,
			-10
		]
	],
	[
		[
			54954,
			29196
		],
		[
			-6,
			-21
		]
	],
	[
		[
			54948,
			29175
		],
		[
			0,
			-10
		]
	],
	[
		[
			54948,
			29165
		],
		[
			-12,
			-21
		]
	],
	[
		[
			54936,
			29144
		],
		[
			0,
			-10
		]
	],
	[
		[
			54936,
			29134
		],
		[
			-12,
			0
		]
	],
	[
		[
			54924,
			29134
		],
		[
			-24,
			0
		]
	],
	[
		[
			54888,
			29144
		],
		[
			0,
			11
		]
	],
	[
		[
			54888,
			29155
		],
		[
			0,
			20
		]
	],
	[
		[
			54888,
			29175
		],
		[
			24,
			31
		]
	],
	[
		[
			55820,
			29186
		],
		[
			0,
			-11
		]
	],
	[
		[
			55820,
			29175
		],
		[
			0,
			11
		]
	],
	[
		[
			55838,
			29175
		],
		[
			-12,
			0
		]
	],
	[
		[
			55826,
			29175
		],
		[
			0,
			11
		],
		[
			12,
			-11
		]
	],
	[
		[
			55123,
			29155
		],
		[
			-6,
			-11
		]
	],
	[
		[
			55117,
			29144
		],
		[
			-36,
			-20
		]
	],
	[
		[
			55081,
			29124
		],
		[
			-36,
			20
		]
	],
	[
		[
			55045,
			29144
		],
		[
			-6,
			-10
		]
	],
	[
		[
			55039,
			29134
		],
		[
			-13,
			-10
		]
	],
	[
		[
			55026,
			29124
		],
		[
			-18,
			0
		]
	],
	[
		[
			55008,
			29124
		],
		[
			-24,
			0
		]
	],
	[
		[
			54984,
			29124
		],
		[
			-6,
			0
		]
	],
	[
		[
			54978,
			29124
		],
		[
			-24,
			10
		]
	],
	[
		[
			54954,
			29134
		],
		[
			-24,
			-10
		]
	],
	[
		[
			54930,
			29134
		],
		[
			6,
			0
		]
	],
	[
		[
			54936,
			29134
		],
		[
			0,
			10
		]
	],
	[
		[
			54936,
			29144
		],
		[
			12,
			21
		]
	],
	[
		[
			54948,
			29165
		],
		[
			0,
			10
		]
	],
	[
		[
			54954,
			29196
		],
		[
			30,
			-10
		]
	],
	[
		[
			54984,
			29186
		],
		[
			36,
			10
		]
	],
	[
		[
			55020,
			29196
		],
		[
			31,
			21
		]
	],
	[
		[
			55051,
			29217
		],
		[
			72,
			-62
		]
	],
	[
		[
			55051,
			29217
		],
		[
			-31,
			-21
		]
	],
	[
		[
			55020,
			29196
		],
		[
			-36,
			-10
		]
	],
	[
		[
			54984,
			29186
		],
		[
			-72,
			20
		]
	],
	[
		[
			54912,
			29206
		],
		[
			-24,
			-31
		]
	],
	[
		[
			54888,
			29175
		],
		[
			0,
			-20
		]
	],
	[
		[
			54888,
			29155
		],
		[
			-6,
			-11
		]
	],
	[
		[
			54882,
			29144
		],
		[
			-54,
			-10
		],
		[
			12,
			83
		],
		[
			60,
			93
		],
		[
			78,
			-21
		],
		[
			18,
			-72
		],
		[
			55,
			0
		]
	],
	[
		[
			59295,
			26907
		],
		[
			-48,
			-62
		]
	],
	[
		[
			59247,
			26845
		],
		[
			-42,
			-21
		]
	],
	[
		[
			59205,
			26824
		],
		[
			-72,
			0
		],
		[
			-108,
			-51
		]
	],
	[
		[
			59025,
			26773
		],
		[
			-18,
			-42
		]
	],
	[
		[
			59001,
			26721
		],
		[
			-48,
			-31
		]
	],
	[
		[
			58953,
			26690
		],
		[
			-54,
			10
		],
		[
			-55,
			-21
		],
		[
			-42,
			42
		],
		[
			-6,
			0
		]
	],
	[
		[
			58790,
			26731
		],
		[
			0,
			-10
		]
	],
	[
		[
			58796,
			26721
		],
		[
			48,
			-52
		],
		[
			-30,
			-41
		],
		[
			30,
			-52
		],
		[
			-6,
			-62
		],
		[
			-48,
			-11
		]
	],
	[
		[
			58772,
			26524
		],
		[
			-24,
			0
		]
	],
	[
		[
			58748,
			26524
		],
		[
			-48,
			0
		]
	],
	[
		[
			58694,
			26545
		],
		[
			-60,
			41
		],
		[
			-42,
			-10
		]
	],
	[
		[
			58586,
			26576
		],
		[
			-24,
			10
		]
	],
	[
		[
			58562,
			26586
		],
		[
			-54,
			-21
		]
	],
	[
		[
			58508,
			26565
		],
		[
			-12,
			52
		]
	],
	[
		[
			58496,
			26617
		],
		[
			-36,
			11
		]
	],
	[
		[
			58460,
			26628
		],
		[
			6,
			-11
		]
	],
	[
		[
			58466,
			26617
		],
		[
			-6,
			0
		]
	],
	[
		[
			58460,
			26628
		],
		[
			-6,
			-11
		]
	],
	[
		[
			58454,
			26617
		],
		[
			-36,
			-41
		],
		[
			-49,
			62
		]
	],
	[
		[
			58369,
			26638
		],
		[
			-36,
			104
		],
		[
			-24,
			-32
		]
	],
	[
		[
			58309,
			26710
		],
		[
			-90,
			-20
		]
	],
	[
		[
			58219,
			26690
		],
		[
			-12,
			-73
		]
	],
	[
		[
			58207,
			26617
		],
		[
			-30,
			-31
		]
	],
	[
		[
			58177,
			26586
		],
		[
			-12,
			0
		]
	],
	[
		[
			58165,
			26586
		],
		[
			-54,
			11
		]
	],
	[
		[
			58111,
			26597
		],
		[
			-36,
			31
		]
	],
	[
		[
			58087,
			26638
		],
		[
			30,
			62
		]
	],
	[
		[
			54407,
			29289
		],
		[
			102,
			-31
		],
		[
			97,
			0
		],
		[
			90,
			42
		],
		[
			60,
			-11
		],
		[
			54,
			-41
		],
		[
			0,
			-135
		],
		[
			108,
			-10
		]
	],
	[
		[
			54918,
			29103
		],
		[
			6,
			10
		]
	],
	[
		[
			54924,
			29113
		],
		[
			30,
			21
		]
	],
	[
		[
			54954,
			29134
		],
		[
			24,
			-10
		]
	],
	[
		[
			54984,
			29124
		],
		[
			24,
			0
		]
	],
	[
		[
			55008,
			29124
		],
		[
			18,
			0
		]
	],
	[
		[
			55026,
			29124
		],
		[
			13,
			10
		]
	],
	[
		[
			55039,
			29134
		],
		[
			6,
			10
		]
	],
	[
		[
			55045,
			29144
		],
		[
			36,
			-20
		]
	],
	[
		[
			55081,
			29124
		],
		[
			36,
			20
		]
	],
	[
		[
			55117,
			29144
		],
		[
			6,
			11
		]
	],
	[
		[
			55123,
			29155
		],
		[
			84,
			31
		],
		[
			84,
			-31
		],
		[
			66,
			10
		]
	],
	[
		[
			55363,
			29144
		],
		[
			0,
			-10
		]
	],
	[
		[
			55363,
			29134
		],
		[
			0,
			-10
		]
	],
	[
		[
			55363,
			29124
		],
		[
			48,
			0
		]
	],
	[
		[
			55423,
			29134
		],
		[
			12,
			0
		]
	],
	[
		[
			55435,
			29134
		],
		[
			6,
			-10
		]
	],
	[
		[
			55447,
			29124
		],
		[
			6,
			0
		]
	],
	[
		[
			55453,
			29124
		],
		[
			-12,
			0
		]
	],
	[
		[
			55441,
			29124
		],
		[
			79,
			41
		],
		[
			66,
			0
		],
		[
			42,
			-62
		]
	],
	[
		[
			55628,
			29103
		],
		[
			36,
			-10
		]
	],
	[
		[
			55664,
			29113
		],
		[
			6,
			0
		]
	],
	[
		[
			55670,
			29113
		],
		[
			6,
			-10
		]
	],
	[
		[
			55676,
			29103
		],
		[
			12,
			10
		]
	],
	[
		[
			55694,
			29103
		],
		[
			18,
			-10
		]
	],
	[
		[
			55718,
			29093
		],
		[
			12,
			20
		]
	],
	[
		[
			55730,
			29113
		],
		[
			0,
			-10
		]
	],
	[
		[
			55730,
			29103
		],
		[
			12,
			0
		]
	],
	[
		[
			55748,
			29103
		],
		[
			24,
			-10
		]
	],
	[
		[
			55766,
			29124
		],
		[
			54,
			62
		]
	],
	[
		[
			55820,
			29175
		],
		[
			6,
			0
		]
	],
	[
		[
			55826,
			29175
		],
		[
			12,
			0
		]
	],
	[
		[
			55838,
			29175
		],
		[
			-96,
			83
		],
		[
			259,
			-93
		],
		[
			336,
			-104
		],
		[
			145,
			-31
		],
		[
			228,
			-31
		],
		[
			156,
			0
		],
		[
			259,
			-41
		],
		[
			282,
			-83
		],
		[
			49,
			-31
		],
		[
			198,
			-93
		],
		[
			54,
			-52
		],
		[
			211,
			-135
		],
		[
			144,
			-83
		],
		[
			108,
			-93
		],
		[
			198,
			-196
		],
		[
			295,
			-239
		],
		[
			259,
			-228
		],
		[
			162,
			-113
		],
		[
			42,
			-63
		],
		[
			60,
			-41
		],
		[
			289,
			-300
		],
		[
			60,
			-94
		],
		[
			36,
			-31
		]
	],
	[
		[
			57522,
			25892
		],
		[
			6,
			11
		]
	],
	[
		[
			57528,
			25903
		],
		[
			-6,
			20
		]
	],
	[
		[
			57522,
			25923
		],
		[
			0,
			-31
		]
	],
	[
		[
			57552,
			25954
		],
		[
			-36,
			-20
		]
	],
	[
		[
			57516,
			25934
		],
		[
			6,
			-11
		]
	],
	[
		[
			57522,
			25923
		],
		[
			6,
			-20
		]
	],
	[
		[
			57522,
			25892
		],
		[
			-12,
			-10
		]
	],
	[
		[
			57510,
			25882
		],
		[
			-18,
			0
		]
	],
	[
		[
			57492,
			25882
		],
		[
			-18,
			-21
		]
	],
	[
		[
			57474,
			25861
		],
		[
			-30,
			-41
		],
		[
			-151,
			-125
		],
		[
			-66,
			63
		],
		[
			-42,
			-42
		],
		[
			-36,
			21
		],
		[
			-30,
			62
		],
		[
			-54,
			31
		],
		[
			12,
			73
		],
		[
			-48,
			-11
		],
		[
			-36,
			52
		],
		[
			24,
			62
		],
		[
			-30,
			42
		],
		[
			-55,
			-63
		]
	],
	[
		[
			56932,
			25985
		],
		[
			-24,
			83
		],
		[
			-54,
			42
		],
		[
			-6,
			52
		],
		[
			115,
			-11
		],
		[
			66,
			-31
		],
		[
			78,
			73
		]
	],
	[
		[
			59392,
			25499
		],
		[
			-37,
			10
		],
		[
			-30,
			-41
		],
		[
			0,
			-94
		],
		[
			-60,
			-82
		],
		[
			-48,
			-11
		]
	],
	[
		[
			59217,
			25281
		],
		[
			-36,
			-31
		]
	],
	[
		[
			59181,
			25250
		],
		[
			-12,
			-41
		]
	],
	[
		[
			59169,
			25209
		],
		[
			18,
			-31
		],
		[
			60,
			0
		]
	],
	[
		[
			59253,
			25178
		],
		[
			0,
			-73
		],
		[
			-228,
			218
		],
		[
			54,
			20
		]
	],
	[
		[
			59079,
			25343
		],
		[
			30,
			21
		]
	],
	[
		[
			59109,
			25364
		],
		[
			48,
			73
		]
	],
	[
		[
			59157,
			25437
		],
		[
			30,
			20
		]
	],
	[
		[
			59187,
			25457
		],
		[
			30,
			42
		],
		[
			36,
			-11
		]
	],
	[
		[
			59271,
			25499
		],
		[
			18,
			20
		]
	],
	[
		[
			59289,
			25519
		],
		[
			18,
			42
		]
	],
	[
		[
			59307,
			25561
		],
		[
			48,
			10
		],
		[
			43,
			52
		],
		[
			24,
			-73
		],
		[
			-12,
			-41
		]
	],
	[
		[
			57516,
			25934
		],
		[
			24,
			0
		]
	],
	[
		[
			57540,
			25934
		],
		[
			-18,
			-11
		]
	],
	[
		[
			57474,
			25861
		],
		[
			6,
			11
		]
	],
	[
		[
			57480,
			25872
		],
		[
			12,
			10
		]
	],
	[
		[
			57510,
			25882
		],
		[
			12,
			10
		]
	],
	[
		[
			57522,
			25923
		],
		[
			18,
			11
		]
	],
	[
		[
			57540,
			25934
		],
		[
			36,
			31
		]
	],
	[
		[
			57654,
			25975
		],
		[
			6,
			-10
		]
	],
	[
		[
			57660,
			25965
		],
		[
			18,
			0
		]
	],
	[
		[
			57678,
			25965
		],
		[
			72,
			-11
		]
	],
	[
		[
			57750,
			25954
		],
		[
			54,
			11
		],
		[
			36,
			-31
		]
	],
	[
		[
			57840,
			25934
		],
		[
			30,
			-145
		],
		[
			42,
			-11
		]
	],
	[
		[
			57912,
			25778
		],
		[
			67,
			31
		],
		[
			30,
			63
		]
	],
	[
		[
			58009,
			25872
		],
		[
			30,
			51
		]
	],
	[
		[
			58039,
			25923
		],
		[
			48,
			11
		]
	],
	[
		[
			58099,
			25944
		],
		[
			60,
			-31
		]
	],
	[
		[
			58159,
			25913
		],
		[
			42,
			-83
		]
	],
	[
		[
			58201,
			25830
		],
		[
			36,
			-52
		]
	],
	[
		[
			58237,
			25778
		],
		[
			54,
			-31
		]
	],
	[
		[
			58291,
			25747
		],
		[
			42,
			-62
		]
	],
	[
		[
			58333,
			25685
		],
		[
			36,
			-62
		]
	],
	[
		[
			58381,
			25613
		],
		[
			85,
			10
		]
	],
	[
		[
			58466,
			25623
		],
		[
			24,
			-31
		]
	],
	[
		[
			58490,
			25592
		],
		[
			24,
			-93
		],
		[
			30,
			-31
		]
	],
	[
		[
			58544,
			25468
		],
		[
			18,
			-11
		],
		[
			102,
			52
		]
	],
	[
		[
			58664,
			25509
		],
		[
			30,
			-72
		],
		[
			-12,
			-52
		],
		[
			42,
			-31
		]
	],
	[
		[
			58724,
			25354
		],
		[
			36,
			31
		]
	],
	[
		[
			58778,
			25364
		],
		[
			12,
			-41
		]
	],
	[
		[
			58790,
			25323
		],
		[
			84,
			31
		],
		[
			67,
			0
		]
	],
	[
		[
			58941,
			25354
		],
		[
			48,
			-11
		],
		[
			300,
			-279
		],
		[
			12,
			-21
		]
	],
	[
		[
			59301,
			25043
		],
		[
			0,
			-31
		]
	],
	[
		[
			59301,
			25012
		],
		[
			6,
			-10
		]
	],
	[
		[
			59307,
			25002
		],
		[
			91,
			-52
		]
	],
	[
		[
			59398,
			24950
		],
		[
			12,
			-21
		]
	],
	[
		[
			59410,
			24929
		],
		[
			0,
			-10
		]
	],
	[
		[
			59410,
			24919
		],
		[
			-12,
			-42
		]
	],
	[
		[
			59398,
			24877
		],
		[
			66,
			-72
		]
	],
	[
		[
			59464,
			24805
		],
		[
			12,
			0
		]
	],
	[
		[
			59476,
			24805
		],
		[
			78,
			31
		]
	],
	[
		[
			59554,
			24836
		],
		[
			6,
			-10
		]
	],
	[
		[
			59560,
			24826
		],
		[
			6,
			-11
		]
	],
	[
		[
			59566,
			24815
		],
		[
			12,
			-41
		]
	],
	[
		[
			59578,
			24774
		],
		[
			24,
			-11
		]
	],
	[
		[
			59602,
			24763
		],
		[
			6,
			-51
		],
		[
			-54,
			-73
		]
	],
	[
		[
			59554,
			24639
		],
		[
			-6,
			-10
		]
	],
	[
		[
			59548,
			24629
		],
		[
			0,
			-42
		]
	],
	[
		[
			59548,
			24587
		],
		[
			-48,
			-31
		]
	],
	[
		[
			59500,
			24556
		],
		[
			-30,
			-62
		]
	],
	[
		[
			59470,
			24494
		],
		[
			-78,
			31
		]
	],
	[
		[
			59392,
			24525
		],
		[
			-6,
			-21
		]
	],
	[
		[
			59386,
			24504
		],
		[
			-43,
			-20
		]
	],
	[
		[
			59343,
			24484
		],
		[
			-54,
			-42
		],
		[
			-114,
			42
		]
	],
	[
		[
			59175,
			24484
		],
		[
			-54,
			62
		]
	],
	[
		[
			59121,
			24546
		],
		[
			-6,
			21
		]
	],
	[
		[
			59115,
			24567
		],
		[
			-60,
			31
		]
	],
	[
		[
			59055,
			24598
		],
		[
			-18,
			-21
		]
	],
	[
		[
			59037,
			24577
		],
		[
			-54,
			-10
		]
	],
	[
		[
			58983,
			24567
		],
		[
			-42,
			-52
		]
	],
	[
		[
			58941,
			24515
		],
		[
			0,
			-11
		]
	],
	[
		[
			58941,
			24504
		],
		[
			-24,
			-31
		]
	],
	[
		[
			58917,
			24473
		],
		[
			0,
			-10
		]
	],
	[
		[
			58917,
			24463
		],
		[
			-43,
			-52
		]
	],
	[
		[
			58874,
			24411
		],
		[
			-18,
			0
		]
	],
	[
		[
			58856,
			24411
		],
		[
			-12,
			0
		]
	],
	[
		[
			58844,
			24411
		],
		[
			-6,
			11
		]
	],
	[
		[
			58838,
			24422
		],
		[
			-30,
			20
		]
	],
	[
		[
			58808,
			24442
		],
		[
			-12,
			0
		]
	],
	[
		[
			58796,
			24442
		],
		[
			-18,
			21
		]
	],
	[
		[
			58778,
			24463
		],
		[
			-12,
			21
		]
	],
	[
		[
			58766,
			24484
		],
		[
			-18,
			10
		]
	],
	[
		[
			58748,
			24494
		],
		[
			-42,
			0
		]
	],
	[
		[
			58706,
			24494
		],
		[
			-18,
			-21
		]
	],
	[
		[
			58688,
			24473
		],
		[
			6,
			0
		]
	],
	[
		[
			58694,
			24473
		],
		[
			-12,
			-31
		]
	],
	[
		[
			58682,
			24442
		],
		[
			-12,
			0
		]
	],
	[
		[
			58670,
			24442
		],
		[
			-12,
			11
		]
	],
	[
		[
			58658,
			24453
		],
		[
			-48,
			-11
		]
	],
	[
		[
			58610,
			24442
		],
		[
			-12,
			0
		]
	],
	[
		[
			58598,
			24442
		],
		[
			-42,
			21
		]
	],
	[
		[
			58556,
			24463
		],
		[
			-6,
			21
		]
	],
	[
		[
			58550,
			24484
		],
		[
			-18,
			-11
		]
	],
	[
		[
			58532,
			24473
		],
		[
			6,
			21
		]
	],
	[
		[
			58538,
			24494
		],
		[
			-12,
			0
		]
	],
	[
		[
			58526,
			24494
		],
		[
			-24,
			10
		]
	],
	[
		[
			58502,
			24504
		],
		[
			-12,
			0
		]
	],
	[
		[
			58490,
			24504
		],
		[
			-42,
			32
		]
	],
	[
		[
			58448,
			24536
		],
		[
			-85,
			-63
		],
		[
			-42,
			-72
		],
		[
			-72,
			-21
		],
		[
			-48,
			21
		],
		[
			-18,
			62
		],
		[
			-48,
			62
		],
		[
			-60,
			-21
		],
		[
			-30,
			-72
		],
		[
			126,
			-52
		],
		[
			12,
			-72
		],
		[
			-54,
			-21
		],
		[
			-102,
			-10
		],
		[
			-96,
			-73
		],
		[
			6,
			-31
		],
		[
			-121,
			-31
		],
		[
			-78,
			-62
		],
		[
			18,
			-104
		],
		[
			-72,
			-41
		],
		[
			-6,
			-42
		]
	],
	[
		[
			57678,
			23893
		],
		[
			-66,
			-20
		],
		[
			-30,
			-83
		],
		[
			-84,
			-52
		],
		[
			-54,
			31
		],
		[
			-109,
			0
		],
		[
			-90,
			-83
		],
		[
			-78,
			-103
		],
		[
			-60,
			-52
		],
		[
			-90,
			-10
		],
		[
			-103,
			-83
		],
		[
			-138,
			62
		],
		[
			-48,
			-31
		],
		[
			-30,
			20
		],
		[
			-126,
			0
		],
		[
			-96,
			63
		],
		[
			-97,
			0
		],
		[
			-66,
			41
		],
		[
			-36,
			-10
		],
		[
			-126,
			20
		],
		[
			-24,
			-10
		],
		[
			-60,
			62
		],
		[
			-72,
			-21
		],
		[
			-151,
			21
		]
	],
	[
		[
			46062,
			24370
		],
		[
			-30,
			0
		],
		[
			-36,
			114
		],
		[
			12,
			83
		],
		[
			-60,
			31
		],
		[
			-55,
			-21
		],
		[
			-24,
			-83
		],
		[
			-66,
			-72
		],
		[
			-60,
			-31
		],
		[
			-18,
			31
		],
		[
			-84,
			-21
		],
		[
			-24,
			114
		],
		[
			-96,
			0
		],
		[
			-78,
			21
		],
		[
			-85,
			217
		],
		[
			-36,
			0
		],
		[
			-90,
			104
		],
		[
			72,
			93
		]
	],
	[
		[
			46002,
			25354
		],
		[
			54,
			-62
		],
		[
			-18,
			-73
		],
		[
			126,
			-62
		],
		[
			48,
			-52
		],
		[
			18,
			-83
		],
		[
			-102,
			-51
		],
		[
			-48,
			10
		],
		[
			-78,
			-62
		],
		[
			18,
			-52
		],
		[
			66,
			10
		],
		[
			18,
			31
		],
		[
			120,
			42
		],
		[
			84,
			-42
		],
		[
			54,
			21
		],
		[
			25,
			-72
		],
		[
			66,
			-83
		],
		[
			-24,
			-104
		],
		[
			-157,
			-62
		],
		[
			-24,
			-52
		],
		[
			-12,
			-103
		],
		[
			-54,
			0
		],
		[
			-84,
			-31
		],
		[
			-36,
			-52
		]
	],
	[
		[
			44697,
			24422
		],
		[
			-30,
			-63
		],
		[
			12,
			-103
		],
		[
			144,
			-31
		],
		[
			78,
			-42
		],
		[
			-54,
			-103
		],
		[
			-66,
			-31
		],
		[
			-24,
			-156
		],
		[
			30,
			-31
		],
		[
			66,
			21
		],
		[
			72,
			-62
		],
		[
			67,
			-31
		],
		[
			54,
			0
		],
		[
			42,
			-83
		],
		[
			12,
			-73
		],
		[
			30,
			-31
		],
		[
			120,
			-62
		],
		[
			48,
			-41
		],
		[
			48,
			-145
		]
	],
	[
		[
			45346,
			23355
		],
		[
			6,
			-135
		],
		[
			-30,
			-83
		],
		[
			-96,
			-83
		],
		[
			-36,
			-72
		],
		[
			24,
			-114
		],
		[
			30,
			-62
		],
		[
			-18,
			-124
		]
	],
	[
		[
			45226,
			22682
		],
		[
			-60,
			-11
		],
		[
			-42,
			62
		],
		[
			-168,
			11
		],
		[
			-49,
			-31
		],
		[
			-42,
			41
		],
		[
			-48,
			-21
		],
		[
			-30,
			-51
		],
		[
			-54,
			51
		],
		[
			-90,
			-41
		],
		[
			-72,
			0
		],
		[
			-36,
			-62
		],
		[
			-48,
			-11
		],
		[
			-49,
			-41
		],
		[
			-90,
			-41
		]
	],
	[
		[
			44348,
			22537
		],
		[
			-60,
			-21
		],
		[
			-102,
			0
		],
		[
			-48,
			-62
		],
		[
			-66,
			-31
		],
		[
			-30,
			-52
		],
		[
			-121,
			-42
		],
		[
			-36,
			0
		],
		[
			-42,
			-72
		],
		[
			-48,
			10
		],
		[
			-54,
			-41
		],
		[
			66,
			-104
		],
		[
			96,
			-186
		],
		[
			-36,
			-31
		],
		[
			-72,
			31
		],
		[
			-150,
			-21
		],
		[
			-42,
			-41
		],
		[
			-18,
			-93
		],
		[
			-109,
			-11
		],
		[
			-84,
			52
		],
		[
			12,
			-72
		],
		[
			-114,
			-94
		],
		[
			-72,
			31
		],
		[
			6,
			-62
		],
		[
			66,
			-31
		],
		[
			24,
			-134
		],
		[
			-168,
			-21
		],
		[
			-60,
			10
		],
		[
			-6,
			0
		],
		[
			-42,
			0
		],
		[
			12,
			145
		],
		[
			-49,
			0
		],
		[
			-18,
			-41
		],
		[
			-78,
			41
		],
		[
			-66,
			11
		],
		[
			-48,
			-114
		],
		[
			-60,
			51
		],
		[
			-54,
			-10
		],
		[
			-24,
			104
		],
		[
			-114,
			31
		],
		[
			6,
			31
		],
		[
			-43,
			197
		]
	],
	[
		[
			42502,
			21895
		],
		[
			0,
			41
		],
		[
			109,
			0
		],
		[
			42,
			21
		],
		[
			-36,
			165
		],
		[
			-66,
			42
		],
		[
			-67,
			176
		],
		[
			103,
			-31
		],
		[
			0,
			52
		],
		[
			84,
			72
		],
		[
			66,
			-10
		],
		[
			42,
			51
		]
	],
	[
		[
			42779,
			22474
		],
		[
			6,
			11
		],
		[
			6,
			0
		],
		[
			36,
			41
		]
	],
	[
		[
			42827,
			22526
		],
		[
			42,
			31
		]
	],
	[
		[
			42869,
			22557
		],
		[
			12,
			21
		]
	],
	[
		[
			42881,
			22578
		],
		[
			-12,
			41
		]
	],
	[
		[
			42869,
			22619
		],
		[
			-30,
			114
		]
	],
	[
		[
			42839,
			22733
		],
		[
			-18,
			73
		],
		[
			-30,
			10
		],
		[
			-6,
			0
		],
		[
			0,
			42
		],
		[
			66,
			114
		],
		[
			66,
			82
		],
		[
			-126,
			52
		],
		[
			-96,
			11
		],
		[
			-78,
			62
		],
		[
			18,
			83
		],
		[
			144,
			93
		],
		[
			54,
			10
		]
	],
	[
		[
			42833,
			23365
		],
		[
			84,
			11
		],
		[
			78,
			41
		],
		[
			97,
			10
		],
		[
			42,
			62
		],
		[
			-175,
			332
		]
	],
	[
		[
			46374,
			22723
		],
		[
			-66,
			104
		],
		[
			-84,
			51
		],
		[
			-18,
			208
		],
		[
			36,
			176
		],
		[
			54,
			51
		],
		[
			6,
			104
		],
		[
			-54,
			72
		]
	],
	[
		[
			46248,
			23489
		],
		[
			60,
			63
		],
		[
			-24,
			155
		]
	],
	[
		[
			46284,
			23707
		],
		[
			24,
			114
		],
		[
			30,
			52
		],
		[
			-48,
			41
		],
		[
			18,
			52
		],
		[
			6,
			124
		],
		[
			-78,
			83
		],
		[
			-72,
			31
		],
		[
			-66,
			-21
		],
		[
			-12,
			104
		],
		[
			-24,
			83
		]
	],
	[
		[
			46248,
			23489
		],
		[
			-24,
			-31
		],
		[
			-126,
			-93
		],
		[
			-18,
			21
		],
		[
			-78,
			-10
		],
		[
			-66,
			10
		],
		[
			-30,
			72
		],
		[
			-67,
			52
		],
		[
			-96,
			0
		],
		[
			-72,
			-52
		],
		[
			-78,
			-93
		],
		[
			-144,
			11
		],
		[
			-49,
			31
		],
		[
			-54,
			-52
		]
	],
	[
		[
			45226,
			22682
		],
		[
			48,
			-135
		]
	],
	[
		[
			45274,
			22547
		],
		[
			-6,
			-21
		],
		[
			6,
			0
		],
		[
			36,
			-41
		],
		[
			18,
			-114
		]
	],
	[
		[
			45328,
			22371
		],
		[
			-126,
			-10
		],
		[
			-114,
			-83
		],
		[
			-42,
			-218
		],
		[
			-145,
			-41
		],
		[
			-60,
			-52
		],
		[
			-12,
			-41
		],
		[
			-78,
			-21
		],
		[
			-18,
			-62
		],
		[
			-132,
			134
		],
		[
			-108,
			73
		],
		[
			-85,
			31
		],
		[
			-96,
			62
		],
		[
			-12,
			197
		],
		[
			30,
			21
		],
		[
			-6,
			145
		],
		[
			24,
			31
		]
	],
	[
		[
			45328,
			22371
		],
		[
			72,
			41
		],
		[
			61,
			-10
		],
		[
			36,
			31
		],
		[
			120,
			-41
		],
		[
			84,
			-63
		],
		[
			18,
			-72
		],
		[
			54,
			-83
		],
		[
			-18,
			-52
		],
		[
			36,
			-176
		],
		[
			36,
			-51
		]
	],
	[
		[
			43446,
			20237
		],
		[
			-42,
			-82
		],
		[
			-36,
			-21
		],
		[
			-18,
			-73
		],
		[
			-36,
			11
		],
		[
			-66,
			-52
		],
		[
			-66,
			10
		],
		[
			-72,
			-114
		],
		[
			-84,
			0
		],
		[
			-37,
			-41
		],
		[
			-192,
			41
		],
		[
			-66,
			42
		],
		[
			-114,
			-52
		],
		[
			-36,
			21
		],
		[
			-79,
			0
		],
		[
			-18,
			145
		],
		[
			36,
			83
		],
		[
			0,
			72
		],
		[
			-36,
			52
		],
		[
			-6,
			62
		],
		[
			-42,
			52
		],
		[
			-12,
			72
		],
		[
			-42,
			62
		],
		[
			-54,
			42
		],
		[
			54,
			134
		],
		[
			12,
			135
		],
		[
			-108,
			0
		],
		[
			-12,
			73
		],
		[
			72,
			51
		],
		[
			120,
			0
		],
		[
			103,
			52
		],
		[
			42,
			-21
		],
		[
			84,
			0
		],
		[
			-72,
			125
		],
		[
			-97,
			72
		],
		[
			-144,
			218
		],
		[
			-24,
			52
		],
		[
			-60,
			62
		],
		[
			-48,
			103
		],
		[
			-42,
			52
		]
	],
	[
		[
			42208,
			21677
		],
		[
			18,
			83
		],
		[
			60,
			41
		],
		[
			30,
			83
		],
		[
			186,
			11
		]
	],
	[
		[
			38324,
			40558
		],
		[
			36,
			-52
		],
		[
			6,
			-73
		],
		[
			30,
			-51
		],
		[
			114,
			31
		],
		[
			54,
			-52
		],
		[
			54,
			-93
		],
		[
			-18,
			-94
		],
		[
			54,
			-72
		],
		[
			73,
			-31
		],
		[
			102,
			-10
		],
		[
			66,
			20
		],
		[
			60,
			-83
		],
		[
			24,
			-93
		],
		[
			138,
			-62
		],
		[
			30,
			-155
		],
		[
			127,
			-104
		],
		[
			-54,
			-72
		],
		[
			-24,
			-83
		],
		[
			-37,
			-11
		],
		[
			-72,
			-62
		],
		[
			0,
			-93
		],
		[
			109,
			-72
		],
		[
			36,
			-135
		],
		[
			60,
			10
		],
		[
			36,
			-52
		],
		[
			0,
			-62
		],
		[
			66,
			-62
		],
		[
			6,
			-41
		],
		[
			-42,
			-73
		],
		[
			48,
			-41
		],
		[
			-186,
			-135
		],
		[
			-61,
			-31
		],
		[
			-30,
			-62
		],
		[
			-78,
			-10
		]
	],
	[
		[
			39051,
			38497
		],
		[
			-6,
			82
		],
		[
			-90,
			-82
		],
		[
			-72,
			31
		],
		[
			-114,
			-73
		],
		[
			-127,
			31
		],
		[
			-96,
			-20
		],
		[
			-12,
			-73
		]
	],
	[
		[
			38534,
			38393
		],
		[
			30,
			-93
		],
		[
			-78,
			-73
		],
		[
			138,
			-134
		],
		[
			0,
			-73
		],
		[
			-156,
			-31
		],
		[
			-6,
			-62
		],
		[
			24,
			-62
		],
		[
			6,
			-83
		],
		[
			-36,
			-93
		],
		[
			-78,
			0
		],
		[
			-24,
			31
		],
		[
			-126,
			-11
		],
		[
			-61,
			-113
		],
		[
			-84,
			-83
		]
	],
	[
		[
			36508,
			41345
		],
		[
			84,
			-73
		],
		[
			78,
			21
		],
		[
			6,
			-62
		],
		[
			42,
			-62
		],
		[
			55,
			41
		],
		[
			126,
			62
		],
		[
			54,
			-10
		],
		[
			126,
			31
		],
		[
			78,
			-41
		],
		[
			54,
			0
		],
		[
			61,
			-83
		],
		[
			90,
			-94
		],
		[
			84,
			63
		],
		[
			36,
			-21
		],
		[
			42,
			21
		],
		[
			18,
			-94
		],
		[
			66,
			0
		],
		[
			90,
			73
		],
		[
			79,
			-10
		],
		[
			72,
			-104
		],
		[
			48,
			-21
		],
		[
			42,
			-52
		],
		[
			60,
			-20
		],
		[
			12,
			-135
		],
		[
			30,
			-10
		],
		[
			48,
			-124
		],
		[
			66,
			-21
		],
		[
			18,
			-52
		],
		[
			73,
			21
		],
		[
			24,
			-42
		],
		[
			54,
			11
		]
	],
	[
		[
			43915,
			43582
		],
		[
			54,
			-83
		],
		[
			49,
			-31
		],
		[
			0,
			-41
		],
		[
			108,
			-21
		],
		[
			48,
			31
		],
		[
			48,
			0
		],
		[
			54,
			-166
		],
		[
			-48,
			-41
		],
		[
			-36,
			20
		],
		[
			-114,
			-10
		],
		[
			-30,
			21
		],
		[
			-127,
			-21
		],
		[
			-6,
			0
		],
		[
			-36,
			-41
		],
		[
			-6,
			0
		],
		[
			-30,
			-21
		]
	],
	[
		[
			43843,
			43178
		],
		[
			-48,
			-83
		],
		[
			24,
			-52
		],
		[
			-12,
			-93
		],
		[
			-54,
			-62
		],
		[
			30,
			-83
		]
	],
	[
		[
			43783,
			42805
		],
		[
			-66,
			-62
		],
		[
			-66,
			0
		],
		[
			66,
			-93
		],
		[
			-48,
			-73
		],
		[
			66,
			-114
		],
		[
			6,
			-124
		],
		[
			-66,
			-21
		],
		[
			-42,
			-124
		],
		[
			-78,
			-166
		],
		[
			-103,
			-10
		],
		[
			-36,
			31
		],
		[
			24,
			62
		],
		[
			-12,
			62
		],
		[
			-72,
			-10
		],
		[
			-72,
			52
		],
		[
			-66,
			0
		],
		[
			-36,
			217
		],
		[
			-48,
			93
		],
		[
			-54,
			-51
		],
		[
			-54,
			0
		],
		[
			-109,
			-31
		],
		[
			-114,
			41
		],
		[
			-54,
			-21
		],
		[
			-72,
			-134
		],
		[
			-24,
			-73
		],
		[
			-54,
			0
		],
		[
			-6,
			-62
		],
		[
			42,
			-104
		],
		[
			66,
			-41
		],
		[
			0,
			-83
		],
		[
			-18,
			-72
		],
		[
			18,
			-62
		],
		[
			108,
			-114
		],
		[
			48,
			-94
		],
		[
			84,
			-331
		],
		[
			-54,
			-21
		],
		[
			-6,
			-72
		],
		[
			42,
			-52
		],
		[
			54,
			-21
		],
		[
			30,
			-145
		],
		[
			-36,
			-62
		],
		[
			55,
			-21
		],
		[
			24,
			-72
		],
		[
			66,
			10
		],
		[
			108,
			-62
		],
		[
			54,
			-10
		],
		[
			72,
			-93
		],
		[
			84,
			-42
		]
	],
	[
		[
			43434,
			40630
		],
		[
			115,
			31
		],
		[
			12,
			-62
		],
		[
			84,
			-31
		],
		[
			-30,
			-104
		],
		[
			60,
			-62
		],
		[
			120,
			-51
		],
		[
			30,
			-42
		],
		[
			102,
			-31
		],
		[
			67,
			-62
		],
		[
			54,
			-21
		],
		[
			30,
			-103
		],
		[
			-96,
			-166
		],
		[
			-109,
			10
		],
		[
			6,
			-83
		],
		[
			-66,
			-93
		],
		[
			0,
			-52
		],
		[
			84,
			-93
		],
		[
			-108,
			-93
		],
		[
			-6,
			-62
		]
	],
	[
		[
			43110,
			38942
		],
		[
			-187,
			135
		],
		[
			-54,
			-21
		],
		[
			0,
			93
		],
		[
			-36,
			104
		],
		[
			-72,
			10
		],
		[
			-30,
			-31
		],
		[
			-72,
			31
		],
		[
			-139,
			-10
		],
		[
			-24,
			114
		],
		[
			-36,
			41
		],
		[
			-6,
			114
		],
		[
			-36,
			10
		],
		[
			-102,
			166
		],
		[
			-120,
			-10
		],
		[
			-66,
			93
		],
		[
			0,
			93
		],
		[
			84,
			-21
		],
		[
			0,
			83
		],
		[
			-24,
			21
		],
		[
			12,
			124
		],
		[
			-30,
			21
		],
		[
			-12,
			104
		],
		[
			36,
			31
		],
		[
			12,
			82
		],
		[
			-66,
			32
		],
		[
			-91,
			134
		],
		[
			-186,
			93
		],
		[
			0,
			42
		],
		[
			-60,
			21
		],
		[
			-60,
			-11
		],
		[
			-30,
			31
		],
		[
			-84,
			11
		],
		[
			-36,
			62
		],
		[
			12,
			41
		],
		[
			-18,
			114
		],
		[
			-61,
			62
		],
		[
			-144,
			-83
		],
		[
			-54,
			135
		],
		[
			-48,
			-31
		],
		[
			-12,
			-135
		],
		[
			-90,
			-10
		],
		[
			-60,
			-52
		],
		[
			-127,
			-10
		],
		[
			-18,
			-31
		],
		[
			-84,
			-11
		],
		[
			-36,
			73
		],
		[
			-72,
			31
		],
		[
			-18,
			31
		],
		[
			-84,
			-31
		],
		[
			18,
			-52
		],
		[
			-12,
			-62
		],
		[
			-36,
			10
		],
		[
			-121,
			-51
		],
		[
			-42,
			41
		],
		[
			-6,
			73
		],
		[
			36,
			165
		],
		[
			-6,
			145
		],
		[
			-48,
			-10
		],
		[
			-54,
			41
		],
		[
			42,
			52
		],
		[
			-12,
			41
		],
		[
			-60,
			63
		],
		[
			-90,
			-31
		],
		[
			-18,
			51
		],
		[
			-48,
			-51
		],
		[
			-48,
			134
		]
	],
	[
		[
			40176,
			41386
		],
		[
			-61,
			114
		],
		[
			-48,
			31
		],
		[
			-12,
			83
		],
		[
			103,
			10
		],
		[
			66,
			-10
		],
		[
			90,
			41
		],
		[
			66,
			73
		]
	],
	[
		[
			40380,
			41728
		],
		[
			6,
			72
		],
		[
			36,
			42
		],
		[
			-6,
			93
		],
		[
			18,
			197
		],
		[
			-24,
			31
		],
		[
			198,
			62
		],
		[
			-36,
			62
		],
		[
			67,
			73
		],
		[
			84,
			-31
		],
		[
			30,
			31
		],
		[
			-6,
			62
		]
	],
	[
		[
			40747,
			42422
		],
		[
			60,
			93
		],
		[
			18,
			135
		],
		[
			60,
			52
		],
		[
			-60,
			41
		],
		[
			-30,
			72
		],
		[
			30,
			52
		],
		[
			78,
			52
		],
		[
			36,
			52
		],
		[
			30,
			145
		],
		[
			78,
			10
		],
		[
			30,
			31
		],
		[
			79,
			21
		],
		[
			48,
			-41
		],
		[
			114,
			0
		],
		[
			84,
			82
		]
	],
	[
		[
			41769,
			43468
		],
		[
			-12,
			72
		]
	],
	[
		[
			41775,
			43572
		],
		[
			30,
			10
		]
	],
	[
		[
			41805,
			43582
		],
		[
			24,
			-31
		]
	],
	[
		[
			41823,
			43520
		],
		[
			18,
			-21
		]
	],
	[
		[
			41841,
			43499
		],
		[
			78,
			21
		]
	],
	[
		[
			41913,
			43551
		],
		[
			12,
			21
		]
	],
	[
		[
			42995,
			38196
		],
		[
			-54,
			31
		],
		[
			-96,
			-10
		],
		[
			-66,
			93
		],
		[
			-66,
			-31
		],
		[
			-42,
			42
		],
		[
			-108,
			-11
		],
		[
			48,
			-62
		],
		[
			-6,
			-72
		],
		[
			-30,
			-42
		],
		[
			-6,
			-166
		],
		[
			-55,
			-51
		],
		[
			-102,
			93
		],
		[
			-96,
			21
		]
	],
	[
		[
			42316,
			38031
		],
		[
			66,
			41
		],
		[
			12,
			104
		],
		[
			-36,
			31
		]
	],
	[
		[
			42358,
			38207
		],
		[
			-6,
			103
		],
		[
			-48,
			0
		],
		[
			-96,
			52
		],
		[
			-66,
			0
		],
		[
			-48,
			41
		],
		[
			-36,
			-31
		],
		[
			-73,
			11
		],
		[
			-66,
			-21
		],
		[
			-24,
			31
		],
		[
			-84,
			-31
		],
		[
			-42,
			-41
		],
		[
			-6,
			-63
		],
		[
			-120,
			0
		],
		[
			-18,
			-31
		],
		[
			18,
			-114
		],
		[
			-48,
			0
		],
		[
			-73,
			-62
		],
		[
			-54,
			0
		],
		[
			-60,
			42
		],
		[
			-66,
			-11
		],
		[
			-54,
			42
		],
		[
			-54,
			0
		],
		[
			-30,
			-31
		],
		[
			-90,
			0
		],
		[
			-43,
			-31
		],
		[
			-42,
			20
		],
		[
			-72,
			0
		],
		[
			-24,
			-72
		],
		[
			-60,
			10
		],
		[
			-24,
			62
		],
		[
			-96,
			-10
		],
		[
			-18,
			-83
		],
		[
			-66,
			21
		],
		[
			-48,
			62
		],
		[
			-79,
			-62
		],
		[
			-120,
			41
		],
		[
			-72,
			0
		],
		[
			-6,
			52
		],
		[
			-144,
			-21
		],
		[
			-48,
			11
		],
		[
			-12,
			51
		],
		[
			-85,
			11
		],
		[
			-66,
			-11
		],
		[
			-6,
			-51
		],
		[
			-54,
			-11
		]
	],
	[
		[
			39929,
			38082
		],
		[
			-66,
			21
		],
		[
			-42,
			52
		],
		[
			0,
			41
		],
		[
			-66,
			-10
		],
		[
			-48,
			31
		],
		[
			-42,
			-41
		],
		[
			-55,
			82
		],
		[
			-90,
			0
		],
		[
			0,
			73
		],
		[
			-42,
			21
		],
		[
			-144,
			-11
		],
		[
			-102,
			21
		],
		[
			-12,
			-83
		],
		[
			-67,
			10
		],
		[
			-6,
			73
		],
		[
			-72,
			52
		],
		[
			-24,
			83
		]
	],
	[
		[
			38324,
			40558
		],
		[
			18,
			31
		],
		[
			126,
			103
		],
		[
			241,
			114
		],
		[
			78,
			0
		],
		[
			168,
			104
		],
		[
			54,
			-11
		],
		[
			36,
			104
		],
		[
			102,
			21
		],
		[
			91,
			41
		],
		[
			54,
			42
		],
		[
			54,
			0
		],
		[
			66,
			82
		],
		[
			-42,
			63
		],
		[
			138,
			-21
		],
		[
			253,
			-52
		],
		[
			96,
			83
		],
		[
			12,
			52
		],
		[
			108,
			31
		],
		[
			114,
			-11
		],
		[
			85,
			52
		]
	],
	[
		[
			46044,
			42443
		],
		[
			6,
			-11
		]
	],
	[
		[
			46050,
			42432
		],
		[
			12,
			0
		]
	],
	[
		[
			46062,
			42432
		],
		[
			18,
			-52
		],
		[
			168,
			83
		],
		[
			-12,
			-103
		],
		[
			36,
			-52
		],
		[
			-6,
			-52
		],
		[
			48,
			-93
		],
		[
			115,
			-114
		],
		[
			66,
			-21
		],
		[
			54,
			-103
		],
		[
			24,
			10
		],
		[
			42,
			-72
		]
	],
	[
		[
			46615,
			41863
		],
		[
			-60,
			-11
		],
		[
			-48,
			-62
		],
		[
			-60,
			-10
		],
		[
			-42,
			-62
		],
		[
			-49,
			-166
		],
		[
			0,
			-93
		],
		[
			37,
			-73
		],
		[
			0,
			-124
		],
		[
			42,
			-62
		],
		[
			6,
			-93
		],
		[
			-60,
			-249
		],
		[
			72,
			-52
		],
		[
			54,
			-10
		],
		[
			66,
			31
		],
		[
			54,
			0
		],
		[
			60,
			-73
		],
		[
			54,
			-10
		],
		[
			54,
			73
		],
		[
			127,
			-21
		],
		[
			60,
			62
		],
		[
			84,
			-21
		],
		[
			24,
			31
		],
		[
			108,
			52
		],
		[
			114,
			31
		],
		[
			61,
			0
		],
		[
			18,
			-93
		],
		[
			30,
			-52
		],
		[
			42,
			-186
		],
		[
			24,
			-52
		]
	],
	[
		[
			43783,
			42805
		],
		[
			186,
			31
		],
		[
			103,
			-72
		],
		[
			126,
			-114
		],
		[
			66,
			10
		],
		[
			84,
			52
		],
		[
			66,
			62
		],
		[
			133,
			-72
		],
		[
			54,
			0
		],
		[
			294,
			-125
		],
		[
			187,
			-62
		],
		[
			60,
			10
		],
		[
			90,
			-217
		],
		[
			66,
			-41
		],
		[
			84,
			0
		],
		[
			49,
			20
		],
		[
			48,
			52
		],
		[
			54,
			10
		],
		[
			36,
			42
		],
		[
			42,
			-93
		],
		[
			54,
			-31
		],
		[
			126,
			20
		],
		[
			18,
			52
		],
		[
			109,
			41
		],
		[
			12,
			63
		],
		[
			114,
			0
		]
	],
	[
		[
			45322,
			44193
		],
		[
			103,
			-21
		],
		[
			72,
			-124
		],
		[
			66,
			-21
		],
		[
			54,
			-134
		],
		[
			120,
			20
		],
		[
			24,
			42
		],
		[
			48,
			-21
		],
		[
			78,
			-93
		],
		[
			73,
			-21
		],
		[
			42,
			-135
		],
		[
			60,
			-51
		],
		[
			144,
			-42
		],
		[
			102,
			-41
		],
		[
			187,
			-31
		],
		[
			24,
			-42
		],
		[
			78,
			-20
		],
		[
			48,
			-52
		],
		[
			24,
			-73
		],
		[
			54,
			-62
		],
		[
			54,
			-31
		],
		[
			42,
			-62
		],
		[
			73,
			-52
		],
		[
			-12,
			-52
		],
		[
			-49,
			-41
		],
		[
			0,
			-104
		],
		[
			49,
			-82
		],
		[
			102,
			-83
		],
		[
			78,
			0
		],
		[
			96,
			-83
		],
		[
			66,
			-93
		],
		[
			102,
			-239
		],
		[
			85,
			-155
		],
		[
			0,
			-72
		],
		[
			48,
			0
		],
		[
			30,
			-270
		],
		[
			24,
			-41
		],
		[
			42,
			-135
		],
		[
			66,
			-41
		],
		[
			-12,
			-125
		],
		[
			60,
			-82
		],
		[
			66,
			-42
		],
		[
			48,
			-83
		],
		[
			18,
			-72
		],
		[
			79,
			-42
		],
		[
			66,
			21
		]
	],
	[
		[
			47944,
			41210
		],
		[
			12,
			-31
		],
		[
			72,
			-31
		],
		[
			66,
			-52
		],
		[
			229,
			-114
		],
		[
			-43,
			-31
		],
		[
			-30,
			-114
		],
		[
			61,
			-176
		],
		[
			60,
			-72
		],
		[
			114,
			-93
		],
		[
			108,
			-73
		],
		[
			78,
			-10
		]
	],
	[
		[
			44282,
			36570
		],
		[
			-42,
			21
		]
	],
	[
		[
			44240,
			36591
		],
		[
			-30,
			41
		],
		[
			-6,
			83
		],
		[
			-66,
			0
		],
		[
			-30,
			31
		]
	],
	[
		[
			44108,
			36746
		],
		[
			-42,
			-41
		],
		[
			-78,
			-42
		],
		[
			-55,
			52
		],
		[
			61,
			52
		]
	],
	[
		[
			43994,
			36767
		],
		[
			-31,
			62
		]
	],
	[
		[
			43963,
			36829
		],
		[
			-48,
			0
		],
		[
			-150,
			62
		]
	],
	[
		[
			43765,
			36891
		],
		[
			-12,
			11
		]
	],
	[
		[
			43753,
			36902
		],
		[
			102,
			41
		]
	],
	[
		[
			43855,
			36943
		],
		[
			-6,
			135
		],
		[
			24,
			72
		],
		[
			-66,
			0
		],
		[
			-72,
			52
		]
	],
	[
		[
			43735,
			37202
		],
		[
			-66,
			21
		]
	],
	[
		[
			43669,
			37223
		],
		[
			-30,
			31
		]
	],
	[
		[
			43639,
			37254
		],
		[
			54,
			93
		],
		[
			-48,
			21
		],
		[
			-30,
			-31
		]
	],
	[
		[
			43615,
			37337
		],
		[
			-24,
			31
		],
		[
			-72,
			31
		],
		[
			-79,
			-11
		],
		[
			-54,
			-31
		],
		[
			-30,
			94
		]
	],
	[
		[
			43356,
			37451
		],
		[
			36,
			0
		]
	],
	[
		[
			43392,
			37451
		],
		[
			18,
			62
		]
	],
	[
		[
			43410,
			37513
		],
		[
			0,
			83
		]
	],
	[
		[
			43410,
			37596
		],
		[
			-24,
			41
		]
	],
	[
		[
			43386,
			37637
		],
		[
			12,
			21
		]
	],
	[
		[
			43398,
			37658
		],
		[
			36,
			10
		]
	],
	[
		[
			43434,
			37668
		],
		[
			42,
			52
		],
		[
			67,
			41
		]
	],
	[
		[
			43543,
			37761
		],
		[
			6,
			31
		]
	],
	[
		[
			43549,
			37792
		],
		[
			18,
			21
		]
	],
	[
		[
			43567,
			37813
		],
		[
			6,
			21
		]
	],
	[
		[
			43519,
			37751
		],
		[
			-85,
			-83
		]
	],
	[
		[
			43434,
			37668
		],
		[
			-36,
			-10
		]
	],
	[
		[
			43398,
			37658
		],
		[
			-12,
			-21
		]
	],
	[
		[
			43386,
			37637
		],
		[
			24,
			-41
		]
	],
	[
		[
			43410,
			37596
		],
		[
			0,
			-83
		]
	],
	[
		[
			43410,
			37513
		],
		[
			-18,
			-62
		]
	],
	[
		[
			43392,
			37451
		],
		[
			-36,
			0
		]
	],
	[
		[
			43356,
			37451
		],
		[
			24,
			-94
		],
		[
			66,
			31
		],
		[
			97,
			0
		],
		[
			72,
			-51
		]
	],
	[
		[
			43615,
			37337
		],
		[
			72,
			31
		],
		[
			-48,
			-114
		]
	],
	[
		[
			43639,
			37254
		],
		[
			30,
			-31
		]
	],
	[
		[
			43669,
			37223
		],
		[
			66,
			-21
		]
	],
	[
		[
			43735,
			37202
		],
		[
			24,
			-31
		],
		[
			72,
			-31
		],
		[
			24,
			-197
		]
	],
	[
		[
			43855,
			36943
		],
		[
			-102,
			-10
		],
		[
			0,
			-31
		]
	],
	[
		[
			43765,
			36891
		],
		[
			102,
			-51
		],
		[
			96,
			-11
		]
	],
	[
		[
			43963,
			36829
		],
		[
			31,
			-62
		]
	],
	[
		[
			43994,
			36767
		],
		[
			-43,
			0
		],
		[
			-18,
			-72
		],
		[
			67,
			-32
		],
		[
			60,
			32
		],
		[
			48,
			51
		]
	],
	[
		[
			44108,
			36746
		],
		[
			18,
			-31
		],
		[
			72,
			-10
		],
		[
			6,
			-62
		],
		[
			36,
			-52
		]
	],
	[
		[
			44240,
			36591
		],
		[
			96,
			-52
		],
		[
			0,
			-93
		],
		[
			108,
			-41
		],
		[
			121,
			-11
		],
		[
			72,
			11
		],
		[
			42,
			-135
		]
	],
	[
		[
			44673,
			36260
		],
		[
			-30,
			10
		]
	],
	[
		[
			44643,
			36270
		],
		[
			-78,
			10
		],
		[
			-96,
			-52
		]
	],
	[
		[
			44469,
			36228
		],
		[
			-79,
			11
		]
	],
	[
		[
			44390,
			36239
		],
		[
			-24,
			0
		]
	],
	[
		[
			44366,
			36239
		],
		[
			-18,
			-104
		]
	],
	[
		[
			44348,
			36135
		],
		[
			-6,
			-31
		]
	],
	[
		[
			44342,
			36104
		],
		[
			-24,
			0
		]
	],
	[
		[
			44318,
			36104
		],
		[
			-6,
			31
		]
	],
	[
		[
			44312,
			36135
		],
		[
			6,
			21
		]
	],
	[
		[
			44318,
			36156
		],
		[
			-48,
			0
		]
	],
	[
		[
			44270,
			36156
		],
		[
			-48,
			-31
		]
	],
	[
		[
			44228,
			36094
		],
		[
			12,
			-21
		]
	],
	[
		[
			44240,
			36073
		],
		[
			-36,
			0
		]
	],
	[
		[
			44156,
			36073
		],
		[
			-48,
			10
		]
	],
	[
		[
			44102,
			36063
		],
		[
			-18,
			-11
		]
	],
	[
		[
			44060,
			36073
		],
		[
			-60,
			10
		]
	],
	[
		[
			43927,
			36063
		],
		[
			-36,
			-11
		]
	],
	[
		[
			43891,
			36052
		],
		[
			-30,
			31
		]
	],
	[
		[
			43849,
			36083
		],
		[
			-36,
			32
		]
	],
	[
		[
			43813,
			36115
		],
		[
			-48,
			51
		]
	],
	[
		[
			43765,
			36166
		],
		[
			-36,
			-31
		]
	],
	[
		[
			43843,
			35690
		],
		[
			-24,
			-52
		],
		[
			-102,
			-21
		],
		[
			-84,
			31
		],
		[
			-253,
			-82
		],
		[
			-6,
			-94
		],
		[
			-30,
			-10
		],
		[
			-96,
			93
		],
		[
			-42,
			11
		],
		[
			-90,
			-52
		],
		[
			-78,
			-21
		],
		[
			-97,
			62
		],
		[
			-60,
			0
		],
		[
			-18,
			-52
		],
		[
			6,
			-113
		],
		[
			-90,
			-32
		]
	],
	[
		[
			42779,
			35358
		],
		[
			-54,
			114
		],
		[
			-66,
			73
		],
		[
			-6,
			72
		],
		[
			48,
			63
		],
		[
			-30,
			113
		],
		[
			48,
			52
		],
		[
			6,
			73
		],
		[
			-12,
			114
		],
		[
			264,
			20
		],
		[
			0,
			52
		],
		[
			-96,
			42
		],
		[
			-12,
			62
		],
		[
			-72,
			31
		],
		[
			-102,
			-31
		],
		[
			-60,
			0
		],
		[
			-60,
			31
		],
		[
			-43,
			103
		],
		[
			-60,
			94
		],
		[
			-90,
			51
		]
	],
	[
		[
			42382,
			36487
		],
		[
			-48,
			31
		],
		[
			-12,
			104
		],
		[
			102,
			0
		],
		[
			12,
			52
		]
	],
	[
		[
			42436,
			36674
		],
		[
			6,
			62
		],
		[
			-36,
			52
		],
		[
			-84,
			62
		],
		[
			6,
			145
		],
		[
			-18,
			93
		],
		[
			24,
			145
		],
		[
			-132,
			114
		],
		[
			42,
			52
		],
		[
			-96,
			72
		],
		[
			0,
			52
		],
		[
			-42,
			62
		],
		[
			198,
			52
		],
		[
			6,
			52
		],
		[
			-36,
			145
		],
		[
			18,
			41
		],
		[
			-12,
			145
		],
		[
			36,
			11
		]
	],
	[
		[
			42623,
			31060
		],
		[
			18,
			-82
		],
		[
			96,
			-32
		],
		[
			12,
			-124
		],
		[
			162,
			-134
		],
		[
			42,
			-11
		],
		[
			97,
			-83
		],
		[
			48,
			-10
		]
	],
	[
		[
			43098,
			30584
		],
		[
			48,
			-41
		],
		[
			30,
			-63
		]
	],
	[
		[
			43176,
			30480
		],
		[
			-120,
			-41
		],
		[
			-61,
			-41
		],
		[
			-42,
			-73
		],
		[
			-90,
			-21
		],
		[
			-42,
			-31
		],
		[
			-30,
			-186
		],
		[
			18,
			-62
		],
		[
			60,
			-52
		],
		[
			102,
			21
		],
		[
			49,
			-42
		],
		[
			60,
			11
		],
		[
			24,
			-125
		],
		[
			-36,
			-155
		]
	],
	[
		[
			42827,
			29579
		],
		[
			-36,
			21
		],
		[
			-6,
			104
		],
		[
			18,
			20
		],
		[
			-138,
			156
		],
		[
			-90,
			-11
		],
		[
			-61,
			83
		],
		[
			-54,
			11
		],
		[
			-60,
			-21
		],
		[
			-30,
			-42
		],
		[
			-36,
			63
		],
		[
			-60,
			-11
		],
		[
			-54,
			62
		],
		[
			-36,
			-10
		]
	],
	[
		[
			45443,
			31920
		],
		[
			-6,
			21
		]
	],
	[
		[
			45292,
			33795
		],
		[
			-42,
			-73
		]
	],
	[
		[
			45250,
			33722
		],
		[
			-90,
			-62
		],
		[
			24,
			-83
		],
		[
			-12,
			-62
		],
		[
			84,
			-83
		],
		[
			72,
			-41
		],
		[
			18,
			-83
		],
		[
			54,
			-42
		]
	],
	[
		[
			45400,
			33266
		],
		[
			12,
			-72
		],
		[
			-30,
			-42
		],
		[
			37,
			-82
		],
		[
			-61,
			-31
		],
		[
			-30,
			-63
		],
		[
			6,
			-51
		]
	],
	[
		[
			45334,
			32925
		],
		[
			66,
			-11
		]
	],
	[
		[
			45400,
			32914
		],
		[
			31,
			21
		],
		[
			60,
			-83
		]
	],
	[
		[
			45491,
			32852
		],
		[
			0,
			-103
		]
	],
	[
		[
			45491,
			32749
		],
		[
			36,
			-42
		],
		[
			-54,
			-93
		],
		[
			36,
			-52
		],
		[
			60,
			0
		]
	],
	[
		[
			45569,
			32562
		],
		[
			-24,
			-41
		],
		[
			0,
			-94
		],
		[
			36,
			-51
		],
		[
			-12,
			-83
		],
		[
			-36,
			-31
		]
	],
	[
		[
			45533,
			32262
		],
		[
			-18,
			52
		]
	],
	[
		[
			45509,
			32324
		],
		[
			-109,
			-145
		],
		[
			79,
			-114
		],
		[
			-73,
			-176
		],
		[
			0,
			-135
		],
		[
			-36,
			-134
		],
		[
			30,
			-42
		],
		[
			12,
			-103
		]
	],
	[
		[
			45412,
			31475
		],
		[
			-24,
			-114
		]
	],
	[
		[
			45388,
			31361
		],
		[
			-24,
			72
		],
		[
			-120,
			11
		],
		[
			-66,
			-11
		],
		[
			-54,
			21
		],
		[
			-18,
			52
		],
		[
			-42,
			10
		],
		[
			-12,
			52
		],
		[
			-48,
			0
		],
		[
			-60,
			-62
		],
		[
			-169,
			103
		],
		[
			-60,
			0
		],
		[
			-108,
			-52
		],
		[
			-30,
			11
		],
		[
			-157,
			-42
		],
		[
			12,
			104
		],
		[
			-60,
			62
		],
		[
			-60,
			31
		],
		[
			-222,
			11
		],
		[
			-96,
			103
		],
		[
			-31,
			124
		],
		[
			-102,
			-72
		],
		[
			-36,
			-10
		],
		[
			-120,
			-104
		],
		[
			-174,
			-52
		]
	],
	[
		[
			43531,
			31723
		],
		[
			-49,
			-41
		],
		[
			-60,
			0
		],
		[
			-12,
			-62
		],
		[
			-132,
			10
		],
		[
			-132,
			-62
		],
		[
			-108,
			0
		],
		[
			-79,
			-31
		],
		[
			-42,
			20
		]
	],
	[
		[
			42971,
			32438
		],
		[
			42,
			72
		],
		[
			103,
			21
		],
		[
			6,
			52
		],
		[
			60,
			21
		],
		[
			24,
			41
		],
		[
			78,
			72
		],
		[
			-66,
			42
		],
		[
			-30,
			114
		],
		[
			60,
			-31
		],
		[
			78,
			20
		],
		[
			-36,
			145
		],
		[
			60,
			11
		],
		[
			24,
			52
		],
		[
			-18,
			134
		],
		[
			60,
			52
		],
		[
			42,
			-10
		],
		[
			0,
			93
		]
	],
	[
		[
			43458,
			33339
		],
		[
			43,
			-10
		],
		[
			54,
			124
		],
		[
			66,
			62
		],
		[
			114,
			21
		],
		[
			66,
			-21
		],
		[
			144,
			52
		],
		[
			6,
			-52
		],
		[
			91,
			10
		],
		[
			12,
			62
		],
		[
			42,
			0
		],
		[
			114,
			259
		],
		[
			-6,
			104
		],
		[
			192,
			114
		],
		[
			103,
			176
		]
	],
	[
		[
			42887,
			28595
		],
		[
			-36,
			-10
		],
		[
			0,
			-62
		],
		[
			-108,
			-31
		]
	],
	[
		[
			43777,
			29890
		],
		[
			6,
			-10
		]
	],
	[
		[
			43783,
			29880
		],
		[
			12,
			-42
		],
		[
			90,
			-31
		],
		[
			36,
			-52
		]
	],
	[
		[
			43921,
			29755
		],
		[
			-42,
			-62
		],
		[
			-66,
			-52
		],
		[
			48,
			-72
		],
		[
			42,
			10
		],
		[
			0,
			-114
		],
		[
			42,
			-31
		],
		[
			37,
			11
		],
		[
			102,
			-73
		]
	],
	[
		[
			44084,
			29372
		],
		[
			-66,
			-52
		],
		[
			-43,
			52
		],
		[
			-48,
			0
		],
		[
			-24,
			-41
		],
		[
			30,
			-114
		],
		[
			0,
			-93
		],
		[
			-48,
			-73
		],
		[
			-30,
			10
		],
		[
			-96,
			-20
		],
		[
			-60,
			52
		],
		[
			-72,
			-73
		]
	],
	[
		[
			43176,
			30480
		],
		[
			42,
			-41
		],
		[
			102,
			10
		],
		[
			-6,
			-72
		],
		[
			66,
			-52
		],
		[
			48,
			0
		],
		[
			-54,
			-124
		],
		[
			90,
			31
		],
		[
			115,
			-31
		],
		[
			6,
			-62
		],
		[
			48,
			-63
		],
		[
			12,
			-51
		],
		[
			54,
			-73
		],
		[
			78,
			-62
		]
	],
	[
		[
			43531,
			31723
		],
		[
			48,
			-52
		],
		[
			-18,
			-93
		],
		[
			-36,
			-10
		],
		[
			0,
			-93
		],
		[
			-55,
			-125
		],
		[
			-84,
			-51
		],
		[
			-48,
			-11
		],
		[
			-96,
			-134
		],
		[
			6,
			-31
		],
		[
			114,
			-83
		],
		[
			78,
			-83
		],
		[
			-66,
			-114
		],
		[
			18,
			-62
		],
		[
			0,
			-104
		],
		[
			-42,
			-52
		],
		[
			-72,
			31
		],
		[
			-84,
			-20
		],
		[
			-36,
			-42
		],
		[
			-60,
			-10
		]
	],
	[
		[
			45166,
			29134
		],
		[
			-96,
			72
		],
		[
			66,
			52
		],
		[
			54,
			114
		],
		[
			-30,
			21
		],
		[
			-48,
			145
		],
		[
			-114,
			62
		],
		[
			-36,
			-31
		],
		[
			-55,
			41
		],
		[
			-24,
			-31
		],
		[
			-66,
			-10
		],
		[
			-24,
			41
		],
		[
			-66,
			42
		],
		[
			-60,
			114
		],
		[
			-24,
			83
		],
		[
			-72,
			-63
		],
		[
			-48,
			-103
		],
		[
			-79,
			-73
		],
		[
			-60,
			-20
		],
		[
			-30,
			-42
		],
		[
			-60,
			-134
		],
		[
			-48,
			-42
		],
		[
			-48,
			11
		],
		[
			-114,
			-11
		]
	],
	[
		[
			45388,
			31361
		],
		[
			24,
			114
		]
	],
	[
		[
			45412,
			31475
		],
		[
			13,
			51
		],
		[
			-49,
			104
		],
		[
			36,
			83
		],
		[
			7,
			114
		]
	],
	[
		[
			43410,
			18145
		],
		[
			-18,
			52
		],
		[
			-54,
			-31
		],
		[
			-36,
			21
		],
		[
			-60,
			-11
		],
		[
			-6,
			73
		],
		[
			-102,
			72
		],
		[
			-90,
			0
		],
		[
			-6,
			-82
		],
		[
			-37,
			-63
		],
		[
			-78,
			11
		],
		[
			-12,
			41
		],
		[
			-120,
			62
		],
		[
			-60,
			11
		],
		[
			-36,
			-104
		],
		[
			24,
			-93
		],
		[
			-54,
			-31
		]
	],
	[
		[
			42665,
			18073
		],
		[
			-30,
			72
		],
		[
			-48,
			-10
		],
		[
			-97,
			31
		],
		[
			-84,
			-93
		],
		[
			-30,
			-52
		]
	],
	[
		[
			42376,
			18021
		],
		[
			-12,
			73
		],
		[
			-6,
			10
		]
	],
	[
		[
			42358,
			18104
		],
		[
			6,
			0
		],
		[
			-6,
			0
		]
	],
	[
		[
			42358,
			18104
		],
		[
			-96,
			-10
		]
	],
	[
		[
			42262,
			18094
		],
		[
			-18,
			31
		],
		[
			0,
			134
		],
		[
			-60,
			73
		],
		[
			60,
			114
		],
		[
			-84,
			145
		],
		[
			18,
			103
		],
		[
			-12,
			42
		],
		[
			30,
			62
		],
		[
			132,
			-21
		],
		[
			54,
			83
		],
		[
			90,
			52
		],
		[
			-12,
			62
		],
		[
			-42,
			31
		],
		[
			-48,
			176
		],
		[
			24,
			93
		],
		[
			-42,
			62
		],
		[
			-102,
			21
		],
		[
			-30,
			104
		],
		[
			-60,
			10
		],
		[
			48,
			72
		],
		[
			-175,
			63
		],
		[
			12,
			51
		],
		[
			-12,
			104
		],
		[
			-84,
			135
		],
		[
			-42,
			10
		],
		[
			-72,
			-21
		],
		[
			-90,
			0
		],
		[
			-84,
			42
		],
		[
			-48,
			62
		],
		[
			-73,
			-52
		],
		[
			0,
			-10
		],
		[
			-228,
			-73
		],
		[
			-48,
			11
		],
		[
			-48,
			82
		],
		[
			-84,
			42
		],
		[
			-24,
			72
		]
	],
	[
		[
			41108,
			20061
		],
		[
			6,
			83
		],
		[
			60,
			145
		],
		[
			24,
			145
		],
		[
			54,
			228
		],
		[
			-30,
			83
		],
		[
			72,
			72
		],
		[
			-18,
			42
		],
		[
			48,
			93
		],
		[
			30,
			21
		],
		[
			18,
			72
		],
		[
			54,
			-41
		],
		[
			114,
			0
		],
		[
			-6,
			176
		],
		[
			169,
			21
		],
		[
			90,
			-73
		],
		[
			6,
			-41
		],
		[
			90,
			-83
		],
		[
			12,
			-31
		],
		[
			150,
			83
		],
		[
			7,
			0
		],
		[
			-7,
			20
		]
	],
	[
		[
			42051,
			21076
		],
		[
			-12,
			11
		]
	],
	[
		[
			42039,
			21087
		],
		[
			-48,
			62
		]
	],
	[
		[
			41991,
			21149
		],
		[
			-6,
			21
		],
		[
			0,
			10
		],
		[
			0,
			21
		],
		[
			-126,
			-11
		],
		[
			42,
			104
		],
		[
			120,
			83
		],
		[
			85,
			-21
		],
		[
			0,
			62
		],
		[
			36,
			31
		],
		[
			30,
			135
		],
		[
			24,
			10
		],
		[
			12,
			83
		]
	],
	[
		[
			42665,
			18073
		],
		[
			186,
			-124
		],
		[
			60,
			0
		],
		[
			72,
			-42
		],
		[
			37,
			0
		],
		[
			30,
			-83
		],
		[
			-49,
			-20
		],
		[
			6,
			-197
		],
		[
			85,
			0
		],
		[
			18,
			-42
		],
		[
			-84,
			-41
		],
		[
			30,
			-42
		],
		[
			-24,
			-82
		],
		[
			-61,
			-21
		],
		[
			-60,
			31
		],
		[
			-84,
			-10
		],
		[
			-96,
			103
		]
	],
	[
		[
			42731,
			17503
		],
		[
			-90,
			73
		],
		[
			-60,
			83
		],
		[
			-103,
			51
		],
		[
			-48,
			52
		],
		[
			-12,
			62
		],
		[
			-48,
			125
		],
		[
			6,
			72
		]
	],
	[
		[
			42815,
			15711
		],
		[
			-6,
			114
		],
		[
			30,
			42
		],
		[
			12,
			83
		],
		[
			78,
			176
		],
		[
			18,
			124
		],
		[
			-60,
			-31
		],
		[
			-90,
			-83
		],
		[
			-18,
			21
		],
		[
			-114,
			20
		],
		[
			-96,
			0
		],
		[
			-85,
			-93
		],
		[
			-36,
			31
		],
		[
			36,
			83
		],
		[
			79,
			104
		],
		[
			30,
			83
		],
		[
			-6,
			72
		],
		[
			54,
			31
		],
		[
			24,
			52
		],
		[
			60,
			0
		],
		[
			138,
			176
		],
		[
			-54,
			-10
		],
		[
			-174,
			83
		],
		[
			-127,
			-63
		],
		[
			-42,
			0
		],
		[
			48,
			145
		]
	],
	[
		[
			42514,
			16871
		],
		[
			-30,
			73
		],
		[
			55,
			31
		],
		[
			72,
			10
		],
		[
			60,
			-41
		],
		[
			138,
			83
		],
		[
			36,
			124
		],
		[
			-54,
			104
		],
		[
			-24,
			145
		],
		[
			-42,
			62
		],
		[
			6,
			41
		]
	],
	[
		[
			40380,
			17110
		],
		[
			54,
			31
		],
		[
			66,
			-31
		],
		[
			127,
			82
		],
		[
			42,
			-41
		],
		[
			78,
			52
		]
	],
	[
		[
			40747,
			17203
		],
		[
			60,
			62
		],
		[
			114,
			-10
		],
		[
			66,
			41
		],
		[
			54,
			-52
		],
		[
			97,
			31
		],
		[
			114,
			-31
		],
		[
			30,
			-41
		],
		[
			36,
			21
		],
		[
			30,
			72
		],
		[
			72,
			-41
		],
		[
			30,
			20
		],
		[
			0,
			104
		],
		[
			48,
			10
		],
		[
			91,
			-31
		]
	],
	[
		[
			41589,
			17358
		],
		[
			6,
			-21
		],
		[
			96,
			21
		],
		[
			90,
			-21
		],
		[
			12,
			-20
		],
		[
			102,
			31
		],
		[
			66,
			72
		],
		[
			36,
			62
		],
		[
			6,
			63
		],
		[
			-36,
			62
		],
		[
			48,
			114
		],
		[
			-6,
			93
		],
		[
			36,
			62
		],
		[
			-12,
			62
		]
	],
	[
		[
			42033,
			17938
		],
		[
			18,
			31
		]
	],
	[
		[
			42051,
			17969
		],
		[
			49,
			11
		],
		[
			78,
			82
		],
		[
			84,
			32
		]
	],
	[
		[
			40284,
			19968
		],
		[
			126,
			-83
		],
		[
			102,
			-103
		],
		[
			54,
			-94
		]
	],
	[
		[
			40566,
			19688
		],
		[
			24,
			-20
		],
		[
			91,
			83
		],
		[
			6,
			82
		],
		[
			84,
			0
		],
		[
			180,
			73
		],
		[
			-24,
			52
		]
	],
	[
		[
			40927,
			19958
		],
		[
			-18,
			52
		],
		[
			78,
			41
		],
		[
			109,
			-31
		],
		[
			12,
			41
		]
	],
	[
		[
			36352,
			11900
		],
		[
			-48,
			21
		],
		[
			-97,
			103
		],
		[
			-108,
			0
		],
		[
			-66,
			-31
		],
		[
			-36,
			73
		],
		[
			-60,
			-73
		],
		[
			-54,
			31
		],
		[
			-66,
			-93
		],
		[
			-55,
			-41
		],
		[
			-42,
			-73
		],
		[
			-24,
			21
		],
		[
			-72,
			-52
		],
		[
			-54,
			11
		],
		[
			-144,
			-135
		],
		[
			-84,
			-42
		],
		[
			-61,
			0
		],
		[
			-120,
			-51
		],
		[
			-18,
			-31
		],
		[
			-186,
			-21
		],
		[
			-60,
			83
		],
		[
			-18,
			-93
		],
		[
			72,
			0
		],
		[
			12,
			-52
		],
		[
			-78,
			10
		]
	],
	[
		[
			34885,
			11465
		],
		[
			12,
			-135
		],
		[
			-79,
			0
		],
		[
			-30,
			-51
		],
		[
			-102,
			0
		],
		[
			-42,
			165
		],
		[
			6,
			83
		],
		[
			-30,
			42
		],
		[
			-6,
			62
		],
		[
			-66,
			0
		],
		[
			-60,
			-73
		],
		[
			-30,
			-103
		],
		[
			-115,
			-42
		],
		[
			-18,
			-20
		],
		[
			-54,
			41
		],
		[
			-42,
			-52
		],
		[
			-6,
			125
		],
		[
			42,
			31
		],
		[
			-72,
			93
		],
		[
			-96,
			52
		],
		[
			-18,
			-73
		],
		[
			-36,
			-41
		],
		[
			-259,
			31
		],
		[
			-18,
			83
		],
		[
			-150,
			0
		]
	],
	[
		[
			33616,
			11683
		],
		[
			-30,
			103
		],
		[
			48,
			11
		],
		[
			78,
			-52
		],
		[
			78,
			0
		],
		[
			6,
			72
		],
		[
			-24,
			31
		],
		[
			0,
			83
		],
		[
			36,
			21
		],
		[
			-12,
			62
		],
		[
			18,
			93
		],
		[
			-330,
			197
		],
		[
			36,
			166
		],
		[
			174,
			-104
		],
		[
			72,
			228
		],
		[
			151,
			31
		],
		[
			42,
			-21
		],
		[
			48,
			21
		],
		[
			6,
			155
		],
		[
			-54,
			52
		],
		[
			-109,
			0
		],
		[
			12,
			166
		],
		[
			37,
			21
		],
		[
			66,
			82
		],
		[
			120,
			83
		],
		[
			66,
			-51
		],
		[
			30,
			41
		],
		[
			72,
			41
		],
		[
			-60,
			52
		],
		[
			6,
			42
		],
		[
			-78,
			20
		],
		[
			-18,
			125
		],
		[
			0,
			103
		],
		[
			-174,
			21
		],
		[
			18,
			103
		],
		[
			-12,
			32
		]
	],
	[
		[
			32600,
			12190
		],
		[
			24,
			-72
		],
		[
			-42,
			-21
		],
		[
			12,
			-62
		]
	],
	[
		[
			32594,
			12035
		],
		[
			18,
			0
		]
	],
	[
		[
			32612,
			12035
		],
		[
			6,
			-31
		]
	],
	[
		[
			32618,
			12004
		],
		[
			-54,
			-42
		]
	],
	[
		[
			32564,
			11962
		],
		[
			-6,
			-31
		]
	],
	[
		[
			32558,
			11931
		],
		[
			12,
			-21
		]
	],
	[
		[
			32570,
			11910
		],
		[
			18,
			-62
		]
	],
	[
		[
			32588,
			11848
		],
		[
			18,
			-62
		]
	],
	[
		[
			32606,
			11786
		],
		[
			42,
			-21
		]
	],
	[
		[
			32648,
			11765
		],
		[
			36,
			-10
		]
	],
	[
		[
			32684,
			11755
		],
		[
			42,
			-31
		]
	],
	[
		[
			32726,
			11724
		],
		[
			24,
			-62
		]
	],
	[
		[
			32750,
			11662
		],
		[
			24,
			-21
		]
	],
	[
		[
			32774,
			11641
		],
		[
			0,
			-31
		]
	],
	[
		[
			32774,
			11610
		],
		[
			36,
			-31
		]
	],
	[
		[
			32810,
			11579
		],
		[
			60,
			-52
		]
	],
	[
		[
			32870,
			11527
		],
		[
			85,
			-72
		]
	],
	[
		[
			32955,
			11455
		],
		[
			6,
			-21
		]
	],
	[
		[
			32961,
			11434
		],
		[
			-30,
			-52
		],
		[
			-43,
			0
		],
		[
			0,
			-62
		],
		[
			115,
			-72
		]
	],
	[
		[
			33003,
			11248
		],
		[
			-30,
			-21
		]
	],
	[
		[
			32973,
			11227
		],
		[
			0,
			-10
		]
	],
	[
		[
			32973,
			11217
		],
		[
			-12,
			-11
		]
	],
	[
		[
			32961,
			11206
		],
		[
			-55,
			11
		],
		[
			-72,
			-63
		],
		[
			-12,
			-41
		],
		[
			-60,
			0
		],
		[
			-78,
			-62
		],
		[
			-90,
			124
		],
		[
			-66,
			-10
		],
		[
			-36,
			20
		],
		[
			-85,
			-31
		],
		[
			0,
			73
		],
		[
			-78,
			31
		],
		[
			-12,
			31
		],
		[
			-114,
			0
		],
		[
			-72,
			41
		],
		[
			-72,
			11
		],
		[
			-24,
			-62
		],
		[
			-48,
			83
		],
		[
			-73,
			0
		],
		[
			-36,
			-21
		],
		[
			-60,
			10
		]
	],
	[
		[
			31818,
			11351
		],
		[
			-36,
			0
		],
		[
			-48,
			62
		],
		[
			-30,
			176
		],
		[
			54,
			11
		],
		[
			0,
			103
		],
		[
			-66,
			-10
		],
		[
			-84,
			-41
		],
		[
			-6,
			41
		],
		[
			-72,
			0
		],
		[
			-67,
			31
		],
		[
			-24,
			62
		]
	],
	[
		[
			31439,
			11786
		],
		[
			-108,
			104
		],
		[
			0,
			31
		],
		[
			60,
			93
		],
		[
			66,
			0
		],
		[
			43,
			41
		],
		[
			54,
			0
		],
		[
			24,
			52
		],
		[
			60,
			11
		],
		[
			30,
			72
		],
		[
			78,
			21
		],
		[
			36,
			-11
		],
		[
			54,
			63
		],
		[
			90,
			10
		],
		[
			43,
			72
		],
		[
			-13,
			52
		],
		[
			61,
			11
		],
		[
			6,
			51
		],
		[
			48,
			11
		],
		[
			36,
			62
		],
		[
			84,
			-31
		],
		[
			72,
			103
		]
	],
	[
		[
			32263,
			12604
		],
		[
			138,
			125
		],
		[
			49,
			10
		],
		[
			-43,
			-207
		],
		[
			-36,
			-42
		],
		[
			-36,
			21
		],
		[
			-84,
			-83
		],
		[
			-18,
			-72
		],
		[
			18,
			-52
		],
		[
			78,
			-93
		],
		[
			72,
			10
		],
		[
			6,
			83
		],
		[
			55,
			21
		],
		[
			60,
			-21
		],
		[
			48,
			-114
		],
		[
			30,
			0
		]
	],
	[
		[
			32642,
			13578
		],
		[
			-24,
			-73
		]
	],
	[
		[
			33616,
			11683
		],
		[
			-144,
			-52
		],
		[
			-24,
			10
		],
		[
			-49,
			-238
		],
		[
			-114,
			31
		],
		[
			-60,
			-114
		]
	],
	[
		[
			33225,
			11320
		],
		[
			-96,
			62
		],
		[
			-42,
			93
		],
		[
			-54,
			-31
		],
		[
			-24,
			31
		],
		[
			-54,
			-20
		]
	],
	[
		[
			32870,
			11527
		],
		[
			-60,
			52
		]
	],
	[
		[
			32774,
			11610
		],
		[
			0,
			31
		]
	],
	[
		[
			32750,
			11662
		],
		[
			-24,
			62
		]
	],
	[
		[
			32684,
			11755
		],
		[
			-36,
			10
		]
	],
	[
		[
			32648,
			11765
		],
		[
			-42,
			21
		]
	],
	[
		[
			32606,
			11786
		],
		[
			-18,
			62
		]
	],
	[
		[
			32588,
			11848
		],
		[
			-18,
			62
		]
	],
	[
		[
			32558,
			11931
		],
		[
			6,
			31
		]
	],
	[
		[
			32564,
			11962
		],
		[
			54,
			42
		]
	],
	[
		[
			32618,
			12004
		],
		[
			-6,
			31
		]
	],
	[
		[
			32594,
			12035
		],
		[
			54,
			155
		],
		[
			-48,
			0
		]
	],
	[
		[
			32600,
			12190
		],
		[
			-78,
			124
		],
		[
			-109,
			21
		],
		[
			-12,
			-83
		],
		[
			-36,
			-41
		],
		[
			-42,
			31
		],
		[
			-60,
			83
		],
		[
			6,
			93
		],
		[
			126,
			41
		],
		[
			61,
			83
		],
		[
			18,
			83
		],
		[
			42,
			93
		],
		[
			42,
			42
		],
		[
			24,
			165
		],
		[
			-12,
			52
		],
		[
			-60,
			73
		],
		[
			-54,
			114
		],
		[
			-6,
			41
		],
		[
			60,
			352
		],
		[
			6,
			176
		],
		[
			90,
			-31
		],
		[
			54,
			-83
		],
		[
			-18,
			-41
		]
	],
	[
		[
			32275,
			9808
		],
		[
			-42,
			41
		],
		[
			-78,
			21
		],
		[
			-48,
			42
		],
		[
			-60,
			82
		],
		[
			24,
			94
		],
		[
			42,
			20
		],
		[
			126,
			-72
		],
		[
			66,
			0
		],
		[
			84,
			31
		],
		[
			12,
			41
		],
		[
			91,
			42
		],
		[
			54,
			124
		],
		[
			18,
			-10
		],
		[
			126,
			72
		],
		[
			-12,
			73
		],
		[
			42,
			0
		],
		[
			-12,
			124
		],
		[
			-36,
			41
		],
		[
			30,
			83
		],
		[
			126,
			21
		],
		[
			60,
			31
		],
		[
			-24,
			52
		],
		[
			24,
			41
		],
		[
			121,
			73
		],
		[
			222,
			228
		],
		[
			18,
			10
		]
	],
	[
		[
			33249,
			11113
		],
		[
			0,
			21
		]
	],
	[
		[
			33249,
			11134
		],
		[
			-24,
			20
		]
	],
	[
		[
			33225,
			11154
		],
		[
			-12,
			21
		]
	],
	[
		[
			33213,
			11175
		],
		[
			-18,
			10
		]
	],
	[
		[
			33195,
			11185
		],
		[
			0,
			42
		]
	],
	[
		[
			33195,
			11227
		],
		[
			6,
			21
		]
	],
	[
		[
			33201,
			11248
		],
		[
			24,
			72
		]
	],
	[
		[
			33027,
			11351
		],
		[
			30,
			-41
		]
	],
	[
		[
			33057,
			11310
		],
		[
			-12,
			-21
		]
	],
	[
		[
			33045,
			11289
		],
		[
			-12,
			-10
		]
	],
	[
		[
			33033,
			11279
		],
		[
			-30,
			-31
		]
	],
	[
		[
			32961,
			11434
		],
		[
			0,
			-10
		]
	],
	[
		[
			32961,
			11424
		],
		[
			66,
			-73
		]
	],
	[
		[
			33201,
			11248
		],
		[
			-6,
			0
		]
	],
	[
		[
			33195,
			11248
		],
		[
			-72,
			0
		]
	],
	[
		[
			33123,
			11248
		],
		[
			-36,
			41
		]
	],
	[
		[
			33087,
			11289
		],
		[
			-60,
			62
		]
	],
	[
		[
			32961,
			11424
		],
		[
			-6,
			31
		]
	],
	[
		[
			32961,
			11206
		],
		[
			12,
			11
		]
	],
	[
		[
			32973,
			11227
		],
		[
			60,
			52
		]
	],
	[
		[
			33045,
			11289
		],
		[
			12,
			21
		]
	],
	[
		[
			33057,
			11310
		],
		[
			30,
			-21
		]
	],
	[
		[
			33087,
			11289
		],
		[
			36,
			-41
		]
	],
	[
		[
			33195,
			11248
		],
		[
			0,
			-21
		]
	],
	[
		[
			33195,
			11227
		],
		[
			0,
			-42
		]
	],
	[
		[
			33213,
			11175
		],
		[
			12,
			-21
		]
	],
	[
		[
			33225,
			11154
		],
		[
			24,
			-20
		]
	],
	[
		[
			30177,
			10937
		],
		[
			108,
			124
		],
		[
			30,
			62
		],
		[
			90,
			-51
		],
		[
			96,
			31
		],
		[
			55,
			41
		],
		[
			-6,
			52
		],
		[
			-49,
			41
		],
		[
			6,
			52
		],
		[
			79,
			21
		],
		[
			84,
			0
		],
		[
			48,
			41
		],
		[
			96,
			11
		],
		[
			108,
			-63
		],
		[
			18,
			-41
		],
		[
			48,
			0
		],
		[
			-12,
			93
		],
		[
			-42,
			21
		],
		[
			-60,
			93
		],
		[
			66,
			83
		],
		[
			30,
			-10
		],
		[
			61,
			-73
		],
		[
			60,
			31
		],
		[
			36,
			104
		],
		[
			90,
			-42
		],
		[
			84,
			114
		],
		[
			54,
			31
		],
		[
			84,
			83
		]
	],
	[
		[
			28415,
			12863
		],
		[
			120,
			-10
		],
		[
			36,
			-21
		],
		[
			223,
			-52
		],
		[
			138,
			0
		],
		[
			54,
			-72
		],
		[
			121,
			41
		],
		[
			84,
			42
		],
		[
			48,
			52
		],
		[
			204,
			20
		],
		[
			229,
			-93
		],
		[
			30,
			10
		],
		[
			84,
			-41
		],
		[
			84,
			-114
		],
		[
			114,
			10
		],
		[
			42,
			-20
		],
		[
			55,
			-104
		],
		[
			168,
			-124
		],
		[
			150,
			21
		],
		[
			72,
			0
		],
		[
			73,
			-31
		],
		[
			90,
			20
		],
		[
			96,
			-10
		],
		[
			48,
			-31
		],
		[
			66,
			31
		],
		[
			84,
			0
		],
		[
			60,
			-21
		],
		[
			109,
			73
		],
		[
			36,
			0
		],
		[
			138,
			51
		],
		[
			60,
			11
		],
		[
			78,
			72
		],
		[
			73,
			11
		],
		[
			54,
			-31
		],
		[
			96,
			31
		],
		[
			42,
			51
		],
		[
			72,
			0
		],
		[
			108,
			21
		],
		[
			66,
			-31
		],
		[
			79,
			10
		],
		[
			138,
			-72
		],
		[
			126,
			41
		]
	],
	[
		[
			38672,
			27373
		],
		[
			43,
			-20
		],
		[
			84,
			-83
		],
		[
			54,
			-21
		],
		[
			6,
			-166
		],
		[
			-78,
			-72
		],
		[
			-48,
			-73
		],
		[
			36,
			-124
		],
		[
			66,
			-41
		],
		[
			-78,
			-42
		],
		[
			-24,
			-93
		],
		[
			-73,
			0
		],
		[
			-18,
			-62
		],
		[
			-54,
			-42
		],
		[
			6,
			-72
		],
		[
			-18,
			-83
		],
		[
			36,
			-52
		]
	],
	[
		[
			38612,
			26327
		],
		[
			0,
			-83
		],
		[
			-30,
			0
		],
		[
			0,
			-93
		],
		[
			-24,
			-31
		],
		[
			-126,
			0
		]
	],
	[
		[
			38432,
			26120
		],
		[
			-48,
			73
		],
		[
			6,
			41
		],
		[
			-72,
			155
		],
		[
			-60,
			31
		],
		[
			-109,
			-10
		],
		[
			-60,
			42
		],
		[
			-54,
			134
		],
		[
			84,
			114
		],
		[
			54,
			31
		],
		[
			0,
			62
		],
		[
			30,
			135
		],
		[
			-6,
			93
		]
	],
	[
		[
			38197,
			27021
		],
		[
			49,
			52
		],
		[
			18,
			114
		],
		[
			-18,
			52
		],
		[
			84,
			10
		],
		[
			42,
			31
		],
		[
			132,
			-21
		],
		[
			168,
			114
		]
	],
	[
		[
			40061,
			26980
		],
		[
			-42,
			-21
		],
		[
			-36,
			21
		],
		[
			-30,
			62
		]
	],
	[
		[
			39953,
			27042
		],
		[
			-66,
			10
		]
	],
	[
		[
			39887,
			27052
		],
		[
			-96,
			0
		],
		[
			-36,
			52
		],
		[
			-72,
			41
		]
	],
	[
		[
			39683,
			27145
		],
		[
			-12,
			0
		]
	],
	[
		[
			39671,
			27145
		],
		[
			-85,
			0
		],
		[
			-126,
			73
		],
		[
			-54,
			-21
		],
		[
			-36,
			135
		],
		[
			0,
			52
		],
		[
			66,
			41
		],
		[
			18,
			42
		],
		[
			-48,
			93
		],
		[
			-144,
			20
		],
		[
			-12,
			-72
		],
		[
			-42,
			-41
		],
		[
			-49,
			10
		],
		[
			-18,
			52
		],
		[
			-84,
			62
		],
		[
			-72,
			31
		],
		[
			-66,
			-42
		],
		[
			-78,
			32
		],
		[
			-150,
			82
		],
		[
			-61,
			0
		]
	],
	[
		[
			38630,
			27694
		],
		[
			-96,
			156
		],
		[
			90,
			83
		],
		[
			36,
			134
		],
		[
			49,
			31
		]
	],
	[
		[
			38709,
			28098
		],
		[
			24,
			21
		]
	],
	[
		[
			38733,
			28119
		],
		[
			-18,
			155
		]
	],
	[
		[
			38715,
			28274
		],
		[
			-133,
			11
		],
		[
			-48,
			41
		],
		[
			-12,
			104
		],
		[
			-66,
			83
		],
		[
			-102,
			-21
		],
		[
			-72,
			83
		],
		[
			-6,
			51
		],
		[
			-157,
			94
		]
	],
	[
		[
			38119,
			28720
		],
		[
			-6,
			10
		]
	],
	[
		[
			38113,
			28730
		],
		[
			6,
			-10
		]
	],
	[
		[
			38119,
			28720
		],
		[
			84,
			83
		],
		[
			49,
			-11
		],
		[
			90,
			52
		]
	],
	[
		[
			38342,
			28844
		],
		[
			78,
			52
		],
		[
			48,
			-11
		],
		[
			18,
			42
		],
		[
			48,
			21
		],
		[
			36,
			-42
		],
		[
			60,
			-21
		]
	],
	[
		[
			38630,
			28885
		],
		[
			103,
			-20
		],
		[
			42,
			93
		],
		[
			96,
			-21
		],
		[
			36,
			62
		],
		[
			-78,
			52
		],
		[
			-48,
			104
		],
		[
			42,
			31
		],
		[
			48,
			-31
		],
		[
			66,
			83
		],
		[
			108,
			-11
		],
		[
			108,
			42
		],
		[
			-18,
			62
		]
	],
	[
		[
			39135,
			29331
		],
		[
			-54,
			114
		],
		[
			-42,
			20
		],
		[
			12,
			73
		],
		[
			-36,
			93
		],
		[
			6,
			62
		],
		[
			72,
			0
		],
		[
			60,
			114
		],
		[
			31,
			21
		],
		[
			48,
			-31
		],
		[
			78,
			21
		],
		[
			72,
			-42
		],
		[
			42,
			10
		],
		[
			120,
			-134
		],
		[
			18,
			93
		],
		[
			-18,
			62
		],
		[
			18,
			104
		],
		[
			66,
			20
		]
	],
	[
		[
			40723,
			26565
		],
		[
			-96,
			-103
		],
		[
			0,
			-31
		],
		[
			-127,
			-93
		],
		[
			-96,
			-52
		]
	],
	[
		[
			40404,
			26286
		],
		[
			-102,
			-52
		],
		[
			-108,
			-31
		],
		[
			-48,
			21
		],
		[
			-73,
			-11
		],
		[
			-120,
			11
		],
		[
			-66,
			-62
		],
		[
			0,
			-52
		],
		[
			36,
			-62
		],
		[
			90,
			-73
		],
		[
			66,
			-93
		],
		[
			55,
			21
		],
		[
			6,
			-104
		],
		[
			-49,
			-83
		],
		[
			-12,
			-62
		]
	],
	[
		[
			40079,
			25654
		],
		[
			-18,
			-21
		]
	],
	[
		[
			40061,
			25633
		],
		[
			-204,
			0
		],
		[
			-36,
			52
		],
		[
			-132,
			-52
		],
		[
			-30,
			31
		],
		[
			-85,
			-41
		]
	],
	[
		[
			39574,
			25623
		],
		[
			-48,
			104
		],
		[
			-180,
			93
		],
		[
			-102,
			-31
		],
		[
			-48,
			-31
		],
		[
			-61,
			-104
		],
		[
			-48,
			-52
		]
	],
	[
		[
			39087,
			25602
		],
		[
			-114,
			135
		],
		[
			42,
			103
		],
		[
			-42,
			104
		],
		[
			-72,
			52
		],
		[
			-66,
			72
		],
		[
			48,
			52
		]
	],
	[
		[
			38883,
			26120
		],
		[
			-60,
			93
		],
		[
			-90,
			104
		],
		[
			-36,
			-52
		],
		[
			-85,
			62
		]
	],
	[
		[
			38672,
			27373
		],
		[
			-42,
			62
		],
		[
			30,
			52
		],
		[
			-66,
			125
		],
		[
			36,
			82
		]
	],
	[
		[
			37127,
			29320
		],
		[
			-48,
			0
		],
		[
			-24,
			-41
		],
		[
			-78,
			-31
		],
		[
			-96,
			-83
		],
		[
			-42,
			21
		],
		[
			-66,
			-73
		],
		[
			-25,
			-62
		],
		[
			31,
			-103
		],
		[
			48,
			-63
		],
		[
			12,
			-62
		],
		[
			-30,
			-41
		],
		[
			-103,
			31
		],
		[
			-72,
			41
		],
		[
			-84,
			0
		],
		[
			-48,
			21
		],
		[
			-72,
			-41
		],
		[
			-78,
			-114
		],
		[
			-67,
			20
		],
		[
			-120,
			-51
		],
		[
			-24,
			-114
		],
		[
			24,
			-83
		]
	],
	[
		[
			37133,
			30594
		],
		[
			66,
			-93
		],
		[
			48,
			-31
		],
		[
			61,
			-114
		]
	],
	[
		[
			38432,
			26120
		],
		[
			-30,
			-31
		],
		[
			-72,
			0
		],
		[
			-60,
			-41
		],
		[
			-54,
			-73
		],
		[
			-67,
			-31
		],
		[
			-90,
			-10
		]
	],
	[
		[
			38059,
			25934
		],
		[
			-48,
			10
		],
		[
			-54,
			-31
		],
		[
			6,
			-41
		],
		[
			-78,
			-21
		],
		[
			-42,
			72
		],
		[
			-30,
			0
		],
		[
			-48,
			145
		],
		[
			-61,
			0
		],
		[
			-12,
			31
		],
		[
			-102,
			-10
		],
		[
			-30,
			-72
		],
		[
			-90,
			0
		],
		[
			6,
			-42
		],
		[
			-90,
			-41
		],
		[
			6,
			-42
		],
		[
			-78,
			-103
		],
		[
			-73,
			20
		],
		[
			25,
			-114
		],
		[
			-6,
			-62
		],
		[
			-79,
			-20
		],
		[
			6,
			-73
		],
		[
			73,
			-10
		],
		[
			48,
			-31
		],
		[
			30,
			-94
		],
		[
			-6,
			-72
		],
		[
			180,
			-21
		],
		[
			24,
			42
		],
		[
			42,
			-52
		]
	],
	[
		[
			37578,
			25302
		],
		[
			-18,
			-187
		],
		[
			-84,
			-72
		],
		[
			42,
			-41
		],
		[
			-36,
			-73
		],
		[
			-78,
			10
		],
		[
			-126,
			-62
		],
		[
			6,
			-72
		],
		[
			42,
			-145
		],
		[
			0,
			-52
		],
		[
			54,
			-83
		],
		[
			-48,
			-145
		],
		[
			30,
			-134
		],
		[
			36,
			-104
		]
	],
	[
		[
			37398,
			24142
		],
		[
			-12,
			-62
		]
	],
	[
		[
			37386,
			24080
		],
		[
			-108,
			21
		],
		[
			-31,
			-21
		],
		[
			-132,
			72
		],
		[
			-30,
			31
		],
		[
			-120,
			11
		],
		[
			-48,
			20
		],
		[
			-120,
			0
		],
		[
			-103,
			83
		],
		[
			0,
			83
		]
	],
	[
		[
			36550,
			27063
		],
		[
			72,
			0
		],
		[
			66,
			31
		],
		[
			85,
			-62
		],
		[
			42,
			0
		],
		[
			48,
			-114
		],
		[
			6,
			-73
		],
		[
			66,
			-21
		],
		[
			30,
			52
		],
		[
			84,
			52
		],
		[
			42,
			62
		],
		[
			96,
			-10
		],
		[
			30,
			31
		],
		[
			49,
			-21
		],
		[
			108,
			114
		],
		[
			36,
			-31
		],
		[
			24,
			52
		],
		[
			0,
			124
		],
		[
			18,
			114
		],
		[
			48,
			93
		],
		[
			36,
			21
		],
		[
			18,
			-62
		],
		[
			54,
			-21
		],
		[
			90,
			-62
		],
		[
			61,
			10
		],
		[
			42,
			104
		],
		[
			102,
			-11
		],
		[
			66,
			-62
		],
		[
			-36,
			-62
		],
		[
			120,
			-52
		],
		[
			42,
			11
		],
		[
			42,
			-73
		],
		[
			60,
			-176
		]
	],
	[
		[
			37843,
			29258
		],
		[
			114,
			-52
		],
		[
			18,
			-72
		],
		[
			36,
			-10
		],
		[
			90,
			-73
		],
		[
			0,
			-31
		],
		[
			-114,
			-249
		],
		[
			54,
			-31
		],
		[
			72,
			-10
		]
	],
	[
		[
			40404,
			26286
		],
		[
			12,
			-62
		],
		[
			48,
			-83
		],
		[
			-48,
			-114
		],
		[
			24,
			-52
		],
		[
			-6,
			-155
		],
		[
			-54,
			-93
		],
		[
			-144,
			-63
		],
		[
			-42,
			21
		],
		[
			-42,
			-52
		],
		[
			-73,
			21
		]
	],
	[
		[
			56632,
			20372
		],
		[
			-30,
			10
		]
	],
	[
		[
			56602,
			20382
		],
		[
			30,
			-10
		]
	],
	[
		[
			54600,
			21698
		],
		[
			36,
			-62
		],
		[
			132,
			-31
		],
		[
			144,
			41
		],
		[
			84,
			-93
		],
		[
			37,
			0
		],
		[
			48,
			-52
		],
		[
			114,
			52
		],
		[
			60,
			-21
		],
		[
			60,
			41
		],
		[
			30,
			-62
		],
		[
			30,
			-134
		],
		[
			-24,
			-73
		],
		[
			42,
			-52
		],
		[
			0,
			-124
		],
		[
			42,
			-52
		],
		[
			85,
			21
		],
		[
			6,
			-62
		],
		[
			30,
			-42
		],
		[
			138,
			21
		],
		[
			18,
			-41
		],
		[
			78,
			-62
		],
		[
			42,
			-83
		],
		[
			-12,
			-73
		],
		[
			90,
			-20
		],
		[
			0,
			51
		],
		[
			60,
			11
		],
		[
			37,
			-83
		],
		[
			42,
			-11
		],
		[
			150,
			0
		],
		[
			102,
			52
		]
	],
	[
		[
			56301,
			20755
		],
		[
			78,
			-83
		],
		[
			0,
			-41
		],
		[
			-72,
			-41
		],
		[
			-18,
			-63
		],
		[
			36,
			-114
		],
		[
			36,
			21
		],
		[
			42,
			-31
		]
	],
	[
		[
			56403,
			20403
		],
		[
			48,
			-31
		],
		[
			85,
			41
		]
	],
	[
		[
			56536,
			20413
		],
		[
			66,
			-82
		],
		[
			36,
			-73
		],
		[
			84,
			-93
		],
		[
			126,
			-31
		],
		[
			30,
			-62
		],
		[
			181,
			-42
		],
		[
			42,
			-31
		],
		[
			114,
			-21
		],
		[
			24,
			-72
		],
		[
			-12,
			-41
		],
		[
			48,
			-166
		],
		[
			-48,
			-42
		],
		[
			-78,
			52
		],
		[
			-102,
			11
		],
		[
			-109,
			-73
		],
		[
			-42,
			31
		],
		[
			-144,
			-10
		],
		[
			-42,
			83
		],
		[
			-90,
			31
		],
		[
			-66,
			-42
		],
		[
			-48,
			0
		],
		[
			-73,
			-52
		],
		[
			-6,
			-41
		],
		[
			-72,
			31
		],
		[
			-114,
			-21
		],
		[
			-54,
			42
		],
		[
			-114,
			-42
		],
		[
			-18,
			-51
		],
		[
			-67,
			51
		],
		[
			-6,
			-10
		]
	],
	[
		[
			53692,
			20890
		],
		[
			-18,
			93
		],
		[
			-133,
			300
		],
		[
			42,
			104
		],
		[
			-30,
			41
		],
		[
			30,
			52
		],
		[
			19,
			83
		],
		[
			72,
			52
		],
		[
			60,
			-42
		],
		[
			72,
			0
		]
	],
	[
		[
			53806,
			21573
		],
		[
			90,
			0
		],
		[
			0,
			73
		],
		[
			30,
			41
		],
		[
			-18,
			94
		],
		[
			24,
			20
		],
		[
			96,
			-41
		],
		[
			49,
			-114
		],
		[
			84,
			41
		],
		[
			24,
			-93
		],
		[
			84,
			0
		],
		[
			24,
			-21
		],
		[
			24,
			156
		],
		[
			66,
			0
		],
		[
			60,
			31
		],
		[
			157,
			-62
		]
	],
	[
		[
			54010,
			23800
		],
		[
			-36,
			-52
		],
		[
			-84,
			-176
		],
		[
			-162,
			-145
		],
		[
			-138,
			-279
		],
		[
			-97,
			-156
		],
		[
			-120,
			94
		],
		[
			-6,
			-52
		],
		[
			-72,
			-104
		],
		[
			36,
			-31
		],
		[
			36,
			-145
		],
		[
			-36,
			-41
		],
		[
			6,
			-135
		],
		[
			-186,
			10
		],
		[
			-6,
			-134
		],
		[
			-49,
			-187
		],
		[
			49,
			-124
		],
		[
			-24,
			-135
		],
		[
			-37,
			94
		],
		[
			-108,
			31
		],
		[
			-6,
			-21
		],
		[
			-114,
			0
		]
	],
	[
		[
			56584,
			20921
		],
		[
			78,
			-62
		],
		[
			90,
			-42
		],
		[
			96,
			-93
		],
		[
			12,
			-145
		],
		[
			18,
			-31
		],
		[
			-30,
			-83
		]
	],
	[
		[
			56848,
			20465
		],
		[
			115,
			-103
		],
		[
			-79,
			-73
		],
		[
			-84,
			31
		],
		[
			-96,
			-31
		]
	],
	[
		[
			56704,
			20289
		],
		[
			-72,
			83
		]
	],
	[
		[
			56602,
			20382
		],
		[
			-66,
			31
		]
	],
	[
		[
			56301,
			20755
		],
		[
			0,
			83
		],
		[
			30,
			104
		],
		[
			36,
			-31
		],
		[
			115,
			20
		],
		[
			54,
			42
		],
		[
			48,
			-52
		]
	],
	[
		[
			57678,
			23893
		],
		[
			78,
			0
		],
		[
			18,
			-51
		],
		[
			60,
			-31
		],
		[
			6,
			-52
		],
		[
			72,
			-93
		],
		[
			61,
			-52
		],
		[
			66,
			-104
		]
	],
	[
		[
			58039,
			23510
		],
		[
			-72,
			-72
		],
		[
			-55,
			-11
		],
		[
			-60,
			-62
		],
		[
			-48,
			-10
		],
		[
			-66,
			-93
		],
		[
			18,
			-31
		],
		[
			-18,
			-104
		],
		[
			90,
			-93
		],
		[
			60,
			-31
		],
		[
			-18,
			-52
		],
		[
			18,
			-93
		],
		[
			103,
			-83
		],
		[
			-103,
			-42
		],
		[
			-42,
			-51
		],
		[
			-174,
			41
		],
		[
			6,
			124
		],
		[
			-90,
			52
		],
		[
			-18,
			-41
		],
		[
			30,
			-62
		],
		[
			42,
			-32
		],
		[
			-18,
			-165
		],
		[
			-54,
			-11
		],
		[
			-36,
			-51
		],
		[
			-109,
			0
		],
		[
			-66,
			-52
		],
		[
			6,
			-62
		],
		[
			-36,
			-73
		],
		[
			-30,
			0
		],
		[
			-192,
			-134
		],
		[
			-30,
			-104
		],
		[
			-6,
			-135
		],
		[
			42,
			0
		],
		[
			36,
			-93
		],
		[
			-48,
			-52
		],
		[
			-42,
			-134
		],
		[
			-66,
			0
		],
		[
			-79,
			-83
		],
		[
			-108,
			-62
		],
		[
			0,
			-62
		],
		[
			-30,
			-83
		],
		[
			-84,
			-31
		],
		[
			6,
			-135
		],
		[
			-78,
			-124
		],
		[
			18,
			-93
		],
		[
			-54,
			-104
		]
	],
	[
		[
			54600,
			21698
		],
		[
			48,
			31
		],
		[
			12,
			52
		],
		[
			66,
			20
		],
		[
			0,
			145
		],
		[
			-24,
			0
		]
	],
	[
		[
			54702,
			21946
		],
		[
			-72,
			21
		],
		[
			-30,
			72
		],
		[
			48,
			197
		],
		[
			-30,
			125
		],
		[
			-60,
			82
		],
		[
			-55,
			11
		],
		[
			12,
			124
		],
		[
			55,
			21
		],
		[
			48,
			-21
		],
		[
			48,
			21
		],
		[
			96,
			-62
		],
		[
			78,
			93
		],
		[
			-12,
			72
		],
		[
			-60,
			62
		],
		[
			72,
			21
		],
		[
			-6,
			52
		],
		[
			84,
			10
		],
		[
			24,
			62
		],
		[
			78,
			-62
		],
		[
			37,
			73
		],
		[
			42,
			-21
		],
		[
			102,
			124
		],
		[
			72,
			11
		],
		[
			-36,
			124
		],
		[
			78,
			83
		],
		[
			84,
			21
		],
		[
			30,
			82
		],
		[
			-24,
			104
		],
		[
			60,
			73
		],
		[
			18,
			51
		]
	],
	[
		[
			58339,
			20517
		],
		[
			-6,
			0
		]
	],
	[
		[
			58333,
			20517
		],
		[
			12,
			31
		]
	],
	[
		[
			58345,
			20548
		],
		[
			-6,
			-31
		]
	],
	[
		[
			57588,
			20610
		],
		[
			0,
			11
		]
	],
	[
		[
			57588,
			20621
		],
		[
			0,
			-11
		]
	],
	[
		[
			58412,
			20600
		],
		[
			-6,
			10
		]
	],
	[
		[
			58406,
			20610
		],
		[
			18,
			21
		]
	],
	[
		[
			58424,
			20631
		],
		[
			18,
			10
		]
	],
	[
		[
			58442,
			20641
		],
		[
			12,
			0
		]
	],
	[
		[
			58454,
			20641
		],
		[
			24,
			21
		]
	],
	[
		[
			58478,
			20662
		],
		[
			-66,
			-62
		]
	],
	[
		[
			59337,
			23220
		],
		[
			6,
			-10
		]
	],
	[
		[
			59343,
			23210
		],
		[
			12,
			0
		]
	],
	[
		[
			59355,
			23210
		],
		[
			7,
			-11
		]
	],
	[
		[
			59362,
			23199
		],
		[
			-55,
			-41
		]
	],
	[
		[
			59307,
			23158
		],
		[
			48,
			52
		]
	],
	[
		[
			59355,
			23210
		],
		[
			-12,
			0
		]
	],
	[
		[
			59313,
			23220
		],
		[
			-24,
			21
		]
	],
	[
		[
			59289,
			23241
		],
		[
			24,
			-21
		]
	],
	[
		[
			59283,
			23231
		],
		[
			-66,
			-63
		],
		[
			-24,
			-62
		],
		[
			-30,
			83
		],
		[
			-36,
			-52
		]
	],
	[
		[
			59127,
			23137
		],
		[
			-42,
			-20
		]
	],
	[
		[
			59085,
			23117
		],
		[
			-30,
			-21
		],
		[
			-36,
			41
		]
	],
	[
		[
			59019,
			23137
		],
		[
			-36,
			42
		]
	],
	[
		[
			58983,
			23179
		],
		[
			-60,
			31
		]
	],
	[
		[
			58923,
			23210
		],
		[
			30,
			62
		],
		[
			126,
			10
		],
		[
			6,
			-31
		],
		[
			132,
			-41
		],
		[
			42,
			41
		],
		[
			24,
			-20
		]
	],
	[
		[
			58484,
			23365
		],
		[
			18,
			-83
		],
		[
			-36,
			-31
		],
		[
			30,
			-72
		],
		[
			54,
			10
		]
	],
	[
		[
			58550,
			23189
		],
		[
			66,
			52
		]
	],
	[
		[
			58616,
			23241
		],
		[
			30,
			31
		],
		[
			174,
			0
		],
		[
			67,
			-62
		],
		[
			36,
			0
		]
	],
	[
		[
			58983,
			23179
		],
		[
			36,
			-42
		]
	],
	[
		[
			59019,
			23137
		],
		[
			66,
			-20
		]
	],
	[
		[
			59085,
			23117
		],
		[
			42,
			20
		]
	],
	[
		[
			59127,
			23137
		],
		[
			48,
			-72
		],
		[
			126,
			62
		],
		[
			6,
			31
		]
	],
	[
		[
			59307,
			23158
		],
		[
			61,
			31
		],
		[
			66,
			-52
		],
		[
			42,
			0
		]
	],
	[
		[
			59476,
			23137
		],
		[
			48,
			-72
		]
	],
	[
		[
			59524,
			23065
		],
		[
			0,
			-11
		]
	],
	[
		[
			59524,
			23054
		],
		[
			-6,
			-10
		],
		[
			0,
			-10
		]
	],
	[
		[
			59518,
			23034
		],
		[
			6,
			-11
		]
	],
	[
		[
			59524,
			23023
		],
		[
			-90,
			-93
		],
		[
			-36,
			-62
		],
		[
			-67,
			-155
		],
		[
			-24,
			-104
		],
		[
			0,
			-207
		],
		[
			-30,
			-238
		],
		[
			-12,
			-321
		],
		[
			-84,
			-197
		],
		[
			-108,
			-497
		],
		[
			-12,
			-114
		],
		[
			-42,
			-135
		],
		[
			-78,
			-62
		],
		[
			-253,
			-114
		],
		[
			114,
			104
		],
		[
			-6,
			103
		],
		[
			78,
			0
		],
		[
			79,
			83
		],
		[
			18,
			52
		],
		[
			-6,
			72
		],
		[
			42,
			21
		],
		[
			54,
			62
		],
		[
			66,
			187
		],
		[
			-6,
			41
		],
		[
			-60,
			-21
		],
		[
			-78,
			32
		],
		[
			42,
			72
		],
		[
			-48,
			62
		],
		[
			-60,
			0
		],
		[
			-36,
			52
		],
		[
			-115,
			0
		],
		[
			-132,
			-93
		],
		[
			-24,
			83
		],
		[
			-36,
			-21
		],
		[
			18,
			-83
		],
		[
			48,
			-31
		],
		[
			54,
			10
		],
		[
			6,
			52
		],
		[
			54,
			10
		],
		[
			66,
			-51
		],
		[
			85,
			0
		],
		[
			48,
			-31
		],
		[
			30,
			-63
		],
		[
			96,
			-41
		],
		[
			-12,
			-83
		],
		[
			-36,
			-93
		],
		[
			-78,
			-52
		],
		[
			-18,
			-52
		],
		[
			12,
			-62
		],
		[
			-85,
			-93
		],
		[
			-90,
			-10
		],
		[
			-12,
			-94
		],
		[
			-60,
			11
		],
		[
			-54,
			-93
		],
		[
			-72,
			0
		],
		[
			-42,
			-73
		],
		[
			-54,
			-31
		]
	],
	[
		[
			58478,
			20662
		],
		[
			-24,
			-21
		]
	],
	[
		[
			58442,
			20641
		],
		[
			-18,
			-10
		]
	],
	[
		[
			58424,
			20631
		],
		[
			-18,
			-21
		]
	],
	[
		[
			58412,
			20600
		],
		[
			-67,
			-52
		]
	],
	[
		[
			58345,
			20548
		],
		[
			-12,
			-31
		]
	],
	[
		[
			58333,
			20517
		],
		[
			6,
			0
		]
	],
	[
		[
			58339,
			20517
		],
		[
			-36,
			-104
		],
		[
			-48,
			-41
		],
		[
			-54,
			-124
		],
		[
			-18,
			-83
		],
		[
			-126,
			-135
		],
		[
			-108,
			-62
		],
		[
			0,
			62
		],
		[
			-85,
			93
		],
		[
			-72,
			32
		],
		[
			-6,
			103
		],
		[
			-48,
			83
		],
		[
			-78,
			52
		],
		[
			42,
			52
		],
		[
			0,
			72
		],
		[
			-48,
			73
		],
		[
			0,
			103
		],
		[
			-78,
			42
		],
		[
			0,
			31
		],
		[
			-72,
			114
		],
		[
			0,
			-73
		],
		[
			24,
			-104
		],
		[
			60,
			-82
		]
	],
	[
		[
			57588,
			20610
		],
		[
			18,
			-62
		],
		[
			72,
			-62
		],
		[
			-54,
			-31
		],
		[
			30,
			-114
		],
		[
			78,
			-41
		],
		[
			-6,
			-94
		],
		[
			54,
			-83
		],
		[
			102,
			-62
		],
		[
			49,
			-72
		],
		[
			-12,
			-93
		],
		[
			-43,
			-31
		],
		[
			-72,
			-114
		],
		[
			-126,
			-52
		],
		[
			-126,
			-176
		],
		[
			-30,
			10
		],
		[
			-42,
			104
		],
		[
			-121,
			93
		],
		[
			-48,
			52
		],
		[
			-18,
			62
		],
		[
			12,
			155
		],
		[
			-66,
			52
		],
		[
			-78,
			31
		],
		[
			-66,
			0
		],
		[
			-114,
			73
		],
		[
			-43,
			-11
		],
		[
			-54,
			52
		],
		[
			-72,
			41
		],
		[
			-54,
			-10
		],
		[
			-54,
			62
		]
	],
	[
		[
			58039,
			23510
		],
		[
			72,
			52
		],
		[
			84,
			-21
		],
		[
			54,
			-72
		],
		[
			126,
			-52
		],
		[
			73,
			-62
		],
		[
			36,
			10
		]
	],
	[
		[
			59560,
			23044
		],
		[
			-36,
			-21
		]
	],
	[
		[
			59518,
			23034
		],
		[
			6,
			20
		]
	],
	[
		[
			59524,
			23054
		],
		[
			6,
			0
		]
	],
	[
		[
			59530,
			23054
		],
		[
			30,
			-10
		]
	],
	[
		[
			59524,
			23065
		],
		[
			6,
			-11
		]
	],
	[
		[
			59524,
			23065
		],
		[
			-48,
			72
		]
	],
	[
		[
			59614,
			24639
		],
		[
			-6,
			-83
		],
		[
			54,
			-41
		],
		[
			90,
			10
		],
		[
			30,
			31
		]
	],
	[
		[
			59782,
			24556
		],
		[
			67,
			21
		],
		[
			96,
			-41
		],
		[
			30,
			-63
		],
		[
			-60,
			-155
		],
		[
			-30,
			-135
		],
		[
			-6,
			-93
		],
		[
			24,
			-103
		],
		[
			-48,
			-197
		],
		[
			-73,
			-145
		],
		[
			-42,
			-114
		],
		[
			-72,
			-155
		],
		[
			-30,
			-156
		],
		[
			-78,
			-176
		]
	],
	[
		[
			59560,
			23044
		],
		[
			-84,
			93
		]
	],
	[
		[
			59476,
			23137
		],
		[
			-114,
			62
		]
	],
	[
		[
			59362,
			23199
		],
		[
			0,
			11
		],
		[
			-7,
			0
		]
	],
	[
		[
			59343,
			23210
		],
		[
			-6,
			10
		]
	],
	[
		[
			59337,
			23220
		],
		[
			-24,
			0
		]
	],
	[
		[
			59289,
			23241
		],
		[
			-6,
			-10
		]
	],
	[
		[
			58448,
			24536
		],
		[
			42,
			-32
		]
	],
	[
		[
			58502,
			24504
		],
		[
			24,
			-10
		]
	],
	[
		[
			58538,
			24494
		],
		[
			-6,
			-21
		]
	],
	[
		[
			58550,
			24484
		],
		[
			6,
			-21
		]
	],
	[
		[
			58598,
			24442
		],
		[
			12,
			0
		]
	],
	[
		[
			58610,
			24442
		],
		[
			48,
			11
		]
	],
	[
		[
			58658,
			24453
		],
		[
			12,
			-11
		]
	],
	[
		[
			58682,
			24442
		],
		[
			12,
			31
		]
	],
	[
		[
			58694,
			24473
		],
		[
			-6,
			0
		]
	],
	[
		[
			58688,
			24473
		],
		[
			18,
			21
		]
	],
	[
		[
			58706,
			24494
		],
		[
			42,
			0
		]
	],
	[
		[
			58748,
			24494
		],
		[
			18,
			-10
		]
	],
	[
		[
			58766,
			24484
		],
		[
			12,
			-21
		]
	],
	[
		[
			58778,
			24463
		],
		[
			18,
			-21
		]
	],
	[
		[
			58796,
			24442
		],
		[
			12,
			0
		]
	],
	[
		[
			58808,
			24442
		],
		[
			30,
			-20
		]
	],
	[
		[
			58838,
			24422
		],
		[
			6,
			-11
		]
	],
	[
		[
			58856,
			24411
		],
		[
			18,
			0
		]
	],
	[
		[
			58874,
			24411
		],
		[
			43,
			52
		]
	],
	[
		[
			58917,
			24463
		],
		[
			0,
			10
		]
	],
	[
		[
			58917,
			24473
		],
		[
			24,
			31
		]
	],
	[
		[
			58941,
			24515
		],
		[
			42,
			52
		]
	],
	[
		[
			58983,
			24567
		],
		[
			54,
			10
		]
	],
	[
		[
			59037,
			24577
		],
		[
			18,
			21
		]
	],
	[
		[
			59055,
			24598
		],
		[
			60,
			-31
		]
	],
	[
		[
			59121,
			24546
		],
		[
			54,
			-62
		]
	],
	[
		[
			59175,
			24484
		],
		[
			60,
			-31
		],
		[
			102,
			-11
		],
		[
			6,
			42
		]
	],
	[
		[
			59343,
			24484
		],
		[
			43,
			20
		]
	],
	[
		[
			59392,
			24525
		],
		[
			78,
			-31
		]
	],
	[
		[
			59470,
			24494
		],
		[
			30,
			62
		]
	],
	[
		[
			59500,
			24556
		],
		[
			48,
			31
		]
	],
	[
		[
			59548,
			24587
		],
		[
			0,
			42
		]
	],
	[
		[
			59548,
			24629
		],
		[
			6,
			10
		]
	],
	[
		[
			59554,
			24639
		],
		[
			60,
			0
		]
	],
	[
		[
			59945,
			25095
		],
		[
			54,
			-145
		],
		[
			48,
			-176
		],
		[
			30,
			-156
		],
		[
			-42,
			-72
		],
		[
			-90,
			0
		],
		[
			-84,
			41
		],
		[
			-79,
			-31
		]
	],
	[
		[
			59782,
			24556
		],
		[
			-138,
			0
		],
		[
			-36,
			21
		],
		[
			6,
			62
		]
	],
	[
		[
			59614,
			24639
		],
		[
			-12,
			124
		]
	],
	[
		[
			59578,
			24774
		],
		[
			-12,
			41
		]
	],
	[
		[
			59554,
			24836
		],
		[
			-78,
			-31
		]
	],
	[
		[
			59464,
			24805
		],
		[
			-66,
			72
		]
	],
	[
		[
			59410,
			24929
		],
		[
			-12,
			21
		]
	],
	[
		[
			59398,
			24950
		],
		[
			-91,
			52
		]
	],
	[
		[
			59301,
			25012
		],
		[
			0,
			31
		]
	],
	[
		[
			48064,
			14375
		],
		[
			42,
			-72
		],
		[
			12,
			-93
		],
		[
			-54,
			-31
		],
		[
			-12,
			-125
		],
		[
			-48,
			-62
		],
		[
			0,
			-83
		]
	],
	[
		[
			48004,
			13909
		],
		[
			-12,
			-145
		]
	],
	[
		[
			47992,
			13764
		],
		[
			-126,
			-83
		],
		[
			-42,
			-72
		],
		[
			-49,
			21
		],
		[
			-24,
			-42
		],
		[
			-72,
			31
		],
		[
			-48,
			-41
		],
		[
			-12,
			-104
		]
	],
	[
		[
			47619,
			13474
		],
		[
			-54,
			-31
		],
		[
			-24,
			73
		],
		[
			-42,
			20
		],
		[
			-126,
			0
		],
		[
			-30,
			32
		],
		[
			-19,
			93
		],
		[
			12,
			83
		],
		[
			-72,
			41
		],
		[
			-36,
			-10
		]
	],
	[
		[
			47228,
			13775
		],
		[
			6,
			51
		],
		[
			-24,
			73
		],
		[
			-66,
			0
		],
		[
			-24,
			62
		]
	],
	[
		[
			47120,
			13961
		],
		[
			60,
			73
		],
		[
			-30,
			31
		],
		[
			90,
			176
		]
	],
	[
		[
			47240,
			14241
		],
		[
			12,
			10
		]
	],
	[
		[
			47252,
			14251
		],
		[
			48,
			73
		],
		[
			49,
			20
		],
		[
			36,
			-62
		],
		[
			42,
			31
		]
	],
	[
		[
			47427,
			14313
		],
		[
			54,
			93
		]
	],
	[
		[
			47481,
			14406
		],
		[
			60,
			83
		],
		[
			102,
			42
		],
		[
			42,
			-11
		]
	],
	[
		[
			47685,
			14520
		],
		[
			24,
			-10
		],
		[
			115,
			41
		],
		[
			108,
			-82
		],
		[
			72,
			-104
		],
		[
			60,
			10
		]
	],
	[
		[
			48485,
			14251
		],
		[
			0,
			-103
		],
		[
			102,
			-63
		],
		[
			60,
			-176
		],
		[
			-78,
			-72
		],
		[
			54,
			-62
		]
	],
	[
		[
			48623,
			13775
		],
		[
			-90,
			-31
		],
		[
			-36,
			-52
		],
		[
			-12,
			-73
		],
		[
			12,
			-62
		],
		[
			-24,
			-83
		],
		[
			-102,
			21
		],
		[
			-42,
			-72
		]
	],
	[
		[
			48329,
			13423
		],
		[
			-37,
			93
		],
		[
			-12,
			83
		],
		[
			-60,
			134
		],
		[
			-36,
			11
		],
		[
			-54,
			82
		]
	],
	[
		[
			48130,
			13826
		],
		[
			12,
			73
		],
		[
			66,
			93
		],
		[
			36,
			93
		],
		[
			145,
			156
		],
		[
			96,
			10
		]
	],
	[
		[
			47619,
			13474
		],
		[
			-12,
			-176
		],
		[
			54,
			-134
		],
		[
			-12,
			-73
		],
		[
			-30,
			-21
		],
		[
			-12,
			-165
		],
		[
			-78,
			-21
		],
		[
			-84,
			62
		],
		[
			-54,
			-31
		],
		[
			48,
			-62
		],
		[
			-24,
			-42
		],
		[
			-36,
			-134
		],
		[
			18,
			-42
		],
		[
			90,
			-72
		],
		[
			48,
			-155
		],
		[
			6,
			-83
		],
		[
			-60,
			-21
		]
	],
	[
		[
			47481,
			12304
		],
		[
			-54,
			21
		],
		[
			-91,
			72
		],
		[
			-72,
			-72
		],
		[
			-66,
			41
		],
		[
			-120,
			-21
		],
		[
			-12,
			42
		],
		[
			-84,
			10
		],
		[
			-12,
			125
		],
		[
			12,
			82
		],
		[
			-127,
			31
		],
		[
			-18,
			42
		],
		[
			-102,
			-31
		],
		[
			-24,
			-83
		],
		[
			-102,
			0
		],
		[
			-24,
			-21
		],
		[
			-18,
			-103
		],
		[
			-78,
			31
		],
		[
			24,
			83
		],
		[
			-36,
			31
		],
		[
			-121,
			41
		],
		[
			-60,
			-52
		],
		[
			-66,
			0
		],
		[
			-12,
			-72
		],
		[
			42,
			-11
		],
		[
			-6,
			-82
		],
		[
			-96,
			-83
		],
		[
			-54,
			114
		],
		[
			-18,
			72
		],
		[
			-54,
			11
		],
		[
			-78,
			-21
		],
		[
			-12,
			-42
		],
		[
			-97,
			21
		],
		[
			-24,
			104
		],
		[
			-78,
			-21
		],
		[
			-66,
			-41
		],
		[
			-84,
			93
		],
		[
			-12,
			72
		],
		[
			36,
			52
		],
		[
			-24,
			104
		]
	],
	[
		[
			45677,
			13309
		],
		[
			66,
			-11
		],
		[
			24,
			31
		],
		[
			66,
			21
		],
		[
			24,
			124
		],
		[
			73,
			156
		],
		[
			90,
			31
		],
		[
			144,
			-52
		]
	],
	[
		[
			46164,
			13609
		],
		[
			-6,
			-73
		],
		[
			42,
			-41
		],
		[
			132,
			-166
		],
		[
			73,
			11
		],
		[
			24,
			31
		],
		[
			66,
			-42
		],
		[
			42,
			-51
		],
		[
			84,
			-32
		],
		[
			48,
			-41
		],
		[
			102,
			-31
		],
		[
			36,
			83
		]
	],
	[
		[
			46807,
			13257
		],
		[
			-60,
			62
		],
		[
			6,
			145
		],
		[
			30,
			41
		]
	],
	[
		[
			46783,
			13505
		],
		[
			60,
			-31
		],
		[
			25,
			52
		],
		[
			48,
			0
		],
		[
			24,
			73
		]
	],
	[
		[
			46940,
			13599
		],
		[
			36,
			10
		],
		[
			48,
			-31
		],
		[
			54,
			72
		],
		[
			60,
			-10
		],
		[
			0,
			73
		],
		[
			-54,
			31
		]
	],
	[
		[
			47084,
			13744
		],
		[
			12,
			41
		],
		[
			66,
			-31
		],
		[
			66,
			21
		]
	],
	[
		[
			48329,
			13423
		],
		[
			36,
			-125
		],
		[
			-6,
			-155
		],
		[
			36,
			-42
		],
		[
			114,
			21
		],
		[
			78,
			-41
		],
		[
			-36,
			-166
		],
		[
			-66,
			-21
		],
		[
			-30,
			-51
		],
		[
			6,
			-63
		],
		[
			60,
			0
		],
		[
			24,
			-51
		]
	],
	[
		[
			48545,
			12729
		],
		[
			42,
			-42
		],
		[
			-12,
			-62
		],
		[
			48,
			-93
		]
	],
	[
		[
			48623,
			12532
		],
		[
			6,
			21
		],
		[
			-6,
			0
		],
		[
			6,
			10
		]
	],
	[
		[
			48629,
			12563
		],
		[
			6,
			-93
		],
		[
			-54,
			-31
		],
		[
			-60,
			0
		],
		[
			6,
			0
		],
		[
			90,
			-125
		],
		[
			84,
			-20
		],
		[
			115,
			41
		],
		[
			60,
			-62
		],
		[
			0,
			-31
		]
	],
	[
		[
			48876,
			12242
		],
		[
			-66,
			-42
		],
		[
			-43,
			0
		],
		[
			-108,
			-113
		],
		[
			-84,
			-42
		],
		[
			-54,
			10
		],
		[
			-60,
			-31
		],
		[
			-30,
			-41
		]
	],
	[
		[
			48431,
			11983
		],
		[
			-72,
			-62
		],
		[
			-115,
			-21
		],
		[
			-30,
			-31
		],
		[
			-78,
			-31
		],
		[
			-72,
			0
		],
		[
			-48,
			21
		],
		[
			-108,
			-73
		],
		[
			-78,
			21
		],
		[
			-55,
			-31
		],
		[
			-162,
			-31
		],
		[
			-48,
			-62
		]
	],
	[
		[
			47565,
			11683
		],
		[
			-84,
			-21
		]
	],
	[
		[
			47481,
			11662
		],
		[
			0,
			41
		]
	],
	[
		[
			47481,
			11703
		],
		[
			24,
			311
		],
		[
			-6,
			197
		],
		[
			-18,
			93
		]
	],
	[
		[
			47992,
			13764
		],
		[
			36,
			-20
		],
		[
			102,
			82
		]
	],
	[
		[
			48996,
			13702
		],
		[
			-30,
			-21
		],
		[
			42,
			-82
		],
		[
			-6,
			-94
		],
		[
			102,
			0
		],
		[
			78,
			-134
		]
	],
	[
		[
			49182,
			13371
		],
		[
			-36,
			-31
		],
		[
			-12,
			-135
		],
		[
			30,
			-52
		],
		[
			-24,
			-62
		],
		[
			-66,
			-31
		],
		[
			0,
			-93
		],
		[
			-72,
			-124
		],
		[
			60,
			-135
		],
		[
			6,
			-52
		],
		[
			48,
			10
		],
		[
			-12,
			-144
		],
		[
			-36,
			-94
		],
		[
			84,
			-114
		],
		[
			6,
			-114
		],
		[
			-42,
			-20
		]
	],
	[
		[
			49116,
			12180
		],
		[
			-30,
			0
		],
		[
			-138,
			0
		],
		[
			-72,
			62
		]
	],
	[
		[
			48623,
			13775
		],
		[
			144,
			134
		],
		[
			121,
			-93
		],
		[
			12,
			-41
		],
		[
			96,
			-73
		]
	],
	[
		[
			46880,
			14769
		],
		[
			66,
			-41
		],
		[
			-6,
			-104
		],
		[
			114,
			-73
		],
		[
			6,
			-113
		],
		[
			30,
			-42
		],
		[
			0,
			-62
		],
		[
			54,
			10
		],
		[
			90,
			-72
		],
		[
			6,
			-31
		]
	],
	[
		[
			47240,
			14241
		],
		[
			12,
			10
		]
	],
	[
		[
			47120,
			13961
		],
		[
			-174,
			-93
		],
		[
			-54,
			52
		],
		[
			-163,
			31
		]
	],
	[
		[
			46729,
			13951
		],
		[
			-12,
			83
		],
		[
			-54,
			51
		],
		[
			-54,
			-20
		],
		[
			-24,
			103
		],
		[
			-120,
			52
		],
		[
			-18,
			93
		],
		[
			-121,
			52
		]
	],
	[
		[
			46958,
			15090
		],
		[
			72,
			-31
		],
		[
			42,
			-41
		],
		[
			72,
			0
		],
		[
			18,
			-32
		],
		[
			90,
			-20
		]
	],
	[
		[
			47252,
			14966
		],
		[
			12,
			-166
		],
		[
			60,
			10
		],
		[
			79,
			-103
		],
		[
			66,
			31
		],
		[
			60,
			-42
		],
		[
			30,
			-51
		],
		[
			78,
			0
		]
	],
	[
		[
			47637,
			14645
		],
		[
			24,
			-21
		],
		[
			24,
			-104
		]
	],
	[
		[
			46729,
			13951
		],
		[
			-72,
			-52
		],
		[
			-66,
			0
		],
		[
			-30,
			-62
		],
		[
			-66,
			31
		],
		[
			-108,
			0
		],
		[
			-49,
			-73
		],
		[
			-54,
			31
		],
		[
			6,
			-72
		],
		[
			-18,
			-104
		],
		[
			-108,
			-41
		]
	],
	[
		[
			49910,
			13775
		],
		[
			24,
			-135
		],
		[
			54,
			-217
		],
		[
			54,
			93
		],
		[
			48,
			52
		],
		[
			48,
			-42
		],
		[
			6,
			-103
		]
	],
	[
		[
			50054,
			11983
		],
		[
			-162,
			0
		],
		[
			-54,
			-10
		],
		[
			-42,
			31
		],
		[
			-36,
			-31
		],
		[
			-121,
			10
		],
		[
			-66,
			-21
		],
		[
			-42,
			42
		],
		[
			-126,
			10
		],
		[
			-42,
			-41
		],
		[
			-109,
			20
		],
		[
			-90,
			0
		],
		[
			-60,
			21
		]
	],
	[
		[
			49104,
			12014
		],
		[
			12,
			166
		]
	],
	[
		[
			49182,
			13371
		],
		[
			36,
			0
		],
		[
			36,
			52
		],
		[
			121,
			82
		],
		[
			12,
			63
		],
		[
			36,
			31
		],
		[
			18,
			82
		],
		[
			90,
			-10
		],
		[
			66,
			31
		],
		[
			30,
			114
		],
		[
			42,
			31
		],
		[
			103,
			11
		],
		[
			24,
			-52
		],
		[
			42,
			10
		],
		[
			72,
			-41
		]
	],
	[
		[
			47481,
			11662
		],
		[
			-114,
			-73
		],
		[
			-31,
			31
		],
		[
			-180,
			-41
		],
		[
			-78,
			10
		],
		[
			-18,
			-31
		]
	],
	[
		[
			47060,
			11558
		],
		[
			-66,
			-51
		],
		[
			-187,
			41
		],
		[
			0,
			-93
		],
		[
			-162,
			0
		],
		[
			-78,
			31
		],
		[
			-66,
			-21
		],
		[
			-36,
			-41
		],
		[
			-54,
			0
		],
		[
			-67,
			41
		],
		[
			-30,
			42
		],
		[
			-156,
			-52
		],
		[
			-96,
			-11
		],
		[
			-24,
			-41
		],
		[
			-126,
			-41
		],
		[
			-43,
			0
		],
		[
			-48,
			51
		],
		[
			-102,
			-10
		],
		[
			-78,
			72
		],
		[
			-90,
			11
		]
	],
	[
		[
			41468,
			25281
		],
		[
			-144,
			-93
		],
		[
			-156,
			-41
		],
		[
			-169,
			-32
		],
		[
			-48,
			11
		],
		[
			-36,
			-124
		],
		[
			18,
			-83
		],
		[
			120,
			-104
		],
		[
			0,
			-41
		],
		[
			61,
			-42
		],
		[
			36,
			-72
		],
		[
			6,
			-83
		],
		[
			-103,
			-21
		],
		[
			-42,
			-93
		]
	],
	[
		[
			41011,
			24463
		],
		[
			-72,
			-72
		],
		[
			-96,
			-11
		],
		[
			-126,
			62
		],
		[
			-30,
			-62
		]
	],
	[
		[
			40687,
			24380
		],
		[
			-91,
			31
		],
		[
			-42,
			52
		],
		[
			-48,
			-21
		],
		[
			12,
			-51
		],
		[
			-48,
			-42
		],
		[
			-30,
			-62
		],
		[
			-96,
			-52
		],
		[
			-42,
			42
		],
		[
			-24,
			-83
		],
		[
			-60,
			0
		],
		[
			-48,
			83
		],
		[
			-73,
			93
		],
		[
			-72,
			114
		],
		[
			-6,
			83
		],
		[
			-108,
			124
		],
		[
			-78,
			176
		],
		[
			-60,
			52
		]
	],
	[
		[
			39773,
			24919
		],
		[
			12,
			72
		],
		[
			60,
			0
		],
		[
			42,
			31
		],
		[
			-54,
			83
		],
		[
			-30,
			83
		],
		[
			-30,
			31
		],
		[
			-12,
			104
		],
		[
			-54,
			10
		],
		[
			-54,
			72
		],
		[
			42,
			63
		],
		[
			-55,
			31
		],
		[
			-66,
			124
		]
	],
	[
		[
			41715,
			25126
		],
		[
			-30,
			-31
		],
		[
			-6,
			-166
		],
		[
			42,
			31
		],
		[
			54,
			-21
		],
		[
			24,
			-134
		],
		[
			-42,
			-135
		],
		[
			24,
			-62
		],
		[
			-24,
			-124
		],
		[
			-66,
			-31
		],
		[
			-90,
			41
		],
		[
			-127,
			-114
		]
	],
	[
		[
			41474,
			24380
		],
		[
			-150,
			11
		],
		[
			-114,
			-63
		],
		[
			-84,
			31
		],
		[
			-91,
			52
		],
		[
			-24,
			52
		]
	],
	[
		[
			42779,
			22474
		],
		[
			-36,
			-10
		],
		[
			-114,
			42
		],
		[
			-72,
			41
		],
		[
			-25,
			62
		],
		[
			-66,
			52
		],
		[
			-48,
			-83
		],
		[
			-78,
			-62
		],
		[
			-36,
			83
		],
		[
			-36,
			0
		],
		[
			-72,
			41
		],
		[
			-72,
			62
		],
		[
			-79,
			31
		],
		[
			-60,
			104
		],
		[
			-126,
			93
		],
		[
			-78,
			21
		],
		[
			-78,
			0
		]
	],
	[
		[
			41703,
			22951
		],
		[
			6,
			83
		],
		[
			48,
			10
		]
	],
	[
		[
			41757,
			23044
		],
		[
			-18,
			62
		],
		[
			-42,
			62
		],
		[
			-90,
			11
		],
		[
			-30,
			52
		],
		[
			-25,
			93
		],
		[
			-48,
			20
		],
		[
			24,
			73
		],
		[
			-78,
			72
		],
		[
			12,
			83
		],
		[
			-18,
			31
		]
	],
	[
		[
			41444,
			23603
		],
		[
			6,
			63
		],
		[
			108,
			62
		],
		[
			49,
			51
		],
		[
			30,
			83
		],
		[
			-42,
			94
		],
		[
			36,
			51
		],
		[
			48,
			156
		],
		[
			-96,
			62
		],
		[
			-25,
			72
		],
		[
			6,
			0
		],
		[
			-90,
			83
		]
	],
	[
		[
			39322,
			23541
		],
		[
			138,
			0
		],
		[
			48,
			-72
		],
		[
			66,
			-31
		],
		[
			24,
			-52
		],
		[
			48,
			-21
		]
	],
	[
		[
			39646,
			23365
		],
		[
			49,
			-186
		],
		[
			-12,
			-83
		],
		[
			48,
			-104
		],
		[
			36,
			-31
		],
		[
			78,
			-20
		],
		[
			42,
			-83
		]
	],
	[
		[
			39887,
			22858
		],
		[
			54,
			41
		],
		[
			66,
			-83
		],
		[
			78,
			11
		],
		[
			55,
			-63
		],
		[
			120,
			21
		],
		[
			-42,
			-155
		],
		[
			6,
			-42
		],
		[
			54,
			-82
		],
		[
			120,
			10
		],
		[
			54,
			-93
		],
		[
			54,
			-11
		],
		[
			12,
			-83
		],
		[
			84,
			11
		],
		[
			25,
			-42
		],
		[
			-37,
			-51
		],
		[
			-78,
			-21
		],
		[
			0,
			-42
		],
		[
			48,
			-62
		]
	],
	[
		[
			40560,
			22122
		],
		[
			115,
			94
		],
		[
			66,
			-21
		]
	],
	[
		[
			40741,
			22195
		],
		[
			6,
			-11
		]
	],
	[
		[
			40747,
			22184
		],
		[
			60,
			-62
		],
		[
			36,
			21
		],
		[
			48,
			124
		],
		[
			30,
			-31
		],
		[
			90,
			0
		],
		[
			66,
			-31
		],
		[
			37,
			52
		],
		[
			30,
			104
		],
		[
			84,
			0
		],
		[
			12,
			-32
		],
		[
			66,
			104
		],
		[
			60,
			124
		],
		[
			72,
			11
		],
		[
			36,
			62
		],
		[
			139,
			31
		],
		[
			-61,
			135
		],
		[
			12,
			72
		],
		[
			109,
			-10
		],
		[
			30,
			93
		]
	],
	[
		[
			39695,
			21149
		],
		[
			-79,
			72
		],
		[
			-72,
			11
		],
		[
			6,
			62
		],
		[
			42,
			41
		],
		[
			-132,
			73
		],
		[
			-90,
			-31
		],
		[
			0,
			83
		],
		[
			-60,
			20
		],
		[
			-30,
			52
		],
		[
			-42,
			-62
		],
		[
			-18,
			-73
		],
		[
			-61,
			11
		],
		[
			-42,
			124
		],
		[
			-96,
			31
		],
		[
			-48,
			-10
		],
		[
			-6,
			-156
		],
		[
			-48,
			-10
		],
		[
			-90,
			83
		],
		[
			-24,
			62
		],
		[
			-108,
			0
		],
		[
			36,
			114
		],
		[
			-6,
			41
		],
		[
			-61,
			11
		],
		[
			-12,
			-31
		],
		[
			-72,
			10
		],
		[
			-6,
			52
		],
		[
			66,
			-11
		],
		[
			49,
			42
		],
		[
			36,
			145
		],
		[
			-6,
			103
		],
		[
			36,
			42
		],
		[
			54,
			21
		],
		[
			18,
			124
		],
		[
			-84,
			228
		]
	],
	[
		[
			38745,
			22423
		],
		[
			-18,
			41
		]
	],
	[
		[
			38727,
			22464
		],
		[
			-6,
			135
		]
	],
	[
		[
			38721,
			22599
		],
		[
			-6,
			93
		],
		[
			120,
			-10
		],
		[
			66,
			31
		],
		[
			42,
			51
		],
		[
			66,
			21
		],
		[
			12,
			73
		],
		[
			48,
			93
		],
		[
			-30,
			62
		]
	],
	[
		[
			39039,
			23013
		],
		[
			60,
			21
		],
		[
			24,
			52
		],
		[
			-6,
			124
		],
		[
			-42,
			83
		],
		[
			-6,
			51
		],
		[
			-54,
			73
		],
		[
			-24,
			72
		],
		[
			78,
			21
		],
		[
			24,
			42
		]
	],
	[
		[
			39093,
			23552
		],
		[
			175,
			-21
		],
		[
			54,
			10
		]
	],
	[
		[
			40657,
			23759
		],
		[
			120,
			-42
		],
		[
			42,
			-31
		],
		[
			30,
			31
		],
		[
			30,
			-83
		],
		[
			42,
			-20
		],
		[
			0,
			-83
		],
		[
			54,
			31
		],
		[
			60,
			83
		],
		[
			61,
			21
		],
		[
			60,
			-94
		],
		[
			54,
			73
		],
		[
			108,
			-11
		],
		[
			60,
			-20
		],
		[
			54,
			31
		],
		[
			12,
			-42
		]
	],
	[
		[
			39646,
			23365
		],
		[
			-18,
			93
		],
		[
			18,
			73
		],
		[
			73,
			-10
		],
		[
			18,
			-52
		],
		[
			66,
			-42
		],
		[
			42,
			21
		],
		[
			42,
			135
		],
		[
			96,
			-31
		],
		[
			-18,
			-94
		],
		[
			60,
			-31
		],
		[
			72,
			11
		],
		[
			24,
			-42
		],
		[
			49,
			42
		],
		[
			6,
			72
		],
		[
			132,
			21
		],
		[
			72,
			-83
		],
		[
			24,
			52
		],
		[
			102,
			41
		],
		[
			18,
			52
		],
		[
			91,
			41
		],
		[
			-7,
			63
		]
	],
	[
		[
			40608,
			23697
		],
		[
			49,
			62
		]
	],
	[
		[
			48653,
			9052
		],
		[
			-78,
			10
		],
		[
			-96,
			-10
		],
		[
			-36,
			31
		],
		[
			-132,
			0
		],
		[
			-73,
			83
		],
		[
			-42,
			135
		],
		[
			12,
			41
		]
	],
	[
		[
			48208,
			9342
		],
		[
			-36,
			21
		]
	],
	[
		[
			48172,
			9363
		],
		[
			-12,
			0
		]
	],
	[
		[
			48160,
			9363
		],
		[
			0,
			31
		]
	],
	[
		[
			48160,
			9394
		],
		[
			6,
			0
		]
	],
	[
		[
			48166,
			9394
		],
		[
			72,
			0
		],
		[
			181,
			-21
		],
		[
			-18,
			83
		],
		[
			84,
			-73
		]
	],
	[
		[
			47793,
			9487
		],
		[
			91,
			-83
		],
		[
			54,
			-31
		],
		[
			162,
			21
		],
		[
			72,
			20
		]
	],
	[
		[
			48172,
			9414
		],
		[
			-12,
			-20
		]
	],
	[
		[
			48160,
			9394
		],
		[
			0,
			-31
		]
	],
	[
		[
			48172,
			9363
		],
		[
			36,
			-21
		]
	],
	[
		[
			48208,
			9342
		],
		[
			-18,
			-52
		],
		[
			42,
			-72
		],
		[
			-6,
			-62
		],
		[
			79,
			-94
		],
		[
			66,
			21
		],
		[
			78,
			-10
		],
		[
			18,
			-31
		],
		[
			-175,
			0
		],
		[
			-138,
			-31
		],
		[
			-174,
			-63
		]
	],
	[
		[
			47980,
			8948
		],
		[
			-36,
			52
		],
		[
			-72,
			0
		],
		[
			-42,
			73
		],
		[
			-13,
			155
		],
		[
			-30,
			0
		],
		[
			-12,
			135
		]
	],
	[
		[
			47775,
			9363
		],
		[
			-24,
			93
		],
		[
			42,
			31
		]
	],
	[
		[
			46729,
			9663
		],
		[
			30,
			31
		]
	],
	[
		[
			46759,
			9694
		],
		[
			-30,
			-31
		]
	],
	[
		[
			46759,
			9694
		],
		[
			-6,
			0
		]
	],
	[
		[
			46753,
			9694
		],
		[
			6,
			10
		]
	],
	[
		[
			46759,
			9704
		],
		[
			0,
			-10
		]
	],
	[
		[
			47775,
			9363
		],
		[
			-84,
			10
		],
		[
			-120,
			-52
		],
		[
			-36,
			-41
		],
		[
			-60,
			72
		],
		[
			-12,
			-186
		],
		[
			-139,
			0
		],
		[
			6,
			-124
		],
		[
			49,
			-228
		]
	],
	[
		[
			47379,
			8814
		],
		[
			-151,
			-11
		],
		[
			-60,
			11
		],
		[
			-198,
			0
		],
		[
			-90,
			-11
		],
		[
			-91,
			11
		],
		[
			-54,
			52
		]
	],
	[
		[
			46735,
			8866
		],
		[
			-72,
			41
		]
	],
	[
		[
			46663,
			8907
		],
		[
			-12,
			62
		]
	],
	[
		[
			46651,
			8969
		],
		[
			-48,
			-31
		]
	],
	[
		[
			46603,
			8938
		],
		[
			-18,
			41
		]
	],
	[
		[
			46585,
			8979
		],
		[
			-12,
			52
		]
	],
	[
		[
			46573,
			9031
		],
		[
			0,
			11
		]
	],
	[
		[
			46573,
			9042
		],
		[
			30,
			20
		]
	],
	[
		[
			46603,
			9062
		],
		[
			24,
			11
		]
	],
	[
		[
			46627,
			9073
		],
		[
			-18,
			20
		]
	],
	[
		[
			46609,
			9093
		],
		[
			-6,
			11
		]
	],
	[
		[
			46603,
			9104
		],
		[
			36,
			31
		]
	],
	[
		[
			46639,
			9135
		],
		[
			6,
			10
		]
	],
	[
		[
			46645,
			9145
		],
		[
			-12,
			21
		]
	],
	[
		[
			46633,
			9166
		],
		[
			12,
			72
		],
		[
			30,
			42
		],
		[
			48,
			10
		]
	],
	[
		[
			46723,
			9290
		],
		[
			18,
			-21
		]
	],
	[
		[
			46741,
			9269
		],
		[
			36,
			21
		]
	],
	[
		[
			46777,
			9290
		],
		[
			-30,
			62
		],
		[
			12,
			62
		]
	],
	[
		[
			46759,
			9414
		],
		[
			6,
			0
		]
	],
	[
		[
			46765,
			9414
		],
		[
			72,
			-20
		],
		[
			31,
			31
		],
		[
			-49,
			62
		],
		[
			-42,
			0
		]
	],
	[
		[
			46777,
			9487
		],
		[
			-6,
			31
		]
	],
	[
		[
			46771,
			9518
		],
		[
			12,
			31
		]
	],
	[
		[
			46783,
			9549
		],
		[
			-6,
			10
		]
	],
	[
		[
			46777,
			9559
		],
		[
			-18,
			0
		]
	],
	[
		[
			46759,
			9559
		],
		[
			36,
			42
		],
		[
			48,
			-52
		],
		[
			61,
			83
		],
		[
			24,
			-10
		],
		[
			84,
			103
		],
		[
			30,
			-83
		],
		[
			66,
			73
		],
		[
			48,
			-42
		],
		[
			-12,
			-83
		],
		[
			72,
			-10
		],
		[
			12,
			62
		],
		[
			42,
			62
		],
		[
			30,
			-145
		],
		[
			61,
			-41
		],
		[
			48,
			114
		],
		[
			36,
			-31
		],
		[
			108,
			-21
		],
		[
			78,
			83
		],
		[
			72,
			-73
		],
		[
			78,
			-10
		],
		[
			12,
			-93
		]
	],
	[
		[
			46693,
			9756
		],
		[
			12,
			-10
		],
		[
			42,
			-21
		]
	],
	[
		[
			46747,
			9725
		],
		[
			12,
			-10
		]
	],
	[
		[
			46759,
			9715
		],
		[
			0,
			-11
		]
	],
	[
		[
			46753,
			9694
		],
		[
			-24,
			-31
		]
	],
	[
		[
			46729,
			9663
		],
		[
			-60,
			-31
		],
		[
			6,
			-52
		]
	],
	[
		[
			46675,
			9580
		],
		[
			54,
			-41
		]
	],
	[
		[
			46729,
			9539
		],
		[
			48,
			20
		]
	],
	[
		[
			46777,
			9559
		],
		[
			6,
			-10
		]
	],
	[
		[
			46783,
			9549
		],
		[
			-12,
			-31
		]
	],
	[
		[
			46771,
			9518
		],
		[
			6,
			-31
		]
	],
	[
		[
			46777,
			9487
		],
		[
			24,
			-62
		]
	],
	[
		[
			46801,
			9425
		],
		[
			-36,
			-11
		]
	],
	[
		[
			46759,
			9414
		],
		[
			18,
			-124
		]
	],
	[
		[
			46777,
			9290
		],
		[
			-36,
			-21
		]
	],
	[
		[
			46741,
			9269
		],
		[
			-18,
			21
		]
	],
	[
		[
			46723,
			9290
		],
		[
			-66,
			-21
		],
		[
			-24,
			-103
		]
	],
	[
		[
			46633,
			9166
		],
		[
			12,
			-21
		]
	],
	[
		[
			46639,
			9135
		],
		[
			-36,
			-31
		]
	],
	[
		[
			46603,
			9104
		],
		[
			6,
			-11
		]
	],
	[
		[
			46609,
			9093
		],
		[
			18,
			-20
		]
	],
	[
		[
			46603,
			9062
		],
		[
			-30,
			-20
		]
	],
	[
		[
			46573,
			9031
		],
		[
			12,
			-52
		]
	],
	[
		[
			46585,
			8979
		],
		[
			18,
			-41
		]
	],
	[
		[
			46603,
			8938
		],
		[
			48,
			31
		]
	],
	[
		[
			46651,
			8969
		],
		[
			12,
			-62
		]
	],
	[
		[
			46663,
			8907
		],
		[
			72,
			-41
		]
	],
	[
		[
			46735,
			8866
		],
		[
			24,
			-83
		],
		[
			-72,
			10
		],
		[
			-180,
			-52
		],
		[
			-96,
			-41
		],
		[
			-73,
			0
		],
		[
			-78,
			-31
		],
		[
			-96,
			0
		],
		[
			-204,
			-73
		],
		[
			-121,
			-20
		],
		[
			-168,
			-73
		],
		[
			-120,
			-114
		]
	],
	[
		[
			45551,
			8389
		],
		[
			-6,
			10
		],
		[
			0,
			11
		],
		[
			24,
			41
		],
		[
			-78,
			83
		]
	],
	[
		[
			45491,
			8534
		],
		[
			36,
			73
		],
		[
			12,
			93
		],
		[
			96,
			10
		],
		[
			48,
			166
		],
		[
			66,
			-21
		],
		[
			48,
			11
		],
		[
			54,
			51
		],
		[
			67,
			-10
		],
		[
			18,
			93
		],
		[
			-36,
			124
		],
		[
			0,
			83
		],
		[
			18,
			73
		],
		[
			48,
			103
		],
		[
			174,
			31
		],
		[
			-12,
			145
		],
		[
			-30,
			52
		],
		[
			6,
			145
		],
		[
			48,
			-31
		],
		[
			66,
			21
		],
		[
			18,
			31
		],
		[
			96,
			0
		],
		[
			73,
			-31
		],
		[
			66,
			10
		],
		[
			84,
			-31
		],
		[
			114,
			10
		],
		[
			24,
			21
		]
	],
	[
		[
			44571,
			9083
		],
		[
			6,
			0
		]
	],
	[
		[
			44577,
			9083
		],
		[
			12,
			-21
		]
	],
	[
		[
			44589,
			9062
		],
		[
			18,
			-10
		]
	],
	[
		[
			44607,
			9052
		],
		[
			48,
			-83
		],
		[
			-18,
			-155
		],
		[
			-156,
			145
		],
		[
			-18,
			83
		],
		[
			18,
			41
		]
	],
	[
		[
			44481,
			9083
		],
		[
			36,
			-21
		],
		[
			54,
			21
		]
	],
	[
		[
			46765,
			9860
		],
		[
			12,
			0
		]
	],
	[
		[
			46777,
			9860
		],
		[
			18,
			20
		]
	],
	[
		[
			46795,
			9880
		],
		[
			-30,
			-20
		]
	],
	[
		[
			47108,
			11206
		],
		[
			42,
			0
		],
		[
			-18,
			-114
		],
		[
			30,
			-83
		],
		[
			-18,
			-155
		],
		[
			-42,
			-10
		],
		[
			0,
			-73
		],
		[
			-48,
			0
		]
	],
	[
		[
			47054,
			10771
		],
		[
			-138,
			-93
		],
		[
			48,
			-41
		],
		[
			-6,
			-63
		],
		[
			-84,
			-10
		],
		[
			-31,
			-93
		]
	],
	[
		[
			46843,
			10471
		],
		[
			0,
			-31
		]
	],
	[
		[
			46843,
			10440
		],
		[
			12,
			-11
		]
	],
	[
		[
			46855,
			10429
		],
		[
			-6,
			-10
		]
	],
	[
		[
			46849,
			10419
		],
		[
			0,
			-10
		]
	],
	[
		[
			46849,
			10409
		],
		[
			-12,
			-52
		]
	],
	[
		[
			46837,
			10357
		],
		[
			18,
			-21
		]
	],
	[
		[
			46855,
			10336
		],
		[
			-24,
			-41
		]
	],
	[
		[
			46831,
			10295
		],
		[
			-24,
			-31
		]
	],
	[
		[
			46807,
			10264
		],
		[
			6,
			-21
		]
	],
	[
		[
			46813,
			10243
		],
		[
			12,
			-10
		]
	],
	[
		[
			46825,
			10233
		],
		[
			-30,
			-52
		],
		[
			-42,
			52
		],
		[
			-72,
			-11
		],
		[
			-66,
			-93
		],
		[
			0,
			-72
		],
		[
			66,
			-52
		],
		[
			6,
			-52
		],
		[
			60,
			-31
		]
	],
	[
		[
			46747,
			9922
		],
		[
			48,
			-31
		]
	],
	[
		[
			46795,
			9891
		],
		[
			0,
			-11
		]
	],
	[
		[
			46795,
			9880
		],
		[
			-18,
			-20
		]
	],
	[
		[
			46765,
			9860
		],
		[
			-36,
			0
		]
	],
	[
		[
			46729,
			9860
		],
		[
			-42,
			-83
		]
	],
	[
		[
			46687,
			9777
		],
		[
			6,
			-21
		]
	],
	[
		[
			45491,
			8534
		],
		[
			-6,
			-41
		],
		[
			-91,
			0
		],
		[
			6,
			-62
		],
		[
			79,
			-42
		],
		[
			24,
			-62
		],
		[
			48,
			62
		]
	],
	[
		[
			45551,
			8389
		],
		[
			-48,
			-72
		],
		[
			-12,
			-63
		],
		[
			-72,
			-124
		],
		[
			-55,
			-72
		],
		[
			-48,
			10
		],
		[
			-150,
			166
		],
		[
			-132,
			114
		],
		[
			-121,
			83
		],
		[
			-246,
			113
		],
		[
			-36,
			63
		],
		[
			48,
			62
		],
		[
			54,
			31
		],
		[
			18,
			72
		],
		[
			54,
			73
		],
		[
			78,
			21
		],
		[
			109,
			-73
		],
		[
			60,
			0
		],
		[
			24,
			41
		],
		[
			60,
			0
		],
		[
			0,
			52
		],
		[
			60,
			42
		],
		[
			36,
			145
		],
		[
			-54,
			-21
		],
		[
			-12,
			-104
		],
		[
			-132,
			-114
		],
		[
			-84,
			21
		],
		[
			-73,
			104
		],
		[
			48,
			103
		],
		[
			-6,
			83
		],
		[
			-42,
			0
		],
		[
			-18,
			-62
		],
		[
			42,
			-41
		],
		[
			-54,
			-83
		],
		[
			-18,
			-62
		],
		[
			-84,
			62
		],
		[
			-12,
			72
		],
		[
			0,
			125
		],
		[
			-126,
			-32
		],
		[
			0,
			-72
		]
	],
	[
		[
			44607,
			9052
		],
		[
			-18,
			10
		]
	],
	[
		[
			44589,
			9062
		],
		[
			-12,
			21
		]
	],
	[
		[
			44571,
			9083
		],
		[
			-90,
			0
		]
	],
	[
		[
			44481,
			9083
		],
		[
			42,
			83
		],
		[
			-6,
			31
		]
	],
	[
		[
			44517,
			9197
		],
		[
			0,
			21
		]
	],
	[
		[
			47060,
			11558
		],
		[
			12,
			-41
		],
		[
			36,
			-311
		]
	],
	[
		[
			49104,
			12014
		],
		[
			-24,
			-145
		],
		[
			30,
			-135
		],
		[
			-54,
			-103
		],
		[
			-96,
			-93
		],
		[
			-193,
			-52
		],
		[
			-90,
			0
		]
	],
	[
		[
			48677,
			11486
		],
		[
			-60,
			114
		],
		[
			-48,
			31
		],
		[
			-30,
			103
		],
		[
			78,
			31
		],
		[
			0,
			83
		],
		[
			48,
			42
		],
		[
			42,
			103
		],
		[
			-114,
			21
		],
		[
			-84,
			0
		],
		[
			-78,
			-31
		]
	],
	[
		[
			46988,
			10243
		],
		[
			6,
			-21
		]
	],
	[
		[
			46994,
			10222
		],
		[
			6,
			-10
		]
	],
	[
		[
			47000,
			10212
		],
		[
			-6,
			-10
		]
	],
	[
		[
			46994,
			10202
		],
		[
			0,
			-21
		]
	],
	[
		[
			46994,
			10181
		],
		[
			0,
			-21
		]
	],
	[
		[
			46994,
			10160
		],
		[
			-30,
			-21
		]
	],
	[
		[
			46964,
			10139
		],
		[
			-24,
			0
		]
	],
	[
		[
			46940,
			10139
		],
		[
			6,
			-51
		]
	],
	[
		[
			46946,
			10088
		],
		[
			-6,
			-21
		]
	],
	[
		[
			46940,
			10067
		],
		[
			-36,
			0
		]
	],
	[
		[
			46904,
			10067
		],
		[
			-36,
			0
		]
	],
	[
		[
			46868,
			10067
		],
		[
			-6,
			21
		]
	],
	[
		[
			46862,
			10088
		],
		[
			-19,
			0
		]
	],
	[
		[
			46843,
			10088
		],
		[
			-24,
			-42
		]
	],
	[
		[
			46819,
			10046
		],
		[
			-54,
			-31
		]
	],
	[
		[
			46765,
			10015
		],
		[
			-30,
			-62
		]
	],
	[
		[
			46735,
			9953
		],
		[
			18,
			-21
		]
	],
	[
		[
			46753,
			9932
		],
		[
			-6,
			-10
		]
	],
	[
		[
			46825,
			10233
		],
		[
			18,
			-11
		]
	],
	[
		[
			46843,
			10222
		],
		[
			12,
			0
		]
	],
	[
		[
			46855,
			10222
		],
		[
			61,
			31
		]
	],
	[
		[
			46916,
			10253
		],
		[
			42,
			11
		]
	],
	[
		[
			46958,
			10264
		],
		[
			30,
			-21
		]
	],
	[
		[
			48677,
			11486
		],
		[
			6,
			-73
		],
		[
			-30,
			-134
		],
		[
			-42,
			-42
		],
		[
			18,
			-83
		],
		[
			-54,
			-124
		],
		[
			-102,
			-41
		],
		[
			-12,
			-83
		],
		[
			66,
			-31
		],
		[
			-42,
			-93
		],
		[
			72,
			-11
		],
		[
			-18,
			-62
		],
		[
			-6,
			-104
		],
		[
			42,
			-62
		],
		[
			-54,
			-93
		],
		[
			-18,
			-83
		],
		[
			6,
			-155
		],
		[
			90,
			-31
		],
		[
			-36,
			-114
		]
	],
	[
		[
			48563,
			10067
		],
		[
			24,
			-218
		],
		[
			-72,
			-51
		],
		[
			-24,
			-104
		],
		[
			0,
			-104
		],
		[
			-30,
			-113
		],
		[
			54,
			-52
		]
	],
	[
		[
			48166,
			9394
		],
		[
			6,
			20
		]
	],
	[
		[
			46759,
			9559
		],
		[
			-30,
			-20
		]
	],
	[
		[
			46675,
			9580
		],
		[
			0,
			52
		],
		[
			54,
			31
		]
	],
	[
		[
			46759,
			9694
		],
		[
			0,
			21
		]
	],
	[
		[
			46747,
			9725
		],
		[
			-54,
			31
		]
	],
	[
		[
			46687,
			9777
		],
		[
			42,
			83
		]
	],
	[
		[
			46729,
			9860
		],
		[
			36,
			0
		]
	],
	[
		[
			46795,
			9880
		],
		[
			0,
			11
		]
	],
	[
		[
			46795,
			9891
		],
		[
			-42,
			41
		]
	],
	[
		[
			46753,
			9932
		],
		[
			-18,
			21
		]
	],
	[
		[
			46735,
			9953
		],
		[
			30,
			62
		]
	],
	[
		[
			46765,
			10015
		],
		[
			54,
			31
		]
	],
	[
		[
			46819,
			10046
		],
		[
			24,
			42
		]
	],
	[
		[
			46843,
			10088
		],
		[
			19,
			0
		]
	],
	[
		[
			46868,
			10067
		],
		[
			36,
			0
		]
	],
	[
		[
			46904,
			10067
		],
		[
			36,
			0
		]
	],
	[
		[
			46940,
			10067
		],
		[
			6,
			21
		]
	],
	[
		[
			46946,
			10088
		],
		[
			-6,
			51
		]
	],
	[
		[
			46940,
			10139
		],
		[
			24,
			0
		]
	],
	[
		[
			46994,
			10160
		],
		[
			0,
			21
		]
	],
	[
		[
			46994,
			10202
		],
		[
			6,
			10
		]
	],
	[
		[
			47000,
			10212
		],
		[
			-6,
			10
		]
	],
	[
		[
			46994,
			10222
		],
		[
			-6,
			21
		]
	],
	[
		[
			46988,
			10243
		],
		[
			-30,
			21
		]
	],
	[
		[
			46958,
			10264
		],
		[
			-42,
			-11
		]
	],
	[
		[
			46855,
			10222
		],
		[
			-12,
			0
		]
	],
	[
		[
			46843,
			10222
		],
		[
			-30,
			21
		]
	],
	[
		[
			46807,
			10264
		],
		[
			24,
			31
		]
	],
	[
		[
			46831,
			10295
		],
		[
			24,
			41
		]
	],
	[
		[
			46837,
			10357
		],
		[
			12,
			52
		]
	],
	[
		[
			46849,
			10419
		],
		[
			6,
			10
		]
	],
	[
		[
			46843,
			10440
		],
		[
			0,
			31
		]
	],
	[
		[
			47980,
			8948
		],
		[
			-138,
			-41
		],
		[
			-91,
			-41
		],
		[
			-282,
			-32
		],
		[
			-90,
			-20
		]
	],
	[
		[
			38119,
			24246
		],
		[
			18,
			-83
		]
	],
	[
		[
			38137,
			24163
		],
		[
			42,
			-52
		],
		[
			31,
			72
		],
		[
			42,
			-20
		]
	],
	[
		[
			38252,
			24163
		],
		[
			42,
			-62
		],
		[
			36,
			-11
		],
		[
			36,
			-72
		],
		[
			-6,
			-73
		],
		[
			-60,
			11
		],
		[
			-72,
			-94
		],
		[
			60,
			-134
		],
		[
			78,
			-52
		],
		[
			48,
			10
		],
		[
			36,
			52
		],
		[
			42,
			0
		],
		[
			60,
			41
		],
		[
			36,
			-31
		],
		[
			30,
			42
		],
		[
			85,
			-31
		],
		[
			36,
			10
		],
		[
			132,
			124
		],
		[
			78,
			-10
		],
		[
			54,
			21
		],
		[
			24,
			-52
		],
		[
			84,
			52
		]
	],
	[
		[
			39111,
			23904
		],
		[
			133,
			-42
		],
		[
			-18,
			-62
		],
		[
			-73,
			-93
		],
		[
			-12,
			-73
		],
		[
			-48,
			-82
		]
	],
	[
		[
			39039,
			23013
		],
		[
			-66,
			104
		],
		[
			-96,
			-11
		],
		[
			-18,
			21
		],
		[
			-168,
			10
		],
		[
			-49,
			-20
		],
		[
			-60,
			-63
		],
		[
			-48,
			-20
		],
		[
			-132,
			-197
		],
		[
			-60,
			-31
		],
		[
			-6,
			-83
		]
	],
	[
		[
			38336,
			22723
		],
		[
			-72,
			-10
		],
		[
			-109,
			41
		],
		[
			-54,
			42
		],
		[
			-84,
			-32
		],
		[
			-108,
			52
		],
		[
			-72,
			0
		],
		[
			24,
			73
		],
		[
			-18,
			62
		],
		[
			12,
			103
		],
		[
			-90,
			-10
		],
		[
			-61,
			10
		],
		[
			-36,
			42
		],
		[
			12,
			72
		],
		[
			-30,
			125
		],
		[
			-30,
			51
		],
		[
			-60,
			42
		]
	],
	[
		[
			37560,
			23386
		],
		[
			48,
			83
		],
		[
			54,
			0
		],
		[
			-24,
			134
		],
		[
			-84,
			197
		],
		[
			18,
			42
		],
		[
			54,
			31
		],
		[
			-48,
			83
		],
		[
			-138,
			-11
		],
		[
			-54,
			135
		]
	],
	[
		[
			37398,
			24142
		],
		[
			108,
			-41
		],
		[
			60,
			0
		],
		[
			42,
			41
		]
	],
	[
		[
			37608,
			24142
		],
		[
			96,
			62
		],
		[
			43,
			73
		],
		[
			36,
			10
		],
		[
			48,
			-31
		],
		[
			24,
			-93
		],
		[
			138,
			0
		],
		[
			18,
			72
		],
		[
			54,
			-10
		],
		[
			54,
			21
		]
	],
	[
		[
			35955,
			23552
		],
		[
			18,
			-73
		],
		[
			-12,
			-52
		],
		[
			-48,
			-51
		],
		[
			12,
			-63
		],
		[
			-30,
			-93
		],
		[
			-42,
			-21
		],
		[
			-6,
			-72
		],
		[
			108,
			0
		],
		[
			18,
			21
		],
		[
			102,
			-31
		],
		[
			114,
			31
		],
		[
			18,
			-73
		],
		[
			66,
			-21
		],
		[
			73,
			52
		],
		[
			66,
			-20
		],
		[
			66,
			51
		],
		[
			6,
			114
		],
		[
			54,
			42
		],
		[
			54,
			-21
		],
		[
			0,
			-83
		],
		[
			30,
			-62
		],
		[
			138,
			62
		],
		[
			55,
			-52
		]
	],
	[
		[
			36815,
			23137
		],
		[
			6,
			-41
		],
		[
			-48,
			-73
		],
		[
			-13,
			-124
		],
		[
			31,
			-176
		],
		[
			-31,
			-62
		],
		[
			61,
			-52
		],
		[
			78,
			-10
		],
		[
			78,
			-93
		],
		[
			42,
			-73
		],
		[
			-30,
			-72
		],
		[
			18,
			-42
		],
		[
			-54,
			-41
		],
		[
			-6,
			-104
		]
	],
	[
		[
			36947,
			22174
		],
		[
			0,
			-41
		],
		[
			48,
			-52
		],
		[
			-78,
			-42
		]
	],
	[
		[
			36917,
			22039
		],
		[
			-18,
			-103
		],
		[
			-54,
			0
		],
		[
			0,
			-124
		],
		[
			42,
			10
		],
		[
			48,
			-104
		],
		[
			36,
			-41
		],
		[
			66,
			-21
		],
		[
			42,
			11
		],
		[
			18,
			-52
		],
		[
			36,
			0
		],
		[
			42,
			52
		]
	],
	[
		[
			37175,
			21667
		],
		[
			36,
			-52
		],
		[
			18,
			-104
		],
		[
			31,
			-51
		],
		[
			114,
			-11
		],
		[
			-24,
			-72
		],
		[
			-72,
			-62
		],
		[
			-37,
			0
		],
		[
			37,
			-114
		],
		[
			54,
			-73
		],
		[
			42,
			-21
		],
		[
			54,
			11
		],
		[
			66,
			-52
		],
		[
			-18,
			-93
		],
		[
			-24,
			0
		],
		[
			-6,
			-104
		],
		[
			24,
			-124
		],
		[
			-30,
			-83
		],
		[
			-42,
			0
		],
		[
			-36,
			-124
		]
	],
	[
		[
			38727,
			22464
		],
		[
			-67,
			-10
		],
		[
			-78,
			-104
		],
		[
			-42,
			-31
		],
		[
			-132,
			10
		],
		[
			-18,
			-20
		],
		[
			-132,
			10
		],
		[
			-18,
			42
		],
		[
			30,
			145
		],
		[
			18,
			31
		],
		[
			-24,
			93
		],
		[
			48,
			0
		],
		[
			24,
			93
		]
	],
	[
		[
			36947,
			22174
		],
		[
			84,
			31
		],
		[
			36,
			62
		],
		[
			78,
			-62
		],
		[
			84,
			-10
		],
		[
			133,
			-52
		],
		[
			78,
			-52
		],
		[
			-42,
			-114
		],
		[
			-36,
			-155
		],
		[
			-48,
			0
		],
		[
			-30,
			-41
		],
		[
			-18,
			-83
		],
		[
			-91,
			-31
		]
	],
	[
		[
			36815,
			23137
		],
		[
			36,
			42
		],
		[
			-48,
			52
		]
	],
	[
		[
			36803,
			23231
		],
		[
			36,
			72
		],
		[
			48,
			0
		],
		[
			48,
			186
		],
		[
			90,
			0
		],
		[
			54,
			-20
		],
		[
			90,
			-73
		],
		[
			12,
			-52
		],
		[
			42,
			-41
		],
		[
			31,
			-114
		],
		[
			54,
			21
		],
		[
			42,
			-31
		],
		[
			-12,
			-83
		],
		[
			48,
			-10
		],
		[
			0,
			62
		],
		[
			90,
			114
		],
		[
			30,
			82
		],
		[
			54,
			42
		]
	],
	[
		[
			48317,
			18539
		],
		[
			60,
			-21
		],
		[
			48,
			-103
		],
		[
			18,
			0
		],
		[
			54,
			-94
		],
		[
			-18,
			-51
		],
		[
			-181,
			-83
		],
		[
			31,
			-62
		],
		[
			-31,
			-145
		],
		[
			61,
			-73
		],
		[
			78,
			-197
		],
		[
			42,
			42
		],
		[
			24,
			-83
		],
		[
			-30,
			-42
		],
		[
			12,
			-62
		],
		[
			-60,
			-20
		]
	],
	[
		[
			48900,
			18736
		],
		[
			24,
			-21
		],
		[
			12,
			-93
		],
		[
			-18,
			-52
		]
	],
	[
		[
			48918,
			18570
		],
		[
			-18,
			10
		]
	],
	[
		[
			48900,
			18580
		],
		[
			18,
			-10
		]
	],
	[
		[
			48918,
			18570
		],
		[
			12,
			-62
		],
		[
			-24,
			-73
		],
		[
			-66,
			-93
		],
		[
			102,
			-52
		],
		[
			90,
			-72
		],
		[
			-60,
			-42
		],
		[
			-24,
			-72
		],
		[
			126,
			-145
		]
	],
	[
		[
			49074,
			17959
		],
		[
			0,
			-176
		],
		[
			24,
			-31
		],
		[
			0,
			-135
		],
		[
			84,
			42
		],
		[
			109,
			0
		],
		[
			36,
			-52
		]
	],
	[
		[
			49291,
			17182
		],
		[
			-97,
			-31
		],
		[
			-78,
			10
		],
		[
			-54,
			-31
		],
		[
			-108,
			21
		]
	],
	[
		[
			48894,
			18912
		],
		[
			150,
			-52
		],
		[
			-42,
			83
		],
		[
			-18,
			93
		],
		[
			30,
			104
		],
		[
			-36,
			20
		]
	],
	[
		[
			48978,
			19160
		],
		[
			18,
			145
		],
		[
			-36,
			31
		]
	],
	[
		[
			36165,
			35452
		],
		[
			-12,
			-42
		],
		[
			36,
			-103
		],
		[
			36,
			0
		],
		[
			30,
			-52
		],
		[
			-12,
			-73
		],
		[
			-54,
			-114
		],
		[
			-6,
			-72
		],
		[
			18,
			-93
		],
		[
			66,
			-42
		],
		[
			31,
			-72
		],
		[
			-67,
			-83
		],
		[
			91,
			-41
		],
		[
			54,
			-42
		],
		[
			24,
			-93
		]
	],
	[
		[
			36400,
			34530
		],
		[
			-60,
			41
		],
		[
			-30,
			-20
		],
		[
			-6,
			-83
		],
		[
			-175,
			41
		],
		[
			-90,
			73
		],
		[
			-48,
			-11
		],
		[
			-72,
			31
		],
		[
			-90,
			11
		],
		[
			-25,
			-73
		],
		[
			-60,
			-51
		]
	],
	[
		[
			35744,
			34489
		],
		[
			-102,
			31
		],
		[
			-18,
			-11
		],
		[
			-150,
			62
		],
		[
			-48,
			0
		],
		[
			-84,
			-103
		]
	],
	[
		[
			35342,
			34468
		],
		[
			-61,
			-42
		]
	],
	[
		[
			35281,
			34426
		],
		[
			-36,
			63
		]
	],
	[
		[
			35245,
			34489
		],
		[
			-18,
			10
		]
	],
	[
		[
			35227,
			34499
		],
		[
			-78,
			72
		],
		[
			-54,
			125
		],
		[
			24,
			93
		],
		[
			-48,
			103
		],
		[
			-60,
			52
		],
		[
			-36,
			73
		],
		[
			-60,
			31
		],
		[
			-175,
			52
		]
	],
	[
		[
			36785,
			35296
		],
		[
			72,
			-83
		],
		[
			48,
			11
		],
		[
			12,
			-42
		],
		[
			-60,
			-103
		],
		[
			-103,
			0
		],
		[
			-24,
			-93
		],
		[
			73,
			-11
		],
		[
			18,
			52
		],
		[
			36,
			-10
		],
		[
			84,
			-125
		],
		[
			18,
			-134
		],
		[
			24,
			-42
		],
		[
			18,
			-103
		],
		[
			-18,
			-31
		]
	],
	[
		[
			36983,
			34582
		],
		[
			-60,
			51
		],
		[
			-66,
			-10
		],
		[
			-54,
			-62
		],
		[
			24,
			-114
		],
		[
			72,
			10
		],
		[
			-30,
			-72
		]
	],
	[
		[
			36869,
			34385
		],
		[
			-84,
			0
		],
		[
			-115,
			-52
		],
		[
			-66,
			42
		],
		[
			0,
			51
		],
		[
			-60,
			52
		],
		[
			-54,
			-10
		],
		[
			-90,
			62
		]
	],
	[
		[
			36983,
			34582
		],
		[
			138,
			31
		],
		[
			42,
			-83
		],
		[
			115,
			-41
		]
	],
	[
		[
			37278,
			34489
		],
		[
			78,
			-21
		],
		[
			42,
			-62
		],
		[
			36,
			20
		],
		[
			24,
			-41
		],
		[
			-36,
			-52
		],
		[
			-60,
			11
		],
		[
			-24,
			-104
		],
		[
			78,
			-41
		],
		[
			-6,
			-52
		]
	],
	[
		[
			37410,
			34147
		],
		[
			-36,
			-42
		],
		[
			18,
			-93
		],
		[
			90,
			-52
		],
		[
			24,
			-51
		],
		[
			-30,
			-94
		],
		[
			-36,
			-20
		]
	],
	[
		[
			37440,
			33795
		],
		[
			-84,
			-73
		],
		[
			-24,
			-135
		],
		[
			-60,
			21
		]
	],
	[
		[
			37272,
			33608
		],
		[
			-37,
			-62
		],
		[
			-96,
			-104
		],
		[
			-30,
			-62
		]
	],
	[
		[
			37109,
			33380
		],
		[
			-24,
			-83
		],
		[
			-96,
			-10
		],
		[
			-60,
			-52
		],
		[
			0,
			-72
		],
		[
			30,
			-62
		],
		[
			24,
			-114
		],
		[
			-24,
			-93
		]
	],
	[
		[
			36538,
			32873
		],
		[
			90,
			31
		],
		[
			66,
			145
		],
		[
			-78,
			83
		],
		[
			6,
			52
		],
		[
			-30,
			62
		],
		[
			-90,
			134
		],
		[
			114,
			-10
		],
		[
			66,
			52
		],
		[
			66,
			0
		],
		[
			12,
			31
		]
	],
	[
		[
			36760,
			33453
		],
		[
			-48,
			52
		],
		[
			-42,
			134
		],
		[
			30,
			93
		],
		[
			85,
			21
		],
		[
			102,
			93
		],
		[
			6,
			0
		],
		[
			-78,
			83
		],
		[
			6,
			31
		]
	],
	[
		[
			36821,
			33960
		],
		[
			12,
			31
		],
		[
			102,
			83
		],
		[
			-60,
			135
		],
		[
			60,
			72
		],
		[
			-6,
			73
		],
		[
			-60,
			31
		]
	],
	[
		[
			38300,
			35317
		],
		[
			6,
			-41
		],
		[
			48,
			-42
		],
		[
			102,
			-176
		],
		[
			84,
			-93
		],
		[
			60,
			-21
		],
		[
			60,
			-52
		],
		[
			24,
			-93
		],
		[
			133,
			-103
		],
		[
			36,
			10
		],
		[
			18,
			-124
		]
	],
	[
		[
			38564,
			34312
		],
		[
			-150,
			73
		],
		[
			-42,
			41
		],
		[
			-72,
			-31
		],
		[
			-42,
			21
		],
		[
			-42,
			62
		],
		[
			-55,
			21
		],
		[
			-102,
			0
		],
		[
			-30,
			-73
		],
		[
			-72,
			0
		],
		[
			-36,
			-20
		],
		[
			-108,
			0
		],
		[
			-60,
			-104
		],
		[
			-91,
			-31
		],
		[
			-6,
			-41
		],
		[
			-66,
			-31
		],
		[
			-24,
			-63
		],
		[
			-156,
			11
		]
	],
	[
		[
			37278,
			34489
		],
		[
			90,
			144
		],
		[
			-6,
			135
		],
		[
			120,
			83
		],
		[
			-12,
			114
		],
		[
			36,
			41
		],
		[
			54,
			-10
		],
		[
			66,
			31
		],
		[
			12,
			31
		],
		[
			6,
			0
		],
		[
			54,
			31
		],
		[
			6,
			62
		],
		[
			103,
			-31
		],
		[
			144,
			-10
		]
	],
	[
		[
			37951,
			35110
		],
		[
			54,
			-21
		],
		[
			24,
			42
		]
	],
	[
		[
			38029,
			35131
		],
		[
			114,
			51
		],
		[
			30,
			73
		],
		[
			-12,
			41
		],
		[
			36,
			94
		]
	],
	[
		[
			38197,
			35390
		],
		[
			25,
			-83
		],
		[
			78,
			10
		]
	],
	[
		[
			37506,
			35928
		],
		[
			78,
			21
		],
		[
			42,
			-83
		],
		[
			42,
			-41
		],
		[
			121,
			20
		],
		[
			66,
			-20
		],
		[
			12,
			62
		],
		[
			60,
			0
		],
		[
			66,
			51
		],
		[
			60,
			11
		],
		[
			-12,
			-62
		],
		[
			12,
			-73
		],
		[
			90,
			-83
		],
		[
			-24,
			-93
		],
		[
			-6,
			-93
		],
		[
			72,
			-62
		],
		[
			12,
			-93
		]
	],
	[
		[
			36821,
			33960
		],
		[
			-85,
			-72
		],
		[
			-24,
			0
		],
		[
			-228,
			145
		],
		[
			-168,
			-52
		],
		[
			-199,
			-114
		],
		[
			-96,
			-93
		],
		[
			-36,
			-73
		],
		[
			-42,
			-134
		],
		[
			-54,
			-52
		],
		[
			-133,
			-93
		]
	],
	[
		[
			35522,
			33836
		],
		[
			54,
			21
		],
		[
			90,
			0
		],
		[
			175,
			31
		],
		[
			-18,
			155
		],
		[
			42,
			218
		],
		[
			60,
			20
		],
		[
			-12,
			125
		],
		[
			-181,
			51
		],
		[
			12,
			32
		]
	],
	[
		[
			37440,
			33795
		],
		[
			18,
			-42
		],
		[
			66,
			-62
		],
		[
			12,
			-52
		],
		[
			72,
			11
		],
		[
			78,
			-11
		]
	],
	[
		[
			37686,
			33639
		],
		[
			73,
			-62
		],
		[
			24,
			42
		],
		[
			54,
			10
		],
		[
			24,
			-42
		]
	],
	[
		[
			37861,
			33587
		],
		[
			0,
			-51
		],
		[
			60,
			-21
		],
		[
			108,
			62
		],
		[
			96,
			-52
		],
		[
			72,
			31
		]
	],
	[
		[
			35023,
			33712
		],
		[
			-42,
			72
		],
		[
			-54,
			11
		],
		[
			-36,
			41
		],
		[
			-79,
			21
		],
		[
			-24,
			41
		],
		[
			30,
			83
		],
		[
			-42,
			62
		],
		[
			-150,
			-10
		],
		[
			-48,
			52
		],
		[
			-18,
			62
		],
		[
			-54,
			62
		],
		[
			-78,
			0
		],
		[
			-30,
			21
		],
		[
			-79,
			0
		],
		[
			-42,
			31
		],
		[
			-24,
			93
		],
		[
			-78,
			-31
		],
		[
			-42,
			83
		]
	],
	[
		[
			33586,
			34074
		],
		[
			48,
			-72
		],
		[
			-12,
			-93
		],
		[
			72,
			-42
		],
		[
			12,
			-114
		],
		[
			54,
			-72
		],
		[
			-54,
			-42
		],
		[
			60,
			-52
		]
	],
	[
		[
			33766,
			33587
		],
		[
			6,
			-20
		],
		[
			96,
			-42
		],
		[
			-36,
			-72
		]
	],
	[
		[
			33832,
			33453
		],
		[
			-18,
			-42
		],
		[
			12,
			-72
		],
		[
			-18,
			-52
		],
		[
			121,
			-10
		],
		[
			120,
			20
		]
	],
	[
		[
			33622,
			32780
		],
		[
			-120,
			0
		],
		[
			-78,
			155
		],
		[
			0,
			124
		],
		[
			30,
			42
		],
		[
			150,
			0
		],
		[
			-42,
			51
		],
		[
			-42,
			125
		],
		[
			-114,
			-52
		],
		[
			-109,
			62
		],
		[
			-36,
			62
		],
		[
			-48,
			-10
		],
		[
			0,
			62
		],
		[
			36,
			31
		],
		[
			72,
			-41
		],
		[
			30,
			51
		],
		[
			0,
			94
		],
		[
			-30,
			93
		],
		[
			24,
			103
		],
		[
			-30,
			42
		],
		[
			-120,
			93
		],
		[
			-42,
			62
		],
		[
			-24,
			-41
		],
		[
			-54,
			0
		],
		[
			-48,
			93
		]
	],
	[
		[
			33027,
			33981
		],
		[
			96,
			155
		],
		[
			54,
			31
		],
		[
			-12,
			52
		],
		[
			60,
			31
		]
	],
	[
		[
			33580,
			32635
		],
		[
			-54,
			-52
		],
		[
			-108,
			10
		],
		[
			-139,
			62
		],
		[
			-144,
			104
		],
		[
			-72,
			83
		],
		[
			-169,
			124
		],
		[
			-168,
			104
		],
		[
			-84,
			124
		],
		[
			-84,
			197
		],
		[
			-30,
			248
		]
	],
	[
		[
			32528,
			33639
		],
		[
			168,
			42
		],
		[
			48,
			83
		],
		[
			-12,
			103
		],
		[
			36,
			42
		],
		[
			54,
			10
		],
		[
			6,
			41
		],
		[
			133,
			0
		],
		[
			66,
			21
		]
	],
	[
		[
			32900,
			35897
		],
		[
			-18,
			0
		]
	],
	[
		[
			32882,
			35897
		],
		[
			-36,
			31
		]
	],
	[
		[
			32846,
			35928
		],
		[
			0,
			21
		]
	],
	[
		[
			32846,
			35949
		],
		[
			6,
			72
		]
	],
	[
		[
			32852,
			36021
		],
		[
			12,
			0
		]
	],
	[
		[
			32852,
			36021
		],
		[
			-30,
			-10
		]
	],
	[
		[
			32822,
			36011
		],
		[
			0,
			62
		]
	],
	[
		[
			32822,
			36073
		],
		[
			12,
			-10
		]
	],
	[
		[
			32828,
			36073
		],
		[
			-6,
			0
		]
	],
	[
		[
			32822,
			36073
		],
		[
			6,
			0
		]
	],
	[
		[
			32822,
			36011
		],
		[
			24,
			-62
		]
	],
	[
		[
			32846,
			35928
		],
		[
			36,
			-31
		]
	],
	[
		[
			32882,
			35897
		],
		[
			12,
			0
		]
	],
	[
		[
			32528,
			33639
		],
		[
			-84,
			166
		],
		[
			-31,
			-10
		],
		[
			-72,
			93
		],
		[
			6,
			83
		],
		[
			-102,
			186
		],
		[
			-18,
			52
		],
		[
			-24,
			155
		],
		[
			-84,
			93
		],
		[
			-36,
			73
		],
		[
			-84,
			62
		],
		[
			-30,
			104
		],
		[
			12,
			114
		],
		[
			36,
			113
		],
		[
			54,
			83
		],
		[
			42,
			94
		],
		[
			90,
			113
		],
		[
			36,
			83
		],
		[
			156,
			311
		],
		[
			55,
			31
		],
		[
			66,
			83
		],
		[
			102,
			166
		],
		[
			42,
			31
		],
		[
			54,
			83
		],
		[
			-6,
			62
		],
		[
			72,
			20
		],
		[
			0,
			-51
		],
		[
			42,
			-21
		]
	],
	[
		[
			31963,
			32459
		],
		[
			60,
			-83
		]
	],
	[
		[
			31938,
			32293
		],
		[
			-24,
			103
		],
		[
			-48,
			114
		],
		[
			36,
			21
		],
		[
			61,
			-72
		]
	],
	[
		[
			32029,
			32376
		],
		[
			-66,
			83
		]
	],
	[
		[
			31963,
			32459
		],
		[
			-55,
			72
		],
		[
			-126,
			114
		],
		[
			-60,
			83
		],
		[
			-78,
			62
		],
		[
			-102,
			135
		],
		[
			-36,
			10
		],
		[
			-73,
			114
		],
		[
			-6,
			93
		],
		[
			169,
			155
		],
		[
			168,
			83
		],
		[
			96,
			31
		],
		[
			139,
			63
		],
		[
			192,
			155
		],
		[
			150,
			41
		],
		[
			36,
			-41
		],
		[
			48,
			-155
		],
		[
			55,
			-94
		],
		[
			48,
			-145
		],
		[
			12,
			-124
		],
		[
			30,
			-83
		],
		[
			66,
			-103
		],
		[
			72,
			-52
		],
		[
			102,
			-197
		],
		[
			48,
			-114
		],
		[
			133,
			-155
		]
	],
	[
		[
			42112,
			34996
		],
		[
			6,
			-31
		],
		[
			120,
			-207
		],
		[
			36,
			10
		],
		[
			96,
			-41
		],
		[
			90,
			-104
		],
		[
			30,
			-155
		],
		[
			36,
			-62
		],
		[
			-66,
			-42
		],
		[
			-138,
			-20
		]
	],
	[
		[
			42322,
			34344
		],
		[
			-180,
			10
		],
		[
			-97,
			-21
		],
		[
			-36,
			21
		],
		[
			-72,
			0
		],
		[
			-102,
			-83
		],
		[
			-66,
			-21
		],
		[
			-18,
			-72
		],
		[
			-96,
			-93
		],
		[
			-78,
			51
		],
		[
			-61,
			-62
		],
		[
			6,
			-72
		],
		[
			-24,
			-52
		]
	],
	[
		[
			41498,
			33950
		],
		[
			-60,
			62
		],
		[
			-84,
			21
		],
		[
			-24,
			41
		],
		[
			-60,
			11
		],
		[
			0,
			-52
		],
		[
			-114,
			-156
		],
		[
			-24,
			-62
		],
		[
			-12,
			-124
		],
		[
			-37,
			-52
		],
		[
			-108,
			31
		],
		[
			-30,
			52
		],
		[
			-6,
			73
		],
		[
			66,
			10
		],
		[
			6,
			62
		],
		[
			-48,
			83
		],
		[
			-12,
			62
		],
		[
			-96,
			73
		],
		[
			-60,
			0
		],
		[
			-90,
			41
		],
		[
			-115,
			31
		],
		[
			-126,
			-10
		],
		[
			-204,
			72
		],
		[
			-120,
			-10
		],
		[
			-49,
			31
		],
		[
			-72,
			-10
		],
		[
			-30,
			-73
		],
		[
			-78,
			-21
		],
		[
			-24,
			-31
		],
		[
			-24,
			-103
		],
		[
			-24,
			20
		],
		[
			-138,
			11
		],
		[
			-103,
			41
		],
		[
			-102,
			-41
		]
	],
	[
		[
			39376,
			34416
		],
		[
			108,
			145
		],
		[
			42,
			-31
		],
		[
			30,
			21
		],
		[
			84,
			0
		],
		[
			31,
			-21
		],
		[
			168,
			72
		],
		[
			78,
			63
		]
	],
	[
		[
			39917,
			34665
		],
		[
			30,
			113
		],
		[
			114,
			0
		],
		[
			30,
			-51
		],
		[
			163,
			0
		],
		[
			48,
			-11
		],
		[
			6,
			62
		],
		[
			60,
			21
		],
		[
			204,
			11
		],
		[
			30,
			82
		],
		[
			67,
			42
		],
		[
			-18,
			103
		],
		[
			78,
			63
		],
		[
			12,
			124
		]
	],
	[
		[
			40741,
			35224
		],
		[
			24,
			-11
		],
		[
			108,
			21
		],
		[
			72,
			-41
		],
		[
			84,
			-83
		]
	],
	[
		[
			41029,
			35110
		],
		[
			36,
			-10
		]
	],
	[
		[
			41065,
			35100
		],
		[
			67,
			51
		],
		[
			66,
			-20
		],
		[
			30,
			20
		],
		[
			108,
			-41
		],
		[
			48,
			52
		],
		[
			108,
			62
		],
		[
			54,
			52
		],
		[
			43,
			-52
		],
		[
			60,
			0
		],
		[
			42,
			-42
		],
		[
			90,
			-10
		],
		[
			36,
			-31
		],
		[
			120,
			83
		],
		[
			90,
			-52
		],
		[
			43,
			-62
		],
		[
			12,
			-114
		],
		[
			30,
			0
		]
	],
	[
		[
			43458,
			33339
		],
		[
			-12,
			41
		],
		[
			-90,
			-20
		],
		[
			-72,
			31
		],
		[
			6,
			124
		],
		[
			-90,
			-10
		],
		[
			-54,
			103
		],
		[
			-133,
			0
		],
		[
			-30,
			-41
		],
		[
			-66,
			10
		],
		[
			-42,
			31
		],
		[
			-36,
			-21
		],
		[
			-102,
			11
		],
		[
			18,
			62
		],
		[
			-84,
			0
		],
		[
			0,
			72
		],
		[
			-30,
			32
		],
		[
			-12,
			113
		],
		[
			54,
			125
		],
		[
			-114,
			83
		],
		[
			-67,
			-63
		],
		[
			-78,
			-31
		],
		[
			-36,
			63
		],
		[
			42,
			31
		],
		[
			-36,
			62
		],
		[
			-78,
			83
		],
		[
			6,
			114
		]
	],
	[
		[
			42112,
			34996
		],
		[
			78,
			-31
		],
		[
			84,
			0
		],
		[
			72,
			-42
		],
		[
			150,
			73
		],
		[
			30,
			62
		],
		[
			109,
			21
		],
		[
			0,
			72
		],
		[
			48,
			21
		],
		[
			30,
			62
		],
		[
			0,
			83
		],
		[
			66,
			41
		]
	],
	[
		[
			44180,
			35731
		],
		[
			6,
			-20
		]
	],
	[
		[
			42250,
			32604
		],
		[
			-6,
			113
		],
		[
			-18,
			73
		],
		[
			-48,
			41
		],
		[
			-18,
			52
		],
		[
			-66,
			73
		],
		[
			-55,
			0
		],
		[
			-24,
			51
		],
		[
			-84,
			94
		],
		[
			-60,
			41
		],
		[
			84,
			83
		],
		[
			-102,
			238
		],
		[
			54,
			0
		],
		[
			12,
			52
		],
		[
			-156,
			-31
		],
		[
			-54,
			72
		],
		[
			-102,
			94
		],
		[
			-43,
			72
		],
		[
			0,
			73
		],
		[
			-66,
			155
		]
	],
	[
		[
			40440,
			48957
		],
		[
			36,
			-166
		],
		[
			-36,
			-62
		],
		[
			126,
			0
		],
		[
			139,
			-20
		],
		[
			30,
			-125
		],
		[
			-42,
			-20
		],
		[
			-30,
			-125
		],
		[
			66,
			-20
		],
		[
			54,
			20
		],
		[
			42,
			-62
		],
		[
			78,
			21
		],
		[
			-18,
			-135
		],
		[
			120,
			-21
		],
		[
			54,
			-51
		]
	],
	[
		[
			41059,
			48191
		],
		[
			-18,
			-31
		],
		[
			-18,
			-145
		],
		[
			-96,
			-52
		],
		[
			-78,
			52
		],
		[
			-54,
			0
		],
		[
			-66,
			51
		],
		[
			-114,
			-20
		],
		[
			-103,
			-73
		],
		[
			-48,
			-10
		],
		[
			-288,
			62
		],
		[
			-109,
			41
		]
	],
	[
		[
			40067,
			48066
		],
		[
			-48,
			-31
		],
		[
			-84,
			31
		],
		[
			0,
			42
		],
		[
			-144,
			72
		],
		[
			-108,
			-10
		]
	],
	[
		[
			41462,
			49040
		],
		[
			36,
			-93
		],
		[
			24,
			-104
		],
		[
			55,
			-83
		],
		[
			54,
			-31
		],
		[
			12,
			-103
		],
		[
			72,
			-156
		],
		[
			-72,
			0
		],
		[
			-18,
			-41
		],
		[
			-67,
			-52
		],
		[
			-24,
			-103
		],
		[
			-24,
			-32
		],
		[
			-168,
			-10
		],
		[
			-204,
			0
		],
		[
			-79,
			-41
		]
	],
	[
		[
			42021,
			47818
		],
		[
			-60,
			-11
		],
		[
			-6,
			-62
		],
		[
			-126,
			31
		],
		[
			-120,
			-62
		],
		[
			-6,
			-31
		],
		[
			-72,
			0
		],
		[
			-6,
			31
		],
		[
			-97,
			11
		],
		[
			-60,
			-42
		],
		[
			-228,
			0
		],
		[
			-66,
			11
		]
	],
	[
		[
			41174,
			47694
		],
		[
			-42,
			196
		],
		[
			18,
			52
		],
		[
			-67,
			10
		],
		[
			-42,
			63
		]
	],
	[
		[
			41041,
			48015
		],
		[
			24,
			145
		],
		[
			79,
			51
		],
		[
			258,
			0
		],
		[
			42,
			-20
		],
		[
			72,
			20
		],
		[
			73,
			104
		],
		[
			6,
			72
		],
		[
			78,
			32
		],
		[
			60,
			-42
		],
		[
			66,
			-103
		],
		[
			54,
			-42
		],
		[
			30,
			10
		],
		[
			60,
			-113
		],
		[
			96,
			-63
		],
		[
			49,
			-124
		],
		[
			-18,
			-62
		],
		[
			-49,
			-62
		]
	],
	[
		[
			41126,
			47176
		],
		[
			72,
			41
		]
	],
	[
		[
			41198,
			47217
		],
		[
			36,
			62
		]
	],
	[
		[
			41234,
			47279
		],
		[
			24,
			11
		]
	],
	[
		[
			41258,
			47290
		],
		[
			90,
			72
		]
	],
	[
		[
			41348,
			47362
		],
		[
			48,
			73
		],
		[
			36,
			0
		]
	],
	[
		[
			41432,
			47435
		],
		[
			12,
			-21
		]
	],
	[
		[
			41444,
			47414
		],
		[
			18,
			-31
		]
	],
	[
		[
			41462,
			47383
		],
		[
			54,
			93
		],
		[
			115,
			62
		],
		[
			90,
			21
		],
		[
			30,
			-31
		],
		[
			102,
			21
		],
		[
			36,
			-52
		]
	],
	[
		[
			41889,
			47497
		],
		[
			84,
			-11
		],
		[
			72,
			63
		],
		[
			37,
			-104
		],
		[
			-43,
			-41
		],
		[
			31,
			-239
		],
		[
			48,
			-93
		],
		[
			0,
			-41
		]
	],
	[
		[
			42021,
			47818
		],
		[
			-18,
			-104
		],
		[
			24,
			-93
		],
		[
			-42,
			-114
		],
		[
			-96,
			-10
		]
	],
	[
		[
			41889,
			47497
		],
		[
			-48,
			72
		],
		[
			-42,
			-31
		],
		[
			-66,
			31
		],
		[
			-60,
			0
		],
		[
			-157,
			-83
		],
		[
			-42,
			-51
		],
		[
			-12,
			-52
		]
	],
	[
		[
			41462,
			47383
		],
		[
			-18,
			31
		]
	],
	[
		[
			41432,
			47435
		],
		[
			-42,
			0
		],
		[
			-42,
			-73
		]
	],
	[
		[
			41348,
			47362
		],
		[
			-90,
			-72
		]
	],
	[
		[
			41258,
			47290
		],
		[
			-24,
			-11
		]
	],
	[
		[
			41234,
			47279
		],
		[
			-36,
			-62
		]
	],
	[
		[
			41198,
			47217
		],
		[
			-24,
			10
		],
		[
			-48,
			-51
		]
	],
	[
		[
			40897,
			47227
		],
		[
			12,
			63
		],
		[
			0,
			196
		],
		[
			-66,
			145
		],
		[
			66,
			52
		],
		[
			30,
			-10
		],
		[
			157,
			41
		],
		[
			78,
			-20
		]
	],
	[
		[
			39773,
			24919
		],
		[
			-84,
			10
		],
		[
			-151,
			-52
		],
		[
			18,
			-51
		],
		[
			157,
			-32
		],
		[
			18,
			-51
		],
		[
			12,
			-135
		]
	],
	[
		[
			39743,
			24608
		],
		[
			18,
			-72
		],
		[
			-42,
			-83
		],
		[
			48,
			-62
		],
		[
			-36,
			-52
		],
		[
			-115,
			-11
		],
		[
			-84,
			42
		],
		[
			-54,
			0
		],
		[
			-42,
			-114
		]
	],
	[
		[
			39436,
			24256
		],
		[
			-42,
			-114
		],
		[
			-36,
			-10
		],
		[
			-54,
			-114
		],
		[
			-48,
			-62
		],
		[
			-84,
			-21
		],
		[
			-37,
			21
		],
		[
			-24,
			-52
		]
	],
	[
		[
			38252,
			24163
		],
		[
			0,
			103
		],
		[
			36,
			114
		],
		[
			-12,
			62
		]
	],
	[
		[
			38276,
			24442
		],
		[
			90,
			11
		],
		[
			120,
			41
		],
		[
			84,
			145
		],
		[
			36,
			-10
		],
		[
			78,
			93
		],
		[
			7,
			52
		],
		[
			-127,
			72
		],
		[
			6,
			104
		],
		[
			24,
			31
		],
		[
			-24,
			83
		],
		[
			60,
			10
		],
		[
			24,
			41
		],
		[
			103,
			-20
		],
		[
			0,
			114
		],
		[
			66,
			31
		]
	],
	[
		[
			38823,
			25240
		],
		[
			36,
			52
		],
		[
			72,
			20
		],
		[
			18,
			42
		],
		[
			102,
			103
		],
		[
			36,
			145
		]
	],
	[
		[
			40657,
			23759
		],
		[
			-18,
			134
		]
	],
	[
		[
			40639,
			23893
		],
		[
			-6,
			135
		],
		[
			-55,
			93
		],
		[
			49,
			114
		],
		[
			54,
			-21
		],
		[
			24,
			73
		],
		[
			-18,
			93
		]
	],
	[
		[
			37927,
			25271
		],
		[
			6,
			-93
		],
		[
			-42,
			-114
		],
		[
			72,
			-83
		],
		[
			36,
			-155
		],
		[
			-54,
			-104
		],
		[
			36,
			-41
		],
		[
			-54,
			-94
		],
		[
			-120,
			-41
		],
		[
			72,
			-93
		],
		[
			102,
			-21
		],
		[
			78,
			21
		],
		[
			18,
			62
		],
		[
			145,
			93
		]
	],
	[
		[
			38222,
			24608
		],
		[
			48,
			-93
		],
		[
			6,
			-73
		]
	],
	[
		[
			37578,
			25302
		],
		[
			36,
			41
		],
		[
			36,
			-10
		],
		[
			66,
			-93
		],
		[
			73,
			-11
		],
		[
			90,
			63
		],
		[
			48,
			-21
		]
	],
	[
		[
			37927,
			25271
		],
		[
			72,
			-31
		],
		[
			60,
			52
		]
	],
	[
		[
			38059,
			25292
		],
		[
			54,
			10
		],
		[
			145,
			145
		],
		[
			30,
			0
		],
		[
			186,
			-93
		],
		[
			156,
			20
		],
		[
			97,
			-31
		],
		[
			72,
			-62
		],
		[
			24,
			-41
		]
	],
	[
		[
			38059,
			25292
		],
		[
			-42,
			72
		],
		[
			42,
			114
		],
		[
			-36,
			31
		]
	],
	[
		[
			38023,
			25509
		],
		[
			-108,
			104
		],
		[
			12,
			41
		]
	],
	[
		[
			37927,
			25654
		],
		[
			90,
			62
		],
		[
			60,
			176
		],
		[
			-18,
			42
		]
	],
	[
		[
			39929,
			38082
		],
		[
			-30,
			-134
		],
		[
			30,
			-73
		],
		[
			-90,
			-31
		],
		[
			-78,
			-10
		],
		[
			-66,
			52
		],
		[
			-36,
			-11
		],
		[
			-19,
			52
		],
		[
			-60,
			31
		],
		[
			-42,
			-31
		],
		[
			-36,
			-73
		],
		[
			36,
			-51
		],
		[
			90,
			-21
		],
		[
			6,
			-62
		],
		[
			103,
			-83
		],
		[
			36,
			41
		],
		[
			66,
			-41
		],
		[
			156,
			31
		],
		[
			126,
			-145
		],
		[
			-60,
			-83
		],
		[
			-6,
			-176
		],
		[
			-18,
			-134
		],
		[
			24,
			-73
		],
		[
			-24,
			-72
		],
		[
			42,
			-104
		],
		[
			109,
			31
		],
		[
			12,
			-21
		],
		[
			0,
			-10
		],
		[
			42,
			-31
		],
		[
			186,
			0
		],
		[
			0,
			-42
		]
	],
	[
		[
			40428,
			36808
		],
		[
			-12,
			-20
		]
	],
	[
		[
			40416,
			36788
		],
		[
			-66,
			-62
		],
		[
			-30,
			10
		],
		[
			-132,
			-104
		]
	],
	[
		[
			40188,
			36632
		],
		[
			-115,
			73
		],
		[
			-96,
			-31
		],
		[
			-102,
			-135
		],
		[
			-66,
			0
		],
		[
			12,
			-114
		],
		[
			-84,
			0
		],
		[
			-60,
			-83
		]
	],
	[
		[
			39677,
			36342
		],
		[
			-49,
			31
		],
		[
			0,
			73
		],
		[
			-36,
			52
		],
		[
			-54,
			31
		],
		[
			0,
			72
		],
		[
			-84,
			104
		],
		[
			-108,
			-10
		],
		[
			-72,
			-73
		],
		[
			-72,
			-52
		],
		[
			-91,
			31
		],
		[
			-24,
			104
		],
		[
			-6,
			135
		],
		[
			-90,
			20
		],
		[
			-144,
			11
		],
		[
			-72,
			51
		],
		[
			-139,
			-10
		],
		[
			-54,
			-21
		],
		[
			-120,
			21
		],
		[
			-36,
			93
		],
		[
			-132,
			104
		],
		[
			-127,
			21
		],
		[
			-30,
			51
		],
		[
			-78,
			42
		],
		[
			-60,
			62
		]
	],
	[
		[
			39677,
			36342
		],
		[
			60,
			-10
		],
		[
			30,
			-41
		],
		[
			78,
			-31
		],
		[
			30,
			-73
		],
		[
			-30,
			-166
		],
		[
			-36,
			21
		],
		[
			-72,
			-10
		],
		[
			-84,
			-73
		],
		[
			-121,
			-31
		],
		[
			-114,
			-52
		],
		[
			-60,
			-62
		],
		[
			-126,
			-21
		],
		[
			-36,
			-31
		],
		[
			-121,
			-62
		]
	],
	[
		[
			39075,
			35700
		],
		[
			-102,
			-83
		],
		[
			-30,
			-41
		],
		[
			-210,
			41
		],
		[
			-49,
			-82
		],
		[
			-120,
			-73
		],
		[
			-54,
			-62
		],
		[
			-42,
			-21
		],
		[
			-144,
			-10
		],
		[
			-24,
			-52
		]
	],
	[
		[
			40188,
			36632
		],
		[
			36,
			-41
		]
	],
	[
		[
			40224,
			36591
		],
		[
			102,
			-62
		],
		[
			108,
			21
		],
		[
			18,
			-83
		]
	],
	[
		[
			40452,
			36467
		],
		[
			36,
			-114
		]
	],
	[
		[
			40488,
			36353
		],
		[
			42,
			-52
		],
		[
			72,
			0
		],
		[
			121,
			-31
		],
		[
			60,
			-83
		],
		[
			42,
			-31
		]
	],
	[
		[
			40825,
			36156
		],
		[
			-156,
			-62
		],
		[
			-24,
			-73
		],
		[
			60,
			-20
		],
		[
			-127,
			-145
		],
		[
			133,
			-104
		],
		[
			-84,
			-62
		],
		[
			-91,
			-10
		],
		[
			-6,
			-114
		],
		[
			42,
			-83
		],
		[
			6,
			-83
		],
		[
			37,
			-42
		],
		[
			72,
			-41
		],
		[
			54,
			-93
		]
	],
	[
		[
			42382,
			36487
		],
		[
			-78,
			-10
		],
		[
			-54,
			-52
		],
		[
			-90,
			21
		],
		[
			-90,
			-52
		],
		[
			-103,
			-10
		],
		[
			-120,
			-62
		],
		[
			-24,
			-42
		],
		[
			-78,
			31
		],
		[
			-90,
			-10
		],
		[
			-36,
			41
		],
		[
			-55,
			21
		],
		[
			-258,
			0
		],
		[
			-6,
			-52
		],
		[
			-84,
			21
		],
		[
			-54,
			31
		],
		[
			-109,
			-114
		],
		[
			-84,
			-52
		],
		[
			-72,
			-103
		],
		[
			-30,
			31
		]
	],
	[
		[
			40867,
			36125
		],
		[
			-42,
			31
		]
	],
	[
		[
			40067,
			48066
		],
		[
			115,
			-62
		],
		[
			138,
			-20
		],
		[
			60,
			-32
		],
		[
			96,
			-20
		],
		[
			96,
			52
		],
		[
			103,
			72
		],
		[
			54,
			0
		],
		[
			66,
			-62
		],
		[
			54,
			10
		],
		[
			84,
			-62
		],
		[
			48,
			31
		],
		[
			48,
			0
		],
		[
			12,
			42
		]
	],
	[
		[
			39592,
			48201
		],
		[
			54,
			-41
		],
		[
			127,
			10
		],
		[
			144,
			-62
		],
		[
			12,
			-52
		],
		[
			48,
			-31
		],
		[
			48,
			0
		],
		[
			42,
			41
		]
	],
	[
		[
			49405,
			15566
		],
		[
			42,
			21
		]
	],
	[
		[
			49447,
			15587
		],
		[
			24,
			-72
		],
		[
			-30,
			-62
		]
	],
	[
		[
			49441,
			15453
		],
		[
			-120,
			31
		],
		[
			-67,
			0
		]
	],
	[
		[
			49254,
			15484
		],
		[
			0,
			41
		]
	],
	[
		[
			49254,
			15525
		],
		[
			37,
			31
		]
	],
	[
		[
			49291,
			15556
		],
		[
			60,
			42
		],
		[
			54,
			-32
		]
	],
	[
		[
			50337,
			15660
		],
		[
			-18,
			0
		]
	],
	[
		[
			50319,
			15660
		],
		[
			-36,
			93
		],
		[
			12,
			41
		]
	],
	[
		[
			50295,
			15794
		],
		[
			6,
			0
		]
	],
	[
		[
			50301,
			15794
		],
		[
			-6,
			-20
		]
	],
	[
		[
			50295,
			15774
		],
		[
			6,
			-11
		]
	],
	[
		[
			50301,
			15763
		],
		[
			0,
			-21
		]
	],
	[
		[
			50301,
			15742
		],
		[
			36,
			-82
		]
	],
	[
		[
			50818,
			15494
		],
		[
			-78,
			21
		],
		[
			-55,
			41
		],
		[
			-60,
			10
		],
		[
			-66,
			-41
		],
		[
			-84,
			-10
		],
		[
			-66,
			114
		]
	],
	[
		[
			50409,
			15629
		],
		[
			-60,
			31
		]
	],
	[
		[
			50349,
			15660
		],
		[
			-12,
			0
		]
	],
	[
		[
			50337,
			15660
		],
		[
			-36,
			82
		]
	],
	[
		[
			50301,
			15763
		],
		[
			-6,
			11
		]
	],
	[
		[
			50301,
			15794
		],
		[
			48,
			0
		],
		[
			48,
			31
		],
		[
			42,
			-10
		],
		[
			60,
			31
		],
		[
			90,
			124
		],
		[
			60,
			52
		],
		[
			-18,
			176
		],
		[
			18,
			31
		],
		[
			103,
			83
		]
	],
	[
		[
			50752,
			16312
		],
		[
			18,
			-31
		],
		[
			0,
			-114
		],
		[
			-18,
			-72
		],
		[
			36,
			-94
		],
		[
			48,
			-41
		],
		[
			66,
			31
		],
		[
			54,
			-31
		],
		[
			42,
			-83
		],
		[
			-48,
			-62
		],
		[
			-102,
			-176
		],
		[
			-30,
			-145
		]
	],
	[
		[
			48846,
			16965
		],
		[
			-18,
			-52
		],
		[
			120,
			-42
		],
		[
			66,
			-51
		]
	],
	[
		[
			49014,
			16820
		],
		[
			6,
			-63
		],
		[
			42,
			-31
		],
		[
			36,
			-62
		],
		[
			54,
			-41
		],
		[
			-36,
			-93
		],
		[
			-36,
			-52
		],
		[
			18,
			-62
		]
	],
	[
		[
			49098,
			16416
		],
		[
			-18,
			-62
		],
		[
			-54,
			-52
		],
		[
			-30,
			72
		],
		[
			-30,
			-72
		],
		[
			0,
			-114
		],
		[
			-30,
			-31
		],
		[
			-24,
			-93
		]
	],
	[
		[
			48912,
			16064
		],
		[
			-90,
			-52
		],
		[
			-73,
			-104
		],
		[
			-84,
			-10
		]
	],
	[
		[
			48665,
			15898
		],
		[
			-48,
			83
		],
		[
			-60,
			72
		],
		[
			-36,
			11
		]
	],
	[
		[
			48521,
			16064
		],
		[
			-48,
			-21
		],
		[
			-42,
			83
		],
		[
			36,
			51
		],
		[
			-108,
			145
		]
	],
	[
		[
			48359,
			16322
		],
		[
			-217,
			301
		],
		[
			0,
			41
		]
	],
	[
		[
			51148,
			15163
		],
		[
			-24,
			-11
		]
	],
	[
		[
			51124,
			15152
		],
		[
			-18,
			-41
		]
	],
	[
		[
			51106,
			15111
		],
		[
			6,
			-52
		]
	],
	[
		[
			51112,
			15059
		],
		[
			0,
			-31
		]
	],
	[
		[
			51112,
			15028
		],
		[
			-42,
			-42
		]
	],
	[
		[
			51070,
			14986
		],
		[
			-24,
			0
		]
	],
	[
		[
			51046,
			14986
		],
		[
			6,
			0
		],
		[
			18,
			0
		]
	],
	[
		[
			50758,
			14520
		],
		[
			-109,
			63
		],
		[
			-66,
			-21
		],
		[
			-84,
			21
		],
		[
			-162,
			155
		]
	],
	[
		[
			50337,
			14738
		],
		[
			-6,
			0
		]
	],
	[
		[
			50331,
			14738
		],
		[
			6,
			21
		]
	],
	[
		[
			50337,
			14759
		],
		[
			30,
			62
		],
		[
			36,
			20
		],
		[
			-6,
			125
		],
		[
			-24,
			83
		],
		[
			18,
			41
		],
		[
			84,
			52
		],
		[
			66,
			-11
		],
		[
			60,
			83
		],
		[
			-6,
			270
		]
	],
	[
		[
			50595,
			15484
		],
		[
			60,
			20
		],
		[
			73,
			-51
		],
		[
			132,
			-42
		],
		[
			30,
			-62
		],
		[
			6,
			-73
		],
		[
			30,
			-51
		],
		[
			48,
			-31
		],
		[
			78,
			-11
		],
		[
			66,
			31
		],
		[
			30,
			-51
		]
	],
	[
		[
			48665,
			15898
		],
		[
			127,
			-176
		]
	],
	[
		[
			48792,
			15722
		],
		[
			-37,
			-52
		],
		[
			-24,
			21
		],
		[
			-72,
			-11
		],
		[
			-6,
			-41
		]
	],
	[
		[
			48653,
			15639
		],
		[
			-72,
			31
		]
	],
	[
		[
			48581,
			15670
		],
		[
			-102,
			21
		]
	],
	[
		[
			48479,
			15691
		],
		[
			-66,
			20
		],
		[
			-66,
			-51
		],
		[
			-61,
			31
		],
		[
			-18,
			51
		],
		[
			-138,
			-41
		],
		[
			-12,
			114
		],
		[
			-108,
			83
		],
		[
			-48,
			10
		]
	],
	[
		[
			47962,
			15908
		],
		[
			36,
			104
		],
		[
			42,
			20
		],
		[
			-30,
			94
		],
		[
			120,
			72
		],
		[
			72,
			0
		],
		[
			66,
			-21
		],
		[
			-18,
			104
		],
		[
			36,
			0
		],
		[
			73,
			41
		]
	],
	[
		[
			50331,
			14738
		],
		[
			6,
			0
		]
	],
	[
		[
			49910,
			13775
		],
		[
			-42,
			217
		],
		[
			-60,
			62
		],
		[
			-42,
			73
		],
		[
			0,
			52
		],
		[
			-37,
			41
		],
		[
			-42,
			0
		],
		[
			0,
			114
		],
		[
			-66,
			41
		],
		[
			-12,
			63
		],
		[
			-54,
			-11
		],
		[
			-42,
			31
		],
		[
			-36,
			62
		],
		[
			-30,
			104
		]
	],
	[
		[
			49447,
			14624
		],
		[
			0,
			10
		]
	],
	[
		[
			49447,
			14634
		],
		[
			24,
			52
		]
	],
	[
		[
			49471,
			14686
		],
		[
			90,
			-31
		],
		[
			72,
			0
		],
		[
			48,
			21
		],
		[
			79,
			-21
		],
		[
			12,
			-52
		],
		[
			42,
			-41
		],
		[
			54,
			10
		],
		[
			72,
			62
		]
	],
	[
		[
			49940,
			14634
		],
		[
			42,
			52
		],
		[
			66,
			21
		],
		[
			60,
			-62
		],
		[
			6,
			103
		],
		[
			-36,
			0
		]
	],
	[
		[
			50078,
			14748
		],
		[
			-12,
			83
		]
	],
	[
		[
			50066,
			14831
		],
		[
			24,
			21
		],
		[
			60,
			-62
		],
		[
			85,
			-114
		],
		[
			30,
			-11
		],
		[
			66,
			73
		]
	],
	[
		[
			49074,
			16032
		],
		[
			12,
			-82
		],
		[
			78,
			-125
		],
		[
			30,
			-93
		],
		[
			-6,
			-62
		],
		[
			42,
			-10
		],
		[
			61,
			-104
		]
	],
	[
		[
			49254,
			15525
		],
		[
			-90,
			-31
		],
		[
			-90,
			114
		],
		[
			-24,
			10
		],
		[
			-30,
			114
		],
		[
			-72,
			-10
		],
		[
			-54,
			31
		],
		[
			-102,
			-31
		]
	],
	[
		[
			48912,
			16064
		],
		[
			72,
			0
		],
		[
			90,
			-32
		]
	],
	[
		[
			48996,
			13702
		],
		[
			60,
			11
		],
		[
			12,
			72
		],
		[
			-24,
			73
		],
		[
			36,
			51
		],
		[
			132,
			11
		],
		[
			-12,
			186
		],
		[
			-42,
			145
		],
		[
			-6,
			62
		],
		[
			-30,
			42
		]
	],
	[
		[
			49122,
			14355
		],
		[
			60,
			62
		],
		[
			-36,
			52
		],
		[
			12,
			82
		]
	],
	[
		[
			49158,
			14551
		],
		[
			90,
			104
		],
		[
			115,
			0
		],
		[
			24,
			-31
		],
		[
			60,
			0
		]
	],
	[
		[
			48479,
			15691
		],
		[
			-36,
			-73
		],
		[
			42,
			-176
		],
		[
			-48,
			-52
		]
	],
	[
		[
			48437,
			15390
		],
		[
			-12,
			-62
		],
		[
			-90,
			0
		],
		[
			-55,
			83
		],
		[
			-120,
			-41
		],
		[
			-60,
			-62
		],
		[
			-24,
			31
		],
		[
			-150,
			0
		],
		[
			-48,
			31
		],
		[
			-48,
			-11
		],
		[
			-79,
			-72
		],
		[
			-36,
			62
		],
		[
			-54,
			-21
		],
		[
			-114,
			52
		]
	],
	[
		[
			47547,
			15380
		],
		[
			78,
			62
		],
		[
			18,
			62
		],
		[
			54,
			52
		],
		[
			30,
			93
		],
		[
			-204,
			52
		],
		[
			-24,
			62
		],
		[
			60,
			21
		],
		[
			42,
			-10
		],
		[
			24,
			62
		],
		[
			90,
			62
		]
	],
	[
		[
			47715,
			15898
		],
		[
			12,
			-21
		],
		[
			78,
			42
		],
		[
			85,
			20
		],
		[
			72,
			-31
		]
	],
	[
		[
			49826,
			16757
		],
		[
			-24,
			-124
		],
		[
			-145,
			-259
		]
	],
	[
		[
			49657,
			16374
		],
		[
			-66,
			31
		],
		[
			-433,
			0
		],
		[
			-60,
			11
		]
	],
	[
		[
			49802,
			15194
		],
		[
			-48,
			51
		]
	],
	[
		[
			49754,
			15245
		],
		[
			42,
			-31
		]
	],
	[
		[
			49796,
			15214
		],
		[
			6,
			-20
		]
	],
	[
		[
			50066,
			14831
		],
		[
			-42,
			10
		],
		[
			0,
			63
		],
		[
			-36,
			10
		]
	],
	[
		[
			49988,
			14914
		],
		[
			-36,
			145
		],
		[
			36,
			72
		],
		[
			-96,
			-20
		],
		[
			-72,
			10
		],
		[
			-54,
			31
		]
	],
	[
		[
			49766,
			15152
		],
		[
			18,
			11
		]
	],
	[
		[
			49784,
			15163
		],
		[
			6,
			0
		]
	],
	[
		[
			49790,
			15163
		],
		[
			12,
			31
		]
	],
	[
		[
			49802,
			15194
		],
		[
			-6,
			20
		]
	],
	[
		[
			49796,
			15214
		],
		[
			96,
			31
		],
		[
			24,
			42
		],
		[
			-30,
			114
		],
		[
			42,
			20
		],
		[
			60,
			-82
		],
		[
			78,
			-21
		],
		[
			66,
			21
		],
		[
			103,
			-11
		],
		[
			102,
			11
		],
		[
			36,
			31
		],
		[
			60,
			93
		],
		[
			162,
			21
		]
	],
	[
		[
			49543,
			16115
		],
		[
			18,
			-51
		],
		[
			78,
			-104
		],
		[
			90,
			0
		],
		[
			73,
			-93
		]
	],
	[
		[
			49802,
			15867
		],
		[
			0,
			-83
		]
	],
	[
		[
			49802,
			15784
		],
		[
			-97,
			21
		],
		[
			-48,
			-73
		],
		[
			-90,
			-31
		],
		[
			-30,
			10
		],
		[
			-54,
			-41
		],
		[
			-36,
			-83
		]
	],
	[
		[
			49405,
			15566
		],
		[
			6,
			42
		],
		[
			-72,
			83
		],
		[
			60,
			41
		],
		[
			42,
			135
		],
		[
			-66,
			20
		],
		[
			-6,
			63
		],
		[
			-42,
			0
		],
		[
			-30,
			41
		]
	],
	[
		[
			49297,
			15991
		],
		[
			72,
			83
		],
		[
			60,
			21
		],
		[
			84,
			0
		],
		[
			30,
			20
		]
	],
	[
		[
			48581,
			15670
		],
		[
			6,
			-83
		],
		[
			60,
			-166
		],
		[
			84,
			-124
		],
		[
			109,
			-134
		]
	],
	[
		[
			48840,
			15163
		],
		[
			6,
			0
		]
	],
	[
		[
			48846,
			15163
		],
		[
			18,
			10
		]
	],
	[
		[
			48864,
			15173
		],
		[
			-42,
			-114
		],
		[
			-91,
			-10
		],
		[
			-84,
			41
		],
		[
			-36,
			52
		],
		[
			-30,
			134
		],
		[
			-96,
			0
		]
	],
	[
		[
			48485,
			15276
		],
		[
			-48,
			114
		]
	],
	[
		[
			49657,
			16374
		],
		[
			-48,
			-83
		],
		[
			-36,
			-124
		],
		[
			-30,
			-52
		]
	],
	[
		[
			49297,
			15991
		],
		[
			-61,
			52
		],
		[
			-30,
			52
		],
		[
			-132,
			-63
		]
	],
	[
		[
			47715,
			15898
		],
		[
			-96,
			331
		],
		[
			-42,
			114
		],
		[
			-12,
			104
		]
	],
	[
		[
			51112,
			15287
		],
		[
			-132,
			-21
		],
		[
			-48,
			166
		],
		[
			-84,
			62
		],
		[
			-30,
			0
		]
	],
	[
		[
			50752,
			16312
		],
		[
			0,
			124
		],
		[
			-55,
			104
		]
	],
	[
		[
			47547,
			15380
		],
		[
			-42,
			-135
		]
	],
	[
		[
			47505,
			15245
		],
		[
			-12,
			-41
		],
		[
			30,
			-104
		],
		[
			-60,
			-31
		],
		[
			-114,
			-93
		],
		[
			-13,
			-41
		],
		[
			-84,
			31
		]
	],
	[
		[
			48485,
			15276
		],
		[
			-30,
			-31
		],
		[
			-6,
			-82
		],
		[
			-42,
			-52
		],
		[
			-42,
			0
		],
		[
			-91,
			134
		],
		[
			-66,
			21
		],
		[
			-36,
			-21
		],
		[
			-48,
			-93
		],
		[
			-84,
			-52
		],
		[
			0,
			-41
		]
	],
	[
		[
			48040,
			15059
		],
		[
			-66,
			-93
		],
		[
			-54,
			20
		],
		[
			-175,
			-10
		],
		[
			-78,
			-93
		],
		[
			42,
			-42
		],
		[
			18,
			-72
		],
		[
			-66,
			-62
		],
		[
			-24,
			-62
		]
	],
	[
		[
			48653,
			15639
		],
		[
			48,
			-10
		],
		[
			48,
			-114
		],
		[
			67,
			-42
		],
		[
			48,
			-114
		],
		[
			66,
			0
		],
		[
			54,
			42
		],
		[
			18,
			-114
		],
		[
			30,
			-42
		]
	],
	[
		[
			49032,
			15245
		],
		[
			-150,
			-41
		],
		[
			-18,
			-31
		]
	],
	[
		[
			48846,
			15163
		],
		[
			-6,
			0
		]
	],
	[
		[
			48515,
			14334
		],
		[
			-30,
			-83
		]
	],
	[
		[
			48064,
			14375
		],
		[
			54,
			83
		],
		[
			-6,
			73
		],
		[
			18,
			124
		],
		[
			24,
			73
		]
	],
	[
		[
			48154,
			14728
		],
		[
			90,
			-104
		],
		[
			36,
			21
		],
		[
			55,
			72
		],
		[
			96,
			73
		]
	],
	[
		[
			48431,
			14790
		],
		[
			18,
			-42
		]
	],
	[
		[
			48449,
			14748
		],
		[
			-18,
			-31
		],
		[
			54,
			-217
		],
		[
			-12,
			-83
		],
		[
			42,
			-83
		]
	],
	[
		[
			49273,
			15463
		],
		[
			12,
			-62
		],
		[
			-25,
			-62
		],
		[
			43,
			-42
		],
		[
			-30,
			-103
		],
		[
			48,
			-31
		],
		[
			6,
			-52
		],
		[
			54,
			-52
		],
		[
			-66,
			-145
		],
		[
			30,
			-41
		],
		[
			42,
			-156
		],
		[
			60,
			-83
		]
	],
	[
		[
			49158,
			14551
		],
		[
			-84,
			11
		],
		[
			12,
			62
		]
	],
	[
		[
			49086,
			14624
		],
		[
			18,
			10
		],
		[
			-12,
			135
		],
		[
			-24,
			62
		],
		[
			-42,
			207
		],
		[
			6,
			42
		],
		[
			66,
			31
		],
		[
			60,
			124
		]
	],
	[
		[
			49158,
			15235
		],
		[
			24,
			31
		],
		[
			48,
			187
		],
		[
			43,
			10
		]
	],
	[
		[
			49711,
			15318
		],
		[
			43,
			-73
		]
	],
	[
		[
			49802,
			15194
		],
		[
			-12,
			-31
		]
	],
	[
		[
			49784,
			15163
		],
		[
			-18,
			-11
		]
	],
	[
		[
			49471,
			14686
		],
		[
			12,
			62
		],
		[
			48,
			42
		],
		[
			0,
			72
		],
		[
			36,
			52
		],
		[
			66,
			-10
		],
		[
			24,
			51
		],
		[
			-24,
			94
		],
		[
			-30,
			20
		]
	],
	[
		[
			49603,
			15069
		],
		[
			-12,
			187
		],
		[
			72,
			52
		]
	],
	[
		[
			49663,
			15308
		],
		[
			48,
			10
		]
	],
	[
		[
			48804,
			14738
		],
		[
			42,
			-62
		],
		[
			120,
			-52
		],
		[
			12,
			31
		],
		[
			84,
			-52
		],
		[
			24,
			21
		]
	],
	[
		[
			49122,
			14355
		],
		[
			-54,
			0
		],
		[
			-126,
			-31
		],
		[
			-54,
			51
		],
		[
			-78,
			-72
		],
		[
			-67,
			-10
		],
		[
			-60,
			31
		],
		[
			-42,
			-73
		],
		[
			-60,
			31
		],
		[
			-36,
			62
		],
		[
			-30,
			-10
		]
	],
	[
		[
			48449,
			14748
		],
		[
			114,
			52
		],
		[
			108,
			-10
		],
		[
			133,
			41
		],
		[
			0,
			-93
		]
	],
	[
		[
			50319,
			15660
		],
		[
			30,
			0
		]
	],
	[
		[
			50349,
			15660
		],
		[
			60,
			-31
		]
	],
	[
		[
			50409,
			15629
		],
		[
			36,
			-104
		],
		[
			-60,
			-31
		],
		[
			-60,
			-114
		],
		[
			-84,
			-10
		],
		[
			-139,
			10
		],
		[
			-84,
			-10
		],
		[
			-84,
			103
		]
	],
	[
		[
			49934,
			15473
		],
		[
			6,
			42
		]
	],
	[
		[
			49940,
			15515
		],
		[
			-12,
			-11
		]
	],
	[
		[
			49928,
			15504
		],
		[
			-6,
			-20
		]
	],
	[
		[
			49922,
			15484
		],
		[
			0,
			31
		]
	],
	[
		[
			49922,
			15515
		],
		[
			-54,
			20
		]
	],
	[
		[
			49868,
			15535
		],
		[
			-6,
			21
		]
	],
	[
		[
			49862,
			15556
		],
		[
			-6,
			42
		]
	],
	[
		[
			49856,
			15598
		],
		[
			0,
			20
		]
	],
	[
		[
			49856,
			15618
		],
		[
			0,
			-20
		]
	],
	[
		[
			49856,
			15598
		],
		[
			0,
			20
		]
	],
	[
		[
			49856,
			15618
		],
		[
			-60,
			62
		],
		[
			-18,
			52
		],
		[
			24,
			52
		]
	],
	[
		[
			49802,
			15867
		],
		[
			48,
			-21
		],
		[
			48,
			21
		],
		[
			96,
			10
		]
	],
	[
		[
			49994,
			15877
		],
		[
			24,
			31
		]
	],
	[
		[
			50018,
			15908
		],
		[
			24,
			-21
		],
		[
			126,
			11
		],
		[
			-30,
			62
		],
		[
			48,
			21
		],
		[
			61,
			-73
		],
		[
			36,
			-10
		],
		[
			12,
			-104
		]
	],
	[
		[
			50018,
			15908
		],
		[
			-36,
			31
		],
		[
			18,
			166
		],
		[
			-24,
			62
		],
		[
			0,
			145
		],
		[
			48,
			114
		],
		[
			-42,
			73
		],
		[
			12,
			31
		],
		[
			6,
			0
		],
		[
			24,
			62
		]
	],
	[
		[
			48202,
			15245
		],
		[
			-6,
			0
		]
	],
	[
		[
			48196,
			15245
		],
		[
			6,
			0
		]
	],
	[
		[
			48611,
			15111
		],
		[
			-60,
			0
		],
		[
			0,
			-73
		],
		[
			-114,
			11
		],
		[
			-36,
			-94
		],
		[
			72,
			-51
		],
		[
			30,
			-63
		],
		[
			-72,
			-51
		]
	],
	[
		[
			48040,
			15059
		],
		[
			24,
			52
		],
		[
			66,
			31
		],
		[
			72,
			103
		]
	],
	[
		[
			48202,
			15245
		],
		[
			36,
			11
		],
		[
			54,
			-42
		],
		[
			43,
			-93
		],
		[
			72,
			-21
		],
		[
			42,
			31
		],
		[
			12,
			94
		],
		[
			60,
			51
		],
		[
			54,
			-20
		],
		[
			36,
			-145
		]
	],
	[
		[
			49273,
			15463
		],
		[
			72,
			0
		],
		[
			186,
			-73
		],
		[
			42,
			0
		],
		[
			78,
			63
		],
		[
			54,
			-11
		],
		[
			6,
			-124
		]
	],
	[
		[
			49856,
			15598
		],
		[
			6,
			-42
		]
	],
	[
		[
			49862,
			15556
		],
		[
			6,
			-21
		]
	],
	[
		[
			49868,
			15535
		],
		[
			54,
			-20
		]
	],
	[
		[
			49922,
			15515
		],
		[
			0,
			-31
		]
	],
	[
		[
			49922,
			15484
		],
		[
			6,
			20
		]
	],
	[
		[
			49940,
			15515
		],
		[
			-6,
			-42
		]
	],
	[
		[
			49934,
			15473
		],
		[
			-66,
			-41
		],
		[
			-12,
			-73
		],
		[
			24,
			-72
		],
		[
			-18,
			-31
		],
		[
			-60,
			-11
		],
		[
			-54,
			42
		],
		[
			-7,
			114
		],
		[
			-18,
			52
		],
		[
			-84,
			20
		],
		[
			-66,
			-62
		],
		[
			-36,
			0
		],
		[
			-96,
			42
		]
	],
	[
		[
			48611,
			15111
		],
		[
			90,
			-73
		],
		[
			115,
			0
		],
		[
			60,
			83
		],
		[
			30,
			73
		],
		[
			132,
			31
		],
		[
			72,
			-11
		],
		[
			48,
			21
		]
	],
	[
		[
			49254,
			15484
		],
		[
			-42,
			-11
		],
		[
			-24,
			-52
		],
		[
			-12,
			-124
		],
		[
			-42,
			-52
		],
		[
			-102,
			0
		]
	],
	[
		[
			28842,
			59262
		],
		[
			60,
			-72
		],
		[
			-42,
			-52
		],
		[
			30,
			-52
		],
		[
			-6,
			-72
		],
		[
			66,
			0
		]
	],
	[
		[
			28950,
			59014
		],
		[
			0,
			-21
		],
		[
			-120,
			-10
		],
		[
			-48,
			-104
		],
		[
			162,
			-72
		],
		[
			-30,
			-21
		],
		[
			-126,
			10
		],
		[
			-108,
			-41
		],
		[
			-30,
			-31
		],
		[
			-169,
			20
		],
		[
			-48,
			-20
		],
		[
			-18,
			-135
		],
		[
			-78,
			-21
		],
		[
			-24,
			-83
		]
	],
	[
		[
			28313,
			58485
		],
		[
			-132,
			63
		],
		[
			-85,
			82
		],
		[
			-108,
			145
		],
		[
			-120,
			42
		],
		[
			-42,
			-31
		],
		[
			-36,
			62
		],
		[
			-96,
			52
		],
		[
			-163,
			-11
		],
		[
			-54,
			94
		]
	],
	[
		[
			27477,
			58983
		],
		[
			30,
			51
		],
		[
			120,
			0
		],
		[
			-90,
			156
		],
		[
			109,
			10
		],
		[
			-13,
			124
		],
		[
			103,
			239
		],
		[
			36,
			-11
		],
		[
			18,
			62
		]
	],
	[
		[
			27790,
			59614
		],
		[
			174,
			83
		],
		[
			138,
			93
		],
		[
			115,
			-51
		],
		[
			18,
			20
		],
		[
			66,
			-134
		],
		[
			18,
			-83
		],
		[
			66,
			41
		],
		[
			48,
			-20
		],
		[
			181,
			41
		],
		[
			114,
			-72
		],
		[
			90,
			124
		],
		[
			78,
			-42
		],
		[
			108,
			83
		],
		[
			91,
			-10
		],
		[
			66,
			-62
		],
		[
			72,
			-21
		],
		[
			-36,
			-62
		],
		[
			-36,
			-145
		],
		[
			-151,
			-52
		],
		[
			-54,
			10
		],
		[
			-36,
			-51
		],
		[
			-60,
			-11
		],
		[
			-18,
			-31
		]
	],
	[
		[
			29648,
			52230
		],
		[
			24,
			-42
		],
		[
			72,
			21
		],
		[
			12,
			-62
		],
		[
			78,
			31
		],
		[
			72,
			-10
		],
		[
			78,
			31
		],
		[
			55,
			-11
		],
		[
			60,
			21
		],
		[
			54,
			52
		],
		[
			72,
			-21
		],
		[
			36,
			-52
		],
		[
			66,
			42
		],
		[
			72,
			-10
		],
		[
			84,
			51
		],
		[
			30,
			-41
		],
		[
			37,
			31
		],
		[
			24,
			83
		],
		[
			48,
			0
		],
		[
			0,
			52
		],
		[
			48,
			82
		],
		[
			36,
			32
		],
		[
			78,
			20
		],
		[
			30,
			-93
		],
		[
			72,
			-41
		],
		[
			42,
			41
		],
		[
			109,
			-10
		],
		[
			54,
			-31
		],
		[
			78,
			-11
		],
		[
			-72,
			-114
		],
		[
			-42,
			-41
		],
		[
			-85,
			-21
		],
		[
			-24,
			-41
		],
		[
			-66,
			-52
		],
		[
			-48,
			-62
		],
		[
			-54,
			-135
		],
		[
			48,
			-103
		],
		[
			-60,
			-11
		],
		[
			12,
			-83
		],
		[
			-48,
			-93
		],
		[
			96,
			-62
		],
		[
			90,
			10
		],
		[
			42,
			52
		],
		[
			91,
			73
		],
		[
			102,
			103
		],
		[
			72,
			-10
		],
		[
			18,
			41
		],
		[
			84,
			52
		],
		[
			18,
			-41
		],
		[
			72,
			-62
		],
		[
			42,
			10
		],
		[
			73,
			-62
		],
		[
			12,
			-73
		],
		[
			30,
			-52
		],
		[
			102,
			42
		],
		[
			168,
			83
		],
		[
			84,
			-52
		],
		[
			18,
			-62
		],
		[
			43,
			31
		],
		[
			24,
			-83
		],
		[
			-6,
			-104
		],
		[
			78,
			-31
		],
		[
			0,
			-72
		],
		[
			48,
			-52
		],
		[
			48,
			21
		],
		[
			6,
			-52
		],
		[
			96,
			-135
		],
		[
			-18,
			-93
		],
		[
			6,
			-72
		],
		[
			60,
			-73
		],
		[
			133,
			62
		],
		[
			42,
			-31
		],
		[
			24,
			-83
		],
		[
			84,
			31
		],
		[
			18,
			63
		],
		[
			60,
			51
		],
		[
			66,
			21
		],
		[
			24,
			52
		],
		[
			132,
			-21
		],
		[
			121,
			-83
		],
		[
			48,
			52
		],
		[
			54,
			10
		],
		[
			60,
			-51
		],
		[
			42,
			-83
		],
		[
			-30,
			-73
		],
		[
			-102,
			-93
		],
		[
			-72,
			-155
		],
		[
			18,
			-21
		],
		[
			138,
			10
		],
		[
			12,
			-20
		],
		[
			102,
			31
		],
		[
			60,
			0
		],
		[
			-18,
			-166
		],
		[
			-120,
			-104
		],
		[
			12,
			-51
		],
		[
			-60,
			-83
		],
		[
			6,
			-42
		],
		[
			-54,
			-145
		],
		[
			30,
			-41
		],
		[
			-6,
			-135
		],
		[
			18,
			-82
		],
		[
			42,
			-52
		],
		[
			84,
			10
		],
		[
			60,
			-62
		],
		[
			30,
			-124
		],
		[
			6,
			-135
		]
	],
	[
		[
			32245,
			48263
		],
		[
			0,
			-21
		]
	],
	[
		[
			32245,
			48242
		],
		[
			-102,
			-72
		],
		[
			-90,
			-41
		],
		[
			-103,
			10
		],
		[
			-66,
			-21
		],
		[
			-72,
			-72
		],
		[
			-78,
			-42
		],
		[
			-42,
			0
		],
		[
			-78,
			52
		],
		[
			-126,
			41
		],
		[
			-133,
			21
		],
		[
			-168,
			-72
		],
		[
			-30,
			31
		],
		[
			-60,
			10
		],
		[
			-54,
			-31
		],
		[
			-18,
			-41
		],
		[
			-175,
			51
		],
		[
			-72,
			42
		],
		[
			-96,
			31
		],
		[
			-66,
			-42
		],
		[
			-115,
			0
		],
		[
			-66,
			-31
		],
		[
			-84,
			21
		],
		[
			-120,
			10
		],
		[
			-72,
			52
		],
		[
			-84,
			125
		],
		[
			-85,
			-135
		],
		[
			-144,
			-104
		],
		[
			-96,
			-20
		],
		[
			-84,
			10
		],
		[
			-102,
			-10
		],
		[
			-67,
			20
		],
		[
			-102,
			62
		],
		[
			-60,
			52
		],
		[
			-12,
			73
		],
		[
			-54,
			93
		],
		[
			-6,
			114
		],
		[
			-60,
			-21
		],
		[
			-30,
			-62
		],
		[
			78,
			-186
		],
		[
			-42,
			-52
		],
		[
			6,
			-83
		],
		[
			30,
			-41
		],
		[
			-48,
			-145
		],
		[
			-18,
			-156
		],
		[
			96,
			-62
		],
		[
			12,
			-83
		],
		[
			42,
			-72
		],
		[
			-48,
			-52
		],
		[
			-24,
			-83
		],
		[
			-90,
			-52
		],
		[
			-30,
			-62
		],
		[
			-12,
			-83
		],
		[
			-115,
			42
		],
		[
			-60,
			0
		],
		[
			-108,
			31
		],
		[
			-240,
			0
		],
		[
			0,
			41
		],
		[
			-55,
			21
		],
		[
			-114,
			-52
		],
		[
			-54,
			0
		],
		[
			-6,
			-52
		],
		[
			-198,
			-176
		],
		[
			-145,
			-31
		],
		[
			-18,
			83
		],
		[
			-114,
			73
		],
		[
			-42,
			124
		],
		[
			6,
			72
		],
		[
			-54,
			-31
		],
		[
			24,
			-93
		],
		[
			-42,
			-21
		],
		[
			90,
			-207
		],
		[
			18,
			-83
		],
		[
			-66,
			21
		],
		[
			-84,
			124
		],
		[
			-6,
			52
		],
		[
			-60,
			0
		],
		[
			0,
			-93
		],
		[
			-85,
			-83
		],
		[
			18,
			-41
		],
		[
			109,
			-73
		],
		[
			30,
			-72
		],
		[
			48,
			10
		],
		[
			18,
			-41
		],
		[
			-84,
			-73
		],
		[
			-42,
			-10
		],
		[
			-67,
			20
		],
		[
			-42,
			-31
		],
		[
			-54,
			-93
		],
		[
			-36,
			0
		],
		[
			-84,
			-52
		],
		[
			-54,
			-10
		],
		[
			-36,
			-41
		],
		[
			-175,
			-42
		],
		[
			-78,
			-83
		],
		[
			-30,
			-51
		],
		[
			-114,
			-52
		],
		[
			-90,
			10
		],
		[
			-66,
			52
		],
		[
			-30,
			-42
		],
		[
			-109,
			21
		],
		[
			-84,
			-31
		],
		[
			-30,
			42
		],
		[
			-90,
			72
		],
		[
			6,
			104
		],
		[
			102,
			186
		],
		[
			-12,
			83
		],
		[
			-60,
			52
		],
		[
			-12,
			103
		],
		[
			72,
			11
		],
		[
			42,
			82
		],
		[
			-42,
			42
		],
		[
			36,
			52
		],
		[
			-42,
			41
		],
		[
			-6,
			-114
		],
		[
			36,
			-31
		],
		[
			-36,
			-72
		],
		[
			-42,
			31
		],
		[
			-90,
			-125
		],
		[
			-30,
			-72
		],
		[
			-60,
			-62
		],
		[
			12,
			-114
		],
		[
			-30,
			-156
		],
		[
			-54,
			-41
		],
		[
			72,
			-72
		],
		[
			-42,
			-63
		],
		[
			-73,
			11
		],
		[
			-12,
			83
		],
		[
			-78,
			10
		],
		[
			30,
			62
		],
		[
			-30,
			31
		],
		[
			-48,
			-103
		],
		[
			-90,
			0
		],
		[
			-66,
			41
		],
		[
			-18,
			62
		],
		[
			-42,
			-10
		],
		[
			-36,
			31
		],
		[
			-42,
			83
		],
		[
			0,
			72
		],
		[
			-91,
			31
		],
		[
			-48,
			42
		],
		[
			-66,
			103
		],
		[
			36,
			104
		],
		[
			-48,
			31
		],
		[
			66,
			238
		],
		[
			-90,
			0
		],
		[
			-18,
			-83
		],
		[
			-60,
			-31
		],
		[
			-30,
			-52
		],
		[
			-54,
			-20
		],
		[
			-18,
			-73
		],
		[
			-54,
			-20
		],
		[
			-85,
			62
		],
		[
			-72,
			20
		],
		[
			-54,
			-10
		],
		[
			-42,
			41
		],
		[
			-54,
			11
		],
		[
			-180,
			93
		],
		[
			-43,
			31
		],
		[
			-72,
			124
		],
		[
			-42,
			31
		],
		[
			-36,
			135
		],
		[
			-90,
			114
		],
		[
			30,
			72
		],
		[
			-18,
			52
		],
		[
			-126,
			31
		],
		[
			-36,
			125
		],
		[
			-60,
			0
		],
		[
			-43,
			41
		],
		[
			-24,
			-72
		],
		[
			115,
			20
		],
		[
			36,
			-124
		],
		[
			54,
			-52
		],
		[
			78,
			0
		],
		[
			-42,
			-134
		],
		[
			60,
			-63
		],
		[
			-156,
			-93
		],
		[
			-18,
			-31
		],
		[
			30,
			-83
		],
		[
			-6,
			-72
		],
		[
			12,
			-166
		],
		[
			36,
			-103
		],
		[
			6,
			-73
		],
		[
			108,
			-62
		],
		[
			72,
			0
		],
		[
			72,
			-52
		],
		[
			85,
			-21
		],
		[
			54,
			-72
		],
		[
			18,
			-52
		],
		[
			-6,
			-72
		],
		[
			-30,
			-21
		],
		[
			-85,
			52
		],
		[
			-36,
			-62
		],
		[
			42,
			-32
		],
		[
			6,
			-82
		],
		[
			-60,
			-21
		],
		[
			48,
			-62
		],
		[
			30,
			10
		],
		[
			13,
			-103
		],
		[
			-25,
			-32
		],
		[
			-36,
			-217
		],
		[
			12,
			-135
		],
		[
			55,
			0
		],
		[
			30,
			-41
		],
		[
			-12,
			-73
		],
		[
			-91,
			-62
		],
		[
			6,
			-83
		],
		[
			-150,
			-124
		],
		[
			-96,
			10
		],
		[
			-24,
			21
		],
		[
			-24,
			11
		],
		[
			-84,
			62
		],
		[
			-145,
			72
		],
		[
			-144,
			31
		],
		[
			-84,
			42
		],
		[
			-72,
			62
		],
		[
			-72,
			41
		],
		[
			-49,
			73
		],
		[
			-60,
			41
		],
		[
			-24,
			62
		],
		[
			-102,
			42
		],
		[
			-60,
			0
		],
		[
			-30,
			124
		],
		[
			-48,
			62
		],
		[
			-12,
			93
		],
		[
			-133,
			125
		],
		[
			-90,
			20
		],
		[
			-120,
			83
		],
		[
			-120,
			62
		],
		[
			-66,
			52
		],
		[
			-85,
			104
		],
		[
			-114,
			103
		],
		[
			-168,
			21
		],
		[
			-48,
			21
		],
		[
			-84,
			-21
		],
		[
			-61,
			41
		],
		[
			-36,
			0
		],
		[
			-54,
			135
		],
		[
			-54,
			21
		],
		[
			-42,
			114
		],
		[
			-198,
			51
		],
		[
			-24,
			32
		],
		[
			-42,
			-114
		],
		[
			-175,
			-73
		],
		[
			-78,
			-41
		],
		[
			-126,
			-93
		],
		[
			-72,
			-11
		],
		[
			-43,
			-41
		],
		[
			-12,
			-52
		],
		[
			-66,
			-83
		],
		[
			-48,
			-114
		],
		[
			54,
			-52
		],
		[
			30,
			-62
		],
		[
			24,
			-114
		],
		[
			24,
			-20
		],
		[
			-6,
			-125
		],
		[
			43,
			-20
		],
		[
			30,
			-114
		],
		[
			54,
			-62
		],
		[
			18,
			-83
		],
		[
			-12,
			-52
		],
		[
			66,
			-166
		],
		[
			-6,
			-93
		],
		[
			36,
			-21
		],
		[
			36,
			-72
		],
		[
			48,
			0
		],
		[
			18,
			-52
		],
		[
			90,
			-41
		],
		[
			-90,
			-114
		],
		[
			12,
			-21
		],
		[
			-18,
			-135
		],
		[
			30,
			-41
		],
		[
			0,
			-73
		],
		[
			-114,
			-10
		],
		[
			-54,
			31
		],
		[
			-90,
			0
		],
		[
			-18,
			31
		],
		[
			-139,
			104
		],
		[
			-30,
			51
		],
		[
			-54,
			11
		],
		[
			-48,
			238
		],
		[
			60,
			62
		],
		[
			84,
			42
		],
		[
			-54,
			41
		],
		[
			-18,
			73
		],
		[
			-36,
			62
		],
		[
			60,
			51
		],
		[
			-6,
			42
		],
		[
			-90,
			41
		],
		[
			-90,
			-10
		],
		[
			-24,
			41
		],
		[
			36,
			104
		],
		[
			-12,
			41
		],
		[
			-90,
			21
		],
		[
			24,
			83
		],
		[
			-6,
			93
		],
		[
			-169,
			166
		],
		[
			-72,
			21
		],
		[
			6,
			82
		],
		[
			-72,
			83
		],
		[
			-66,
			11
		],
		[
			-72,
			41
		],
		[
			-54,
			114
		],
		[
			-109,
			21
		],
		[
			-114,
			124
		],
		[
			-36,
			83
		],
		[
			-36,
			-10
		],
		[
			-42,
			62
		],
		[
			6,
			124
		],
		[
			-60,
			93
		],
		[
			-48,
			135
		],
		[
			-60,
			72
		],
		[
			-60,
			104
		],
		[
			-18,
			166
		],
		[
			12,
			113
		],
		[
			-6,
			94
		],
		[
			42,
			103
		],
		[
			0,
			62
		],
		[
			-36,
			73
		],
		[
			156,
			280
		],
		[
			120,
			-11
		],
		[
			24,
			31
		],
		[
			66,
			11
		],
		[
			42,
			51
		],
		[
			97,
			11
		],
		[
			48,
			-62
		],
		[
			12,
			-104
		],
		[
			72,
			-52
		],
		[
			24,
			-62
		],
		[
			-6,
			-62
		],
		[
			48,
			-124
		],
		[
			-66,
			-42
		],
		[
			30,
			-103
		],
		[
			0,
			-156
		],
		[
			48,
			-124
		],
		[
			84,
			-52
		],
		[
			12,
			-31
		],
		[
			84,
			-83
		],
		[
			109,
			11
		],
		[
			84,
			51
		],
		[
			36,
			83
		],
		[
			-30,
			145
		],
		[
			-36,
			62
		],
		[
			-24,
			104
		],
		[
			-78,
			155
		],
		[
			-43,
			31
		],
		[
			-54,
			94
		],
		[
			-18,
			134
		]
	],
	[
		[
			20803,
			48325
		],
		[
			139,
			73
		],
		[
			132,
			31
		],
		[
			36,
			21
		],
		[
			72,
			114
		],
		[
			66,
			-32
		],
		[
			72,
			104
		],
		[
			36,
			114
		],
		[
			73,
			72
		],
		[
			0,
			125
		],
		[
			108,
			20
		],
		[
			18,
			-41
		],
		[
			48,
			21
		],
		[
			36,
			-31
		],
		[
			-6,
			-73
		],
		[
			78,
			-52
		],
		[
			-6,
			-51
		],
		[
			60,
			-42
		],
		[
			42,
			31
		],
		[
			151,
			31
		],
		[
			36,
			-83
		],
		[
			42,
			52
		],
		[
			132,
			31
		],
		[
			66,
			-62
		],
		[
			12,
			-62
		],
		[
			78,
			104
		],
		[
			85,
			-42
		],
		[
			120,
			93
		],
		[
			36,
			-62
		],
		[
			48,
			42
		],
		[
			60,
			-73
		],
		[
			126,
			62
		],
		[
			73,
			0
		],
		[
			24,
			42
		],
		[
			78,
			41
		],
		[
			42,
			-10
		],
		[
			30,
			31
		],
		[
			48,
			-62
		],
		[
			42,
			52
		],
		[
			60,
			124
		],
		[
			-54,
			103
		],
		[
			-48,
			-10
		],
		[
			-24,
			41
		],
		[
			-66,
			52
		],
		[
			12,
			73
		],
		[
			-24,
			52
		],
		[
			0,
			134
		],
		[
			12,
			52
		],
		[
			54,
			21
		]
	],
	[
		[
			23058,
			49496
		],
		[
			18,
			51
		],
		[
			108,
			63
		],
		[
			24,
			62
		],
		[
			157,
			-11
		]
	],
	[
		[
			23365,
			49661
		],
		[
			66,
			21
		],
		[
			48,
			93
		],
		[
			60,
			52
		],
		[
			48,
			10
		],
		[
			144,
			0
		],
		[
			109,
			-62
		],
		[
			204,
			11
		],
		[
			90,
			103
		],
		[
			6,
			52
		]
	],
	[
		[
			24140,
			49941
		],
		[
			36,
			10
		],
		[
			48,
			-62
		],
		[
			24,
			-93
		],
		[
			0,
			-72
		],
		[
			43,
			-83
		],
		[
			84,
			51
		],
		[
			66,
			73
		],
		[
			18,
			72
		],
		[
			-36,
			83
		],
		[
			18,
			73
		]
	],
	[
		[
			24441,
			49993
		],
		[
			0,
			21
		]
	],
	[
		[
			24441,
			50014
		],
		[
			126,
			238
		],
		[
			60,
			93
		],
		[
			12,
			72
		],
		[
			54,
			83
		],
		[
			24,
			135
		],
		[
			37,
			83
		],
		[
			-25,
			31
		],
		[
			25,
			83
		],
		[
			42,
			0
		]
	],
	[
		[
			24796,
			50832
		],
		[
			12,
			-21
		],
		[
			-6,
			0
		]
	],
	[
		[
			24802,
			50811
		],
		[
			-6,
			21
		]
	],
	[
		[
			24796,
			50832
		],
		[
			18,
			62
		],
		[
			36,
			10
		],
		[
			66,
			62
		],
		[
			96,
			145
		],
		[
			0,
			62
		],
		[
			48,
			94
		],
		[
			96,
			-31
		],
		[
			91,
			41
		],
		[
			120,
			-52
		],
		[
			54,
			145
		],
		[
			42,
			11
		],
		[
			30,
			-42
		],
		[
			60,
			-21
		],
		[
			78,
			21
		],
		[
			85,
			-83
		]
	],
	[
		[
			25716,
			51256
		],
		[
			30,
			-31
		]
	],
	[
		[
			25746,
			51225
		],
		[
			66,
			-114
		],
		[
			126,
			-83
		],
		[
			60,
			-10
		],
		[
			54,
			114
		],
		[
			78,
			31
		],
		[
			24,
			52
		],
		[
			-54,
			83
		],
		[
			18,
			83
		],
		[
			97,
			145
		],
		[
			18,
			51
		],
		[
			78,
			73
		],
		[
			-78,
			62
		],
		[
			-49,
			104
		],
		[
			37,
			124
		],
		[
			24,
			31
		],
		[
			-6,
			93
		],
		[
			42,
			156
		],
		[
			114,
			31
		],
		[
			114,
			82
		],
		[
			30,
			-20
		],
		[
			54,
			20
		],
		[
			169,
			114
		],
		[
			18,
			52
		],
		[
			-48,
			62
		],
		[
			42,
			62
		],
		[
			54,
			11
		],
		[
			54,
			83
		]
	],
	[
		[
			26882,
			52717
		],
		[
			60,
			-31
		],
		[
			36,
			-63
		],
		[
			108,
			73
		],
		[
			91,
			-41
		],
		[
			48,
			20
		],
		[
			18,
			-31
		],
		[
			60,
			0
		],
		[
			78,
			31
		],
		[
			66,
			-31
		],
		[
			114,
			0
		],
		[
			48,
			-41
		],
		[
			205,
			-73
		],
		[
			12,
			-83
		],
		[
			36,
			-82
		],
		[
			36,
			0
		],
		[
			42,
			-63
		],
		[
			42,
			-10
		],
		[
			24,
			-83
		],
		[
			78,
			-21
		],
		[
			6,
			-41
		],
		[
			73,
			-31
		],
		[
			12,
			-114
		],
		[
			24,
			-83
		],
		[
			60,
			-83
		],
		[
			78,
			-62
		],
		[
			78,
			11
		],
		[
			54,
			-42
		],
		[
			-48,
			-103
		],
		[
			48,
			-42
		],
		[
			6,
			-217
		],
		[
			66,
			-42
		],
		[
			0,
			-41
		],
		[
			121,
			-42
		],
		[
			84,
			-165
		],
		[
			108,
			10
		],
		[
			60,
			21
		],
		[
			90,
			0
		],
		[
			6,
			155
		],
		[
			-18,
			41
		],
		[
			78,
			94
		],
		[
			91,
			0
		],
		[
			30,
			-31
		],
		[
			66,
			51
		],
		[
			-18,
			63
		],
		[
			-54,
			93
		],
		[
			66,
			52
		],
		[
			-6,
			72
		],
		[
			36,
			104
		],
		[
			-42,
			41
		],
		[
			0,
			114
		],
		[
			120,
			31
		],
		[
			42,
			93
		],
		[
			108,
			-20
		],
		[
			61,
			62
		],
		[
			0,
			31
		],
		[
			78,
			62
		]
	],
	[
		[
			24627,
			55099
		],
		[
			12,
			-62
		],
		[
			66,
			-21
		],
		[
			61,
			-104
		],
		[
			114,
			21
		],
		[
			6,
			-52
		],
		[
			42,
			-62
		],
		[
			168,
			-31
		],
		[
			78,
			-52
		],
		[
			85,
			62
		],
		[
			66,
			-93
		],
		[
			54,
			31
		]
	],
	[
		[
			25379,
			54736
		],
		[
			0,
			-41
		],
		[
			144,
			-197
		],
		[
			30,
			-93
		],
		[
			-30,
			-83
		],
		[
			108,
			-73
		],
		[
			12,
			-41
		],
		[
			-24,
			-72
		],
		[
			97,
			-42
		],
		[
			42,
			-52
		],
		[
			-79,
			-41
		],
		[
			-42,
			-93
		]
	],
	[
		[
			25637,
			53908
		],
		[
			-12,
			-83
		],
		[
			-42,
			-42
		]
	],
	[
		[
			25583,
			53783
		],
		[
			-60,
			-41
		],
		[
			-72,
			-83
		],
		[
			42,
			-52
		],
		[
			-6,
			-62
		],
		[
			42,
			-21
		],
		[
			114,
			63
		],
		[
			42,
			41
		],
		[
			79,
			41
		],
		[
			72,
			0
		],
		[
			114,
			63
		],
		[
			60,
			-42
		],
		[
			66,
			-21
		],
		[
			96,
			0
		],
		[
			97,
			42
		],
		[
			60,
			-21
		],
		[
			96,
			73
		],
		[
			0,
			41
		],
		[
			96,
			42
		],
		[
			66,
			51
		],
		[
			24,
			-51
		],
		[
			151,
			-94
		],
		[
			-12,
			-41
		],
		[
			72,
			-62
		],
		[
			78,
			-11
		],
		[
			42,
			21
		],
		[
			30,
			-72
		],
		[
			72,
			0
		],
		[
			-12,
			-156
		],
		[
			-78,
			-93
		],
		[
			-78,
			-41
		],
		[
			-36,
			-125
		],
		[
			-72,
			-51
		],
		[
			-78,
			-83
		],
		[
			-37,
			-62
		],
		[
			85,
			-83
		],
		[
			-24,
			-104
		],
		[
			42,
			-10
		],
		[
			72,
			-62
		],
		[
			54,
			0
		]
	],
	[
		[
			24140,
			49941
		],
		[
			-36,
			104
		],
		[
			6,
			103
		],
		[
			-18,
			42
		],
		[
			18,
			82
		]
	],
	[
		[
			24110,
			50272
		],
		[
			72,
			31
		],
		[
			12,
			135
		]
	],
	[
		[
			24194,
			50438
		],
		[
			12,
			145
		],
		[
			30,
			73
		],
		[
			79,
			72
		]
	],
	[
		[
			24315,
			50728
		],
		[
			-30,
			10
		],
		[
			-31,
			125
		],
		[
			19,
			41
		],
		[
			-115,
			124
		],
		[
			48,
			52
		],
		[
			-12,
			62
		],
		[
			48,
			42
		],
		[
			37,
			62
		],
		[
			-103,
			62
		],
		[
			-60,
			21
		],
		[
			-48,
			72
		],
		[
			-72,
			-20
		],
		[
			-54,
			10
		],
		[
			-6,
			62
		],
		[
			-78,
			31
		],
		[
			-85,
			83
		],
		[
			-12,
			62
		],
		[
			-48,
			11
		],
		[
			-72,
			51
		],
		[
			-72,
			31
		],
		[
			36,
			52
		],
		[
			30,
			-10
		],
		[
			66,
			93
		],
		[
			91,
			93
		],
		[
			-7,
			52
		],
		[
			-78,
			62
		],
		[
			-114,
			-10
		],
		[
			-36,
			-73
		],
		[
			-96,
			125
		],
		[
			48,
			41
		],
		[
			18,
			83
		],
		[
			30,
			41
		],
		[
			-12,
			83
		],
		[
			48,
			0
		],
		[
			60,
			-52
		],
		[
			60,
			31
		],
		[
			109,
			-145
		],
		[
			84,
			-51
		],
		[
			6,
			-31
		],
		[
			78,
			20
		],
		[
			36,
			-10
		],
		[
			72,
			31
		],
		[
			90,
			62
		]
	],
	[
		[
			24188,
			52209
		],
		[
			12,
			62
		],
		[
			-24,
			125
		],
		[
			-42,
			10
		],
		[
			-30,
			-31
		],
		[
			-60,
			31
		],
		[
			-42,
			104
		],
		[
			60,
			51
		],
		[
			-42,
			94
		],
		[
			-36,
			31
		],
		[
			-24,
			93
		],
		[
			60,
			10
		],
		[
			18,
			73
		],
		[
			48,
			62
		],
		[
			66,
			-31
		],
		[
			133,
			134
		],
		[
			0,
			73
		],
		[
			102,
			10
		],
		[
			54,
			42
		],
		[
			42,
			124
		],
		[
			-42,
			72
		],
		[
			0,
			94
		],
		[
			-24,
			145
		],
		[
			-66,
			-11
		],
		[
			-18,
			52
		],
		[
			-36,
			-10
		],
		[
			-24,
			51
		],
		[
			-103,
			-31
		],
		[
			-36,
			31
		],
		[
			-138,
			-10
		],
		[
			-78,
			-21
		],
		[
			-54,
			63
		],
		[
			-91,
			20
		],
		[
			-54,
			52
		],
		[
			-60,
			93
		],
		[
			-6,
			52
		],
		[
			-138,
			10
		],
		[
			6,
			83
		],
		[
			-60,
			-41
		],
		[
			-78,
			0
		]
	],
	[
		[
			23383,
			53970
		],
		[
			36,
			93
		],
		[
			-12,
			83
		],
		[
			90,
			72
		],
		[
			60,
			-20
		],
		[
			30,
			238
		],
		[
			42,
			-10
		],
		[
			84,
			20
		],
		[
			145,
			83
		],
		[
			84,
			0
		],
		[
			-18,
			83
		],
		[
			-84,
			-52
		],
		[
			-103,
			0
		]
	],
	[
		[
			23737,
			54560
		],
		[
			-18,
			62
		],
		[
			-72,
			0
		],
		[
			-48,
			-31
		],
		[
			-126,
			-134
		],
		[
			-96,
			-52
		],
		[
			-60,
			31
		],
		[
			42,
			72
		],
		[
			-36,
			42
		],
		[
			-79,
			41
		],
		[
			-24,
			42
		],
		[
			-66,
			0
		],
		[
			54,
			83
		],
		[
			54,
			-11
		],
		[
			24,
			62
		],
		[
			55,
			31
		],
		[
			54,
			73
		],
		[
			-6,
			52
		],
		[
			72,
			62
		],
		[
			0,
			72
		],
		[
			72,
			31
		],
		[
			72,
			83
		],
		[
			24,
			62
		],
		[
			54,
			73
		],
		[
			60,
			52
		]
	],
	[
		[
			23743,
			55358
		],
		[
			73,
			114
		],
		[
			60,
			62
		],
		[
			90,
			-21
		],
		[
			-6,
			-41
		],
		[
			42,
			-73
		],
		[
			138,
			0
		],
		[
			-42,
			-155
		],
		[
			60,
			41
		],
		[
			102,
			-31
		],
		[
			109,
			-52
		],
		[
			120,
			-134
		],
		[
			96,
			83
		],
		[
			42,
			-52
		]
	],
	[
		[
			36237,
			57253
		],
		[
			0,
			-31
		],
		[
			-108,
			-93
		],
		[
			-42,
			-21
		],
		[
			-36,
			-73
		]
	],
	[
		[
			36051,
			57035
		],
		[
			-72,
			-93
		],
		[
			-42,
			-10
		],
		[
			-24,
			-52
		],
		[
			-72,
			-21
		],
		[
			-67,
			-62
		],
		[
			-12,
			-41
		],
		[
			-66,
			-11
		],
		[
			-42,
			-72
		],
		[
			-72,
			31
		],
		[
			-60,
			114
		]
	],
	[
		[
			35522,
			56818
		],
		[
			-12,
			21
		],
		[
			-6,
			0
		],
		[
			0,
			10
		],
		[
			-6,
			10
		],
		[
			-60,
			73
		],
		[
			-102,
			-31
		],
		[
			-67,
			21
		],
		[
			-12,
			31
		],
		[
			-108,
			-21
		],
		[
			-18,
			-62
		],
		[
			18,
			-52
		],
		[
			-66,
			-21
		],
		[
			-24,
			-52
		],
		[
			54,
			-62
		],
		[
			48,
			-10
		],
		[
			78,
			-114
		],
		[
			12,
			-103
		],
		[
			-36,
			-125
		],
		[
			-66,
			-83
		],
		[
			-108,
			63
		],
		[
			-48,
			-11
		],
		[
			-12,
			-103
		],
		[
			-60,
			-52
		],
		[
			-60,
			0
		],
		[
			-31,
			52
		],
		[
			-132,
			20
		],
		[
			-54,
			-20
		],
		[
			-6,
			62
		],
		[
			-36,
			31
		],
		[
			-66,
			-11
		],
		[
			-66,
			32
		],
		[
			-139,
			-94
		],
		[
			-54,
			11
		],
		[
			-102,
			-21
		],
		[
			-96,
			-62
		],
		[
			-90,
			31
		],
		[
			-54,
			72
		],
		[
			-55,
			-20
		],
		[
			-18,
			62
		],
		[
			-48,
			-73
		],
		[
			-156,
			-62
		],
		[
			-30,
			0
		],
		[
			-126,
			-114
		],
		[
			-36,
			11
		]
	],
	[
		[
			33466,
			56052
		],
		[
			-54,
			145
		],
		[
			-43,
			41
		]
	],
	[
		[
			33369,
			56238
		],
		[
			-36,
			0
		],
		[
			-72,
			93
		],
		[
			-78,
			0
		],
		[
			-24,
			52
		]
	],
	[
		[
			33159,
			56383
		],
		[
			24,
			52
		]
	],
	[
		[
			33183,
			56435
		],
		[
			-60,
			10
		],
		[
			-48,
			-31
		],
		[
			-30,
			52
		],
		[
			-54,
			-21
		],
		[
			-48,
			31
		],
		[
			-6,
			114
		],
		[
			-61,
			52
		],
		[
			-6,
			103
		],
		[
			-60,
			21
		],
		[
			12,
			62
		],
		[
			-54,
			11
		],
		[
			6,
			83
		],
		[
			-48,
			20
		],
		[
			-84,
			0
		],
		[
			-84,
			-41
		],
		[
			-48,
			-73
		],
		[
			-133,
			73
		],
		[
			-108,
			21
		],
		[
			-60,
			62
		],
		[
			-66,
			10
		],
		[
			-78,
			124
		]
	],
	[
		[
			32065,
			57118
		],
		[
			54,
			21
		],
		[
			-18,
			83
		],
		[
			30,
			41
		]
	],
	[
		[
			32131,
			57263
		],
		[
			66,
			-20
		],
		[
			96,
			41
		],
		[
			36,
			41
		],
		[
			127,
			-20
		],
		[
			138,
			41
		],
		[
			96,
			52
		],
		[
			54,
			83
		],
		[
			78,
			21
		],
		[
			121,
			0
		],
		[
			126,
			20
		],
		[
			42,
			52
		],
		[
			60,
			31
		],
		[
			-12,
			42
		],
		[
			60,
			41
		],
		[
			24,
			93
		],
		[
			-30,
			73
		],
		[
			90,
			41
		],
		[
			30,
			-31
		],
		[
			103,
			21
		],
		[
			-91,
			134
		],
		[
			12,
			94
		],
		[
			73,
			0
		],
		[
			84,
			31
		],
		[
			36,
			103
		],
		[
			36,
			0
		],
		[
			72,
			114
		],
		[
			36,
			-21
		],
		[
			42,
			32
		],
		[
			72,
			10
		],
		[
			85,
			-21
		],
		[
			84,
			-41
		],
		[
			48,
			0
		],
		[
			48,
			31
		],
		[
			90,
			-31
		],
		[
			48,
			10
		],
		[
			102,
			-31
		],
		[
			55,
			41
		],
		[
			66,
			0
		],
		[
			48,
			-41
		],
		[
			96,
			21
		],
		[
			24,
			-52
		],
		[
			156,
			-41
		],
		[
			66,
			-104
		],
		[
			18,
			-52
		],
		[
			55,
			-72
		],
		[
			78,
			-31
		],
		[
			-36,
			-52
		],
		[
			-6,
			-93
		],
		[
			-54,
			-42
		],
		[
			18,
			-41
		],
		[
			120,
			31
		],
		[
			0,
			41
		],
		[
			48,
			52
		],
		[
			90,
			-83
		],
		[
			54,
			-31
		],
		[
			12,
			62
		],
		[
			42,
			-10
		],
		[
			97,
			21
		],
		[
			60,
			-73
		],
		[
			90,
			-31
		],
		[
			108,
			0
		],
		[
			36,
			-72
		],
		[
			126,
			0
		],
		[
			24,
			-63
		],
		[
			103,
			-62
		],
		[
			24,
			-41
		],
		[
			78,
			21
		],
		[
			42,
			-42
		],
		[
			18,
			-103
		],
		[
			108,
			-94
		],
		[
			60,
			-10
		]
	],
	[
		[
			25355,
			55731
		],
		[
			6,
			-52
		]
	],
	[
		[
			25361,
			55679
		],
		[
			-36,
			-73
		],
		[
			-78,
			21
		],
		[
			-73,
			-41
		],
		[
			42,
			-114
		]
	],
	[
		[
			25216,
			55472
		],
		[
			6,
			-21
		]
	],
	[
		[
			25222,
			55451
		],
		[
			49,
			0
		],
		[
			24,
			-52
		],
		[
			36,
			0
		],
		[
			48,
			-103
		]
	],
	[
		[
			25379,
			55296
		],
		[
			36,
			-42
		],
		[
			42,
			0
		],
		[
			54,
			-41
		],
		[
			6,
			-104
		],
		[
			24,
			-41
		],
		[
			-42,
			-135
		],
		[
			24,
			-83
		],
		[
			-132,
			-93
		],
		[
			-12,
			-21
		]
	],
	[
		[
			23743,
			55358
		],
		[
			-60,
			62
		],
		[
			0,
			103
		],
		[
			-60,
			42
		]
	],
	[
		[
			23623,
			55565
		],
		[
			54,
			114
		],
		[
			115,
			-42
		],
		[
			42,
			94
		],
		[
			48,
			10
		],
		[
			24,
			83
		],
		[
			42,
			62
		],
		[
			54,
			-31
		],
		[
			72,
			0
		],
		[
			42,
			62
		],
		[
			36,
			-21
		],
		[
			84,
			11
		],
		[
			61,
			51
		],
		[
			78,
			-10
		],
		[
			120,
			31
		],
		[
			36,
			52
		],
		[
			72,
			62
		]
	],
	[
		[
			24603,
			56093
		],
		[
			48,
			-41
		],
		[
			-18,
			-63
		],
		[
			24,
			-51
		],
		[
			0,
			-114
		],
		[
			163,
			10
		],
		[
			60,
			-21
		],
		[
			60,
			73
		],
		[
			-6,
			62
		],
		[
			108,
			31
		],
		[
			48,
			-10
		],
		[
			78,
			20
		],
		[
			54,
			-31
		],
		[
			43,
			21
		],
		[
			36,
			-124
		],
		[
			-42,
			-52
		],
		[
			24,
			-62
		],
		[
			72,
			-10
		]
	],
	[
		[
			5730,
			65145
		],
		[
			-6,
			0
		],
		[
			30,
			52
		],
		[
			150,
			-11
		],
		[
			-18,
			-72
		],
		[
			-90,
			-21
		],
		[
			-66,
			52
		]
	],
	[
		[
			5676,
			65342
		],
		[
			18,
			103
		]
	],
	[
		[
			5694,
			65445
		],
		[
			-18,
			62
		],
		[
			210,
			21
		],
		[
			30,
			-62
		],
		[
			-60,
			-83
		],
		[
			48,
			-41
		],
		[
			-126,
			-83
		],
		[
			-66,
			0
		],
		[
			-36,
			83
		]
	],
	[
		[
			5898,
			65715
		],
		[
			-12,
			0
		],
		[
			12,
			0
		]
	],
	[
		[
			6259,
			65808
		],
		[
			6,
			0
		]
	],
	[
		[
			6265,
			65808
		],
		[
			-6,
			0
		]
	],
	[
		[
			6265,
			65808
		],
		[
			-6,
			0
		]
	],
	[
		[
			6259,
			65808
		],
		[
			-60,
			-42
		],
		[
			-132,
			-20
		],
		[
			-18,
			93
		],
		[
			132,
			31
		],
		[
			84,
			-62
		]
	],
	[
		[
			6644,
			66118
		],
		[
			-6,
			0
		]
	],
	[
		[
			6638,
			66118
		],
		[
			6,
			0
		]
	],
	[
		[
			6614,
			66212
		],
		[
			-6,
			-62
		],
		[
			30,
			-32
		]
	],
	[
		[
			6638,
			66118
		],
		[
			-84,
			-62
		],
		[
			-18,
			31
		],
		[
			-67,
			0
		],
		[
			-60,
			42
		],
		[
			-24,
			52
		],
		[
			24,
			72
		],
		[
			127,
			0
		],
		[
			78,
			-41
		]
	],
	[
		[
			6223,
			66212
		],
		[
			-18,
			-42
		]
	],
	[
		[
			6205,
			66170
		],
		[
			-12,
			11
		],
		[
			0,
			10
		]
	],
	[
		[
			6193,
			66191
		],
		[
			30,
			21
		]
	],
	[
		[
			6938,
			66440
		],
		[
			30,
			-42
		],
		[
			-60,
			-62
		],
		[
			-30,
			93
		],
		[
			60,
			11
		]
	],
	[
		[
			6127,
			66564
		],
		[
			6,
			-21
		]
	],
	[
		[
			6133,
			66543
		],
		[
			-6,
			21
		]
	],
	[
		[
			6175,
			66553
		],
		[
			-42,
			-10
		]
	],
	[
		[
			6127,
			66564
		],
		[
			48,
			-11
		]
	],
	[
		[
			6692,
			66678
		],
		[
			6,
			-11
		]
	],
	[
		[
			6698,
			66667
		],
		[
			-6,
			11
		]
	],
	[
		[
			7065,
			66957
		],
		[
			6,
			-10
		]
	],
	[
		[
			7071,
			66947
		],
		[
			-6,
			0
		]
	],
	[
		[
			7065,
			66947
		],
		[
			0,
			10
		]
	],
	[
		[
			7365,
			66978
		],
		[
			-12,
			0
		],
		[
			12,
			0
		]
	],
	[
		[
			7293,
			66988
		],
		[
			-6,
			0
		]
	],
	[
		[
			7287,
			66988
		],
		[
			6,
			0
		]
	],
	[
		[
			7371,
			67185
		],
		[
			30,
			-41
		],
		[
			-30,
			-52
		],
		[
			-48,
			31
		],
		[
			-6,
			62
		],
		[
			54,
			0
		]
	],
	[
		[
			7209,
			67175
		],
		[
			-6,
			21
		]
	],
	[
		[
			7203,
			67196
		],
		[
			24,
			0
		]
	],
	[
		[
			7227,
			67196
		],
		[
			-18,
			-21
		]
	],
	[
		[
			7077,
			67185
		],
		[
			-6,
			-10
		]
	],
	[
		[
			7071,
			67175
		],
		[
			0,
			10
		]
	],
	[
		[
			7071,
			67185
		],
		[
			6,
			0
		]
	],
	[
		[
			7239,
			67196
		],
		[
			-6,
			10
		]
	],
	[
		[
			7233,
			67206
		],
		[
			6,
			-10
		]
	],
	[
		[
			7071,
			67185
		],
		[
			6,
			0
		]
	],
	[
		[
			7071,
			67185
		],
		[
			-6,
			0
		]
	],
	[
		[
			7065,
			67185
		],
		[
			6,
			0
		]
	],
	[
		[
			7227,
			67196
		],
		[
			-12,
			0
		]
	],
	[
		[
			7215,
			67196
		],
		[
			12,
			0
		]
	],
	[
		[
			7233,
			67237
		],
		[
			6,
			-41
		]
	],
	[
		[
			7233,
			67206
		],
		[
			0,
			31
		]
	],
	[
		[
			6542,
			67216
		],
		[
			-6,
			0
		]
	],
	[
		[
			6536,
			67216
		],
		[
			6,
			0
		]
	],
	[
		[
			7492,
			67351
		],
		[
			-49,
			-83
		],
		[
			-54,
			52
		],
		[
			79,
			41
		],
		[
			24,
			-10
		]
	],
	[
		[
			7576,
			67330
		],
		[
			-42,
			21
		],
		[
			6,
			52
		],
		[
			60,
			31
		],
		[
			24,
			-83
		],
		[
			-48,
			-21
		]
	],
	[
		[
			7215,
			67196
		],
		[
			-12,
			0
		]
	],
	[
		[
			7203,
			67196
		],
		[
			-72,
			0
		],
		[
			-66,
			-11
		]
	],
	[
		[
			7065,
			67185
		],
		[
			6,
			-10
		]
	],
	[
		[
			7071,
			67175
		],
		[
			30,
			-21
		],
		[
			48,
			31
		],
		[
			36,
			-20
		],
		[
			42,
			-42
		],
		[
			6,
			0
		],
		[
			60,
			-31
		],
		[
			0,
			-104
		]
	],
	[
		[
			7293,
			66988
		],
		[
			-6,
			0
		]
	],
	[
		[
			7287,
			66988
		],
		[
			-12,
			0
		]
	],
	[
		[
			7275,
			66988
		],
		[
			-144,
			32
		],
		[
			6,
			-63
		],
		[
			-72,
			0
		]
	],
	[
		[
			7065,
			66957
		],
		[
			0,
			-10
		]
	],
	[
		[
			7065,
			66947
		],
		[
			-24,
			-21
		],
		[
			-18,
			-93
		],
		[
			-61,
			10
		],
		[
			-30,
			-31
		],
		[
			67,
			-72
		],
		[
			-31,
			-42
		],
		[
			-78,
			11
		],
		[
			-54,
			-31
		],
		[
			-90,
			-21
		],
		[
			-48,
			10
		]
	],
	[
		[
			6692,
			66678
		],
		[
			-12,
			72
		],
		[
			-30,
			11
		],
		[
			-66,
			-83
		],
		[
			-139,
			0
		],
		[
			-30,
			-93
		],
		[
			103,
			0
		],
		[
			84,
			-32
		],
		[
			54,
			11
		],
		[
			0,
			-52
		],
		[
			-102,
			10
		],
		[
			-60,
			31
		],
		[
			-103,
			-93
		],
		[
			84,
			-31
		],
		[
			109,
			11
		],
		[
			-24,
			-63
		]
	],
	[
		[
			6560,
			66377
		],
		[
			-66,
			-31
		],
		[
			-85,
			21
		],
		[
			-78,
			-41
		],
		[
			-90,
			114
		]
	],
	[
		[
			6241,
			66440
		],
		[
			96,
			-11
		],
		[
			0,
			83
		],
		[
			-138,
			21
		],
		[
			-24,
			20
		]
	],
	[
		[
			6175,
			66553
		],
		[
			18,
			52
		],
		[
			0,
			93
		],
		[
			174,
			-41
		],
		[
			-24,
			52
		],
		[
			-60,
			10
		],
		[
			-12,
			83
		]
	],
	[
		[
			6271,
			66802
		],
		[
			-6,
			62
		],
		[
			72,
			52
		]
	],
	[
		[
			6337,
			66916
		],
		[
			12,
			10
		],
		[
			108,
			-10
		],
		[
			91,
			176
		],
		[
			-30,
			73
		],
		[
			36,
			82
		],
		[
			-54,
			31
		],
		[
			-13,
			42
		],
		[
			133,
			-21
		],
		[
			72,
			11
		],
		[
			36,
			41
		],
		[
			114,
			41
		],
		[
			60,
			176
		],
		[
			-48,
			94
		],
		[
			12,
			72
		],
		[
			66,
			-10
		],
		[
			6,
			-93
		],
		[
			97,
			0
		],
		[
			6,
			-63
		],
		[
			-18,
			-82
		],
		[
			-127,
			-63
		],
		[
			12,
			-62
		],
		[
			229,
			-103
		],
		[
			78,
			-62
		]
	],
	[
		[
			7239,
			67745
		],
		[
			60,
			-11
		],
		[
			36,
			-72
		],
		[
			-78,
			-83
		],
		[
			-66,
			0
		],
		[
			-30,
			31
		],
		[
			78,
			135
		]
	],
	[
		[
			7612,
			67962
		],
		[
			12,
			-10
		]
	],
	[
		[
			7624,
			67952
		],
		[
			-12,
			10
		]
	],
	[
		[
			7612,
			67962
		],
		[
			12,
			-10
		]
	],
	[
		[
			7456,
			67962
		],
		[
			-13,
			0
		]
	],
	[
		[
			7443,
			67962
		],
		[
			13,
			0
		]
	],
	[
		[
			7443,
			67962
		],
		[
			13,
			0
		]
	],
	[
		[
			7456,
			67962
		],
		[
			-31,
			-10
		]
	],
	[
		[
			7425,
			67952
		],
		[
			18,
			10
		]
	],
	[
		[
			7648,
			68107
		],
		[
			6,
			0
		]
	],
	[
		[
			7654,
			68107
		],
		[
			36,
			-93
		],
		[
			54,
			-21
		],
		[
			42,
			42
		],
		[
			138,
			0
		],
		[
			-18,
			-104
		],
		[
			-42,
			-62
		],
		[
			-42,
			-187
		],
		[
			-36,
			-10
		],
		[
			-84,
			62
		],
		[
			0,
			176
		],
		[
			-12,
			83
		],
		[
			-42,
			73
		],
		[
			0,
			41
		]
	],
	[
		[
			7690,
			68148
		],
		[
			-12,
			11
		]
	],
	[
		[
			7678,
			68159
		],
		[
			12,
			-11
		]
	],
	[
		[
			7738,
			68542
		],
		[
			6,
			0
		]
	],
	[
		[
			7744,
			68542
		],
		[
			-6,
			0
		]
	],
	[
		[
			7504,
			68521
		],
		[
			24,
			31
		]
	],
	[
		[
			7528,
			68552
		],
		[
			-24,
			-31
		]
	],
	[
		[
			7738,
			68542
		],
		[
			-18,
			-21
		]
	],
	[
		[
			7720,
			68521
		],
		[
			-72,
			0
		],
		[
			-60,
			62
		]
	],
	[
		[
			7588,
			68583
		],
		[
			12,
			11
		],
		[
			114,
			-31
		],
		[
			24,
			-21
		]
	],
	[
		[
			7576,
			68594
		],
		[
			12,
			-11
		]
	],
	[
		[
			7588,
			68583
		],
		[
			-18,
			0
		]
	],
	[
		[
			7570,
			68583
		],
		[
			6,
			11
		]
	],
	[
		[
			7973,
			69143
		],
		[
			0,
			-11
		]
	],
	[
		[
			7973,
			69132
		],
		[
			-6,
			11
		]
	],
	[
		[
			7967,
			69143
		],
		[
			6,
			0
		]
	],
	[
		[
			7967,
			69143
		],
		[
			6,
			0
		]
	],
	[
		[
			7594,
			69288
		],
		[
			0,
			10
		]
	],
	[
		[
			7594,
			69298
		],
		[
			0,
			-10
		]
	],
	[
		[
			7522,
			69298
		],
		[
			-6,
			10
		]
	],
	[
		[
			7516,
			69308
		],
		[
			6,
			-10
		]
	],
	[
		[
			7564,
			69308
		],
		[
			-12,
			-10
		],
		[
			12,
			10
		]
	],
	[
		[
			7606,
			69339
		],
		[
			0,
			11
		]
	],
	[
		[
			7606,
			69350
		],
		[
			0,
			-11
		]
	],
	[
		[
			7606,
			69339
		],
		[
			-6,
			11
		]
	],
	[
		[
			7600,
			69350
		],
		[
			6,
			0
		]
	],
	[
		[
			7600,
			69350
		],
		[
			-6,
			0
		]
	],
	[
		[
			7594,
			69350
		],
		[
			6,
			10
		]
	],
	[
		[
			7600,
			69360
		],
		[
			0,
			-10
		]
	],
	[
		[
			7732,
			69381
		],
		[
			-6,
			21
		]
	],
	[
		[
			7726,
			69402
		],
		[
			6,
			-21
		]
	],
	[
		[
			7474,
			69412
		],
		[
			-49,
			10
		],
		[
			49,
			-10
		]
	],
	[
		[
			8075,
			70241
		],
		[
			12,
			10
		]
	],
	[
		[
			8087,
			70251
		],
		[
			-12,
			-10
		]
	],
	[
		[
			8087,
			70251
		],
		[
			-12,
			-10
		]
	],
	[
		[
			8075,
			70241
		],
		[
			12,
			10
		]
	],
	[
		[
			8111,
			70406
		],
		[
			-6,
			0
		]
	],
	[
		[
			8105,
			70406
		],
		[
			-6,
			11
		]
	],
	[
		[
			8099,
			70417
		],
		[
			12,
			-11
		]
	],
	[
		[
			8105,
			70468
		],
		[
			-6,
			0
		]
	],
	[
		[
			8099,
			70468
		],
		[
			6,
			0
		]
	],
	[
		[
			7931,
			70624
		],
		[
			-13,
			10
		]
	],
	[
		[
			7918,
			70634
		],
		[
			13,
			-10
		]
	],
	[
		[
			7949,
			70769
		],
		[
			-12,
			0
		]
	],
	[
		[
			7937,
			70769
		],
		[
			12,
			0
		]
	],
	[
		[
			7949,
			70769
		],
		[
			-12,
			0
		]
	],
	[
		[
			7937,
			70769
		],
		[
			12,
			0
		]
	],
	[
		[
			8279,
			70862
		],
		[
			6,
			0
		]
	],
	[
		[
			8285,
			70862
		],
		[
			-6,
			0
		]
	],
	[
		[
			8015,
			70883
		],
		[
			12,
			-21
		],
		[
			-12,
			21
		]
	],
	[
		[
			7937,
			70914
		],
		[
			6,
			-11
		],
		[
			-6,
			11
		]
	],
	[
		[
			7906,
			70914
		],
		[
			12,
			-21
		]
	],
	[
		[
			7918,
			70893
		],
		[
			-18,
			21
		]
	],
	[
		[
			7900,
			70914
		],
		[
			6,
			0
		]
	],
	[
		[
			8033,
			70924
		],
		[
			6,
			-21
		]
	],
	[
		[
			8039,
			70903
		],
		[
			-24,
			-20
		]
	],
	[
		[
			8015,
			70883
		],
		[
			18,
			41
		]
	],
	[
		[
			7894,
			70914
		],
		[
			6,
			0
		]
	],
	[
		[
			7900,
			70914
		],
		[
			-6,
			0
		]
	],
	[
		[
			8087,
			70934
		],
		[
			-48,
			-31
		]
	],
	[
		[
			8039,
			70903
		],
		[
			-6,
			21
		]
	],
	[
		[
			8033,
			70924
		],
		[
			54,
			10
		]
	],
	[
		[
			7973,
			70955
		],
		[
			6,
			11
		],
		[
			-6,
			-11
		]
	],
	[
		[
			8021,
			70966
		],
		[
			-6,
			10
		],
		[
			6,
			-10
		]
	],
	[
		[
			7931,
			71007
		],
		[
			-19,
			10
		]
	],
	[
		[
			7912,
			71017
		],
		[
			19,
			-10
		]
	],
	[
		[
			8363,
			70883
		],
		[
			-36,
			-31
		],
		[
			-42,
			10
		]
	],
	[
		[
			8279,
			70862
		],
		[
			-60,
			-21
		],
		[
			12,
			-20
		]
	],
	[
		[
			8231,
			70821
		],
		[
			-78,
			51
		],
		[
			36,
			73
		]
	],
	[
		[
			8189,
			70945
		],
		[
			48,
			62
		],
		[
			132,
			21
		],
		[
			-18,
			-73
		],
		[
			12,
			-72
		]
	],
	[
		[
			7906,
			71017
		],
		[
			6,
			0
		]
	],
	[
		[
			7912,
			71017
		],
		[
			-6,
			0
		]
	],
	[
		[
			7606,
			71007
		],
		[
			-24,
			-73
		],
		[
			6,
			-51
		],
		[
			48,
			0
		],
		[
			72,
			-62
		],
		[
			96,
			-11
		],
		[
			18,
			0
		],
		[
			102,
			-62
		],
		[
			-12,
			-72
		]
	],
	[
		[
			7912,
			70676
		],
		[
			6,
			-42
		]
	],
	[
		[
			7918,
			70634
		],
		[
			13,
			-10
		]
	],
	[
		[
			7931,
			70624
		],
		[
			12,
			-42
		],
		[
			66,
			-51
		],
		[
			66,
			-21
		],
		[
			30,
			-42
		]
	],
	[
		[
			8099,
			70468
		],
		[
			-60,
			-20
		],
		[
			-78,
			20
		]
	],
	[
		[
			7961,
			70468
		],
		[
			18,
			-62
		],
		[
			54,
			0
		],
		[
			30,
			31
		],
		[
			36,
			-20
		]
	],
	[
		[
			8099,
			70417
		],
		[
			6,
			-11
		]
	],
	[
		[
			8111,
			70406
		],
		[
			24,
			42
		],
		[
			18,
			10
		],
		[
			54,
			10
		],
		[
			-66,
			-134
		],
		[
			-114,
			-21
		],
		[
			-6,
			-31
		],
		[
			-121,
			-10
		],
		[
			6,
			-42
		],
		[
			97,
			21
		],
		[
			90,
			-62
		],
		[
			36,
			41
		],
		[
			72,
			-31
		]
	],
	[
		[
			8201,
			70199
		],
		[
			-6,
			-72
		],
		[
			30,
			-94
		],
		[
			114,
			31
		],
		[
			30,
			-62
		],
		[
			-42,
			-31
		],
		[
			0,
			-114
		],
		[
			-54,
			-51
		],
		[
			-54,
			0
		],
		[
			-36,
			31
		],
		[
			-42,
			-94
		],
		[
			-114,
			-103
		],
		[
			54,
			-114
		],
		[
			-72,
			-42
		],
		[
			-36,
			-93
		],
		[
			-6,
			-83
		],
		[
			-115,
			-10
		],
		[
			-42,
			-21
		],
		[
			-72,
			21
		],
		[
			-6,
			83
		]
	],
	[
		[
			7732,
			69381
		],
		[
			42,
			21
		]
	],
	[
		[
			7774,
			69402
		],
		[
			-48,
			0
		]
	],
	[
		[
			7726,
			69402
		],
		[
			-24,
			-31
		],
		[
			-42,
			20
		],
		[
			-60,
			-31
		]
	],
	[
		[
			7600,
			69360
		],
		[
			-6,
			-10
		]
	],
	[
		[
			7594,
			69350
		],
		[
			-30,
			0
		],
		[
			-66,
			83
		],
		[
			-24,
			-21
		]
	],
	[
		[
			7474,
			69412
		],
		[
			-55,
			10
		],
		[
			6,
			-51
		],
		[
			43,
			-73
		],
		[
			48,
			10
		]
	],
	[
		[
			7516,
			69308
		],
		[
			6,
			-10
		]
	],
	[
		[
			7522,
			69298
		],
		[
			42,
			10
		]
	],
	[
		[
			7564,
			69308
		],
		[
			30,
			-10
		]
	],
	[
		[
			7594,
			69288
		],
		[
			42,
			51
		],
		[
			66,
			0
		],
		[
			36,
			-124
		],
		[
			66,
			-31
		],
		[
			108,
			21
		],
		[
			61,
			-73
		]
	],
	[
		[
			7973,
			69132
		],
		[
			-18,
			-124
		],
		[
			84,
			-103
		],
		[
			18,
			-187
		],
		[
			-54,
			-52
		],
		[
			0,
			-51
		],
		[
			-60,
			-21
		],
		[
			-109,
			0
		],
		[
			-102,
			72
		],
		[
			-12,
			-31
		]
	],
	[
		[
			7720,
			68635
		],
		[
			-30,
			-41
		],
		[
			-138,
			10
		],
		[
			-24,
			-52
		]
	],
	[
		[
			7528,
			68552
		],
		[
			-24,
			-31
		]
	],
	[
		[
			7504,
			68521
		],
		[
			24,
			-51
		],
		[
			78,
			10
		],
		[
			102,
			-10
		],
		[
			54,
			41
		],
		[
			120,
			10
		],
		[
			73,
			-10
		]
	],
	[
		[
			7955,
			68511
		],
		[
			30,
			-41
		],
		[
			84,
			-21
		],
		[
			24,
			-145
		]
	],
	[
		[
			8093,
			68304
		],
		[
			36,
			62
		],
		[
			96,
			-83
		],
		[
			-36,
			-124
		],
		[
			-42,
			0
		],
		[
			6,
			-83
		],
		[
			-42,
			0
		],
		[
			-48,
			41
		],
		[
			-66,
			-10
		],
		[
			-85,
			73
		],
		[
			-150,
			10
		],
		[
			-84,
			-31
		]
	],
	[
		[
			7678,
			68159
		],
		[
			-24,
			-52
		]
	],
	[
		[
			7648,
			68107
		],
		[
			-36,
			41
		],
		[
			-193,
			-10
		],
		[
			-96,
			21
		],
		[
			-36,
			62
		],
		[
			-60,
			31
		],
		[
			-12,
			93
		],
		[
			-36,
			52
		],
		[
			-30,
			114
		],
		[
			-48,
			72
		],
		[
			30,
			83
		],
		[
			-72,
			207
		],
		[
			-24,
			104
		],
		[
			12,
			62
		],
		[
			-12,
			83
		],
		[
			6,
			83
		],
		[
			-42,
			72
		],
		[
			-6,
			94
		],
		[
			-55,
			82
		],
		[
			61,
			42
		],
		[
			30,
			62
		],
		[
			12,
			207
		],
		[
			18,
			135
		],
		[
			90,
			52
		],
		[
			42,
			62
		],
		[
			-18,
			93
		],
		[
			30,
			155
		],
		[
			0,
			62
		],
		[
			-48,
			239
		],
		[
			-48,
			114
		],
		[
			-66,
			72
		],
		[
			-36,
			83
		],
		[
			24,
			31
		],
		[
			72,
			-41
		],
		[
			78,
			103
		],
		[
			48,
			21
		],
		[
			54,
			-31
		]
	],
	[
		[
			7281,
			70914
		],
		[
			54,
			-21
		],
		[
			36,
			41
		],
		[
			72,
			0
		],
		[
			61,
			32
		],
		[
			78,
			-32
		],
		[
			18,
			73
		]
	],
	[
		[
			7600,
			71007
		],
		[
			6,
			0
		]
	],
	[
		[
			8075,
			71038
		],
		[
			30,
			0
		]
	],
	[
		[
			8105,
			71038
		],
		[
			-18,
			-10
		]
	],
	[
		[
			8087,
			71028
		],
		[
			-12,
			10
		]
	],
	[
		[
			7882,
			71028
		],
		[
			0,
			10
		]
	],
	[
		[
			7882,
			71038
		],
		[
			0,
			-10
		]
	],
	[
		[
			8177,
			71059
		],
		[
			-12,
			0
		]
	],
	[
		[
			8165,
			71059
		],
		[
			12,
			0
		]
	],
	[
		[
			8231,
			71069
		],
		[
			24,
			0
		]
	],
	[
		[
			8255,
			71069
		],
		[
			-24,
			-41
		],
		[
			-90,
			20
		]
	],
	[
		[
			8141,
			71048
		],
		[
			0,
			11
		]
	],
	[
		[
			8141,
			71059
		],
		[
			24,
			0
		]
	],
	[
		[
			8165,
			71059
		],
		[
			12,
			0
		]
	],
	[
		[
			8177,
			71059
		],
		[
			54,
			10
		]
	],
	[
		[
			8309,
			71121
		],
		[
			-6,
			0
		]
	],
	[
		[
			8303,
			71121
		],
		[
			6,
			0
		]
	],
	[
		[
			8387,
			71245
		],
		[
			-12,
			0
		]
	],
	[
		[
			8375,
			71245
		],
		[
			12,
			0
		]
	],
	[
		[
			8159,
			71224
		],
		[
			-12,
			0
		]
	],
	[
		[
			8147,
			71224
		],
		[
			0,
			21
		]
	],
	[
		[
			8147,
			71245
		],
		[
			12,
			-21
		]
	],
	[
		[
			8387,
			71245
		],
		[
			-12,
			0
		]
	],
	[
		[
			8375,
			71245
		],
		[
			12,
			0
		]
	],
	[
		[
			8207,
			71287
		],
		[
			-12,
			0
		]
	],
	[
		[
			8195,
			71287
		],
		[
			-12,
			0
		]
	],
	[
		[
			8183,
			71287
		],
		[
			-24,
			0
		]
	],
	[
		[
			8159,
			71287
		],
		[
			48,
			0
		]
	],
	[
		[
			8165,
			71349
		],
		[
			18,
			-11
		]
	],
	[
		[
			8183,
			71338
		],
		[
			-18,
			11
		]
	],
	[
		[
			7967,
			71349
		],
		[
			-6,
			0
		]
	],
	[
		[
			7961,
			71349
		],
		[
			6,
			0
		]
	],
	[
		[
			7997,
			71349
		],
		[
			0,
			10
		]
	],
	[
		[
			7997,
			71359
		],
		[
			0,
			-10
		]
	],
	[
		[
			8405,
			71432
		],
		[
			-6,
			0
		]
	],
	[
		[
			8399,
			71432
		],
		[
			6,
			0
		]
	],
	[
		[
			8418,
			71421
		],
		[
			-13,
			11
		]
	],
	[
		[
			8399,
			71432
		],
		[
			19,
			-11
		]
	],
	[
		[
			8189,
			71442
		],
		[
			-6,
			10
		]
	],
	[
		[
			8183,
			71452
		],
		[
			6,
			0
		]
	],
	[
		[
			8189,
			71452
		],
		[
			0,
			-10
		]
	],
	[
		[
			8177,
			71452
		],
		[
			-6,
			0
		]
	],
	[
		[
			8171,
			71452
		],
		[
			6,
			0
		]
	],
	[
		[
			8135,
			71442
		],
		[
			-6,
			0
		]
	],
	[
		[
			8129,
			71442
		],
		[
			6,
			0
		]
	],
	[
		[
			8412,
			71473
		],
		[
			6,
			10
		]
	],
	[
		[
			8418,
			71483
		],
		[
			-6,
			-10
		]
	],
	[
		[
			8213,
			71463
		],
		[
			0,
			10
		]
	],
	[
		[
			8213,
			71473
		],
		[
			0,
			-10
		]
	],
	[
		[
			8393,
			71494
		],
		[
			25,
			-11
		]
	],
	[
		[
			8418,
			71483
		],
		[
			-6,
			-10
		]
	],
	[
		[
			8412,
			71473
		],
		[
			-19,
			21
		]
	],
	[
		[
			8159,
			71494
		],
		[
			30,
			-42
		]
	],
	[
		[
			8189,
			71452
		],
		[
			-6,
			0
		]
	],
	[
		[
			8183,
			71452
		],
		[
			-6,
			0
		]
	],
	[
		[
			8171,
			71452
		],
		[
			-12,
			42
		]
	],
	[
		[
			8351,
			71701
		],
		[
			6,
			-10
		],
		[
			-6,
			10
		]
	],
	[
		[
			8357,
			71701
		],
		[
			-12,
			0
		],
		[
			-30,
			21
		]
	],
	[
		[
			8315,
			71722
		],
		[
			42,
			-21
		]
	],
	[
		[
			8357,
			71732
		],
		[
			0,
			10
		]
	],
	[
		[
			8357,
			71742
		],
		[
			0,
			-10
		]
	],
	[
		[
			7906,
			71722
		],
		[
			79,
			-31
		],
		[
			12,
			-63
		],
		[
			-73,
			0
		],
		[
			-18,
			94
		]
	],
	[
		[
			8556,
			71815
		],
		[
			0,
			10
		]
	],
	[
		[
			8556,
			71825
		],
		[
			0,
			-10
		]
	],
	[
		[
			8520,
			71856
		],
		[
			-6,
			0
		]
	],
	[
		[
			8514,
			71856
		],
		[
			6,
			11
		],
		[
			0,
			-11
		]
	],
	[
		[
			8303,
			71463
		],
		[
			-90,
			10
		]
	],
	[
		[
			8213,
			71473
		],
		[
			-54,
			21
		]
	],
	[
		[
			8159,
			71494
		],
		[
			-30,
			-52
		]
	],
	[
		[
			8129,
			71442
		],
		[
			6,
			0
		]
	],
	[
		[
			8135,
			71442
		],
		[
			60,
			-10
		],
		[
			18,
			-31
		]
	],
	[
		[
			8213,
			71401
		],
		[
			-24,
			-32
		],
		[
			-120,
			0
		]
	],
	[
		[
			8069,
			71369
		],
		[
			-48,
			11
		],
		[
			-24,
			-31
		]
	],
	[
		[
			7997,
			71349
		],
		[
			0,
			10
		]
	],
	[
		[
			7997,
			71359
		],
		[
			-30,
			-10
		]
	],
	[
		[
			7961,
			71349
		],
		[
			-24,
			-42
		],
		[
			120,
			-72
		],
		[
			30,
			21
		],
		[
			60,
			-32
		]
	],
	[
		[
			8147,
			71224
		],
		[
			12,
			0
		]
	],
	[
		[
			8159,
			71224
		],
		[
			-12,
			21
		]
	],
	[
		[
			8147,
			71245
		],
		[
			12,
			42
		]
	],
	[
		[
			8159,
			71287
		],
		[
			24,
			0
		]
	],
	[
		[
			8183,
			71287
		],
		[
			12,
			0
		]
	],
	[
		[
			8207,
			71287
		],
		[
			30,
			0
		],
		[
			72,
			-73
		]
	],
	[
		[
			8309,
			71214
		],
		[
			-6,
			-93
		]
	],
	[
		[
			8309,
			71121
		],
		[
			-18,
			-31
		],
		[
			-102,
			0
		],
		[
			-48,
			-31
		]
	],
	[
		[
			8141,
			71059
		],
		[
			0,
			-11
		]
	],
	[
		[
			8141,
			71048
		],
		[
			-66,
			-10
		]
	],
	[
		[
			8075,
			71038
		],
		[
			12,
			-10
		]
	],
	[
		[
			8087,
			71028
		],
		[
			12,
			-73
		]
	],
	[
		[
			8099,
			70955
		],
		[
			-78,
			31
		],
		[
			-97,
			52
		],
		[
			-42,
			0
		]
	],
	[
		[
			7882,
			71038
		],
		[
			-36,
			10
		],
		[
			-60,
			31
		],
		[
			24,
			-31
		]
	],
	[
		[
			7810,
			71048
		],
		[
			72,
			-20
		]
	],
	[
		[
			7882,
			71028
		],
		[
			24,
			-11
		]
	],
	[
		[
			7906,
			71017
		],
		[
			49,
			-83
		]
	],
	[
		[
			7955,
			70934
		],
		[
			-6,
			0
		]
	],
	[
		[
			7949,
			70934
		],
		[
			-61,
			21
		]
	],
	[
		[
			7888,
			70955
		],
		[
			-60,
			62
		],
		[
			-90,
			-10
		],
		[
			-84,
			-52
		],
		[
			-48,
			52
		]
	],
	[
		[
			7600,
			71007
		],
		[
			-48,
			31
		],
		[
			-36,
			104
		],
		[
			-42,
			-21
		],
		[
			-31,
			31
		],
		[
			-42,
			-21
		],
		[
			-132,
			42
		],
		[
			-48,
			-21
		],
		[
			-6,
			124
		],
		[
			-24,
			83
		],
		[
			-78,
			62
		],
		[
			36,
			42
		],
		[
			12,
			72
		],
		[
			-48,
			0
		],
		[
			12,
			73
		],
		[
			78,
			41
		],
		[
			78,
			-10
		],
		[
			54,
			62
		],
		[
			18,
			93
		],
		[
			90,
			42
		],
		[
			43,
			-11
		],
		[
			-6,
			-83
		],
		[
			54,
			11
		],
		[
			30,
			-42
		],
		[
			114,
			0
		],
		[
			36,
			31
		],
		[
			66,
			11
		],
		[
			18,
			-52
		],
		[
			78,
			-10
		],
		[
			55,
			-125
		],
		[
			78,
			11
		],
		[
			6,
			93
		],
		[
			66,
			-11
		],
		[
			30,
			-51
		],
		[
			66,
			0
		],
		[
			90,
			-62
		],
		[
			36,
			-83
		]
	],
	[
		[
			8574,
			71918
		],
		[
			60,
			-31
		],
		[
			-42,
			-51
		],
		[
			-18,
			82
		]
	],
	[
		[
			8424,
			71908
		],
		[
			84,
			0
		],
		[
			6,
			-52
		]
	],
	[
		[
			8520,
			71856
		],
		[
			42,
			-20
		],
		[
			-6,
			-11
		]
	],
	[
		[
			8556,
			71825
		],
		[
			0,
			-10
		]
	],
	[
		[
			8556,
			71815
		],
		[
			-12,
			-114
		],
		[
			-30,
			-10
		]
	],
	[
		[
			8514,
			71691
		],
		[
			-6,
			-42
		],
		[
			-48,
			-52
		],
		[
			-48,
			31
		],
		[
			-55,
			104
		]
	],
	[
		[
			8357,
			71732
		],
		[
			0,
			10
		]
	],
	[
		[
			8357,
			71742
		],
		[
			-66,
			42
		],
		[
			30,
			83
		],
		[
			121,
			-63
		],
		[
			-18,
			104
		]
	],
	[
		[
			8105,
			71908
		],
		[
			6,
			-10
		]
	],
	[
		[
			8111,
			71898
		],
		[
			-6,
			10
		]
	],
	[
		[
			8279,
			71918
		],
		[
			-12,
			11
		]
	],
	[
		[
			8267,
			71929
		],
		[
			12,
			-11
		]
	],
	[
		[
			8267,
			71929
		],
		[
			12,
			-11
		]
	],
	[
		[
			8213,
			71929
		],
		[
			-12,
			0
		]
	],
	[
		[
			8201,
			71929
		],
		[
			12,
			0
		]
	],
	[
		[
			8003,
			71918
		],
		[
			-6,
			0
		],
		[
			6,
			0
		]
	],
	[
		[
			7961,
			71939
		],
		[
			-6,
			-10
		],
		[
			0,
			10
		]
	],
	[
		[
			7955,
			71939
		],
		[
			6,
			0
		]
	],
	[
		[
			7924,
			71939
		],
		[
			13,
			0
		]
	],
	[
		[
			7937,
			71939
		],
		[
			-13,
			0
		]
	],
	[
		[
			8147,
			71908
		],
		[
			-42,
			0
		]
	],
	[
		[
			8105,
			71908
		],
		[
			-6,
			-21
		],
		[
			12,
			11
		]
	],
	[
		[
			8111,
			71898
		],
		[
			72,
			-11
		]
	],
	[
		[
			8183,
			71887
		],
		[
			54,
			-10
		],
		[
			-6,
			-62
		]
	],
	[
		[
			8231,
			71815
		],
		[
			6,
			-42
		],
		[
			78,
			-51
		]
	],
	[
		[
			8315,
			71722
		],
		[
			-18,
			-63
		],
		[
			-36,
			-20
		],
		[
			-90,
			52
		],
		[
			-12,
			51
		],
		[
			-78,
			-62
		],
		[
			-42,
			21
		],
		[
			-48,
			103
		],
		[
			-67,
			32
		],
		[
			-108,
			-32
		]
	],
	[
		[
			7816,
			71804
		],
		[
			18,
			52
		],
		[
			66,
			-10
		],
		[
			12,
			41
		],
		[
			55,
			21
		]
	],
	[
		[
			7967,
			71908
		],
		[
			60,
			-10
		]
	],
	[
		[
			8027,
			71898
		],
		[
			24,
			51
		],
		[
			96,
			-41
		]
	],
	[
		[
			7804,
			72012
		],
		[
			12,
			0
		]
	],
	[
		[
			7816,
			72012
		],
		[
			-12,
			0
		]
	],
	[
		[
			7918,
			72053
		],
		[
			6,
			-10
		]
	],
	[
		[
			7924,
			72043
		],
		[
			-6,
			10
		]
	],
	[
		[
			7534,
			72177
		],
		[
			-12,
			-10
		]
	],
	[
		[
			7522,
			72167
		],
		[
			12,
			10
		]
	],
	[
		[
			7534,
			72177
		],
		[
			-12,
			-10
		]
	],
	[
		[
			7522,
			72167
		],
		[
			12,
			10
		]
	],
	[
		[
			5988,
			72198
		],
		[
			31,
			-21
		],
		[
			-31,
			-93
		],
		[
			-30,
			0
		],
		[
			-18,
			-93
		],
		[
			-48,
			0
		],
		[
			-18,
			72
		],
		[
			24,
			73
		],
		[
			48,
			10
		],
		[
			42,
			52
		]
	],
	[
		[
			5525,
			72167
		],
		[
			-6,
			-10
		]
	],
	[
		[
			5519,
			72157
		],
		[
			0,
			10
		]
	],
	[
		[
			5519,
			72167
		],
		[
			6,
			0
		]
	],
	[
		[
			5519,
			72167
		],
		[
			19,
			21
		]
	],
	[
		[
			5538,
			72188
		],
		[
			12,
			0
		]
	],
	[
		[
			5550,
			72188
		],
		[
			-25,
			-21
		]
	],
	[
		[
			5550,
			72188
		],
		[
			-12,
			0
		]
	],
	[
		[
			5538,
			72188
		],
		[
			12,
			0
		]
	],
	[
		[
			5790,
			72126
		],
		[
			-36,
			10
		],
		[
			-78,
			-42
		],
		[
			-6,
			32
		],
		[
			60,
			72
		],
		[
			60,
			-72
		]
	],
	[
		[
			7834,
			72374
		],
		[
			-18,
			0
		]
	],
	[
		[
			7816,
			72374
		],
		[
			18,
			10
		]
	],
	[
		[
			7834,
			72384
		],
		[
			0,
			-10
		]
	],
	[
		[
			7780,
			72405
		],
		[
			6,
			0
		]
	],
	[
		[
			7786,
			72405
		],
		[
			-6,
			0
		]
	],
	[
		[
			7864,
			72415
		],
		[
			0,
			-10
		]
	],
	[
		[
			7864,
			72405
		],
		[
			0,
			10
		]
	],
	[
		[
			7780,
			72405
		],
		[
			-24,
			21
		]
	],
	[
		[
			7756,
			72426
		],
		[
			18,
			10
		]
	],
	[
		[
			7774,
			72436
		],
		[
			12,
			-31
		]
	],
	[
		[
			7961,
			72467
		],
		[
			-18,
			-10
		]
	],
	[
		[
			7943,
			72457
		],
		[
			18,
			10
		]
	],
	[
		[
			7053,
			72436
		],
		[
			24,
			31
		],
		[
			42,
			-103
		],
		[
			-66,
			0
		],
		[
			-85,
			83
		],
		[
			-18,
			51
		],
		[
			49,
			42
		],
		[
			54,
			-104
		]
	],
	[
		[
			8484,
			72809
		],
		[
			12,
			0
		]
	],
	[
		[
			8496,
			72809
		],
		[
			-12,
			0
		]
	],
	[
		[
			8664,
			73016
		],
		[
			-12,
			0
		]
	],
	[
		[
			8652,
			73016
		],
		[
			12,
			0
		]
	],
	[
		[
			8454,
			73037
		],
		[
			-55,
			-21
		],
		[
			55,
			21
		]
	],
	[
		[
			8508,
			73058
		],
		[
			6,
			-11
		]
	],
	[
		[
			8514,
			73047
		],
		[
			-6,
			11
		]
	],
	[
		[
			8472,
			73068
		],
		[
			-6,
			0
		],
		[
			6,
			0
		]
	],
	[
		[
			8586,
			73078
		],
		[
			-12,
			11
		]
	],
	[
		[
			8574,
			73089
		],
		[
			12,
			0
		]
	],
	[
		[
			8586,
			73089
		],
		[
			0,
			-11
		]
	],
	[
		[
			8628,
			73099
		],
		[
			-12,
			0
		]
	],
	[
		[
			8616,
			73099
		],
		[
			12,
			0
		]
	],
	[
		[
			8574,
			73089
		],
		[
			12,
			0
		]
	],
	[
		[
			6578,
			73192
		],
		[
			-6,
			11
		],
		[
			6,
			-11
		]
	],
	[
		[
			6614,
			73213
		],
		[
			-6,
			0
		]
	],
	[
		[
			6608,
			73213
		],
		[
			6,
			0
		]
	],
	[
		[
			8387,
			73379
		],
		[
			12,
			-31
		]
	],
	[
		[
			8399,
			73348
		],
		[
			-6,
			0
		]
	],
	[
		[
			8393,
			73348
		],
		[
			-6,
			0
		]
	],
	[
		[
			8387,
			73348
		],
		[
			-12,
			10
		]
	],
	[
		[
			8375,
			73358
		],
		[
			0,
			10
		]
	],
	[
		[
			8375,
			73368
		],
		[
			0,
			11
		]
	],
	[
		[
			8375,
			73379
		],
		[
			12,
			0
		]
	],
	[
		[
			8514,
			73399
		],
		[
			-6,
			0
		]
	],
	[
		[
			8508,
			73399
		],
		[
			-6,
			0
		]
	],
	[
		[
			8502,
			73399
		],
		[
			12,
			0
		]
	],
	[
		[
			8730,
			73430
		],
		[
			-42,
			-124
		],
		[
			-42,
			52
		],
		[
			84,
			72
		]
	],
	[
		[
			8670,
			73513
		],
		[
			-18,
			0
		]
	],
	[
		[
			8652,
			73513
		],
		[
			6,
			0
		]
	],
	[
		[
			8658,
			73513
		],
		[
			12,
			0
		]
	],
	[
		[
			8712,
			73493
		],
		[
			-42,
			20
		]
	],
	[
		[
			8670,
			73513
		],
		[
			42,
			-20
		]
	],
	[
		[
			8658,
			73513
		],
		[
			-6,
			0
		]
	],
	[
		[
			8652,
			73513
		],
		[
			6,
			0
		]
	],
	[
		[
			6740,
			73420
		],
		[
			-6,
			0
		]
	],
	[
		[
			6734,
			73420
		],
		[
			0,
			10
		]
	],
	[
		[
			6734,
			73430
		],
		[
			6,
			-10
		]
	],
	[
		[
			6975,
			73368
		],
		[
			78,
			31
		],
		[
			18,
			31
		],
		[
			72,
			21
		],
		[
			48,
			42
		],
		[
			54,
			-11
		],
		[
			0,
			-62
		],
		[
			-48,
			-31
		],
		[
			-36,
			10
		],
		[
			-78,
			-31
		],
		[
			-108,
			0
		]
	],
	[
		[
			8688,
			73596
		],
		[
			0,
			11
		]
	],
	[
		[
			8688,
			73607
		],
		[
			0,
			-11
		]
	],
	[
		[
			8688,
			73596
		],
		[
			0,
			11
		]
	],
	[
		[
			8580,
			73679
		],
		[
			6,
			-10
		]
	],
	[
		[
			8586,
			73669
		],
		[
			-6,
			10
		]
	],
	[
		[
			8586,
			73669
		],
		[
			-6,
			10
		]
	],
	[
		[
			9121,
			73917
		],
		[
			6,
			0
		]
	],
	[
		[
			9127,
			73917
		],
		[
			-6,
			0
		]
	],
	[
		[
			5339,
			73658
		],
		[
			12,
			-10
		]
	],
	[
		[
			5351,
			73648
		],
		[
			-12,
			10
		]
	],
	[
		[
			5363,
			73658
		],
		[
			-12,
			-10
		]
	],
	[
		[
			5351,
			73648
		],
		[
			-12,
			10
		]
	],
	[
		[
			5339,
			73658
		],
		[
			24,
			0
		]
	],
	[
		[
			5363,
			73669
		],
		[
			0,
			-11
		]
	],
	[
		[
			5363,
			73658
		],
		[
			0,
			11
		]
	],
	[
		[
			9121,
			73917
		],
		[
			6,
			0
		]
	],
	[
		[
			7816,
			73959
		],
		[
			78,
			-42
		],
		[
			-42,
			-62
		],
		[
			0,
			-83
		],
		[
			-54,
			21
		],
		[
			-54,
			104
		],
		[
			36,
			62
		],
		[
			36,
			0
		]
	],
	[
		[
			8550,
			73451
		],
		[
			-12,
			-21
		]
	],
	[
		[
			8538,
			73430
		],
		[
			-36,
			-31
		]
	],
	[
		[
			8502,
			73399
		],
		[
			6,
			0
		]
	],
	[
		[
			8514,
			73399
		],
		[
			6,
			-31
		],
		[
			-133,
			11
		]
	],
	[
		[
			8387,
			73379
		],
		[
			-12,
			0
		]
	],
	[
		[
			8375,
			73379
		],
		[
			-84,
			10
		],
		[
			84,
			-21
		]
	],
	[
		[
			8375,
			73368
		],
		[
			0,
			-10
		]
	],
	[
		[
			8375,
			73358
		],
		[
			12,
			-10
		]
	],
	[
		[
			8387,
			73348
		],
		[
			6,
			0
		]
	],
	[
		[
			8399,
			73348
		],
		[
			-6,
			-63
		],
		[
			121,
			11
		],
		[
			12,
			41
		],
		[
			60,
			0
		],
		[
			18,
			-41
		],
		[
			72,
			-11
		],
		[
			12,
			-51
		],
		[
			42,
			-11
		],
		[
			66,
			52
		]
	],
	[
		[
			8796,
			73275
		],
		[
			109,
			10
		],
		[
			42,
			-20
		],
		[
			102,
			0
		],
		[
			72,
			-42
		],
		[
			-36,
			-72
		],
		[
			-114,
			-114
		],
		[
			-36,
			-104
		],
		[
			-49,
			-10
		],
		[
			-96,
			62
		],
		[
			-60,
			93
		],
		[
			-102,
			21
		]
	],
	[
		[
			8628,
			73099
		],
		[
			-12,
			0
		]
	],
	[
		[
			8616,
			73099
		],
		[
			-84,
			73
		],
		[
			-30,
			62
		],
		[
			-84,
			31
		],
		[
			-67,
			-52
		]
	],
	[
		[
			8351,
			73213
		],
		[
			-114,
			10
		],
		[
			0,
			-62
		],
		[
			96,
			0
		],
		[
			66,
			-52
		]
	],
	[
		[
			8399,
			73109
		],
		[
			-24,
			-41
		],
		[
			12,
			-52
		],
		[
			0,
			-41
		],
		[
			79,
			10
		],
		[
			84,
			-10
		]
	],
	[
		[
			8550,
			72975
		],
		[
			48,
			-52
		],
		[
			-54,
			-124
		],
		[
			-48,
			10
		]
	],
	[
		[
			8484,
			72809
		],
		[
			12,
			-41
		],
		[
			78,
			-42
		]
	],
	[
		[
			8574,
			72726
		],
		[
			42,
			-10
		],
		[
			78,
			41
		],
		[
			78,
			-20
		],
		[
			90,
			51
		],
		[
			37,
			-41
		],
		[
			-55,
			-62
		],
		[
			-6,
			-104
		],
		[
			-42,
			-83
		],
		[
			-30,
			0
		],
		[
			-72,
			-62
		],
		[
			-156,
			-10
		],
		[
			-36,
			62
		],
		[
			-48,
			0
		],
		[
			-42,
			-41
		],
		[
			-73,
			0
		],
		[
			-48,
			-21
		],
		[
			-84,
			0
		],
		[
			-54,
			-31
		],
		[
			-174,
			10
		],
		[
			-36,
			52
		]
	],
	[
		[
			7943,
			72457
		],
		[
			18,
			10
		]
	],
	[
		[
			7961,
			72467
		],
		[
			60,
			-41
		],
		[
			18,
			52
		]
	],
	[
		[
			8039,
			72478
		],
		[
			-12,
			20
		]
	],
	[
		[
			8027,
			72498
		],
		[
			-18,
			-10
		]
	],
	[
		[
			8009,
			72488
		],
		[
			-48,
			21
		],
		[
			-97,
			-104
		]
	],
	[
		[
			7864,
			72405
		],
		[
			0,
			10
		]
	],
	[
		[
			7864,
			72415
		],
		[
			-90,
			21
		]
	],
	[
		[
			7774,
			72436
		],
		[
			-18,
			-10
		]
	],
	[
		[
			7756,
			72426
		],
		[
			0,
			-52
		],
		[
			78,
			0
		]
	],
	[
		[
			7834,
			72374
		],
		[
			0,
			10
		]
	],
	[
		[
			7834,
			72384
		],
		[
			78,
			0
		],
		[
			199,
			-20
		],
		[
			72,
			10
		],
		[
			204,
			0
		],
		[
			55,
			10
		],
		[
			36,
			-41
		],
		[
			48,
			31
		]
	],
	[
		[
			8526,
			72374
		],
		[
			60,
			41
		],
		[
			90,
			-10
		],
		[
			48,
			-166
		],
		[
			-102,
			-165
		],
		[
			6,
			-83
		],
		[
			-84,
			-21
		],
		[
			-96,
			0
		],
		[
			-49,
			21
		]
	],
	[
		[
			8399,
			71991
		],
		[
			-72,
			31
		],
		[
			-24,
			-52
		],
		[
			-102,
			-10
		],
		[
			-42,
			41
		],
		[
			-24,
			-31
		]
	],
	[
		[
			8135,
			71970
		],
		[
			-72,
			-21
		],
		[
			-102,
			42
		],
		[
			-43,
			62
		]
	],
	[
		[
			7918,
			72053
		],
		[
			37,
			-72
		],
		[
			12,
			-73
		]
	],
	[
		[
			7967,
			71908
		],
		[
			-6,
			31
		]
	],
	[
		[
			7955,
			71939
		],
		[
			-18,
			0
		]
	],
	[
		[
			7924,
			71939
		],
		[
			-30,
			73
		]
	],
	[
		[
			7894,
			72012
		],
		[
			-24,
			31
		],
		[
			-54,
			-31
		]
	],
	[
		[
			7816,
			72012
		],
		[
			-12,
			0
		]
	],
	[
		[
			7804,
			72012
		],
		[
			-18,
			-11
		],
		[
			-66,
			73
		]
	],
	[
		[
			7720,
			72074
		],
		[
			12,
			-104
		],
		[
			-54,
			0
		],
		[
			-84,
			31
		],
		[
			24,
			83
		]
	],
	[
		[
			7618,
			72084
		],
		[
			-12,
			135
		],
		[
			-72,
			20
		],
		[
			-42,
			42
		],
		[
			-43,
			-11
		],
		[
			49,
			-93
		],
		[
			-79,
			-41
		],
		[
			55,
			-114
		],
		[
			-43,
			-73
		],
		[
			-12,
			-82
		],
		[
			-66,
			41
		],
		[
			-24,
			135
		],
		[
			-24,
			51
		],
		[
			-72,
			73
		],
		[
			-6,
			62
		],
		[
			72,
			93
		],
		[
			12,
			-10
		],
		[
			60,
			31
		],
		[
			72,
			-73
		],
		[
			43,
			11
		],
		[
			-37,
			93
		],
		[
			-60,
			31
		],
		[
			-102,
			83
		],
		[
			-108,
			21
		],
		[
			-54,
			41
		],
		[
			-36,
			83
		],
		[
			-96,
			62
		],
		[
			12,
			-72
		],
		[
			-85,
			-73
		],
		[
			-72,
			-10
		],
		[
			-48,
			-42
		],
		[
			-102,
			52
		],
		[
			-42,
			62
		],
		[
			24,
			73
		],
		[
			-36,
			93
		],
		[
			-18,
			-93
		],
		[
			-30,
			-21
		],
		[
			-66,
			62
		],
		[
			-79,
			11
		],
		[
			-42,
			82
		],
		[
			-60,
			63
		],
		[
			36,
			51
		],
		[
			36,
			-83
		],
		[
			60,
			21
		],
		[
			-12,
			62
		]
	],
	[
		[
			6469,
			72933
		],
		[
			37,
			0
		],
		[
			0,
			83
		],
		[
			-55,
			31
		],
		[
			55,
			0
		],
		[
			24,
			42
		]
	],
	[
		[
			6530,
			73089
		],
		[
			30,
			-21
		],
		[
			54,
			62
		],
		[
			-36,
			62
		]
	],
	[
		[
			6578,
			73192
		],
		[
			36,
			21
		]
	],
	[
		[
			6608,
			73213
		],
		[
			6,
			0
		]
	],
	[
		[
			6614,
			73213
		],
		[
			0,
			10
		]
	],
	[
		[
			6614,
			73223
		],
		[
			6,
			11
		]
	],
	[
		[
			6620,
			73234
		],
		[
			24,
			83
		],
		[
			24,
			10
		]
	],
	[
		[
			6668,
			73327
		],
		[
			-6,
			52
		],
		[
			72,
			41
		]
	],
	[
		[
			6734,
			73420
		],
		[
			6,
			0
		]
	],
	[
		[
			6740,
			73420
		],
		[
			60,
			-31
		],
		[
			54,
			21
		],
		[
			199,
			-135
		],
		[
			60,
			-31
		],
		[
			12,
			-52
		],
		[
			54,
			0
		],
		[
			96,
			-41
		],
		[
			48,
			52
		],
		[
			-12,
			41
		],
		[
			36,
			62
		],
		[
			-24,
			73
		],
		[
			114,
			41
		],
		[
			109,
			93
		],
		[
			-18,
			62
		],
		[
			36,
			52
		],
		[
			66,
			21
		],
		[
			18,
			62
		],
		[
			48,
			-62
		],
		[
			-72,
			-41
		],
		[
			6,
			-83
		],
		[
			-72,
			-73
		],
		[
			6,
			-93
		],
		[
			108,
			10
		],
		[
			126,
			-41
		],
		[
			-6,
			-104
		],
		[
			48,
			-10
		],
		[
			-12,
			114
		],
		[
			54,
			10
		]
	],
	[
		[
			7882,
			73337
		],
		[
			42,
			-62
		],
		[
			49,
			21
		],
		[
			-12,
			62
		],
		[
			-79,
			62
		],
		[
			18,
			31
		],
		[
			61,
			0
		],
		[
			120,
			52
		],
		[
			30,
			83
		],
		[
			126,
			93
		],
		[
			42,
			-62
		],
		[
			24,
			93
		],
		[
			115,
			73
		],
		[
			-49,
			82
		],
		[
			-30,
			0
		],
		[
			-48,
			-62
		],
		[
			-126,
			11
		],
		[
			90,
			103
		],
		[
			36,
			62
		],
		[
			42,
			114
		],
		[
			109,
			31
		],
		[
			114,
			11
		],
		[
			90,
			-62
		],
		[
			-48,
			-73
		],
		[
			18,
			-52
		],
		[
			-96,
			21
		],
		[
			-36,
			-31
		],
		[
			-30,
			-135
		],
		[
			-79,
			-51
		],
		[
			12,
			-94
		],
		[
			73,
			-10
		],
		[
			42,
			-31
		],
		[
			60,
			-104
		],
		[
			-12,
			-62
		]
	],
	[
		[
			9861,
			74290
		],
		[
			30,
			-21
		]
	],
	[
		[
			9891,
			74269
		],
		[
			-43,
			21
		]
	],
	[
		[
			9848,
			74290
		],
		[
			13,
			0
		]
	],
	[
		[
			8971,
			74238
		],
		[
			36,
			-10
		],
		[
			36,
			-114
		],
		[
			-30,
			-21
		],
		[
			-78,
			62
		],
		[
			-12,
			42
		],
		[
			48,
			41
		]
	],
	[
		[
			9380,
			74311
		],
		[
			12,
			-11
		]
	],
	[
		[
			9392,
			74300
		],
		[
			-12,
			11
		]
	],
	[
		[
			9007,
			74477
		],
		[
			24,
			-83
		],
		[
			42,
			-62
		],
		[
			-48,
			-42
		],
		[
			-90,
			83
		],
		[
			60,
			62
		],
		[
			12,
			42
		]
	],
	[
		[
			9963,
			74539
		],
		[
			0,
			-11
		]
	],
	[
		[
			9963,
			74528
		],
		[
			0,
			11
		]
	],
	[
		[
			8165,
			74570
		],
		[
			78,
			0
		],
		[
			84,
			-114
		],
		[
			-54,
			-73
		],
		[
			-72,
			-41
		],
		[
			-108,
			-10
		],
		[
			-72,
			41
		],
		[
			-72,
			72
		],
		[
			60,
			94
		],
		[
			78,
			0
		],
		[
			12,
			31
		],
		[
			66,
			0
		]
	],
	[
		[
			8003,
			74684
		],
		[
			-6,
			10
		]
	],
	[
		[
			7997,
			74694
		],
		[
			6,
			-10
		]
	],
	[
		[
			8027,
			74746
		],
		[
			-24,
			-62
		]
	],
	[
		[
			8003,
			74684
		],
		[
			-6,
			10
		]
	],
	[
		[
			7997,
			74694
		],
		[
			30,
			52
		]
	],
	[
		[
			8772,
			75077
		],
		[
			-6,
			-10
		]
	],
	[
		[
			8766,
			75067
		],
		[
			-12,
			10
		]
	],
	[
		[
			8754,
			75077
		],
		[
			12,
			0
		]
	],
	[
		[
			8766,
			75077
		],
		[
			6,
			0
		]
	],
	[
		[
			8766,
			75077
		],
		[
			6,
			0
		]
	],
	[
		[
			11285,
			75243
		],
		[
			6,
			62
		],
		[
			-42,
			52
		],
		[
			-48,
			-73
		],
		[
			-18,
			83
		],
		[
			60,
			93
		],
		[
			18,
			-20
		],
		[
			139,
			-42
		],
		[
			54,
			11
		],
		[
			66,
			-73
		],
		[
			24,
			-93
		],
		[
			-150,
			-52
		],
		[
			-109,
			52
		]
	],
	[
		[
			451,
			74694
		],
		[
			48,
			-31
		]
	],
	[
		[
			499,
			74663
		],
		[
			-48,
			31
		]
	],
	[
		[
			451,
			74694
		],
		[
			-48,
			10
		],
		[
			12,
			11
		],
		[
			36,
			-21
		]
	],
	[
		[
			355,
			74932
		],
		[
			90,
			21
		]
	],
	[
		[
			445,
			74953
		],
		[
			0,
			-41
		],
		[
			78,
			-73
		]
	],
	[
		[
			523,
			74839
		],
		[
			-30,
			-41
		],
		[
			-54,
			20
		],
		[
			-36,
			-31
		],
		[
			-30,
			-72
		]
	],
	[
		[
			373,
			74715
		],
		[
			-42,
			62
		],
		[
			-54,
			-10
		],
		[
			-85,
			41
		],
		[
			-18,
			114
		],
		[
			79,
			-21
		],
		[
			24,
			62
		],
		[
			78,
			-31
		]
	],
	[
		[
			120,
			74974
		],
		[
			18,
			10
		],
		[
			-18,
			-10
		]
	],
	[
		[
			96,
			74953
		],
		[
			-54,
			-21
		],
		[
			-36,
			31
		],
		[
			12,
			42
		],
		[
			78,
			31
		],
		[
			0,
			-83
		]
	],
	[
		[
			9434,
			75854
		],
		[
			84,
			-21
		],
		[
			36,
			-155
		],
		[
			-60,
			-124
		],
		[
			-60,
			-63
		],
		[
			-48,
			0
		],
		[
			-19,
			42
		],
		[
			-96,
			31
		],
		[
			-36,
			52
		],
		[
			-42,
			-21
		],
		[
			0,
			-83
		],
		[
			-66,
			-52
		],
		[
			-60,
			0
		],
		[
			-48,
			31
		],
		[
			18,
			63
		],
		[
			-42,
			51
		],
		[
			210,
			21
		],
		[
			36,
			135
		],
		[
			60,
			20
		],
		[
			30,
			42
		],
		[
			73,
			0
		],
		[
			30,
			31
		]
	],
	[
		[
			9734,
			75978
		],
		[
			-6,
			0
		]
	],
	[
		[
			9728,
			75978
		],
		[
			6,
			0
		]
	],
	[
		[
			9686,
			76051
		],
		[
			48,
			-73
		]
	],
	[
		[
			9728,
			75978
		],
		[
			-24,
			0
		],
		[
			-30,
			0
		]
	],
	[
		[
			9674,
			75978
		],
		[
			12,
			73
		]
	],
	[
		[
			8730,
			76009
		],
		[
			-6,
			11
		],
		[
			6,
			-11
		]
	],
	[
		[
			878,
			75315
		],
		[
			-48,
			21
		],
		[
			36,
			83
		]
	],
	[
		[
			866,
			75419
		],
		[
			42,
			-52
		],
		[
			-30,
			-52
		]
	],
	[
		[
			9217,
			76206
		],
		[
			6,
			10
		],
		[
			-6,
			-10
		]
	],
	[
		[
			9217,
			76206
		],
		[
			-6,
			10
		],
		[
			6,
			-10
		]
	],
	[
		[
			12777,
			76569
		],
		[
			-85,
			10
		],
		[
			0,
			62
		],
		[
			139,
			10
		],
		[
			42,
			-72
		],
		[
			-96,
			-10
		]
	],
	[
		[
			12596,
			76745
		],
		[
			6,
			0
		]
	],
	[
		[
			12602,
			76745
		],
		[
			-18,
			10
		]
	],
	[
		[
			12584,
			76755
		],
		[
			12,
			-10
		]
	],
	[
		[
			11081,
			76662
		],
		[
			54,
			-93
		],
		[
			6,
			-42
		],
		[
			-54,
			-52
		],
		[
			-42,
			21
		],
		[
			-60,
			83
		],
		[
			18,
			72
		],
		[
			78,
			11
		]
	],
	[
		[
			12596,
			76745
		],
		[
			6,
			0
		]
	],
	[
		[
			8965,
			76631
		],
		[
			-6,
			-11
		]
	],
	[
		[
			8959,
			76620
		],
		[
			6,
			11
		]
	],
	[
		[
			8610,
			76693
		],
		[
			-12,
			-10
		]
	],
	[
		[
			8598,
			76683
		],
		[
			12,
			10
		]
	],
	[
		[
			8520,
			76838
		],
		[
			12,
			-10
		]
	],
	[
		[
			8532,
			76828
		],
		[
			-12,
			10
		]
	],
	[
		[
			8742,
			76952
		],
		[
			120,
			-83
		],
		[
			31,
			-93
		],
		[
			12,
			-125
		],
		[
			-79,
			-31
		],
		[
			-42,
			21
		],
		[
			-12,
			42
		],
		[
			-90,
			10
		],
		[
			-6,
			0
		],
		[
			-78,
			-10
		]
	],
	[
		[
			8610,
			76693
		],
		[
			-42,
			31
		]
	],
	[
		[
			8568,
			76724
		],
		[
			6,
			31
		],
		[
			-42,
			62
		],
		[
			0,
			11
		]
	],
	[
		[
			8532,
			76828
		],
		[
			-12,
			10
		]
	],
	[
		[
			8520,
			76838
		],
		[
			0,
			10
		],
		[
			-18,
			0
		]
	],
	[
		[
			8502,
			76848
		],
		[
			6,
			31
		],
		[
			102,
			52
		],
		[
			48,
			-10
		],
		[
			84,
			31
		]
	],
	[
		[
			13047,
			77501
		],
		[
			0,
			10
		]
	],
	[
		[
			13047,
			77511
		],
		[
			0,
			-10
		]
	],
	[
		[
			13071,
			77470
		],
		[
			-24,
			41
		]
	],
	[
		[
			13047,
			77511
		],
		[
			24,
			-41
		]
	],
	[
		[
			13035,
			77542
		],
		[
			-18,
			11
		],
		[
			6,
			10
		]
	],
	[
		[
			13023,
			77563
		],
		[
			12,
			-21
		]
	],
	[
		[
			8905,
			77304
		],
		[
			-6,
			0
		]
	],
	[
		[
			8899,
			77304
		],
		[
			6,
			0
		]
	],
	[
		[
			13023,
			77563
		],
		[
			-54,
			10
		]
	],
	[
		[
			12969,
			77573
		],
		[
			54,
			-10
		]
	],
	[
		[
			12789,
			77615
		],
		[
			-12,
			-42
		]
	],
	[
		[
			12777,
			77573
		],
		[
			-73,
			-41
		],
		[
			-6,
			72
		],
		[
			91,
			11
		]
	],
	[
		[
			8760,
			77408
		],
		[
			36,
			-32
		],
		[
			6,
			-93
		],
		[
			-12,
			0
		],
		[
			-54,
			0
		],
		[
			-36,
			42
		],
		[
			42,
			20
		],
		[
			18,
			63
		]
	],
	[
		[
			8730,
			77718
		],
		[
			6,
			0
		]
	],
	[
		[
			8736,
			77718
		],
		[
			-6,
			0
		]
	],
	[
		[
			8736,
			77729
		],
		[
			0,
			-11
		]
	],
	[
		[
			8730,
			77718
		],
		[
			6,
			11
		]
	],
	[
		[
			8736,
			77884
		],
		[
			-12,
			-21
		]
	],
	[
		[
			8724,
			77863
		],
		[
			6,
			21
		],
		[
			6,
			0
		]
	],
	[
		[
			8742,
			77905
		],
		[
			-6,
			-11
		]
	],
	[
		[
			8736,
			77894
		],
		[
			6,
			21
		]
	],
	[
		[
			8742,
			77915
		],
		[
			0,
			-10
		]
	],
	[
		[
			8754,
			77925
		],
		[
			-12,
			-10
		]
	],
	[
		[
			8742,
			77915
		],
		[
			12,
			10
		]
	],
	[
		[
			8820,
			77925
		],
		[
			-6,
			0
		],
		[
			6,
			0
		]
	],
	[
		[
			10161,
			78236
		],
		[
			6,
			-10
		]
	],
	[
		[
			10167,
			78226
		],
		[
			-12,
			10
		]
	],
	[
		[
			10155,
			78236
		],
		[
			6,
			0
		]
	],
	[
		[
			13041,
			78412
		],
		[
			-6,
			0
		]
	],
	[
		[
			13035,
			78412
		],
		[
			6,
			0
		]
	],
	[
		[
			14159,
			78505
		],
		[
			-6,
			0
		]
	],
	[
		[
			14153,
			78505
		],
		[
			6,
			0
		]
	],
	[
		[
			10161,
			78288
		],
		[
			-6,
			-52
		]
	],
	[
		[
			10155,
			78236
		],
		[
			6,
			52
		]
	],
	[
		[
			10287,
			78371
		],
		[
			0,
			-31
		]
	],
	[
		[
			10287,
			78340
		],
		[
			0,
			31
		]
	],
	[
		[
			9193,
			78381
		],
		[
			6,
			10
		]
	],
	[
		[
			9199,
			78391
		],
		[
			-6,
			-10
		]
	],
	[
		[
			9193,
			78381
		],
		[
			6,
			10
		]
	],
	[
		[
			9013,
			78371
		],
		[
			-12,
			10
		]
	],
	[
		[
			9001,
			78381
		],
		[
			12,
			-10
		]
	],
	[
		[
			10847,
			78423
		],
		[
			-79,
			62
		],
		[
			55,
			41
		],
		[
			24,
			-103
		]
	],
	[
		[
			10095,
			78661
		],
		[
			42,
			-73
		],
		[
			-48,
			-41
		],
		[
			6,
			114
		]
	],
	[
		[
			10702,
			78692
		],
		[
			-6,
			0
		]
	],
	[
		[
			10696,
			78692
		],
		[
			-30,
			52
		],
		[
			36,
			-52
		]
	],
	[
		[
			9951,
			78764
		],
		[
			12,
			0
		],
		[
			6,
			11
		],
		[
			6,
			0
		]
	],
	[
		[
			9975,
			78775
		],
		[
			-24,
			-11
		]
	],
	[
		[
			9981,
			78785
		],
		[
			-6,
			-10
		]
	],
	[
		[
			9975,
			78775
		],
		[
			0,
			10
		],
		[
			6,
			0
		]
	],
	[
		[
			9879,
			78795
		],
		[
			-6,
			-10
		]
	],
	[
		[
			9873,
			78785
		],
		[
			6,
			10
		]
	],
	[
		[
			14358,
			79075
		],
		[
			-6,
			0
		]
	],
	[
		[
			14352,
			79075
		],
		[
			6,
			0
		]
	],
	[
		[
			9873,
			78785
		],
		[
			-18,
			-41
		],
		[
			-85,
			82
		],
		[
			66,
			42
		]
	],
	[
		[
			9836,
			78868
		],
		[
			37,
			-83
		]
	],
	[
		[
			10414,
			78837
		],
		[
			48,
			-21
		],
		[
			60,
			-62
		],
		[
			6,
			83
		],
		[
			102,
			-93
		],
		[
			24,
			-73
		]
	],
	[
		[
			10654,
			78671
		],
		[
			42,
			21
		]
	],
	[
		[
			10702,
			78692
		],
		[
			42,
			-62
		],
		[
			-48,
			-145
		],
		[
			-60,
			51
		],
		[
			-66,
			21
		],
		[
			-96,
			-31
		]
	],
	[
		[
			10474,
			78526
		],
		[
			-78,
			0
		],
		[
			-73,
			21
		],
		[
			-72,
			0
		],
		[
			-42,
			83
		],
		[
			90,
			41
		],
		[
			-42,
			166
		],
		[
			-6,
			10
		],
		[
			30,
			-114
		],
		[
			-72,
			11
		],
		[
			-24,
			62
		]
	],
	[
		[
			10185,
			78806
		],
		[
			30,
			-11
		],
		[
			-30,
			73
		],
		[
			-48,
			-11
		],
		[
			-24,
			187
		],
		[
			54,
			-31
		],
		[
			54,
			21
		],
		[
			54,
			-21
		],
		[
			85,
			0
		],
		[
			36,
			-62
		],
		[
			18,
			-114
		]
	],
	[
		[
			10558,
			79116
		],
		[
			-6,
			0
		]
	],
	[
		[
			10552,
			79116
		],
		[
			6,
			0
		]
	],
	[
		[
			10299,
			79096
		],
		[
			-6,
			0
		]
	],
	[
		[
			10293,
			79096
		],
		[
			6,
			10
		]
	],
	[
		[
			10299,
			79106
		],
		[
			0,
			-10
		]
	],
	[
		[
			10023,
			79096
		],
		[
			-6,
			0
		]
	],
	[
		[
			10017,
			79096
		],
		[
			6,
			0
		]
	],
	[
		[
			10275,
			79116
		],
		[
			0,
			-10
		]
	],
	[
		[
			10275,
			79106
		],
		[
			0,
			10
		]
	],
	[
		[
			10281,
			79106
		],
		[
			-6,
			0
		]
	],
	[
		[
			10275,
			79116
		],
		[
			6,
			-10
		]
	],
	[
		[
			10017,
			79096
		],
		[
			-24,
			31
		]
	],
	[
		[
			9993,
			79127
		],
		[
			24,
			-31
		]
	],
	[
		[
			10281,
			79106
		],
		[
			12,
			-10
		]
	],
	[
		[
			10299,
			79096
		],
		[
			-6,
			-42
		],
		[
			-114,
			-10
		],
		[
			-42,
			62
		],
		[
			0,
			31
		]
	],
	[
		[
			10137,
			79137
		],
		[
			66,
			0
		],
		[
			42,
			-41
		],
		[
			36,
			10
		]
	],
	[
		[
			10191,
			79158
		],
		[
			-6,
			0
		],
		[
			6,
			0
		]
	],
	[
		[
			10203,
			79179
		],
		[
			6,
			0
		]
	],
	[
		[
			10209,
			79179
		],
		[
			-6,
			0
		]
	],
	[
		[
			10215,
			79179
		],
		[
			-12,
			0
		]
	],
	[
		[
			10209,
			79179
		],
		[
			6,
			0
		]
	],
	[
		[
			10600,
			79344
		],
		[
			0,
			-10
		]
	],
	[
		[
			10600,
			79334
		],
		[
			0,
			10
		]
	],
	[
		[
			6097,
			79158
		],
		[
			-24,
			0
		]
	],
	[
		[
			6073,
			79158
		],
		[
			24,
			10
		]
	],
	[
		[
			6097,
			79168
		],
		[
			0,
			-10
		]
	],
	[
		[
			6073,
			79168
		],
		[
			0,
			-10
		]
	],
	[
		[
			6073,
			79158
		],
		[
			0,
			10
		]
	],
	[
		[
			6073,
			79168
		],
		[
			24,
			0
		]
	],
	[
		[
			6097,
			79168
		],
		[
			-24,
			-10
		]
	],
	[
		[
			5724,
			79261
		],
		[
			0,
			11
		]
	],
	[
		[
			5724,
			79272
		],
		[
			6,
			0
		]
	],
	[
		[
			5730,
			79272
		],
		[
			-6,
			-11
		]
	],
	[
		[
			5724,
			79261
		],
		[
			0,
			11
		]
	],
	[
		[
			5748,
			79261
		],
		[
			-18,
			11
		]
	],
	[
		[
			5730,
			79272
		],
		[
			18,
			-11
		]
	],
	[
		[
			6091,
			79292
		],
		[
			-48,
			21
		]
	],
	[
		[
			6043,
			79313
		],
		[
			48,
			-21
		]
	],
	[
		[
			11087,
			79686
		],
		[
			-12,
			0
		]
	],
	[
		[
			11075,
			79686
		],
		[
			12,
			0
		]
	],
	[
		[
			11171,
			79748
		],
		[
			-6,
			0
		]
	],
	[
		[
			11165,
			79748
		],
		[
			6,
			11
		]
	],
	[
		[
			11171,
			79759
		],
		[
			0,
			-11
		]
	],
	[
		[
			11454,
			79893
		],
		[
			0,
			-10
		],
		[
			0,
			10
		]
	],
	[
		[
			11436,
			79893
		],
		[
			-6,
			0
		]
	],
	[
		[
			11430,
			79893
		],
		[
			6,
			0
		]
	],
	[
		[
			11406,
			79893
		],
		[
			-6,
			0
		]
	],
	[
		[
			11400,
			79893
		],
		[
			6,
			11
		]
	],
	[
		[
			11406,
			79904
		],
		[
			0,
			-11
		]
	],
	[
		[
			11418,
			79893
		],
		[
			-6,
			0
		]
	],
	[
		[
			11412,
			79893
		],
		[
			-6,
			11
		]
	],
	[
		[
			11406,
			79904
		],
		[
			12,
			-11
		]
	],
	[
		[
			11857,
			79986
		],
		[
			-6,
			0
		]
	],
	[
		[
			11851,
			79986
		],
		[
			-6,
			0
		],
		[
			12,
			0
		]
	],
	[
		[
			11887,
			80007
		],
		[
			-6,
			-10
		]
	],
	[
		[
			11881,
			79997
		],
		[
			6,
			10
		]
	],
	[
		[
			14141,
			80359
		],
		[
			12,
			11
		]
	],
	[
		[
			14153,
			80370
		],
		[
			-12,
			-11
		]
	],
	[
		[
			12320,
			80339
		],
		[
			-6,
			0
		]
	],
	[
		[
			12314,
			80339
		],
		[
			6,
			0
		]
	],
	[
		[
			13396,
			81095
		],
		[
			-6,
			0
		]
	],
	[
		[
			13390,
			81095
		],
		[
			6,
			0
		]
	],
	[
		[
			13925,
			81343
		],
		[
			-12,
			0
		]
	],
	[
		[
			13913,
			81343
		],
		[
			12,
			0
		]
	],
	[
		[
			13654,
			81354
		],
		[
			6,
			-11
		]
	],
	[
		[
			13660,
			81343
		],
		[
			-6,
			0
		],
		[
			0,
			11
		]
	],
	[
		[
			13630,
			81395
		],
		[
			-12,
			0
		]
	],
	[
		[
			13618,
			81395
		],
		[
			6,
			10
		],
		[
			6,
			-10
		]
	],
	[
		[
			13763,
			81457
		],
		[
			-6,
			0
		]
	],
	[
		[
			13763,
			81457
		],
		[
			72,
			-62
		],
		[
			0,
			-10
		]
	],
	[
		[
			13835,
			81385
		],
		[
			24,
			-21
		]
	],
	[
		[
			13859,
			81364
		],
		[
			30,
			-21
		],
		[
			12,
			0
		],
		[
			12,
			0
		]
	],
	[
		[
			13913,
			81343
		],
		[
			12,
			0
		]
	],
	[
		[
			13925,
			81343
		],
		[
			18,
			-31
		]
	],
	[
		[
			13943,
			81312
		],
		[
			18,
			-21
		],
		[
			0,
			-10
		],
		[
			18,
			-21
		],
		[
			-12,
			-20
		]
	],
	[
		[
			13967,
			81240
		],
		[
			24,
			-73
		]
	],
	[
		[
			13991,
			81167
		],
		[
			72,
			-21
		],
		[
			18,
			-31
		],
		[
			6,
			0
		],
		[
			24,
			-31
		],
		[
			12,
			-10
		],
		[
			18,
			0
		],
		[
			0,
			-21
		],
		[
			6,
			0
		],
		[
			6,
			0
		],
		[
			12,
			-41
		],
		[
			-24,
			-125
		],
		[
			18,
			-124
		],
		[
			31,
			0
		],
		[
			24,
			-83
		],
		[
			42,
			-20
		],
		[
			30,
			-83
		],
		[
			0,
			-11
		],
		[
			0,
			-41
		],
		[
			-60,
			-21
		],
		[
			-61,
			-62
		],
		[
			-12,
			-72
		]
	],
	[
		[
			14153,
			80370
		],
		[
			-12,
			-11
		]
	],
	[
		[
			14141,
			80359
		],
		[
			-78,
			-145
		],
		[
			-6,
			-72
		],
		[
			-42,
			-73
		],
		[
			18,
			-62
		],
		[
			66,
			-72
		],
		[
			103,
			-73
		],
		[
			42,
			-52
		],
		[
			-115,
			-10
		],
		[
			-72,
			-104
		],
		[
			-78,
			-103
		],
		[
			-60,
			-11
		],
		[
			-48,
			-72
		]
	],
	[
		[
			13871,
			79510
		],
		[
			18,
			-93
		],
		[
			-30,
			-42
		],
		[
			-78,
			-10
		],
		[
			-6,
			0
		],
		[
			-115,
			0
		],
		[
			-30,
			-31
		],
		[
			0,
			-207
		],
		[
			-132,
			-21
		],
		[
			-66,
			31
		],
		[
			-66,
			-72
		],
		[
			12,
			-176
		],
		[
			-48,
			-52
		],
		[
			-72,
			-21
		],
		[
			-73,
			0
		],
		[
			-24,
			-124
		],
		[
			54,
			-21
		],
		[
			133,
			31
		],
		[
			78,
			-72
		],
		[
			54,
			-11
		],
		[
			18,
			-41
		],
		[
			72,
			-31
		],
		[
			48,
			0
		],
		[
			127,
			62
		],
		[
			36,
			62
		],
		[
			72,
			31
		],
		[
			48,
			-10
		],
		[
			96,
			83
		],
		[
			6,
			62
		],
		[
			66,
			20
		],
		[
			12,
			73
		],
		[
			72,
			10
		],
		[
			73,
			42
		],
		[
			36,
			-11
		],
		[
			48,
			42
		],
		[
			-12,
			52
		]
	],
	[
		[
			14298,
			79065
		],
		[
			60,
			10
		]
	],
	[
		[
			14352,
			79075
		],
		[
			18,
			-31
		],
		[
			102,
			-21
		],
		[
			-36,
			-72
		],
		[
			-42,
			10
		],
		[
			-24,
			-41
		],
		[
			18,
			-63
		],
		[
			-36,
			-51
		],
		[
			-18,
			-31
		],
		[
			-24,
			-42
		]
	],
	[
		[
			14310,
			78733
		],
		[
			36,
			-31
		]
	],
	[
		[
			14346,
			78702
		],
		[
			0,
			-41
		],
		[
			-114,
			-135
		],
		[
			-24,
			-10
		],
		[
			-37,
			-11
		],
		[
			-6,
			0
		],
		[
			-6,
			0
		]
	],
	[
		[
			14153,
			78505
		],
		[
			-24,
			-31
		],
		[
			-6,
			0
		],
		[
			-30,
			11
		],
		[
			-54,
			-52
		],
		[
			-12,
			-62
		],
		[
			-90,
			-62
		],
		[
			-120,
			-11
		],
		[
			-66,
			73
		],
		[
			-61,
			0
		],
		[
			-30,
			93
		],
		[
			-78,
			72
		],
		[
			-108,
			-10
		],
		[
			-72,
			-31
		],
		[
			-66,
			-83
		],
		[
			-30,
			11
		],
		[
			-60,
			-52
		],
		[
			-115,
			134
		],
		[
			-66,
			0
		],
		[
			-66,
			42
		],
		[
			-12,
			-73
		],
		[
			-12,
			0
		],
		[
			60,
			-62
		]
	],
	[
		[
			13035,
			78412
		],
		[
			30,
			-41
		],
		[
			54,
			10
		],
		[
			-6,
			0
		],
		[
			-54,
			-41
		],
		[
			12,
			-73
		],
		[
			60,
			-155
		],
		[
			6,
			-73
		],
		[
			-90,
			-83
		],
		[
			90,
			-31
		],
		[
			-18,
			-93
		],
		[
			-6,
			0
		],
		[
			-48,
			-10
		]
	],
	[
		[
			13065,
			77822
		],
		[
			-60,
			0
		],
		[
			-78,
			41
		],
		[
			-6,
			-31
		],
		[
			-78,
			-21
		],
		[
			-84,
			32
		],
		[
			-79,
			0
		],
		[
			-78,
			20
		],
		[
			-24,
			-20
		]
	],
	[
		[
			12578,
			77843
		],
		[
			72,
			-42
		],
		[
			12,
			31
		],
		[
			85,
			-52
		],
		[
			6,
			0
		],
		[
			-31,
			-51
		],
		[
			-90,
			-94
		],
		[
			-42,
			-62
		],
		[
			-102,
			0
		],
		[
			-48,
			-41
		],
		[
			-90,
			21
		],
		[
			-66,
			-42
		],
		[
			-24,
			21
		]
	],
	[
		[
			12260,
			77532
		],
		[
			-49,
			-11
		],
		[
			-66,
			-51
		],
		[
			-114,
			0
		],
		[
			-186,
			-42
		],
		[
			-133,
			-10
		],
		[
			-102,
			-31
		],
		[
			30,
			-42
		],
		[
			78,
			52
		],
		[
			115,
			21
		]
	],
	[
		[
			11833,
			77418
		],
		[
			96,
			10
		],
		[
			66,
			-62
		],
		[
			30,
			62
		],
		[
			156,
			-10
		]
	],
	[
		[
			12181,
			77418
		],
		[
			85,
			10
		],
		[
			42,
			52
		],
		[
			108,
			-10
		],
		[
			108,
			31
		],
		[
			168,
			-11
		],
		[
			49,
			42
		]
	],
	[
		[
			12741,
			77532
		],
		[
			36,
			41
		]
	],
	[
		[
			12777,
			77573
		],
		[
			66,
			21
		],
		[
			48,
			41
		],
		[
			42,
			-20
		],
		[
			24,
			31
		],
		[
			12,
			-73
		]
	],
	[
		[
			12969,
			77573
		],
		[
			66,
			-114
		],
		[
			-84,
			11
		],
		[
			12,
			-83
		],
		[
			108,
			83
		]
	],
	[
		[
			13071,
			77470
		],
		[
			0,
			-52
		],
		[
			-12,
			-83
		],
		[
			54,
			0
		],
		[
			-12,
			-104
		],
		[
			36,
			-20
		],
		[
			6,
			-62
		],
		[
			-36,
			-31
		],
		[
			-24,
			-73
		],
		[
			-132,
			-10
		],
		[
			-144,
			20
		],
		[
			6,
			-31
		],
		[
			72,
			0
		],
		[
			42,
			-41
		],
		[
			168,
			10
		],
		[
			96,
			-31
		],
		[
			-6,
			-83
		],
		[
			-72,
			-114
		],
		[
			-54,
			-41
		],
		[
			-12,
			-41
		],
		[
			-30,
			-73
		],
		[
			-60,
			-10
		],
		[
			-60,
			93
		],
		[
			-66,
			21
		],
		[
			-30,
			-31
		],
		[
			-54,
			62
		],
		[
			-85,
			-94
		],
		[
			-48,
			94
		],
		[
			-30,
			10
		]
	],
	[
		[
			12584,
			76755
		],
		[
			-42,
			-72
		],
		[
			-132,
			20
		],
		[
			-30,
			-52
		],
		[
			-96,
			21
		],
		[
			-67,
			42
		],
		[
			-12,
			-73
		],
		[
			18,
			-41
		],
		[
			103,
			-21
		],
		[
			36,
			31
		],
		[
			150,
			0
		],
		[
			120,
			-72
		],
		[
			0,
			-73
		],
		[
			30,
			-72
		],
		[
			-12,
			-83
		],
		[
			18,
			-42
		],
		[
			-102,
			-52
		],
		[
			-6,
			-165
		],
		[
			-24,
			-42
		],
		[
			-180,
			0
		],
		[
			-48,
			-72
		],
		[
			-48,
			-31
		],
		[
			-49,
			62
		],
		[
			-6,
			52
		],
		[
			-54,
			10
		],
		[
			-42,
			114
		],
		[
			-12,
			-93
		],
		[
			42,
			-104
		],
		[
			18,
			-93
		],
		[
			-18,
			-31
		],
		[
			-120,
			-10
		],
		[
			-96,
			-52
		],
		[
			-54,
			41
		],
		[
			-54,
			104
		],
		[
			-36,
			41
		],
		[
			-43,
			93
		],
		[
			-84,
			104
		],
		[
			-42,
			-31
		],
		[
			42,
			-83
		],
		[
			24,
			-83
		],
		[
			48,
			-52
		],
		[
			6,
			-93
		]
	],
	[
		[
			11730,
			75802
		],
		[
			-72,
			11
		],
		[
			-24,
			62
		],
		[
			-42,
			-21
		],
		[
			-66,
			31
		],
		[
			-36,
			-62
		],
		[
			-126,
			166
		],
		[
			-91,
			165
		],
		[
			-12,
			62
		],
		[
			-60,
			11
		],
		[
			-42,
			124
		],
		[
			-12,
			83
		],
		[
			42,
			114
		],
		[
			-54,
			124
		],
		[
			24,
			83
		],
		[
			108,
			104
		],
		[
			18,
			62
		],
		[
			43,
			31
		],
		[
			30,
			-21
		],
		[
			54,
			52
		],
		[
			-6,
			83
		],
		[
			48,
			52
		],
		[
			162,
			-11
		],
		[
			54,
			-72
		],
		[
			42,
			72
		],
		[
			-126,
			31
		],
		[
			-301,
			0
		],
		[
			97,
			-31
		],
		[
			6,
			-72
		],
		[
			-48,
			-52
		],
		[
			-67,
			-31
		],
		[
			-84,
			-114
		],
		[
			-126,
			-124
		],
		[
			-144,
			-63
		],
		[
			0,
			-113
		],
		[
			66,
			-11
		],
		[
			84,
			-197
		],
		[
			24,
			-93
		],
		[
			-54,
			-83
		],
		[
			72,
			-20
		],
		[
			60,
			31
		],
		[
			30,
			-83
		],
		[
			72,
			-73
		],
		[
			61,
			-114
		],
		[
			36,
			-31
		],
		[
			-60,
			-62
		],
		[
			-91,
			31
		],
		[
			-18,
			-62
		],
		[
			115,
			-62
		],
		[
			66,
			-52
		],
		[
			-12,
			-52
		],
		[
			48,
			-62
		],
		[
			-18,
			-72
		],
		[
			-90,
			10
		],
		[
			-85,
			-10
		],
		[
			-42,
			31
		],
		[
			-42,
			-11
		],
		[
			-30,
			32
		],
		[
			-78,
			-11
		],
		[
			-24,
			31
		],
		[
			-48,
			-20
		],
		[
			-54,
			31
		],
		[
			-42,
			51
		],
		[
			-30,
			-10
		],
		[
			-61,
			52
		],
		[
			-66,
			-31
		],
		[
			-30,
			10
		],
		[
			-6,
			-103
		],
		[
			-84,
			-32
		],
		[
			-12,
			-51
		],
		[
			42,
			-94
		],
		[
			42,
			-10
		],
		[
			66,
			42
		],
		[
			91,
			-63
		],
		[
			42,
			-113
		],
		[
			48,
			-94
		],
		[
			48,
			21
		],
		[
			42,
			-93
		],
		[
			6,
			-73
		],
		[
			-72,
			-31
		],
		[
			-18,
			62
		],
		[
			-54,
			-82
		],
		[
			-49,
			41
		],
		[
			-162,
			52
		],
		[
			54,
			-73
		],
		[
			12,
			-93
		],
		[
			-12,
			-83
		],
		[
			-90,
			73
		],
		[
			-48,
			-31
		],
		[
			-60,
			31
		],
		[
			-126,
			176
		],
		[
			-18,
			-52
		],
		[
			72,
			-83
		],
		[
			-30,
			-21
		],
		[
			-18,
			-93
		],
		[
			-48,
			83
		],
		[
			-49,
			0
		],
		[
			-12,
			-83
		],
		[
			12,
			-103
		]
	],
	[
		[
			10287,
			74653
		],
		[
			-102,
			-21
		],
		[
			-24,
			-52
		],
		[
			42,
			-52
		],
		[
			18,
			-62
		],
		[
			-48,
			-10
		],
		[
			-96,
			10
		],
		[
			-30,
			62
		],
		[
			-84,
			11
		]
	],
	[
		[
			9963,
			74539
		],
		[
			0,
			-11
		]
	],
	[
		[
			9963,
			74528
		],
		[
			66,
			-103
		],
		[
			-18,
			-83
		],
		[
			-126,
			-10
		],
		[
			-24,
			-42
		]
	],
	[
		[
			9861,
			74290
		],
		[
			-13,
			0
		]
	],
	[
		[
			9848,
			74290
		],
		[
			-36,
			-124
		],
		[
			-120,
			-42
		],
		[
			-60,
			-82
		],
		[
			-54,
			124
		],
		[
			-60,
			41
		],
		[
			-78,
			93
		],
		[
			-48,
			0
		]
	],
	[
		[
			9380,
			74311
		],
		[
			36,
			21
		],
		[
			-85,
			82
		],
		[
			-30,
			0
		],
		[
			-234,
			208
		],
		[
			-18,
			103
		],
		[
			-48,
			52
		],
		[
			-133,
			41
		],
		[
			-78,
			52
		],
		[
			-48,
			73
		],
		[
			18,
			62
		],
		[
			-6,
			72
		]
	],
	[
		[
			8754,
			75077
		],
		[
			12,
			-10
		]
	],
	[
		[
			8772,
			75077
		],
		[
			108,
			21
		],
		[
			49,
			-41
		],
		[
			72,
			-32
		],
		[
			24,
			-41
		],
		[
			0,
			-145
		],
		[
			78,
			83
		],
		[
			72,
			21
		],
		[
			96,
			93
		],
		[
			78,
			0
		],
		[
			121,
			134
		],
		[
			18,
			94
		],
		[
			42,
			20
		],
		[
			-18,
			62
		],
		[
			60,
			21
		],
		[
			36,
			-52
		],
		[
			126,
			52
		],
		[
			48,
			-31
		],
		[
			73,
			52
		],
		[
			42,
			-42
		],
		[
			48,
			-10
		],
		[
			42,
			52
		],
		[
			-54,
			41
		],
		[
			-60,
			11
		],
		[
			-79,
			62
		],
		[
			-36,
			0
		],
		[
			-54,
			52
		],
		[
			72,
			62
		],
		[
			-6,
			72
		],
		[
			85,
			0
		],
		[
			102,
			73
		],
		[
			102,
			-42
		],
		[
			96,
			0
		],
		[
			48,
			-62
		],
		[
			78,
			21
		],
		[
			61,
			-31
		],
		[
			12,
			52
		],
		[
			48,
			41
		],
		[
			-73,
			52
		],
		[
			-54,
			62
		],
		[
			18,
			52
		],
		[
			61,
			-21
		],
		[
			30,
			41
		],
		[
			-30,
			52
		],
		[
			-49,
			-52
		],
		[
			-66,
			42
		],
		[
			-42,
			-31
		],
		[
			-54,
			41
		],
		[
			-144,
			11
		],
		[
			-90,
			93
		],
		[
			-42,
			-11
		],
		[
			-79,
			63
		],
		[
			-12,
			-21
		],
		[
			-102,
			10
		],
		[
			-54,
			52
		],
		[
			-36,
			0
		],
		[
			-66,
			41
		],
		[
			-18,
			52
		],
		[
			-36,
			-20
		],
		[
			36,
			-42
		],
		[
			-30,
			-62
		],
		[
			-60,
			41
		],
		[
			-36,
			-41
		],
		[
			-73,
			21
		],
		[
			-84,
			51
		],
		[
			-54,
			21
		],
		[
			-12,
			83
		],
		[
			-36,
			-41
		],
		[
			-90,
			10
		],
		[
			-18,
			83
		],
		[
			18,
			41
		],
		[
			-36,
			52
		],
		[
			0,
			62
		],
		[
			-60,
			21
		],
		[
			-36,
			-83
		],
		[
			-43,
			0
		],
		[
			-24,
			41
		],
		[
			48,
			73
		],
		[
			61,
			0
		],
		[
			24,
			41
		]
	],
	[
		[
			8965,
			76631
		],
		[
			-12,
			72
		],
		[
			60,
			83
		],
		[
			66,
			-21
		],
		[
			66,
			-93
		],
		[
			42,
			11
		],
		[
			-6,
			72
		],
		[
			48,
			83
		],
		[
			90,
			52
		],
		[
			109,
			31
		],
		[
			120,
			72
		],
		[
			126,
			-10
		],
		[
			-18,
			62
		],
		[
			-66,
			0
		],
		[
			-168,
			-72
		],
		[
			-30,
			10
		],
		[
			-49,
			-42
		],
		[
			-84,
			-31
		],
		[
			-54,
			11
		],
		[
			-30,
			62
		],
		[
			-48,
			0
		],
		[
			0,
			52
		],
		[
			48,
			0
		],
		[
			42,
			41
		],
		[
			126,
			10
		],
		[
			-18,
			42
		],
		[
			-174,
			-31
		],
		[
			6,
			72
		],
		[
			102,
			42
		],
		[
			60,
			41
		],
		[
			0,
			104
		],
		[
			-48,
			-62
		],
		[
			-144,
			-52
		],
		[
			0,
			-73
		],
		[
			-36,
			-10
		],
		[
			-90,
			72
		],
		[
			-54,
			21
		],
		[
			-42,
			0
		],
		[
			-6,
			52
		]
	],
	[
		[
			8905,
			77304
		],
		[
			-19,
			93
		],
		[
			7,
			83
		],
		[
			-49,
			83
		],
		[
			6,
			72
		],
		[
			-24,
			31
		]
	],
	[
		[
			8826,
			77666
		],
		[
			-6,
			0
		],
		[
			-48,
			11
		],
		[
			-36,
			52
		]
	],
	[
		[
			8736,
			77729
		],
		[
			-30,
			10
		],
		[
			18,
			124
		]
	],
	[
		[
			8724,
			77863
		],
		[
			12,
			21
		]
	],
	[
		[
			8736,
			77884
		],
		[
			0,
			10
		]
	],
	[
		[
			8736,
			77894
		],
		[
			6,
			11
		]
	],
	[
		[
			8742,
			77905
		],
		[
			36,
			-21
		],
		[
			30,
			31
		],
		[
			12,
			10
		]
	],
	[
		[
			8820,
			77925
		],
		[
			54,
			94
		]
	],
	[
		[
			8874,
			78019
		],
		[
			91,
			134
		],
		[
			-30,
			11
		],
		[
			-67,
			124
		],
		[
			49,
			72
		],
		[
			42,
			0
		],
		[
			6,
			0
		]
	],
	[
		[
			8965,
			78360
		],
		[
			36,
			21
		]
	],
	[
		[
			9013,
			78371
		],
		[
			18,
			-42
		],
		[
			66,
			0
		],
		[
			54,
			-31
		],
		[
			48,
			31
		],
		[
			24,
			-83
		],
		[
			78,
			104
		],
		[
			73,
			0
		],
		[
			-7,
			41
		],
		[
			-72,
			83
		],
		[
			-18,
			-83
		],
		[
			-168,
			42
		]
	],
	[
		[
			9109,
			78433
		],
		[
			24,
			83
		],
		[
			30,
			51
		],
		[
			42,
			156
		],
		[
			0,
			62
		],
		[
			54,
			0
		],
		[
			0,
			62
		],
		[
			66,
			52
		],
		[
			61,
			-93
		],
		[
			132,
			-11
		],
		[
			6,
			-51
		],
		[
			42,
			-21
		],
		[
			60,
			-62
		],
		[
			60,
			20
		],
		[
			-6,
			52
		],
		[
			30,
			83
		],
		[
			42,
			-21
		],
		[
			24,
			-93
		],
		[
			48,
			-10
		],
		[
			18,
			-42
		],
		[
			55,
			-20
		],
		[
			84,
			0
		],
		[
			30,
			-52
		]
	],
	[
		[
			10011,
			78578
		],
		[
			-6,
			-62
		],
		[
			-163,
			-11
		],
		[
			-42,
			-41
		]
	],
	[
		[
			9800,
			78464
		],
		[
			79,
			-83
		],
		[
			72,
			-31
		],
		[
			72,
			-10
		],
		[
			66,
			31
		],
		[
			48,
			-114
		],
		[
			6,
			-52
		],
		[
			-24,
			-124
		],
		[
			6,
			-73
		],
		[
			60,
			-124
		],
		[
			6,
			-83
		],
		[
			54,
			-62
		],
		[
			-6,
			114
		],
		[
			-72,
			145
		],
		[
			-24,
			176
		],
		[
			24,
			52
		]
	],
	[
		[
			10167,
			78226
		],
		[
			30,
			52
		],
		[
			-12,
			82
		],
		[
			96,
			-62
		],
		[
			6,
			42
		]
	],
	[
		[
			10287,
			78340
		],
		[
			0,
			31
		]
	],
	[
		[
			10287,
			78371
		],
		[
			18,
			52
		],
		[
			55,
			62
		],
		[
			42,
			-31
		],
		[
			30,
			31
		],
		[
			-12,
			0
		],
		[
			-12,
			20
		]
	],
	[
		[
			10408,
			78505
		],
		[
			66,
			21
		]
	],
	[
		[
			10474,
			78526
		],
		[
			48,
			-41
		],
		[
			162,
			-21
		],
		[
			66,
			-83
		],
		[
			42,
			31
		],
		[
			49,
			-41
		],
		[
			48,
			20
		],
		[
			48,
			-20
		],
		[
			72,
			-125
		],
		[
			42,
			-10
		]
	],
	[
		[
			11051,
			78236
		],
		[
			48,
			31
		],
		[
			0,
			83
		],
		[
			-36,
			52
		],
		[
			-66,
			-11
		],
		[
			-126,
			114
		],
		[
			18,
			62
		],
		[
			48,
			52
		],
		[
			-78,
			42
		],
		[
			-42,
			124
		],
		[
			-25,
			31
		],
		[
			-54,
			0
		],
		[
			-54,
			31
		],
		[
			-24,
			52
		],
		[
			-48,
			72
		],
		[
			-24,
			94
		],
		[
			-36,
			31
		],
		[
			6,
			20
		]
	],
	[
		[
			10552,
			79116
		],
		[
			66,
			42
		],
		[
			-12,
			72
		],
		[
			-84,
			-10
		],
		[
			6,
			83
		]
	],
	[
		[
			10528,
			79303
		],
		[
			36,
			21
		],
		[
			36,
			10
		]
	],
	[
		[
			10600,
			79334
		],
		[
			18,
			41
		],
		[
			36,
			114
		],
		[
			66,
			0
		],
		[
			6,
			11
		],
		[
			6,
			0
		],
		[
			48,
			10
		],
		[
			127,
			-21
		],
		[
			24,
			62
		],
		[
			48,
			0
		],
		[
			42,
			52
		],
		[
			36,
			42
		],
		[
			0,
			10
		]
	],
	[
		[
			11057,
			79655
		],
		[
			18,
			31
		]
	],
	[
		[
			11075,
			79686
		],
		[
			18,
			0
		],
		[
			6,
			0
		],
		[
			6,
			0
		],
		[
			30,
			10
		],
		[
			12,
			31
		],
		[
			18,
			11
		]
	],
	[
		[
			11165,
			79738
		],
		[
			0,
			10
		]
	],
	[
		[
			11171,
			79748
		],
		[
			0,
			11
		]
	],
	[
		[
			11171,
			79759
		],
		[
			54,
			10
		],
		[
			24,
			-52
		],
		[
			49,
			10
		],
		[
			6,
			52
		],
		[
			6,
			11
		],
		[
			42,
			10
		],
		[
			0,
			10
		],
		[
			12,
			0
		],
		[
			12,
			42
		],
		[
			6,
			0
		],
		[
			-6,
			10
		],
		[
			18,
			31
		],
		[
			6,
			0
		]
	],
	[
		[
			11406,
			79893
		],
		[
			6,
			0
		]
	],
	[
		[
			11418,
			79893
		],
		[
			12,
			0
		]
	],
	[
		[
			11430,
			79893
		],
		[
			6,
			0
		]
	],
	[
		[
			11436,
			79893
		],
		[
			18,
			0
		]
	],
	[
		[
			11454,
			79893
		],
		[
			6,
			11
		],
		[
			72,
			0
		],
		[
			0,
			-63
		],
		[
			36,
			-20
		],
		[
			24,
			51
		],
		[
			78,
			-20
		],
		[
			78,
			41
		],
		[
			49,
			52
		],
		[
			12,
			10
		],
		[
			6,
			11
		],
		[
			24,
			10
		],
		[
			6,
			0
		],
		[
			6,
			10
		]
	],
	[
		[
			11851,
			79986
		],
		[
			30,
			11
		]
	],
	[
		[
			11881,
			79997
		],
		[
			6,
			10
		]
	],
	[
		[
			11887,
			80007
		],
		[
			156,
			31
		],
		[
			42,
			-10
		],
		[
			30,
			31
		],
		[
			66,
			145
		],
		[
			79,
			135
		],
		[
			54,
			0
		]
	],
	[
		[
			12314,
			80339
		],
		[
			72,
			10
		],
		[
			96,
			103
		],
		[
			210,
			145
		],
		[
			6,
			42
		],
		[
			67,
			62
		]
	],
	[
		[
			12765,
			80701
		],
		[
			228,
			124
		],
		[
			42,
			11
		],
		[
			66,
			51
		],
		[
			108,
			42
		],
		[
			55,
			52
		]
	],
	[
		[
			13264,
			80981
		],
		[
			54,
			103
		]
	],
	[
		[
			13318,
			81084
		],
		[
			18,
			21
		],
		[
			54,
			-10
		]
	],
	[
		[
			13396,
			81095
		],
		[
			78,
			20
		]
	],
	[
		[
			13474,
			81115
		],
		[
			48,
			11
		],
		[
			66,
			72
		],
		[
			90,
			73
		],
		[
			-18,
			72
		]
	],
	[
		[
			13660,
			81343
		],
		[
			18,
			21
		],
		[
			-60,
			21
		],
		[
			0,
			10
		]
	],
	[
		[
			13630,
			81395
		],
		[
			0,
			10
		]
	],
	[
		[
			13630,
			81405
		],
		[
			6,
			11
		],
		[
			6,
			0
		],
		[
			18,
			0
		],
		[
			6,
			0
		],
		[
			37,
			31
		],
		[
			54,
			10
		]
	],
	[
		[
			13757,
			81457
		],
		[
			6,
			0
		]
	],
	[
		[
			14346,
			86926
		],
		[
			0,
			-11
		]
	],
	[
		[
			14346,
			86915
		],
		[
			-6,
			11
		],
		[
			6,
			0
		]
	],
	[
		[
			14346,
			86926
		],
		[
			0,
			-11
		]
	],
	[
		[
			16264,
			87278
		],
		[
			36,
			-31
		],
		[
			-12,
			-114
		],
		[
			-78,
			0
		],
		[
			12,
			62
		],
		[
			54,
			0
		],
		[
			-12,
			83
		]
	],
	[
		[
			29600,
			57781
		],
		[
			24,
			-83
		],
		[
			-97,
			-10
		],
		[
			-12,
			-52
		],
		[
			-54,
			21
		],
		[
			-18,
			-31
		],
		[
			-222,
			41
		],
		[
			0,
			42
		],
		[
			-108,
			20
		],
		[
			-55,
			-31
		],
		[
			-30,
			-62
		],
		[
			-102,
			-41
		],
		[
			6,
			-83
		],
		[
			-78,
			-42
		],
		[
			-54,
			-51
		],
		[
			-12,
			-52
		],
		[
			-48,
			21
		],
		[
			-54,
			-63
		],
		[
			6,
			-82
		],
		[
			-97,
			-63
		],
		[
			-42,
			0
		],
		[
			-36,
			-41
		],
		[
			-72,
			10
		]
	],
	[
		[
			28445,
			57149
		],
		[
			-78,
			11
		],
		[
			-78,
			-62
		]
	],
	[
		[
			28289,
			57098
		],
		[
			-42,
			-42
		],
		[
			-102,
			-155
		],
		[
			-73,
			-42
		]
	],
	[
		[
			28072,
			56859
		],
		[
			-18,
			-31
		],
		[
			-84,
			-10
		],
		[
			-24,
			-21
		],
		[
			-114,
			-10
		]
	],
	[
		[
			27832,
			56787
		],
		[
			18,
			72
		],
		[
			-84,
			31
		],
		[
			-54,
			52
		],
		[
			-127,
			73
		],
		[
			-66,
			20
		],
		[
			-132,
			187
		],
		[
			60,
			62
		],
		[
			114,
			41
		],
		[
			6,
			83
		],
		[
			-186,
			-10
		],
		[
			-66,
			-21
		],
		[
			-84,
			52
		],
		[
			-66,
			-21
		],
		[
			-25,
			62
		],
		[
			-48,
			21
		],
		[
			42,
			83
		],
		[
			-48,
			41
		],
		[
			-78,
			21
		],
		[
			-120,
			-41
		],
		[
			-24,
			41
		],
		[
			72,
			42
		],
		[
			-66,
			155
		],
		[
			-42,
			-21
		],
		[
			-48,
			21
		],
		[
			-84,
			-21
		],
		[
			-18,
			42
		],
		[
			-49,
			0
		],
		[
			55,
			114
		],
		[
			6,
			51
		]
	],
	[
		[
			26690,
			58019
		],
		[
			120,
			73
		],
		[
			24,
			31
		],
		[
			96,
			10
		],
		[
			30,
			83
		],
		[
			192,
			21
		],
		[
			85,
			-21
		],
		[
			60,
			11
		],
		[
			102,
			-42
		],
		[
			24,
			31
		],
		[
			102,
			-10
		],
		[
			84,
			31
		],
		[
			211,
			0
		],
		[
			72,
			114
		],
		[
			72,
			0
		],
		[
			-6,
			52
		],
		[
			-42,
			41
		],
		[
			-90,
			52
		],
		[
			-30,
			83
		],
		[
			48,
			103
		]
	],
	[
		[
			27844,
			58682
		],
		[
			120,
			62
		],
		[
			48,
			-103
		],
		[
			72,
			-73
		],
		[
			49,
			-72
		],
		[
			60,
			-52
		],
		[
			132,
			-62
		],
		[
			54,
			-176
		],
		[
			-6,
			-145
		],
		[
			66,
			-52
		],
		[
			42,
			-10
		],
		[
			60,
			31
		],
		[
			12,
			52
		],
		[
			42,
			31
		],
		[
			43,
			-11
		],
		[
			54,
			-176
		],
		[
			6,
			-62
		],
		[
			66,
			31
		],
		[
			168,
			0
		],
		[
			108,
			21
		],
		[
			18,
			31
		],
		[
			73,
			10
		],
		[
			162,
			-52
		],
		[
			30,
			-41
		],
		[
			132,
			-21
		],
		[
			145,
			-62
		]
	],
	[
		[
			35179,
			59459
		],
		[
			-78,
			83
		]
	],
	[
		[
			35101,
			59542
		],
		[
			78,
			-42
		],
		[
			0,
			-41
		]
	],
	[
		[
			35101,
			59542
		],
		[
			-12,
			21
		]
	],
	[
		[
			35089,
			59563
		],
		[
			12,
			-21
		]
	],
	[
		[
			34103,
			59739
		],
		[
			-180,
			-52
		],
		[
			-121,
			-73
		],
		[
			-30,
			0
		],
		[
			-102,
			-103
		],
		[
			-30,
			31
		],
		[
			-60,
			10
		],
		[
			-66,
			-52
		],
		[
			-84,
			42
		],
		[
			-91,
			-21
		],
		[
			6,
			62
		],
		[
			-66,
			62
		],
		[
			-102,
			73
		],
		[
			-162,
			41
		],
		[
			-103,
			0
		],
		[
			-126,
			-31
		],
		[
			-168,
			-134
		],
		[
			-24,
			-62
		],
		[
			-108,
			-94
		],
		[
			-18,
			-41
		],
		[
			-79,
			-42
		],
		[
			-60,
			-10
		],
		[
			-126,
			-103
		],
		[
			-18,
			-52
		],
		[
			-42,
			-31
		],
		[
			-48,
			-83
		],
		[
			-66,
			0
		],
		[
			-54,
			-62
		],
		[
			-73,
			-52
		],
		[
			-84,
			-83
		],
		[
			-48,
			10
		],
		[
			-78,
			-62
		],
		[
			-42,
			-134
		],
		[
			12,
			-145
		],
		[
			-30,
			-83
		],
		[
			-60,
			-62
		],
		[
			6,
			-52
		],
		[
			-115,
			0
		],
		[
			-66,
			21
		],
		[
			-102,
			-21
		],
		[
			-12,
			-52
		],
		[
			-60,
			-31
		],
		[
			-96,
			62
		],
		[
			-193,
			-41
		],
		[
			-54,
			-31
		],
		[
			-96,
			-83
		],
		[
			-18,
			-62
		],
		[
			-150,
			20
		],
		[
			-36,
			-83
		],
		[
			-60,
			-41
		],
		[
			-103,
			31
		],
		[
			-84,
			-62
		],
		[
			6,
			-114
		],
		[
			-84,
			-21
		],
		[
			-42,
			62
		],
		[
			-205,
			73
		],
		[
			-60,
			-31
		],
		[
			-54,
			103
		],
		[
			-24,
			-10
		],
		[
			-78,
			42
		],
		[
			-132,
			10
		],
		[
			-48,
			52
		],
		[
			-175,
			-11
		],
		[
			-66,
			42
		],
		[
			-18,
			52
		],
		[
			-96,
			82
		],
		[
			-66,
			0
		],
		[
			0,
			-72
		],
		[
			-30,
			-42
		],
		[
			-97,
			0
		],
		[
			-54,
			94
		],
		[
			-60,
			-21
		],
		[
			-60,
			10
		],
		[
			-78,
			-20
		],
		[
			-60,
			-52
		],
		[
			-126,
			0
		],
		[
			-139,
			83
		],
		[
			-174,
			196
		]
	],
	[
		[
			28950,
			59014
		],
		[
			96,
			10
		],
		[
			85,
			31
		],
		[
			54,
			0
		],
		[
			30,
			124
		],
		[
			60,
			63
		],
		[
			60,
			20
		],
		[
			30,
			-20
		],
		[
			60,
			10
		],
		[
			36,
			-114
		],
		[
			60,
			21
		],
		[
			24,
			-21
		],
		[
			151,
			31
		],
		[
			102,
			-21
		],
		[
			72,
			21
		],
		[
			48,
			-31
		],
		[
			48,
			10
		],
		[
			103,
			-20
		],
		[
			108,
			-63
		],
		[
			84,
			32
		],
		[
			120,
			10
		],
		[
			66,
			41
		],
		[
			12,
			83
		],
		[
			-24,
			73
		],
		[
			133,
			62
		],
		[
			36,
			31
		],
		[
			126,
			-31
		],
		[
			24,
			-42
		],
		[
			48,
			31
		],
		[
			66,
			11
		],
		[
			-24,
			72
		],
		[
			-48,
			62
		],
		[
			277,
			104
		],
		[
			-54,
			62
		],
		[
			-31,
			114
		],
		[
			0,
			83
		],
		[
			-90,
			21
		],
		[
			12,
			93
		],
		[
			-96,
			10
		],
		[
			-54,
			31
		],
		[
			-36,
			-20
		],
		[
			-132,
			10
		],
		[
			-79,
			21
		],
		[
			-6,
			72
		],
		[
			25,
			73
		]
	],
	[
		[
			30532,
			60174
		],
		[
			-85,
			31
		],
		[
			-84,
			83
		],
		[
			84,
			62
		],
		[
			66,
			31
		],
		[
			43,
			72
		],
		[
			54,
			0
		],
		[
			30,
			31
		],
		[
			60,
			-62
		],
		[
			84,
			42
		],
		[
			96,
			20
		],
		[
			0,
			94
		],
		[
			-24,
			72
		],
		[
			6,
			73
		],
		[
			42,
			62
		],
		[
			84,
			51
		],
		[
			49,
			11
		],
		[
			-6,
			103
		],
		[
			36,
			0
		],
		[
			36,
			63
		],
		[
			-36,
			31
		],
		[
			-66,
			-11
		],
		[
			-25,
			31
		]
	],
	[
		[
			30976,
			61064
		],
		[
			121,
			0
		],
		[
			132,
			31
		],
		[
			24,
			21
		],
		[
			174,
			73
		],
		[
			73,
			51
		],
		[
			120,
			52
		],
		[
			114,
			73
		],
		[
			78,
			20
		],
		[
			90,
			63
		],
		[
			127,
			20
		],
		[
			90,
			62
		],
		[
			90,
			21
		],
		[
			120,
			83
		],
		[
			18,
			41
		],
		[
			157,
			21
		],
		[
			66,
			31
		],
		[
			48,
			-10
		],
		[
			150,
			103
		],
		[
			30,
			0
		],
		[
			90,
			52
		],
		[
			55,
			93
		],
		[
			96,
			52
		],
		[
			84,
			11
		],
		[
			138,
			-11
		],
		[
			102,
			-103
		],
		[
			79,
			-21
		],
		[
			54,
			31
		],
		[
			186,
			21
		],
		[
			30,
			-42
		],
		[
			-12,
			-186
		],
		[
			-24,
			-62
		],
		[
			-12,
			-187
		],
		[
			-42,
			-52
		],
		[
			-48,
			-103
		],
		[
			-150,
			-83
		],
		[
			-37,
			31
		],
		[
			-48,
			-41
		],
		[
			-84,
			10
		],
		[
			-30,
			-62
		],
		[
			108,
			-21
		],
		[
			30,
			42
		],
		[
			36,
			-52
		],
		[
			91,
			-52
		],
		[
			72,
			10
		],
		[
			54,
			125
		],
		[
			42,
			-52
		],
		[
			48,
			-155
		],
		[
			78,
			-21
		],
		[
			42,
			-31
		],
		[
			24,
			-62
		],
		[
			133,
			-11
		],
		[
			144,
			-52
		],
		[
			60,
			-10
		],
		[
			30,
			21
		],
		[
			108,
			-31
		],
		[
			43,
			20
		],
		[
			60,
			-62
		],
		[
			114,
			-20
		],
		[
			12,
			-52
		],
		[
			156,
			-187
		],
		[
			102,
			-62
		],
		[
			79,
			11
		],
		[
			24,
			-52
		],
		[
			54,
			-21
		],
		[
			-54,
			-103
		],
		[
			-73,
			-63
		],
		[
			-60,
			0
		],
		[
			-54,
			-41
		],
		[
			-78,
			-104
		],
		[
			-120,
			-93
		],
		[
			-60,
			-21
		],
		[
			-84,
			-103
		],
		[
			-91,
			-10
		],
		[
			-30,
			-63
		],
		[
			-72,
			-10
		],
		[
			-90,
			-41
		]
	],
	[
		[
			15608,
			63985
		],
		[
			-6,
			-10
		]
	],
	[
		[
			15602,
			63975
		],
		[
			6,
			10
		]
	],
	[
		[
			15633,
			64057
		],
		[
			-6,
			-10
		]
	],
	[
		[
			15627,
			64047
		],
		[
			6,
			10
		]
	],
	[
		[
			15939,
			64078
		],
		[
			54,
			-93
		],
		[
			-36,
			-52
		],
		[
			-60,
			-41
		],
		[
			-36,
			31
		],
		[
			6,
			83
		],
		[
			72,
			72
		]
	],
	[
		[
			15602,
			63975
		],
		[
			6,
			10
		]
	],
	[
		[
			15608,
			63985
		],
		[
			19,
			62
		]
	],
	[
		[
			15633,
			64057
		],
		[
			66,
			-41
		],
		[
			90,
			-31
		],
		[
			6,
			-31
		],
		[
			-120,
			0
		],
		[
			-73,
			21
		]
	],
	[
		[
			15897,
			64120
		],
		[
			-6,
			10
		]
	],
	[
		[
			15891,
			64130
		],
		[
			12,
			0
		]
	],
	[
		[
			15903,
			64130
		],
		[
			-6,
			-10
		]
	],
	[
		[
			15578,
			64234
		],
		[
			12,
			0
		]
	],
	[
		[
			15590,
			64234
		],
		[
			-12,
			0
		]
	],
	[
		[
			15993,
			65207
		],
		[
			6,
			0
		]
	],
	[
		[
			15999,
			65207
		],
		[
			-6,
			0
		]
	],
	[
		[
			15915,
			65217
		],
		[
			-6,
			0
		]
	],
	[
		[
			15909,
			65217
		],
		[
			6,
			0
		]
	],
	[
		[
			15993,
			65207
		],
		[
			-78,
			10
		]
	],
	[
		[
			15909,
			65217
		],
		[
			12,
			52
		],
		[
			66,
			104
		],
		[
			78,
			-21
		],
		[
			24,
			21
		],
		[
			73,
			-52
		],
		[
			54,
			-62
		],
		[
			42,
			41
		],
		[
			90,
			-72
		],
		[
			-90,
			-21
		],
		[
			-18,
			42
		],
		[
			-54,
			-73
		],
		[
			-109,
			-10
		],
		[
			-78,
			41
		]
	],
	[
		[
			13739,
			65725
		],
		[
			42,
			-52
		],
		[
			60,
			31
		],
		[
			114,
			11
		],
		[
			42,
			-21
		],
		[
			18,
			-52
		],
		[
			-66,
			-93
		],
		[
			-78,
			-10
		],
		[
			-66,
			72
		],
		[
			-36,
			-62
		],
		[
			-85,
			21
		],
		[
			55,
			155
		]
	],
	[
		[
			15753,
			66377
		],
		[
			0,
			11
		]
	],
	[
		[
			15753,
			66388
		],
		[
			0,
			-11
		]
	],
	[
		[
			15753,
			66388
		],
		[
			0,
			-11
		]
	],
	[
		[
			15753,
			66377
		],
		[
			0,
			11
		]
	],
	[
		[
			14598,
			66502
		],
		[
			0,
			-176
		],
		[
			-36,
			-218
		],
		[
			-48,
			10
		],
		[
			-12,
			-103
		],
		[
			-54,
			-52
		],
		[
			-24,
			21
		],
		[
			-114,
			-11
		],
		[
			-60,
			21
		],
		[
			-42,
			42
		],
		[
			-55,
			10
		],
		[
			-90,
			114
		],
		[
			-12,
			114
		],
		[
			42,
			62
		],
		[
			139,
			52
		],
		[
			90,
			-21
		],
		[
			36,
			41
		],
		[
			-24,
			83
		],
		[
			24,
			104
		],
		[
			30,
			31
		],
		[
			78,
			31
		],
		[
			114,
			-93
		],
		[
			18,
			-62
		]
	],
	[
		[
			11340,
			66895
		],
		[
			6,
			-10
		]
	],
	[
		[
			11346,
			66885
		],
		[
			-6,
			10
		]
	],
	[
		[
			11340,
			66895
		],
		[
			6,
			11
		]
	],
	[
		[
			11346,
			66906
		],
		[
			0,
			-21
		]
	],
	[
		[
			13354,
			67745
		],
		[
			12,
			-32
		],
		[
			90,
			-20
		],
		[
			60,
			-62
		],
		[
			42,
			10
		],
		[
			48,
			-83
		],
		[
			90,
			0
		],
		[
			61,
			-31
		],
		[
			60,
			-104
		],
		[
			12,
			-51
		],
		[
			-72,
			-31
		],
		[
			-115,
			-21
		],
		[
			18,
			-42
		],
		[
			97,
			0
		],
		[
			102,
			-20
		],
		[
			18,
			-21
		],
		[
			-24,
			-93
		],
		[
			-36,
			-31
		],
		[
			-24,
			-228
		],
		[
			-48,
			-73
		],
		[
			-91,
			-72
		],
		[
			-66,
			-21
		],
		[
			-30,
			-93
		],
		[
			-84,
			-52
		],
		[
			-114,
			0
		],
		[
			-30,
			62
		],
		[
			-60,
			62
		],
		[
			-145,
			32
		],
		[
			6,
			51
		],
		[
			-24,
			83
		],
		[
			-48,
			83
		],
		[
			-54,
			-10
		],
		[
			-48,
			31
		],
		[
			-132,
			134
		],
		[
			-91,
			31
		],
		[
			-72,
			52
		],
		[
			-54,
			83
		],
		[
			72,
			0
		],
		[
			48,
			42
		],
		[
			13,
			51
		],
		[
			60,
			52
		],
		[
			90,
			42
		],
		[
			72,
			124
		],
		[
			102,
			52
		],
		[
			54,
			51
		],
		[
			48,
			0
		],
		[
			67,
			-31
		],
		[
			24,
			52
		],
		[
			96,
			42
		]
	],
	[
		[
			12440,
			67631
		],
		[
			-150,
			-21
		],
		[
			30,
			83
		]
	],
	[
		[
			12320,
			67693
		],
		[
			42,
			-31
		],
		[
			24,
			41
		],
		[
			114,
			-72
		],
		[
			48,
			20
		],
		[
			24,
			-51
		],
		[
			-90,
			-11
		],
		[
			-42,
			42
		]
	],
	[
		[
			12350,
			67703
		],
		[
			-18,
			0
		],
		[
			-12,
			-10
		]
	],
	[
		[
			12320,
			67693
		],
		[
			-48,
			20
		],
		[
			-127,
			-10
		],
		[
			-60,
			21
		],
		[
			-120,
			-124
		],
		[
			-120,
			-21
		],
		[
			-66,
			10
		],
		[
			-43,
			73
		],
		[
			43,
			62
		],
		[
			162,
			31
		],
		[
			162,
			72
		],
		[
			78,
			0
		],
		[
			24,
			-20
		],
		[
			55,
			31
		],
		[
			72,
			10
		],
		[
			42,
			-31
		],
		[
			78,
			-10
		],
		[
			-12,
			-94
		],
		[
			-42,
			32
		],
		[
			-48,
			-42
		]
	],
	[
		[
			14069,
			68739
		],
		[
			42,
			-21
		],
		[
			66,
			10
		],
		[
			43,
			-72
		],
		[
			-18,
			-52
		],
		[
			-49,
			-31
		],
		[
			-60,
			0
		],
		[
			-36,
			31
		],
		[
			-24,
			-62
		],
		[
			54,
			-62
		],
		[
			-90,
			-83
		],
		[
			-72,
			0
		],
		[
			-126,
			124
		],
		[
			-18,
			62
		],
		[
			60,
			21
		],
		[
			90,
			62
		],
		[
			48,
			-20
		],
		[
			48,
			93
		],
		[
			42,
			0
		]
	],
	[
		[
			16089,
			69837
		],
		[
			49,
			-73
		],
		[
			-55,
			-52
		],
		[
			-48,
			0
		],
		[
			-24,
			83
		],
		[
			78,
			42
		]
	],
	[
		[
			15254,
			70241
		],
		[
			60,
			-21
		],
		[
			48,
			10
		],
		[
			54,
			-41
		],
		[
			72,
			10
		],
		[
			66,
			-21
		],
		[
			85,
			-72
		],
		[
			48,
			-21
		],
		[
			36,
			-93
		],
		[
			-90,
			-197
		],
		[
			-55,
			-31
		],
		[
			-192,
			0
		],
		[
			-36,
			10
		],
		[
			-72,
			104
		],
		[
			-54,
			31
		],
		[
			-97,
			135
		],
		[
			37,
			155
		],
		[
			30,
			-10
		],
		[
			60,
			52
		]
	],
	[
		[
			16102,
			70541
		],
		[
			54,
			-83
		],
		[
			54,
			31
		],
		[
			36,
			-62
		],
		[
			48,
			-21
		],
		[
			6,
			-62
		],
		[
			-42,
			-31
		],
		[
			-60,
			0
		],
		[
			-48,
			41
		],
		[
			-79,
			145
		],
		[
			31,
			42
		]
	],
	[
		[
			12416,
			70427
		],
		[
			42,
			-31
		],
		[
			-42,
			-104
		],
		[
			-60,
			21
		],
		[
			0,
			62
		],
		[
			60,
			52
		]
	],
	[
		[
			15115,
			71856
		],
		[
			31,
			-41
		],
		[
			6,
			-83
		],
		[
			-67,
			-52
		],
		[
			-24,
			114
		],
		[
			54,
			62
		]
	],
	[
		[
			15302,
			71949
		],
		[
			78,
			-124
		],
		[
			-24,
			-103
		],
		[
			-36,
			-83
		],
		[
			-36,
			-135
		],
		[
			-54,
			-83
		],
		[
			-109,
			-72
		],
		[
			-48,
			-83
		],
		[
			0,
			-52
		],
		[
			67,
			-145
		],
		[
			6,
			-207
		],
		[
			48,
			-114
		],
		[
			54,
			-83
		],
		[
			54,
			-21
		],
		[
			-12,
			-124
		],
		[
			-114,
			-124
		],
		[
			-43,
			-83
		],
		[
			-54,
			0
		],
		[
			-102,
			-41
		],
		[
			-90,
			31
		],
		[
			-36,
			83
		],
		[
			12,
			41
		],
		[
			-78,
			114
		],
		[
			0,
			135
		],
		[
			42,
			72
		],
		[
			-12,
			135
		],
		[
			-36,
			72
		],
		[
			18,
			42
		],
		[
			-30,
			93
		],
		[
			24,
			176
		],
		[
			24,
			62
		],
		[
			78,
			135
		],
		[
			54,
			62
		],
		[
			66,
			-31
		],
		[
			127,
			-21
		],
		[
			54,
			83
		],
		[
			-91,
			31
		],
		[
			43,
			114
		],
		[
			48,
			93
		],
		[
			66,
			0
		],
		[
			30,
			73
		],
		[
			12,
			82
		]
	],
	[
		[
			15302,
			71949
		],
		[
			-72,
			21
		],
		[
			6,
			73
		],
		[
			66,
			-94
		]
	],
	[
		[
			11532,
			72094
		],
		[
			6,
			-93
		],
		[
			-48,
			42
		],
		[
			42,
			51
		]
	],
	[
		[
			15434,
			72674
		],
		[
			66,
			-31
		],
		[
			18,
			-145
		],
		[
			-54,
			-114
		],
		[
			0,
			-93
		],
		[
			-30,
			-52
		],
		[
			-24,
			-134
		],
		[
			-30,
			-83
		],
		[
			-72,
			41
		],
		[
			-36,
			83
		],
		[
			30,
			73
		],
		[
			-48,
			41
		],
		[
			6,
			52
		],
		[
			48,
			-21
		],
		[
			54,
			31
		],
		[
			-30,
			93
		],
		[
			18,
			83
		],
		[
			-24,
			52
		],
		[
			54,
			31
		],
		[
			78,
			-10
		],
		[
			-24,
			103
		]
	],
	[
		[
			12266,
			72654
		],
		[
			6,
			0
		],
		[
			-6,
			0
		]
	],
	[
		[
			13240,
			73834
		],
		[
			48,
			-51
		],
		[
			60,
			-21
		],
		[
			48,
			10
		],
		[
			54,
			62
		],
		[
			96,
			11
		],
		[
			12,
			-145
		],
		[
			78,
			-42
		],
		[
			24,
			-51
		],
		[
			97,
			-32
		],
		[
			54,
			-51
		],
		[
			24,
			-114
		],
		[
			42,
			-52
		],
		[
			30,
			-186
		],
		[
			108,
			-21
		],
		[
			48,
			31
		],
		[
			60,
			-52
		],
		[
			30,
			10
		],
		[
			91,
			-124
		],
		[
			30,
			-114
		],
		[
			78,
			-93
		],
		[
			18,
			-72
		],
		[
			66,
			-42
		],
		[
			-18,
			-145
		],
		[
			6,
			-145
		],
		[
			24,
			-52
		],
		[
			-18,
			-145
		],
		[
			18,
			-51
		],
		[
			-18,
			-218
		],
		[
			-30,
			-52
		],
		[
			36,
			-51
		],
		[
			12,
			-114
		],
		[
			24,
			-94
		],
		[
			-24,
			-217
		],
		[
			-60,
			-238
		],
		[
			-60,
			-21
		],
		[
			-84,
			-93
		],
		[
			-67,
			31
		],
		[
			-84,
			-176
		],
		[
			6,
			-42
		],
		[
			103,
			83
		],
		[
			78,
			11
		],
		[
			42,
			41
		],
		[
			114,
			0
		],
		[
			42,
			-31
		],
		[
			66,
			-104
		],
		[
			-72,
			-186
		],
		[
			-54,
			0
		],
		[
			54,
			-114
		],
		[
			54,
			-52
		],
		[
			24,
			-72
		],
		[
			90,
			-114
		],
		[
			12,
			-156
		],
		[
			-30,
			21
		],
		[
			-126,
			-41
		],
		[
			-168,
			-156
		],
		[
			30,
			-31
		],
		[
			48,
			31
		],
		[
			48,
			62
		],
		[
			126,
			73
		],
		[
			72,
			10
		],
		[
			115,
			-41
		],
		[
			72,
			31
		],
		[
			90,
			0
		],
		[
			54,
			-41
		],
		[
			-18,
			-114
		],
		[
			24,
			-73
		],
		[
			-156,
			-114
		],
		[
			-30,
			-10
		],
		[
			12,
			-104
		],
		[
			54,
			21
		],
		[
			42,
			52
		],
		[
			66,
			41
		],
		[
			36,
			-10
		],
		[
			30,
			52
		],
		[
			97,
			51
		],
		[
			54,
			-62
		],
		[
			36,
			-10
		],
		[
			66,
			-93
		],
		[
			42,
			10
		],
		[
			42,
			-41
		],
		[
			30,
			20
		],
		[
			156,
			-62
		],
		[
			42,
			-31
		],
		[
			19,
			42
		],
		[
			48,
			10
		],
		[
			126,
			-104
		],
		[
			-18,
			-93
		],
		[
			60,
			-41
		],
		[
			102,
			-11
		],
		[
			48,
			62
		],
		[
			96,
			42
		],
		[
			55,
			52
		],
		[
			30,
			-42
		],
		[
			102,
			62
		],
		[
			72,
			-10
		],
		[
			48,
			52
		],
		[
			150,
			93
		],
		[
			97,
			0
		],
		[
			96,
			31
		],
		[
			48,
			-31
		],
		[
			96,
			21
		],
		[
			6,
			-62
		],
		[
			-60,
			-21
		],
		[
			0,
			-42
		],
		[
			78,
			21
		],
		[
			72,
			0
		],
		[
			115,
			21
		],
		[
			114,
			0
		],
		[
			78,
			-124
		],
		[
			-84,
			-104
		],
		[
			-24,
			-52
		],
		[
			24,
			-72
		],
		[
			-36,
			-104
		],
		[
			0,
			-72
		],
		[
			-253,
			-218
		],
		[
			-126,
			-62
		],
		[
			-48,
			0
		],
		[
			-42,
			-41
		],
		[
			-175,
			-73
		],
		[
			-36,
			11
		],
		[
			-84,
			82
		],
		[
			0,
			-103
		],
		[
			18,
			-124
		],
		[
			-24,
			-32
		],
		[
			12,
			-72
		],
		[
			48,
			10
		],
		[
			12,
			-51
		],
		[
			-48,
			-42
		],
		[
			-36,
			-93
		],
		[
			-36,
			-21
		],
		[
			-30,
			-62
		],
		[
			-54,
			-52
		],
		[
			-48,
			0
		],
		[
			-90,
			31
		],
		[
			-37,
			-20
		],
		[
			-12,
			-63
		],
		[
			-72,
			-155
		],
		[
			-102,
			-52
		],
		[
			-12,
			-83
		],
		[
			-36,
			-31
		],
		[
			-78,
			-145
		],
		[
			-36,
			-10
		],
		[
			-54,
			-93
		],
		[
			-157,
			-62
		],
		[
			-42,
			-83
		],
		[
			-48,
			41
		],
		[
			-102,
			-31
		],
		[
			-30,
			-41
		],
		[
			-72,
			-31
		],
		[
			-78,
			72
		],
		[
			-73,
			104
		],
		[
			-36,
			83
		],
		[
			-12,
			82
		],
		[
			84,
			135
		],
		[
			61,
			-10
		],
		[
			30,
			20
		],
		[
			0,
			166
		],
		[
			66,
			135
		],
		[
			42,
			0
		],
		[
			6,
			52
		],
		[
			-84,
			82
		],
		[
			42,
			73
		],
		[
			48,
			21
		],
		[
			108,
			124
		],
		[
			54,
			31
		],
		[
			96,
			10
		],
		[
			6,
			52
		],
		[
			121,
			83
		],
		[
			30,
			52
		],
		[
			174,
			10
		],
		[
			108,
			42
		],
		[
			42,
			31
		],
		[
			37,
			62
		],
		[
			54,
			21
		],
		[
			-6,
			51
		],
		[
			-79,
			-72
		],
		[
			-30,
			10
		],
		[
			-84,
			-62
		],
		[
			-84,
			41
		],
		[
			-48,
			-41
		],
		[
			0,
			-41
		],
		[
			-120,
			0
		],
		[
			-30,
			31
		],
		[
			-79,
			10
		],
		[
			-186,
			-72
		],
		[
			-78,
			0
		],
		[
			-54,
			31
		],
		[
			12,
			134
		],
		[
			-60,
			93
		],
		[
			-42,
			104
		],
		[
			-54,
			0
		],
		[
			-25,
			114
		],
		[
			-66,
			83
		],
		[
			-12,
			-104
		],
		[
			60,
			-72
		],
		[
			12,
			-125
		],
		[
			-24,
			-113
		],
		[
			-36,
			-42
		],
		[
			-72,
			10
		],
		[
			0,
			-113
		],
		[
			-66,
			-135
		],
		[
			-30,
			-93
		],
		[
			-54,
			-62
		],
		[
			-12,
			-52
		],
		[
			-48,
			-52
		],
		[
			-60,
			52
		],
		[
			-18,
			41
		],
		[
			-55,
			-21
		],
		[
			-18,
			83
		],
		[
			30,
			62
		],
		[
			-18,
			42
		],
		[
			24,
			62
		],
		[
			13,
			93
		],
		[
			-49,
			73
		],
		[
			-6,
			124
		],
		[
			-60,
			0
		],
		[
			-42,
			-62
		],
		[
			-54,
			41
		],
		[
			-36,
			-10
		],
		[
			-30,
			83
		],
		[
			-24,
			-31
		],
		[
			-48,
			51
		],
		[
			-36,
			-31
		],
		[
			24,
			-145
		],
		[
			-18,
			-41
		],
		[
			-109,
			-21
		],
		[
			-126,
			42
		],
		[
			-192,
			-73
		],
		[
			-66,
			0
		],
		[
			-133,
			-31
		],
		[
			-186,
			-62
		],
		[
			-36,
			93
		],
		[
			66,
			31
		],
		[
			60,
			62
		],
		[
			60,
			104
		],
		[
			0,
			72
		],
		[
			-60,
			42
		],
		[
			-120,
			-104
		],
		[
			-84,
			-51
		],
		[
			-108,
			-11
		],
		[
			-30,
			21
		],
		[
			-193,
			238
		],
		[
			6,
			114
		],
		[
			18,
			21
		],
		[
			156,
			0
		],
		[
			49,
			62
		],
		[
			6,
			186
		],
		[
			-42,
			-51
		],
		[
			-13,
			-94
		],
		[
			-54,
			-31
		],
		[
			-120,
			11
		],
		[
			-60,
			-42
		],
		[
			-42,
			0
		],
		[
			-36,
			42
		],
		[
			-54,
			10
		],
		[
			-48,
			41
		],
		[
			0,
			83
		],
		[
			-48,
			52
		],
		[
			-79,
			41
		],
		[
			-78,
			197
		],
		[
			-18,
			73
		],
		[
			-66,
			-11
		],
		[
			-30,
			31
		],
		[
			12,
			104
		],
		[
			-18,
			83
		],
		[
			144,
			72
		],
		[
			18,
			42
		],
		[
			48,
			-21
		],
		[
			36,
			52
		],
		[
			73,
			10
		],
		[
			-18,
			114
		],
		[
			54,
			-52
		],
		[
			54,
			21
		],
		[
			30,
			-41
		],
		[
			72,
			-21
		],
		[
			132,
			-104
		],
		[
			84,
			-145
		],
		[
			109,
			-51
		],
		[
			90,
			-11
		],
		[
			24,
			42
		],
		[
			-138,
			41
		],
		[
			-103,
			145
		],
		[
			-180,
			176
		],
		[
			-42,
			-10
		],
		[
			-90,
			103
		],
		[
			-54,
			11
		],
		[
			-85,
			-31
		],
		[
			-108,
			20
		],
		[
			0,
			114
		],
		[
			-78,
			0
		],
		[
			-60,
			83
		],
		[
			60,
			52
		],
		[
			-66,
			31
		],
		[
			-36,
			52
		],
		[
			12,
			72
		],
		[
			-18,
			104
		],
		[
			-42,
			-73
		],
		[
			-6,
			-72
		],
		[
			-66,
			-42
		],
		[
			-24,
			-72
		],
		[
			-73,
			52
		],
		[
			55,
			114
		],
		[
			-67,
			103
		],
		[
			-54,
			52
		],
		[
			-30,
			-135
		],
		[
			-78,
			-93
		],
		[
			-18,
			42
		],
		[
			-42,
			-52
		],
		[
			-18,
			-62
		],
		[
			36,
			-114
		],
		[
			-18,
			-187
		],
		[
			0,
			-93
		],
		[
			-30,
			-31
		],
		[
			-60,
			0
		],
		[
			-12,
			41
		],
		[
			-54,
			0
		],
		[
			-85,
			42
		],
		[
			-96,
			83
		],
		[
			-84,
			31
		],
		[
			-54,
			0
		],
		[
			-24,
			41
		],
		[
			-132,
			-10
		],
		[
			-145,
			124
		],
		[
			-60,
			-10
		],
		[
			-54,
			21
		],
		[
			-72,
			93
		],
		[
			-6,
			62
		],
		[
			30,
			72
		],
		[
			-36,
			63
		],
		[
			-24,
			103
		],
		[
			-72,
			83
		],
		[
			-54,
			0
		],
		[
			-24,
			62
		],
		[
			-97,
			-21
		],
		[
			-36,
			63
		],
		[
			6,
			62
		],
		[
			54,
			31
		],
		[
			-42,
			83
		],
		[
			30,
			62
		],
		[
			85,
			10
		],
		[
			78,
			-21
		],
		[
			48,
			-51
		],
		[
			54,
			10
		],
		[
			36,
			41
		],
		[
			-66,
			42
		],
		[
			-42,
			72
		],
		[
			-18,
			135
		],
		[
			6,
			155
		],
		[
			90,
			83
		],
		[
			84,
			42
		],
		[
			36,
			0
		],
		[
			108,
			-228
		],
		[
			97,
			-93
		],
		[
			0,
			-52
		],
		[
			54,
			-31
		],
		[
			-6,
			-83
		],
		[
			66,
			-11
		],
		[
			36,
			-72
		],
		[
			72,
			-104
		],
		[
			12,
			11
		],
		[
			84,
			-83
		],
		[
			72,
			124
		],
		[
			79,
			-41
		],
		[
			60,
			-187
		],
		[
			36,
			104
		],
		[
			-54,
			62
		],
		[
			-36,
			124
		],
		[
			-55,
			52
		],
		[
			-54,
			-41
		],
		[
			-24,
			51
		],
		[
			24,
			63
		],
		[
			-60,
			62
		],
		[
			-30,
			155
		],
		[
			-24,
			21
		],
		[
			-30,
			103
		],
		[
			102,
			-20
		],
		[
			60,
			62
		],
		[
			67,
			21
		],
		[
			72,
			-63
		],
		[
			84,
			-93
		],
		[
			48,
			21
		],
		[
			-24,
			62
		],
		[
			42,
			41
		],
		[
			-72,
			83
		],
		[
			-72,
			11
		],
		[
			-18,
			83
		],
		[
			-24,
			10
		],
		[
			-67,
			93
		],
		[
			-54,
			10
		],
		[
			-36,
			42
		],
		[
			-84,
			52
		],
		[
			-54,
			51
		],
		[
			-24,
			-62
		],
		[
			-42,
			-20
		],
		[
			6,
			103
		],
		[
			30,
			-10
		],
		[
			48,
			83
		],
		[
			-6,
			62
		],
		[
			42,
			114
		],
		[
			-12,
			62
		],
		[
			18,
			72
		],
		[
			-24,
			31
		],
		[
			12,
			83
		],
		[
			42,
			-20
		],
		[
			72,
			0
		],
		[
			97,
			-94
		],
		[
			54,
			-10
		],
		[
			84,
			-135
		],
		[
			30,
			-83
		],
		[
			6,
			-186
		],
		[
			78,
			-72
		],
		[
			78,
			41
		],
		[
			78,
			-73
		],
		[
			85,
			-31
		],
		[
			78,
			-51
		],
		[
			24,
			-73
		],
		[
			36,
			0
		],
		[
			96,
			-103
		],
		[
			60,
			-94
		],
		[
			36,
			-20
		],
		[
			133,
			165
		],
		[
			36,
			-51
		],
		[
			-79,
			-187
		],
		[
			-60,
			-83
		],
		[
			109,
			-83
		],
		[
			-31,
			104
		],
		[
			7,
			41
		],
		[
			90,
			73
		],
		[
			-6,
			52
		],
		[
			78,
			20
		],
		[
			48,
			83
		],
		[
			-42,
			73
		],
		[
			18,
			41
		],
		[
			72,
			-20
		],
		[
			36,
			-32
		],
		[
			60,
			-196
		],
		[
			48,
			31
		],
		[
			103,
			-93
		],
		[
			6,
			-114
		],
		[
			24,
			-11
		],
		[
			36,
			93
		],
		[
			18,
			-103
		],
		[
			36,
			-52
		],
		[
			-6,
			-114
		],
		[
			42,
			21
		],
		[
			18,
			72
		],
		[
			-42,
			73
		],
		[
			36,
			62
		],
		[
			42,
			-52
		],
		[
			18,
			42
		],
		[
			-84,
			41
		],
		[
			-132,
			155
		],
		[
			-43,
			11
		],
		[
			-66,
			62
		],
		[
			-60,
			135
		],
		[
			12,
			51
		],
		[
			-66,
			83
		],
		[
			-60,
			104
		],
		[
			-18,
			83
		],
		[
			24,
			62
		],
		[
			78,
			-52
		],
		[
			12,
			72
		],
		[
			30,
			0
		],
		[
			66,
			114
		],
		[
			6,
			63
		],
		[
			-60,
			0
		],
		[
			-42,
			-52
		],
		[
			-72,
			0
		],
		[
			-18,
			145
		],
		[
			-18,
			52
		],
		[
			18,
			62
		],
		[
			-108,
			176
		],
		[
			-24,
			10
		],
		[
			-60,
			93
		],
		[
			36,
			62
		],
		[
			90,
			21
		],
		[
			-24,
			93
		],
		[
			162,
			-10
		],
		[
			162,
			114
		],
		[
			55,
			83
		],
		[
			12,
			52
		],
		[
			-42,
			93
		],
		[
			0,
			103
		]
	],
	[
		[
			16294,
			74114
		],
		[
			96,
			-10
		],
		[
			48,
			20
		],
		[
			6,
			-62
		],
		[
			-42,
			-31
		],
		[
			-66,
			0
		],
		[
			-42,
			83
		]
	],
	[
		[
			27128,
			74860
		],
		[
			6,
			-11
		]
	],
	[
		[
			27134,
			74849
		],
		[
			-6,
			0
		]
	],
	[
		[
			27128,
			74849
		],
		[
			-6,
			11
		]
	],
	[
		[
			27122,
			74860
		],
		[
			6,
			0
		]
	],
	[
		[
			20635,
			74860
		],
		[
			-6,
			0
		]
	],
	[
		[
			20629,
			74860
		],
		[
			6,
			0
		]
	],
	[
		[
			17382,
			75160
		],
		[
			-12,
			-41
		],
		[
			90,
			-62
		],
		[
			78,
			-32
		],
		[
			31,
			-72
		],
		[
			-18,
			-41
		],
		[
			-79,
			10
		],
		[
			-132,
			103
		],
		[
			-12,
			104
		],
		[
			54,
			31
		]
	],
	[
		[
			17051,
			75346
		],
		[
			6,
			0
		]
	],
	[
		[
			17057,
			75346
		],
		[
			-6,
			0
		]
	],
	[
		[
			18314,
			75647
		],
		[
			42,
			-42
		],
		[
			6,
			-145
		],
		[
			-30,
			-10
		],
		[
			-72,
			73
		],
		[
			-6,
			82
		],
		[
			60,
			42
		]
	],
	[
		[
			19721,
			76123
		],
		[
			72,
			-10
		],
		[
			12,
			-42
		],
		[
			-30,
			-72
		],
		[
			-96,
			52
		],
		[
			-12,
			62
		],
		[
			54,
			10
		]
	],
	[
		[
			18957,
			76216
		],
		[
			-12,
			0
		]
	],
	[
		[
			18945,
			76216
		],
		[
			12,
			0
		]
	],
	[
		[
			18158,
			76216
		],
		[
			-6,
			11
		]
	],
	[
		[
			18152,
			76227
		],
		[
			6,
			-11
		]
	],
	[
		[
			18380,
			76237
		],
		[
			6,
			0
		],
		[
			-6,
			0
		]
	],
	[
		[
			18513,
			76268
		],
		[
			-6,
			-10
		]
	],
	[
		[
			18507,
			76258
		],
		[
			6,
			10
		]
	],
	[
		[
			18146,
			76227
		],
		[
			6,
			0
		]
	],
	[
		[
			18158,
			76216
		],
		[
			-24,
			-41
		],
		[
			-102,
			-10
		],
		[
			12,
			72
		],
		[
			48,
			52
		],
		[
			12,
			-62
		],
		[
			42,
			0
		]
	],
	[
		[
			19012,
			76527
		],
		[
			42,
			-10
		],
		[
			12,
			-62
		],
		[
			-36,
			-52
		],
		[
			-30,
			31
		],
		[
			12,
			93
		]
	],
	[
		[
			18452,
			76724
		],
		[
			67,
			-41
		],
		[
			-73,
			-52
		],
		[
			-42,
			62
		],
		[
			48,
			31
		]
	],
	[
		[
			18801,
			76672
		],
		[
			-60,
			-72
		],
		[
			-84,
			-11
		],
		[
			-54,
			52
		],
		[
			6,
			124
		]
	],
	[
		[
			18609,
			76765
		],
		[
			42,
			52
		],
		[
			60,
			-10
		],
		[
			-6,
			-104
		],
		[
			48,
			-41
		],
		[
			48,
			10
		]
	],
	[
		[
			18476,
			77066
		],
		[
			31,
			0
		],
		[
			42,
			-62
		],
		[
			-12,
			-52
		],
		[
			-97,
			21
		],
		[
			-12,
			41
		],
		[
			48,
			52
		]
	],
	[
		[
			18398,
			77055
		],
		[
			-30,
			21
		],
		[
			30,
			-21
		]
	],
	[
		[
			20912,
			79065
		],
		[
			-31,
			10
		]
	],
	[
		[
			20881,
			79075
		],
		[
			31,
			-10
		]
	],
	[
		[
			19637,
			79065
		],
		[
			-12,
			-11
		]
	],
	[
		[
			19625,
			79054
		],
		[
			12,
			11
		]
	],
	[
		[
			19637,
			78951
		],
		[
			-162,
			31
		],
		[
			-55,
			72
		],
		[
			97,
			62
		],
		[
			30,
			-62
		],
		[
			78,
			-41
		],
		[
			12,
			-62
		]
	],
	[
		[
			31301,
			79469
		],
		[
			18,
			10
		]
	],
	[
		[
			31319,
			79479
		],
		[
			-18,
			-10
		]
	],
	[
		[
			20214,
			79230
		],
		[
			-6,
			-10
		]
	],
	[
		[
			20208,
			79220
		],
		[
			-60,
			41
		],
		[
			66,
			-31
		]
	],
	[
		[
			31433,
			79593
		],
		[
			0,
			10
		]
	],
	[
		[
			31433,
			79603
		],
		[
			0,
			-10
		]
	],
	[
		[
			20268,
			79313
		],
		[
			30,
			-93
		],
		[
			-66,
			10
		],
		[
			36,
			83
		]
	],
	[
		[
			19943,
			79489
		],
		[
			-6,
			-10
		]
	],
	[
		[
			19937,
			79479
		],
		[
			6,
			10
		]
	],
	[
		[
			19943,
			79489
		],
		[
			-6,
			-10
		]
	],
	[
		[
			20052,
			79551
		],
		[
			6,
			0
		],
		[
			-6,
			0
		]
	],
	[
		[
			20220,
			79593
		],
		[
			0,
			-11
		]
	],
	[
		[
			20220,
			79582
		],
		[
			-6,
			0
		]
	],
	[
		[
			20214,
			79582
		],
		[
			6,
			11
		]
	],
	[
		[
			19998,
			79872
		],
		[
			0,
			11
		]
	],
	[
		[
			19998,
			79883
		],
		[
			0,
			-11
		]
	],
	[
		[
			20190,
			80245
		],
		[
			-6,
			0
		],
		[
			6,
			0
		]
	],
	[
		[
			20088,
			80256
		],
		[
			-6,
			0
		],
		[
			6,
			0
		]
	],
	[
		[
			20160,
			80276
		],
		[
			12,
			0
		]
	],
	[
		[
			20172,
			80276
		],
		[
			-12,
			0
		]
	],
	[
		[
			19895,
			80245
		],
		[
			97,
			21
		],
		[
			78,
			-72
		],
		[
			-42,
			-63
		],
		[
			-78,
			0
		],
		[
			-31,
			-31
		],
		[
			-72,
			21
		],
		[
			18,
			83
		],
		[
			30,
			41
		]
	],
	[
		[
			20154,
			80287
		],
		[
			6,
			-11
		]
	],
	[
		[
			20160,
			80276
		],
		[
			-6,
			11
		]
	],
	[
		[
			20124,
			80287
		],
		[
			6,
			0
		]
	],
	[
		[
			20130,
			80287
		],
		[
			-6,
			0
		]
	],
	[
		[
			20575,
			80287
		],
		[
			42,
			10
		]
	],
	[
		[
			20617,
			80297
		],
		[
			-42,
			-10
		]
	],
	[
		[
			20130,
			80297
		],
		[
			6,
			-10
		],
		[
			-6,
			0
		]
	],
	[
		[
			20130,
			80287
		],
		[
			0,
			10
		]
	],
	[
		[
			20509,
			80318
		],
		[
			-6,
			10
		],
		[
			6,
			-10
		]
	],
	[
		[
			20256,
			80473
		],
		[
			-6,
			0
		]
	],
	[
		[
			20250,
			80473
		],
		[
			6,
			0
		]
	],
	[
		[
			22481,
			80846
		],
		[
			6,
			10
		]
	],
	[
		[
			22487,
			80856
		],
		[
			-6,
			-10
		]
	],
	[
		[
			22481,
			80846
		],
		[
			6,
			10
		]
	],
	[
		[
			20539,
			80846
		],
		[
			-12,
			0
		],
		[
			12,
			0
		]
	],
	[
		[
			20545,
			80856
		],
		[
			-6,
			-10
		]
	],
	[
		[
			20539,
			80846
		],
		[
			6,
			10
		]
	],
	[
		[
			24206,
			81105
		],
		[
			18,
			0
		]
	],
	[
		[
			24224,
			81105
		],
		[
			-18,
			0
		]
	],
	[
		[
			24224,
			81105
		],
		[
			-18,
			0
		]
	],
	[
		[
			24206,
			81105
		],
		[
			18,
			0
		]
	],
	[
		[
			20352,
			81126
		],
		[
			0,
			-11
		],
		[
			0,
			11
		]
	],
	[
		[
			20232,
			81136
		],
		[
			-6,
			0
		]
	],
	[
		[
			20226,
			81136
		],
		[
			6,
			0
		]
	],
	[
		[
			20226,
			81136
		],
		[
			6,
			0
		]
	],
	[
		[
			32071,
			81747
		],
		[
			-6,
			10
		]
	],
	[
		[
			32065,
			81757
		],
		[
			6,
			-10
		]
	],
	[
		[
			25517,
			81612
		],
		[
			-6,
			11
		]
	],
	[
		[
			25511,
			81623
		],
		[
			6,
			-11
		]
	],
	[
		[
			24519,
			81623
		],
		[
			-12,
			-42
		],
		[
			-54,
			21
		],
		[
			24,
			62
		],
		[
			42,
			-41
		]
	],
	[
		[
			25854,
			81737
		],
		[
			-6,
			10
		]
	],
	[
		[
			25848,
			81747
		],
		[
			6,
			-10
		]
	],
	[
		[
			25854,
			81747
		],
		[
			-6,
			0
		]
	],
	[
		[
			25848,
			81747
		],
		[
			6,
			0
		]
	],
	[
		[
			24206,
			81788
		],
		[
			0,
			-20
		]
	],
	[
		[
			24206,
			81768
		],
		[
			-18,
			31
		]
	],
	[
		[
			24188,
			81799
		],
		[
			18,
			-11
		]
	],
	[
		[
			27621,
			81902
		],
		[
			-12,
			11
		]
	],
	[
		[
			27609,
			81913
		],
		[
			12,
			-11
		]
	],
	[
		[
			24808,
			81882
		],
		[
			60,
			10
		],
		[
			36,
			-21
		],
		[
			-60,
			-114
		],
		[
			-42,
			42
		],
		[
			6,
			83
		]
	],
	[
		[
			26461,
			81944
		],
		[
			-6,
			0
		]
	],
	[
		[
			26455,
			81944
		],
		[
			6,
			0
		]
	],
	[
		[
			26479,
			81954
		],
		[
			-6,
			-10
		]
	],
	[
		[
			26473,
			81944
		],
		[
			0,
			10
		],
		[
			6,
			0
		]
	],
	[
		[
			23016,
			81996
		],
		[
			0,
			-11
		]
	],
	[
		[
			23016,
			81985
		],
		[
			0,
			11
		]
	],
	[
		[
			23016,
			81996
		],
		[
			0,
			-11
		]
	],
	[
		[
			23425,
			82047
		],
		[
			6,
			-10
		]
	],
	[
		[
			23431,
			82037
		],
		[
			-6,
			10
		]
	],
	[
		[
			26635,
			82172
		],
		[
			-12,
			-11
		]
	],
	[
		[
			26623,
			82161
		],
		[
			12,
			11
		]
	],
	[
		[
			21916,
			82275
		],
		[
			-6,
			11
		]
	],
	[
		[
			21910,
			82286
		],
		[
			6,
			-11
		]
	],
	[
		[
			31482,
			82845
		],
		[
			0,
			-10
		]
	],
	[
		[
			31482,
			82835
		],
		[
			0,
			10
		]
	],
	[
		[
			31482,
			82835
		],
		[
			0,
			10
		]
	],
	[
		[
			31367,
			82772
		],
		[
			90,
			0
		],
		[
			18,
			42
		],
		[
			109,
			-93
		],
		[
			18,
			-73
		],
		[
			36,
			-41
		],
		[
			54,
			-11
		],
		[
			102,
			21
		],
		[
			36,
			31
		],
		[
			90,
			0
		],
		[
			79,
			42
		],
		[
			162,
			-32
		],
		[
			96,
			11
		],
		[
			18,
			31
		],
		[
			78,
			-42
		],
		[
			78,
			11
		],
		[
			-72,
			-124
		],
		[
			-6,
			-156
		],
		[
			18,
			-41
		],
		[
			-48,
			-135
		],
		[
			-54,
			0
		],
		[
			-114,
			-41
		],
		[
			30,
			-73
		],
		[
			42,
			-31
		],
		[
			-42,
			-114
		],
		[
			-6,
			-52
		]
	],
	[
		[
			32179,
			81902
		],
		[
			-30,
			-20
		],
		[
			-84,
			-125
		]
	],
	[
		[
			32071,
			81747
		],
		[
			-102,
			-83
		],
		[
			-55,
			-62
		],
		[
			-30,
			0
		],
		[
			-66,
			-114
		],
		[
			-12,
			-155
		],
		[
			48,
			-176
		],
		[
			48,
			-62
		],
		[
			79,
			-42
		],
		[
			162,
			21
		],
		[
			72,
			41
		],
		[
			78,
			-31
		],
		[
			-18,
			-114
		],
		[
			-24,
			-51
		],
		[
			36,
			-63
		],
		[
			-72,
			-93
		],
		[
			-156,
			0
		],
		[
			18,
			-31
		],
		[
			96,
			-52
		],
		[
			-6,
			-51
		],
		[
			-84,
			-83
		],
		[
			-30,
			-73
		],
		[
			18,
			-72
		],
		[
			-78,
			-83
		],
		[
			12,
			-62
		],
		[
			-42,
			-62
		],
		[
			-19,
			-104
		],
		[
			-144,
			-135
		],
		[
			-42,
			0
		],
		[
			-54,
			-62
		],
		[
			-60,
			-41
		],
		[
			-18,
			-52
		],
		[
			-90,
			-73
		],
		[
			-103,
			-124
		]
	],
	[
		[
			31433,
			79593
		],
		[
			-114,
			-114
		]
	],
	[
		[
			31319,
			79479
		],
		[
			-18,
			-10
		]
	],
	[
		[
			31301,
			79469
		],
		[
			-108,
			-32
		],
		[
			-90,
			-41
		],
		[
			-24,
			31
		],
		[
			-48,
			-21
		],
		[
			-61,
			-10
		]
	],
	[
		[
			30970,
			79396
		],
		[
			-84,
			-62
		],
		[
			-132,
			-42
		],
		[
			-66,
			-41
		],
		[
			-187,
			-41
		],
		[
			-204,
			-145
		],
		[
			-30,
			-63
		],
		[
			-102,
			-103
		],
		[
			-36,
			10
		],
		[
			-66,
			-93
		],
		[
			-24,
			-72
		],
		[
			-139,
			-135
		],
		[
			-66,
			-124
		],
		[
			6,
			-21
		],
		[
			-6,
			0
		],
		[
			0,
			-21
		],
		[
			-60,
			-41
		],
		[
			-120,
			-176
		],
		[
			-109,
			-73
		],
		[
			-78,
			-31
		],
		[
			-72,
			-52
		],
		[
			-18,
			-20
		],
		[
			-102,
			-73
		],
		[
			-60,
			-62
		],
		[
			-145,
			-72
		],
		[
			-30,
			0
		],
		[
			-102,
			-125
		],
		[
			-66,
			-41
		],
		[
			-96,
			-21
		],
		[
			-78,
			-103
		],
		[
			-175,
			-114
		],
		[
			-78,
			-73
		],
		[
			-54,
			0
		],
		[
			-54,
			-41
		],
		[
			-60,
			-83
		],
		[
			-78,
			-11
		],
		[
			-36,
			-41
		],
		[
			-49,
			21
		],
		[
			-60,
			-11
		],
		[
			-120,
			-62
		],
		[
			-72,
			-124
		],
		[
			-96,
			-52
		],
		[
			-30,
			-93
		],
		[
			-12,
			-145
		],
		[
			-48,
			-73
		],
		[
			-115,
			-31
		],
		[
			-84,
			-62
		],
		[
			-42,
			-72
		],
		[
			-150,
			-42
		],
		[
			-108,
			-10
		],
		[
			-97,
			-62
		],
		[
			-72,
			-21
		],
		[
			-36,
			10
		],
		[
			-72,
			-51
		],
		[
			-48,
			-114
		],
		[
			-66,
			-218
		],
		[
			-90,
			-10
		],
		[
			-6,
			83
		],
		[
			-25,
			72
		],
		[
			-36,
			-31
		],
		[
			-78,
			0
		],
		[
			-18,
			-21
		],
		[
			-42,
			94
		],
		[
			-48,
			-11
		],
		[
			-42,
			31
		],
		[
			-72,
			-51
		],
		[
			60,
			-125
		],
		[
			204,
			-62
		],
		[
			36,
			-31
		],
		[
			79,
			42
		],
		[
			54,
			0
		],
		[
			36,
			-52
		],
		[
			6,
			-73
		],
		[
			36,
			-124
		],
		[
			-60,
			-62
		],
		[
			-6,
			-52
		],
		[
			-42,
			-21
		],
		[
			12,
			-93
		],
		[
			-36,
			-31
		],
		[
			42,
			-135
		],
		[
			-18,
			-51
		],
		[
			-42,
			41
		],
		[
			-79,
			41
		],
		[
			-228,
			0
		],
		[
			-126,
			-51
		],
		[
			-54,
			-42
		],
		[
			-43,
			-83
		],
		[
			-24,
			52
		],
		[
			-96,
			21
		],
		[
			0,
			103
		],
		[
			-36,
			32
		],
		[
			-36,
			-83
		],
		[
			-42,
			-21
		],
		[
			-120,
			0
		],
		[
			-12,
			83
		],
		[
			-121,
			0
		],
		[
			-36,
			31
		],
		[
			-174,
			31
		],
		[
			-42,
			-41
		],
		[
			-193,
			-11
		],
		[
			-12,
			-83
		],
		[
			-90,
			11
		],
		[
			-84,
			114
		],
		[
			-90,
			20
		],
		[
			-72,
			42
		],
		[
			-72,
			93
		],
		[
			-42,
			93
		],
		[
			-55,
			62
		],
		[
			-96,
			42
		],
		[
			-84,
			20
		],
		[
			-18,
			-31
		],
		[
			102,
			-103
		],
		[
			18,
			21
		],
		[
			102,
			0
		],
		[
			61,
			-104
		],
		[
			-79,
			-73
		],
		[
			79,
			-103
		],
		[
			186,
			-93
		],
		[
			72,
			10
		],
		[
			12,
			-93
		],
		[
			24,
			-10
		],
		[
			90,
			41
		],
		[
			55,
			-52
		],
		[
			84,
			42
		],
		[
			114,
			31
		],
		[
			78,
			0
		],
		[
			108,
			41
		],
		[
			78,
			-10
		],
		[
			19,
			-114
		],
		[
			36,
			62
		],
		[
			78,
			-114
		],
		[
			30,
			-104
		],
		[
			78,
			0
		],
		[
			30,
			-41
		],
		[
			84,
			-10
		],
		[
			66,
			10
		],
		[
			6,
			31
		],
		[
			85,
			42
		],
		[
			6,
			-32
		],
		[
			132,
			-41
		],
		[
			66,
			-41
		],
		[
			42,
			-52
		],
		[
			66,
			-42
		],
		[
			132,
			63
		],
		[
			121,
			93
		],
		[
			30,
			10
		],
		[
			192,
			124
		],
		[
			36,
			11
		],
		[
			120,
			-52
		],
		[
			91,
			-73
		],
		[
			30,
			42
		],
		[
			72,
			-62
		],
		[
			-72,
			-42
		],
		[
			-36,
			-51
		],
		[
			-85,
			0
		],
		[
			-24,
			-52
		]
	],
	[
		[
			27122,
			74860
		],
		[
			6,
			-11
		]
	],
	[
		[
			27128,
			74849
		],
		[
			6,
			0
		]
	],
	[
		[
			27134,
			74849
		],
		[
			133,
			21
		],
		[
			60,
			52
		],
		[
			132,
			-10
		],
		[
			156,
			31
		],
		[
			115,
			82
		],
		[
			66,
			21
		],
		[
			0,
			42
		],
		[
			84,
			145
		],
		[
			-6,
			31
		],
		[
			96,
			62
		],
		[
			48,
			-11
		],
		[
			36,
			31
		],
		[
			30,
			-124
		],
		[
			-42,
			-93
		],
		[
			-90,
			-124
		],
		[
			-66,
			-62
		],
		[
			-12,
			-42
		],
		[
			-60,
			-62
		],
		[
			-66,
			-104
		],
		[
			-48,
			-31
		],
		[
			-48,
			-93
		],
		[
			-133,
			-155
		],
		[
			-108,
			-62
		],
		[
			-30,
			-62
		],
		[
			-102,
			-83
		],
		[
			0,
			-62
		],
		[
			-72,
			-104
		],
		[
			-12,
			-52
		],
		[
			-91,
			-124
		],
		[
			-54,
			-52
		],
		[
			-126,
			-155
		],
		[
			-90,
			-11
		],
		[
			-72,
			31
		],
		[
			-78,
			-20
		],
		[
			-85,
			20
		],
		[
			12,
			94
		],
		[
			60,
			155
		],
		[
			73,
			41
		],
		[
			6,
			125
		],
		[
			-169,
			-21
		],
		[
			-48,
			-62
		],
		[
			-150,
			21
		],
		[
			-205,
			-125
		],
		[
			-36,
			-62
		],
		[
			-258,
			-217
		],
		[
			-78,
			-42
		],
		[
			-42,
			42
		],
		[
			-157,
			31
		],
		[
			-90,
			-11
		],
		[
			-96,
			-31
		],
		[
			-12,
			-31
		],
		[
			-126,
			-62
		],
		[
			-91,
			52
		],
		[
			-72,
			-31
		],
		[
			-48,
			-42
		],
		[
			-30,
			-186
		],
		[
			-60,
			-21
		],
		[
			-48,
			21
		],
		[
			-96,
			-83
		],
		[
			-36,
			-72
		],
		[
			-73,
			-42
		],
		[
			-42,
			-52
		],
		[
			-234,
			-176
		],
		[
			-48,
			-51
		],
		[
			-18,
			-52
		],
		[
			60,
			-73
		],
		[
			-54,
			-62
		],
		[
			-42,
			-83
		],
		[
			54,
			0
		],
		[
			132,
			125
		],
		[
			42,
			10
		],
		[
			102,
			83
		],
		[
			97,
			124
		],
		[
			78,
			73
		],
		[
			72,
			93
		],
		[
			150,
			93
		],
		[
			114,
			83
		],
		[
			187,
			155
		],
		[
			186,
			73
		],
		[
			48,
			-11
		],
		[
			109,
			21
		],
		[
			126,
			10
		],
		[
			0,
			-155
		],
		[
			66,
			-21
		],
		[
			48,
			21
		],
		[
			138,
			0
		],
		[
			36,
			21
		],
		[
			181,
			31
		],
		[
			144,
			93
		],
		[
			72,
			10
		],
		[
			72,
			73
		],
		[
			48,
			-42
		],
		[
			145,
			11
		],
		[
			30,
			-21
		],
		[
			-42,
			-93
		],
		[
			-48,
			-62
		],
		[
			-79,
			-31
		],
		[
			-84,
			-73
		],
		[
			-72,
			-93
		],
		[
			-60,
			-52
		],
		[
			-48,
			-93
		],
		[
			-54,
			-31
		],
		[
			-126,
			-135
		],
		[
			-25,
			-103
		],
		[
			-36,
			-21
		],
		[
			18,
			-93
		],
		[
			61,
			-73
		],
		[
			-199,
			21
		],
		[
			-72,
			-31
		],
		[
			-156,
			-104
		],
		[
			-24,
			-62
		],
		[
			12,
			-52
		],
		[
			-78,
			-72
		],
		[
			-55,
			31
		],
		[
			-72,
			0
		],
		[
			-102,
			31
		],
		[
			-84,
			0
		],
		[
			-6,
			-52
		],
		[
			72,
			11
		],
		[
			78,
			-52
		],
		[
			90,
			21
		],
		[
			48,
			-63
		],
		[
			-48,
			-103
		],
		[
			-96,
			-93
		],
		[
			-66,
			-83
		],
		[
			-24,
			-62
		],
		[
			-150,
			10
		],
		[
			-73,
			21
		],
		[
			-126,
			0
		],
		[
			-90,
			-21
		],
		[
			-72,
			31
		],
		[
			-120,
			0
		],
		[
			-115,
			62
		],
		[
			-114,
			0
		],
		[
			-66,
			-20
		],
		[
			-126,
			-63
		],
		[
			12,
			-51
		],
		[
			78,
			-31
		],
		[
			42,
			-42
		],
		[
			48,
			-83
		],
		[
			42,
			-20
		],
		[
			295,
			51
		],
		[
			66,
			-41
		],
		[
			36,
			31
		],
		[
			126,
			-21
		],
		[
			211,
			83
		],
		[
			30,
			42
		],
		[
			42,
			0
		],
		[
			30,
			-42
		],
		[
			78,
			62
		],
		[
			78,
			-31
		],
		[
			127,
			-93
		],
		[
			102,
			52
		],
		[
			96,
			103
		],
		[
			0,
			114
		],
		[
			30,
			52
		],
		[
			96,
			-31
		],
		[
			78,
			10
		],
		[
			-12,
			52
		],
		[
			85,
			135
		],
		[
			288,
			165
		],
		[
			66,
			73
		],
		[
			18,
			62
		],
		[
			-54,
			93
		],
		[
			-72,
			52
		],
		[
			6,
			83
		],
		[
			180,
			0
		],
		[
			85,
			93
		],
		[
			156,
			-62
		],
		[
			60,
			-10
		],
		[
			259,
			-73
		],
		[
			96,
			0
		],
		[
			318,
			62
		],
		[
			115,
			52
		],
		[
			36,
			-10
		],
		[
			144,
			124
		],
		[
			48,
			0
		],
		[
			72,
			135
		],
		[
			97,
			31
		],
		[
			42,
			31
		]
	],
	[
		[
			28175,
			73120
		],
		[
			24,
			-42
		],
		[
			66,
			-196
		],
		[
			42,
			-73
		],
		[
			-54,
			-52
		],
		[
			18,
			-41
		],
		[
			108,
			-73
		],
		[
			84,
			-124
		],
		[
			-96,
			-62
		],
		[
			48,
			-42
		],
		[
			54,
			-207
		],
		[
			30,
			-62
		],
		[
			84,
			-72
		],
		[
			-54,
			-73
		],
		[
			97,
			-145
		],
		[
			12,
			-62
		],
		[
			-43,
			-145
		],
		[
			-30,
			-186
		],
		[
			18,
			-114
		],
		[
			-66,
			-21
		],
		[
			30,
			-52
		],
		[
			85,
			-10
		],
		[
			102,
			-42
		],
		[
			174,
			11
		],
		[
			102,
			41
		],
		[
			48,
			114
		],
		[
			259,
			0
		],
		[
			90,
			31
		]
	],
	[
		[
			29407,
			71421
		],
		[
			157,
			42
		],
		[
			78,
			51
		],
		[
			114,
			-82
		]
	],
	[
		[
			29756,
			71432
		],
		[
			-6,
			-11
		],
		[
			6,
			0
		],
		[
			12,
			-52
		]
	],
	[
		[
			29768,
			71369
		],
		[
			30,
			-72
		],
		[
			156,
			-83
		],
		[
			91,
			-21
		],
		[
			30,
			-51
		],
		[
			54,
			0
		],
		[
			66,
			31
		],
		[
			48,
			-62
		],
		[
			42,
			-208
		],
		[
			66,
			-62
		],
		[
			-78,
			-62
		],
		[
			30,
			-103
		],
		[
			-84,
			-83
		],
		[
			-132,
			-104
		],
		[
			-24,
			-93
		],
		[
			-103,
			-145
		],
		[
			-36,
			0
		],
		[
			-102,
			-52
		],
		[
			-72,
			-103
		],
		[
			-36,
			-114
		],
		[
			126,
			-73
		],
		[
			54,
			0
		],
		[
			30,
			-62
		],
		[
			6,
			-124
		],
		[
			54,
			-42
		],
		[
			6,
			-41
		]
	],
	[
		[
			29990,
			69640
		],
		[
			-18,
			-114
		],
		[
			-72,
			-73
		],
		[
			0,
			-31
		],
		[
			72,
			-51
		]
	],
	[
		[
			29972,
			69371
		],
		[
			73,
			0
		],
		[
			48,
			-114
		],
		[
			-97,
			-83
		],
		[
			85,
			-73
		],
		[
			-30,
			-93
		],
		[
			-61,
			-52
		],
		[
			-42,
			-103
		],
		[
			-84,
			-31
		],
		[
			-60,
			0
		],
		[
			-42,
			31
		],
		[
			-30,
			-31
		],
		[
			-78,
			-31
		],
		[
			-48,
			-52
		],
		[
			-139,
			0
		],
		[
			-102,
			-145
		],
		[
			-6,
			-62
		],
		[
			-42,
			-52
		],
		[
			-78,
			-31
		],
		[
			-24,
			-31
		],
		[
			-66,
			-11
		],
		[
			-36,
			-41
		],
		[
			0,
			-52
		],
		[
			-55,
			-10
		],
		[
			-36,
			-62
		],
		[
			-54,
			-31
		],
		[
			-96,
			62
		],
		[
			-72,
			0
		],
		[
			-12,
			-83
		],
		[
			-120,
			-42
		],
		[
			-36,
			-72
		]
	],
	[
		[
			28632,
			68076
		],
		[
			-79,
			-52
		],
		[
			-54,
			0
		],
		[
			-48,
			-103
		],
		[
			-66,
			10
		],
		[
			-54,
			-41
		],
		[
			-84,
			10
		],
		[
			-48,
			-73
		],
		[
			36,
			-72
		],
		[
			54,
			-42
		],
		[
			6,
			-82
		],
		[
			-48,
			-31
		],
		[
			-30,
			-73
		],
		[
			30,
			-104
		],
		[
			18,
			-113
		],
		[
			-12,
			-83
		],
		[
			6,
			-114
		],
		[
			-60,
			-52
		],
		[
			6,
			-83
		],
		[
			-24,
			-52
		],
		[
			-151,
			-93
		],
		[
			-30,
			-145
		],
		[
			-36,
			-31
		],
		[
			-12,
			-83
		]
	],
	[
		[
			27952,
			66574
		],
		[
			-96,
			-10
		],
		[
			-48,
			31
		],
		[
			-108,
			-114
		],
		[
			-54,
			-31
		],
		[
			-73,
			31
		],
		[
			-24,
			-31
		],
		[
			-90,
			41
		],
		[
			-48,
			-41
		],
		[
			-30,
			83
		],
		[
			-150,
			10
		],
		[
			-60,
			31
		],
		[
			-12,
			124
		],
		[
			-67,
			-20
		],
		[
			-18,
			-73
		],
		[
			-60,
			-20
		],
		[
			-30,
			-73
		],
		[
			-12,
			-104
		],
		[
			48,
			-82
		],
		[
			-30,
			-94
		],
		[
			-54,
			-41
		],
		[
			-90,
			-41
		],
		[
			-108,
			72
		],
		[
			-12,
			-62
		],
		[
			-61,
			10
		],
		[
			-60,
			83
		],
		[
			-42,
			-52
		],
		[
			-162,
			-20
		],
		[
			-48,
			20
		],
		[
			-36,
			-20
		],
		[
			-96,
			0
		],
		[
			-97,
			20
		],
		[
			-54,
			31
		],
		[
			-54,
			-20
		],
		[
			-78,
			51
		],
		[
			-138,
			52
		],
		[
			-60,
			0
		],
		[
			-24,
			-72
		],
		[
			-67,
			-62
		],
		[
			-6,
			-114
		],
		[
			12,
			-114
		],
		[
			-96,
			0
		],
		[
			-108,
			-114
		],
		[
			-108,
			-42
		],
		[
			-54,
			42
		],
		[
			-54,
			-62
		],
		[
			-109,
			0
		],
		[
			-24,
			20
		],
		[
			-84,
			-41
		],
		[
			-18,
			-52
		],
		[
			-66,
			-20
		],
		[
			-30,
			-42
		],
		[
			-6,
			-124
		],
		[
			-78,
			-21
		],
		[
			-48,
			52
		],
		[
			-127,
			52
		],
		[
			-30,
			-62
		],
		[
			-210,
			-259
		],
		[
			-114,
			-197
		],
		[
			-37,
			-31
		],
		[
			-90,
			41
		],
		[
			-72,
			11
		],
		[
			-78,
			113
		],
		[
			-48,
			11
		],
		[
			-126,
			103
		],
		[
			-42,
			11
		],
		[
			-43,
			-31
		],
		[
			-60,
			-135
		],
		[
			-60,
			-62
		],
		[
			6,
			-83
		],
		[
			-180,
			-62
		],
		[
			-42,
			-62
		],
		[
			48,
			-218
		],
		[
			-78,
			-114
		],
		[
			-85,
			-145
		],
		[
			85,
			-31
		],
		[
			-18,
			-124
		],
		[
			-91,
			0
		],
		[
			-120,
			-52
		],
		[
			-54,
			-52
		],
		[
			-48,
			-10
		],
		[
			-48,
			-41
		],
		[
			-144,
			20
		],
		[
			-61,
			-20
		],
		[
			-144,
			10
		],
		[
			-18,
			-186
		],
		[
			24,
			-125
		],
		[
			138,
			0
		],
		[
			175,
			-31
		],
		[
			168,
			156
		],
		[
			18,
			-94
		],
		[
			66,
			-72
		],
		[
			-12,
			-42
		],
		[
			-90,
			-93
		],
		[
			60,
			-83
		]
	],
	[
		[
			23190,
			63560
		],
		[
			-30,
			-20
		],
		[
			-72,
			10
		],
		[
			-114,
			-31
		],
		[
			-138,
			-104
		],
		[
			-55,
			31
		],
		[
			-42,
			-51
		],
		[
			-72,
			-31
		],
		[
			-54,
			-73
		],
		[
			-216,
			-21
		],
		[
			-55,
			31
		],
		[
			-54,
			-51
		],
		[
			-150,
			-104
		],
		[
			-54,
			21
		],
		[
			-72,
			-42
		],
		[
			-48,
			42
		],
		[
			-127,
			-31
		],
		[
			-114,
			-42
		],
		[
			-24,
			31
		],
		[
			-144,
			0
		],
		[
			-108,
			52
		],
		[
			-103,
			-10
		],
		[
			-78,
			-125
		],
		[
			-66,
			-20
		],
		[
			0,
			-42
		],
		[
			-84,
			21
		],
		[
			-18,
			-93
		],
		[
			-36,
			-42
		],
		[
			-60,
			0
		],
		[
			-97,
			-51
		],
		[
			-102,
			10
		],
		[
			-72,
			-10
		],
		[
			-54,
			-94
		],
		[
			-120,
			21
		],
		[
			-78,
			0
		]
	],
	[
		[
			20479,
			62742
		],
		[
			66,
			83
		],
		[
			24,
			83
		],
		[
			78,
			145
		],
		[
			-66,
			-11
		],
		[
			-72,
			-176
		],
		[
			-42,
			-62
		]
	],
	[
		[
			20467,
			62804
		],
		[
			-73,
			52
		],
		[
			-24,
			73
		],
		[
			54,
			20
		],
		[
			43,
			83
		],
		[
			-18,
			62
		],
		[
			30,
			83
		],
		[
			-55,
			52
		],
		[
			-24,
			62
		],
		[
			61,
			21
		],
		[
			18,
			41
		],
		[
			54,
			21
		],
		[
			36,
			124
		],
		[
			-66,
			-10
		],
		[
			-115,
			72
		],
		[
			-168,
			0
		],
		[
			-60,
			-20
		],
		[
			-12,
			124
		],
		[
			-174,
			0
		],
		[
			-151,
			52
		],
		[
			-42,
			-73
		],
		[
			36,
			-145
		],
		[
			-72,
			-93
		],
		[
			-72,
			-62
		],
		[
			-84,
			-11
		],
		[
			-54,
			52
		],
		[
			-97,
			31
		],
		[
			-102,
			-31
		],
		[
			-30,
			42
		],
		[
			-90,
			72
		],
		[
			-60,
			104
		]
	],
	[
		[
			19156,
			63602
		],
		[
			48,
			72
		],
		[
			96,
			83
		],
		[
			18,
			62
		],
		[
			-108,
			62
		],
		[
			18,
			63
		],
		[
			168,
			72
		],
		[
			30,
			52
		],
		[
			30,
			-11
		],
		[
			151,
			42
		],
		[
			108,
			114
		],
		[
			54,
			21
		],
		[
			144,
			-11
		],
		[
			67,
			21
		],
		[
			162,
			-104
		],
		[
			96,
			21
		],
		[
			156,
			10
		],
		[
			30,
			104
		],
		[
			205,
			72
		],
		[
			48,
			0
		],
		[
			72,
			52
		],
		[
			90,
			21
		],
		[
			109,
			0
		],
		[
			6,
			62
		],
		[
			-175,
			-72
		],
		[
			-78,
			0
		],
		[
			-144,
			-52
		],
		[
			-84,
			0
		],
		[
			-73,
			-52
		],
		[
			-84,
			0
		],
		[
			-84,
			-52
		],
		[
			-114,
			-10
		],
		[
			-36,
			-21
		],
		[
			-18,
			52
		]
	],
	[
		[
			20064,
			64275
		],
		[
			-60,
			-21
		],
		[
			-48,
			31
		],
		[
			-19,
			73
		],
		[
			-90,
			10
		],
		[
			-144,
			-10
		],
		[
			-96,
			52
		],
		[
			48,
			41
		],
		[
			-6,
			73
		],
		[
			42,
			82
		],
		[
			102,
			104
		],
		[
			36,
			21
		],
		[
			102,
			155
		],
		[
			49,
			41
		],
		[
			72,
			104
		],
		[
			30,
			83
		],
		[
			132,
			135
		],
		[
			102,
			155
		],
		[
			181,
			166
		],
		[
			-109,
			93
		],
		[
			-108,
			41
		],
		[
			-66,
			-41
		],
		[
			-48,
			0
		],
		[
			-78,
			52
		],
		[
			-6,
			41
		],
		[
			-157,
			62
		],
		[
			-90,
			-10
		],
		[
			-451,
			0
		],
		[
			-240,
			41
		],
		[
			24,
			-83
		],
		[
			90,
			-31
		],
		[
			24,
			11
		],
		[
			277,
			-52
		],
		[
			156,
			0
		],
		[
			120,
			31
		],
		[
			205,
			-10
		],
		[
			84,
			-63
		],
		[
			54,
			-20
		],
		[
			48,
			10
		],
		[
			84,
			-21
		],
		[
			12,
			-72
		],
		[
			-66,
			-73
		],
		[
			-36,
			-62
		],
		[
			-54,
			-52
		],
		[
			-36,
			-62
		],
		[
			-54,
			-31
		],
		[
			-48,
			-62
		],
		[
			-103,
			-83
		],
		[
			-132,
			-134
		],
		[
			-90,
			10
		],
		[
			-42,
			-31
		],
		[
			42,
			-114
		],
		[
			-18,
			-41
		],
		[
			-108,
			-94
		],
		[
			-24,
			-83
		],
		[
			72,
			-72
		],
		[
			-36,
			-31
		],
		[
			-108,
			-42
		],
		[
			-43,
			-31
		],
		[
			-42,
			-82
		],
		[
			-42,
			82
		],
		[
			-72,
			11
		],
		[
			-60,
			-62
		],
		[
			-54,
			-94
		],
		[
			-90,
			-41
		],
		[
			-12,
			-41
		],
		[
			-66,
			-21
		],
		[
			-19,
			-93
		],
		[
			-66,
			-52
		],
		[
			-12,
			-42
		],
		[
			-132,
			-103
		],
		[
			-84,
			-114
		],
		[
			-42,
			52
		],
		[
			-54,
			-11
		],
		[
			-115,
			-93
		],
		[
			-72,
			-114
		],
		[
			-72,
			-62
		],
		[
			-54,
			-21
		],
		[
			-108,
			-10
		],
		[
			-48,
			21
		],
		[
			-90,
			0
		],
		[
			-6,
			-42
		],
		[
			132,
			-52
		],
		[
			12,
			-51
		],
		[
			-132,
			-176
		],
		[
			-31,
			-83
		],
		[
			-108,
			-114
		],
		[
			-66,
			-114
		],
		[
			-36,
			0
		],
		[
			-30,
			-62
		],
		[
			-66,
			-73
		],
		[
			-66,
			-10
		],
		[
			-30,
			-62
		],
		[
			-127,
			-73
		],
		[
			-42,
			0
		],
		[
			-114,
			-93
		],
		[
			-216,
			-93
		],
		[
			-61,
			-10
		],
		[
			-18,
			103
		],
		[
			-42,
			31
		],
		[
			-186,
			42
		],
		[
			-42,
			51
		],
		[
			-60,
			11
		],
		[
			-18,
			-62
		],
		[
			-103,
			134
		],
		[
			85,
			93
		],
		[
			0,
			63
		],
		[
			54,
			51
		],
		[
			30,
			83
		],
		[
			-84,
			-31
		],
		[
			-48,
			-62
		],
		[
			-55,
			-166
		],
		[
			-48,
			-31
		],
		[
			-126,
			11
		],
		[
			-36,
			31
		],
		[
			-108,
			20
		],
		[
			-114,
			52
		],
		[
			-97,
			21
		],
		[
			-96,
			52
		],
		[
			-96,
			-21
		],
		[
			-42,
			52
		],
		[
			-108,
			62
		],
		[
			-66,
			62
		],
		[
			-67,
			93
		],
		[
			-150,
			176
		],
		[
			-6,
			83
		],
		[
			-36,
			73
		],
		[
			-42,
			0
		],
		[
			-84,
			103
		],
		[
			6,
			83
		],
		[
			-24,
			114
		],
		[
			18,
			41
		],
		[
			90,
			-10
		],
		[
			138,
			10
		],
		[
			54,
			21
		],
		[
			30,
			42
		],
		[
			60,
			-42
		],
		[
			127,
			0
		],
		[
			12,
			42
		],
		[
			66,
			-11
		],
		[
			66,
			-62
		],
		[
			-6,
			-83
		],
		[
			60,
			21
		],
		[
			42,
			-42
		],
		[
			60,
			0
		],
		[
			48,
			-51
		],
		[
			67,
			-21
		],
		[
			54,
			-62
		],
		[
			42,
			-21
		],
		[
			12,
			52
		],
		[
			-126,
			103
		],
		[
			-61,
			-10
		],
		[
			-96,
			73
		],
		[
			-24,
			62
		],
		[
			30,
			41
		],
		[
			133,
			62
		],
		[
			42,
			-31
		],
		[
			78,
			62
		],
		[
			96,
			52
		],
		[
			42,
			42
		],
		[
			120,
			62
		],
		[
			30,
			62
		],
		[
			91,
			62
		],
		[
			48,
			0
		],
		[
			54,
			52
		],
		[
			144,
			-31
		],
		[
			84,
			-104
		],
		[
			18,
			-41
		],
		[
			42,
			20
		],
		[
			103,
			-20
		],
		[
			18,
			-42
		],
		[
			174,
			-10
		],
		[
			66,
			21
		],
		[
			36,
			-31
		],
		[
			108,
			10
		],
		[
			55,
			52
		],
		[
			162,
			0
		],
		[
			108,
			20
		],
		[
			-84,
			73
		],
		[
			-120,
			-31
		],
		[
			-36,
			31
		],
		[
			-61,
			-31
		],
		[
			-60,
			10
		],
		[
			-102,
			-52
		],
		[
			-30,
			11
		],
		[
			-66,
			-31
		],
		[
			-48,
			10
		],
		[
			-60,
			62
		],
		[
			-84,
			0
		],
		[
			-31,
			73
		],
		[
			-78,
			41
		],
		[
			-90,
			83
		],
		[
			-126,
			10
		],
		[
			-78,
			-20
		],
		[
			-36,
			10
		],
		[
			-109,
			-21
		],
		[
			-60,
			-51
		],
		[
			-30,
			-63
		],
		[
			-54,
			-31
		],
		[
			-48,
			-72
		],
		[
			-30,
			0
		],
		[
			-144,
			-114
		]
	],
	[
		[
			16168,
			64099
		],
		[
			-48,
			10
		],
		[
			-43,
			62
		],
		[
			-66,
			-10
		],
		[
			-72,
			-41
		],
		[
			-36,
			10
		]
	],
	[
		[
			15903,
			64130
		],
		[
			-12,
			0
		]
	],
	[
		[
			15891,
			64130
		],
		[
			-30,
			-31
		],
		[
			-48,
			62
		],
		[
			-42,
			-41
		]
	],
	[
		[
			15771,
			64120
		],
		[
			-60,
			20
		],
		[
			-60,
			73
		],
		[
			-61,
			21
		]
	],
	[
		[
			15590,
			64234
		],
		[
			-12,
			0
		]
	],
	[
		[
			15578,
			64234
		],
		[
			-150,
			-83
		],
		[
			-6,
			-52
		],
		[
			-48,
			0
		],
		[
			-72,
			93
		],
		[
			-132,
			0
		],
		[
			-91,
			-21
		],
		[
			-96,
			104
		],
		[
			-90,
			21
		],
		[
			-78,
			-21
		],
		[
			-126,
			-10
		],
		[
			-73,
			62
		],
		[
			-42,
			-11
		],
		[
			-66,
			-51
		],
		[
			-54,
			-73
		],
		[
			-54,
			0
		],
		[
			-60,
			42
		],
		[
			-102,
			-11
		],
		[
			-73,
			21
		],
		[
			-144,
			103
		],
		[
			-72,
			114
		],
		[
			12,
			73
		]
	],
	[
		[
			13961,
			64534
		],
		[
			-12,
			83
		],
		[
			90,
			-21
		],
		[
			24,
			104
		],
		[
			54,
			10
		],
		[
			42,
			-21
		],
		[
			43,
			11
		],
		[
			12,
			72
		],
		[
			-43,
			93
		],
		[
			163,
			-10
		],
		[
			30,
			52
		],
		[
			54,
			31
		],
		[
			78,
			0
		],
		[
			78,
			31
		],
		[
			103,
			0
		],
		[
			54,
			-21
		],
		[
			150,
			-41
		],
		[
			36,
			10
		],
		[
			54,
			62
		],
		[
			60,
			-31
		],
		[
			133,
			11
		],
		[
			12,
			72
		],
		[
			42,
			-31
		],
		[
			138,
			0
		],
		[
			30,
			52
		],
		[
			54,
			0
		],
		[
			12,
			83
		],
		[
			54,
			0
		],
		[
			163,
			-176
		],
		[
			66,
			-32
		],
		[
			12,
			-72
		],
		[
			48,
			-31
		],
		[
			102,
			114
		],
		[
			48,
			0
		],
		[
			54,
			-62
		],
		[
			6,
			-125
		],
		[
			133,
			0
		],
		[
			6,
			104
		],
		[
			-36,
			-10
		],
		[
			-31,
			62
		],
		[
			-126,
			41
		],
		[
			-12,
			62
		],
		[
			-66,
			42
		],
		[
			0,
			52
		],
		[
			54,
			41
		],
		[
			60,
			0
		],
		[
			48,
			-62
		],
		[
			211,
			21
		],
		[
			36,
			62
		],
		[
			84,
			-21
		],
		[
			48,
			21
		],
		[
			42,
			51
		],
		[
			66,
			-82
		],
		[
			36,
			62
		],
		[
			-150,
			62
		],
		[
			-48,
			0
		],
		[
			-84,
			52
		],
		[
			-241,
			83
		],
		[
			18,
			145
		],
		[
			42,
			72
		],
		[
			193,
			0
		],
		[
			12,
			-41
		],
		[
			60,
			82
		],
		[
			78,
			-20
		],
		[
			60,
			10
		],
		[
			66,
			62
		],
		[
			55,
			0
		],
		[
			6,
			42
		],
		[
			66,
			0
		],
		[
			36,
			-31
		],
		[
			42,
			10
		]
	],
	[
		[
			16769,
			65725
		],
		[
			24,
			-21
		],
		[
			96,
			0
		],
		[
			48,
			52
		],
		[
			24,
			124
		],
		[
			60,
			52
		],
		[
			133,
			31
		],
		[
			-6,
			52
		],
		[
			-54,
			31
		],
		[
			-91,
			-41
		],
		[
			-30,
			-63
		],
		[
			-78,
			-51
		],
		[
			-12,
			-104
		],
		[
			-54,
			-10
		],
		[
			-48,
			41
		],
		[
			-48,
			-21
		],
		[
			-60,
			11
		],
		[
			-60,
			52
		],
		[
			-127,
			10
		],
		[
			12,
			52
		],
		[
			133,
			103
		],
		[
			96,
			62
		],
		[
			42,
			-10
		],
		[
			78,
			31
		],
		[
			-72,
			93
		],
		[
			-24,
			-10
		]
	],
	[
		[
			16751,
			66191
		],
		[
			-60,
			-10
		],
		[
			-145,
			0
		],
		[
			-72,
			-42
		],
		[
			-30,
			21
		],
		[
			-150,
			-62
		]
	],
	[
		[
			16294,
			66098
		],
		[
			-78,
			20
		],
		[
			-84,
			-62
		],
		[
			-67,
			31
		],
		[
			-42,
			-10
		],
		[
			-114,
			-83
		],
		[
			-156,
			62
		],
		[
			-48,
			83
		],
		[
			6,
			31
		],
		[
			96,
			11
		],
		[
			54,
			93
		],
		[
			72,
			0
		],
		[
			18,
			-52
		],
		[
			60,
			10
		],
		[
			48,
			-51
		],
		[
			61,
			41
		],
		[
			36,
			73
		],
		[
			-42,
			51
		],
		[
			-49,
			-20
		],
		[
			-72,
			0
		],
		[
			-60,
			124
		],
		[
			72,
			21
		],
		[
			30,
			31
		],
		[
			-12,
			72
		],
		[
			24,
			42
		],
		[
			55,
			0
		],
		[
			-13,
			62
		],
		[
			61,
			176
		],
		[
			18,
			21
		],
		[
			108,
			-32
		],
		[
			-6,
			83
		],
		[
			-132,
			-10
		],
		[
			24,
			72
		],
		[
			0,
			94
		],
		[
			72,
			31
		],
		[
			-18,
			41
		],
		[
			18,
			93
		],
		[
			42,
			-31
		],
		[
			18,
			73
		],
		[
			42,
			21
		],
		[
			180,
			0
		],
		[
			121,
			10
		],
		[
			192,
			31
		],
		[
			30,
			-93
		],
		[
			24,
			-21
		],
		[
			48,
			-135
		],
		[
			66,
			-51
		],
		[
			42,
			10
		],
		[
			73,
			-73
		],
		[
			108,
			-41
		],
		[
			30,
			21
		],
		[
			78,
			-31
		],
		[
			144,
			20
		],
		[
			24,
			52
		],
		[
			79,
			11
		],
		[
			36,
			-32
		],
		[
			60,
			11
		],
		[
			90,
			52
		],
		[
			204,
			62
		],
		[
			103,
			10
		],
		[
			-49,
			52
		],
		[
			-66,
			21
		],
		[
			-66,
			-42
		],
		[
			-42,
			21
		],
		[
			-42,
			-42
		],
		[
			-48,
			0
		],
		[
			-168,
			-51
		],
		[
			-24,
			-31
		],
		[
			-97,
			-42
		],
		[
			-42,
			52
		],
		[
			-54,
			0
		],
		[
			-54,
			52
		],
		[
			-84,
			0
		],
		[
			-120,
			155
		],
		[
			-30,
			83
		],
		[
			84,
			93
		],
		[
			-24,
			52
		],
		[
			-109,
			62
		],
		[
			-78,
			10
		],
		[
			-174,
			-51
		],
		[
			0,
			-62
		],
		[
			-72,
			0
		],
		[
			-18,
			62
		],
		[
			-36,
			31
		],
		[
			-48,
			103
		],
		[
			-37,
			-41
		],
		[
			-90,
			41
		],
		[
			-36,
			83
		],
		[
			48,
			135
		],
		[
			66,
			72
		],
		[
			49,
			11
		],
		[
			36,
			62
		],
		[
			84,
			21
		],
		[
			90,
			113
		],
		[
			48,
			145
		],
		[
			144,
			21
		],
		[
			67,
			-21
		],
		[
			126,
			42
		],
		[
			54,
			41
		],
		[
			72,
			0
		],
		[
			30,
			-41
		],
		[
			54,
			0
		],
		[
			90,
			-31
		],
		[
			115,
			0
		],
		[
			30,
			-73
		],
		[
			48,
			-31
		],
		[
			66,
			-124
		],
		[
			36,
			31
		],
		[
			42,
			-52
		],
		[
			84,
			-31
		],
		[
			109,
			-83
		],
		[
			42,
			145
		],
		[
			114,
			11
		],
		[
			48,
			31
		],
		[
			156,
			20
		],
		[
			66,
			32
		],
		[
			115,
			0
		],
		[
			48,
			82
		],
		[
			-253,
			-62
		],
		[
			-54,
			-31
		],
		[
			-54,
			0
		],
		[
			-36,
			-41
		],
		[
			-72,
			41
		],
		[
			-84,
			-31
		],
		[
			-85,
			0
		],
		[
			-102,
			62
		],
		[
			-42,
			42
		],
		[
			0,
			72
		],
		[
			-48,
			124
		],
		[
			-48,
			11
		],
		[
			-48,
			-21
		],
		[
			-48,
			73
		],
		[
			-24,
			-11
		],
		[
			-115,
			62
		],
		[
			-126,
			-10
		],
		[
			-90,
			-21
		],
		[
			-78,
			0
		],
		[
			-84,
			52
		],
		[
			-91,
			135
		],
		[
			25,
			41
		],
		[
			-25,
			52
		],
		[
			49,
			41
		],
		[
			30,
			63
		],
		[
			102,
			62
		],
		[
			24,
			31
		],
		[
			102,
			62
		],
		[
			24,
			72
		],
		[
			60,
			62
		],
		[
			-96,
			114
		],
		[
			-72,
			0
		],
		[
			-18,
			73
		],
		[
			42,
			72
		],
		[
			72,
			83
		],
		[
			66,
			0
		],
		[
			90,
			31
		],
		[
			61,
			52
		],
		[
			42,
			-31
		],
		[
			54,
			0
		],
		[
			78,
			52
		],
		[
			108,
			31
		],
		[
			96,
			62
		],
		[
			60,
			-21
		],
		[
			37,
			-41
		],
		[
			48,
			-104
		],
		[
			90,
			-72
		],
		[
			36,
			-73
		],
		[
			72,
			-62
		],
		[
			42,
			-10
		],
		[
			120,
			-93
		],
		[
			73,
			-83
		],
		[
			84,
			103
		],
		[
			96,
			52
		],
		[
			-30,
			52
		],
		[
			-48,
			-21
		],
		[
			-157,
			52
		],
		[
			-48,
			0
		],
		[
			-54,
			31
		],
		[
			-120,
			145
		],
		[
			-108,
			62
		],
		[
			-90,
			124
		],
		[
			-6,
			42
		],
		[
			72,
			72
		],
		[
			78,
			52
		],
		[
			48,
			135
		],
		[
			240,
			41
		],
		[
			-6,
			73
		],
		[
			-60,
			-42
		],
		[
			-78,
			11
		],
		[
			-90,
			-42
		],
		[
			-54,
			-52
		],
		[
			12,
			-62
		],
		[
			-60,
			-62
		],
		[
			-78,
			-31
		],
		[
			-67,
			-83
		],
		[
			-66,
			11
		],
		[
			-84,
			-52
		],
		[
			-54,
			41
		],
		[
			-90,
			-83
		],
		[
			-12,
			21
		],
		[
			-102,
			-31
		],
		[
			-18,
			73
		],
		[
			-55,
			0
		],
		[
			-72,
			-42
		],
		[
			-42,
			73
		],
		[
			-144,
			41
		],
		[
			-36,
			-41
		],
		[
			-126,
			-21
		],
		[
			-42,
			21
		],
		[
			-55,
			-21
		],
		[
			-174,
			0
		],
		[
			36,
			83
		],
		[
			-30,
			52
		],
		[
			-12,
			93
		],
		[
			48,
			83
		],
		[
			54,
			41
		],
		[
			48,
			0
		],
		[
			0,
			62
		],
		[
			60,
			21
		],
		[
			31,
			-21
		],
		[
			30,
			145
		],
		[
			132,
			11
		],
		[
			-6,
			51
		],
		[
			90,
			0
		],
		[
			-42,
			-114
		],
		[
			78,
			42
		],
		[
			108,
			-11
		],
		[
			103,
			63
		],
		[
			78,
			31
		],
		[
			42,
			62
		],
		[
			108,
			0
		],
		[
			96,
			-21
		],
		[
			60,
			10
		],
		[
			91,
			83
		],
		[
			60,
			21
		],
		[
			78,
			104
		],
		[
			132,
			82
		],
		[
			78,
			73
		],
		[
			12,
			93
		],
		[
			96,
			124
		],
		[
			-48,
			73
		],
		[
			-60,
			0
		],
		[
			-66,
			-52
		],
		[
			-66,
			-124
		],
		[
			-90,
			-42
		],
		[
			-66,
			-72
		],
		[
			-12,
			-52
		],
		[
			-54,
			-31
		],
		[
			-85,
			-114
		],
		[
			-66,
			-62
		],
		[
			-102,
			-52
		],
		[
			-114,
			11
		],
		[
			-108,
			-42
		],
		[
			-12,
			62
		],
		[
			-181,
			42
		],
		[
			-12,
			114
		],
		[
			36,
			31
		],
		[
			126,
			20
		],
		[
			79,
			73
		],
		[
			-18,
			41
		],
		[
			-79,
			42
		],
		[
			-6,
			41
		],
		[
			42,
			73
		],
		[
			-18,
			52
		],
		[
			-108,
			-187
		],
		[
			-72,
			-52
		],
		[
			-108,
			-31
		],
		[
			-78,
			-72
		],
		[
			-115,
			-42
		],
		[
			-6,
			-20
		],
		[
			-138,
			-114
		],
		[
			-54,
			-62
		],
		[
			-120,
			-52
		],
		[
			-139,
			-11
		],
		[
			-78,
			-20
		],
		[
			-114,
			103
		],
		[
			-12,
			62
		],
		[
			6,
			104
		],
		[
			-90,
			-124
		],
		[
			-12,
			103
		],
		[
			-30,
			73
		],
		[
			36,
			41
		],
		[
			12,
			135
		],
		[
			60,
			-11
		],
		[
			-6,
			63
		],
		[
			-36,
			51
		],
		[
			-36,
			0
		],
		[
			-12,
			73
		],
		[
			60,
			145
		],
		[
			54,
			52
		],
		[
			-66,
			41
		],
		[
			-48,
			-21
		],
		[
			-108,
			-10
		],
		[
			-67,
			31
		],
		[
			-30,
			52
		],
		[
			-6,
			114
		],
		[
			-60,
			134
		],
		[
			24,
			42
		],
		[
			-18,
			83
		],
		[
			24,
			93
		],
		[
			-18,
			31
		],
		[
			97,
			228
		],
		[
			-13,
			72
		],
		[
			43,
			166
		],
		[
			-12,
			93
		],
		[
			78,
			0
		],
		[
			-24,
			125
		],
		[
			72,
			41
		],
		[
			72,
			62
		],
		[
			30,
			0
		],
		[
			60,
			-93
		],
		[
			114,
			-31
		],
		[
			0,
			-62
		],
		[
			67,
			-11
		],
		[
			120,
			-124
		],
		[
			42,
			-83
		],
		[
			84,
			42
		],
		[
			48,
			-31
		],
		[
			6,
			72
		],
		[
			48,
			41
		],
		[
			54,
			-51
		],
		[
			-6,
			-156
		],
		[
			85,
			-72
		],
		[
			60,
			10
		],
		[
			78,
			-114
		],
		[
			42,
			0
		],
		[
			30,
			-62
		],
		[
			30,
			42
		],
		[
			-36,
			82
		],
		[
			6,
			42
		],
		[
			-36,
			124
		],
		[
			48,
			21
		],
		[
			24,
			-52
		],
		[
			78,
			-41
		],
		[
			-6,
			-94
		],
		[
			72,
			0
		],
		[
			42,
			114
		],
		[
			30,
			21
		],
		[
			49,
			-52
		],
		[
			90,
			11
		],
		[
			30,
			41
		],
		[
			42,
			0
		],
		[
			30,
			-52
		],
		[
			78,
			42
		],
		[
			54,
			-42
		],
		[
			102,
			-10
		],
		[
			49,
			31
		],
		[
			6,
			114
		],
		[
			-12,
			41
		],
		[
			-85,
			11
		],
		[
			-54,
			31
		],
		[
			-90,
			-11
		],
		[
			-162,
			11
		],
		[
			-30,
			31
		],
		[
			-97,
			-11
		],
		[
			-72,
			-31
		],
		[
			-90,
			31
		],
		[
			-18,
			-51
		],
		[
			-96,
			10
		],
		[
			-60,
			-52
		],
		[
			-48,
			83
		],
		[
			-72,
			0
		],
		[
			-43,
			83
		],
		[
			-48,
			-21
		],
		[
			6,
			73
		],
		[
			48,
			10
		],
		[
			61,
			-31
		],
		[
			-36,
			104
		],
		[
			-79,
			0
		],
		[
			-120,
			41
		],
		[
			-36,
			31
		],
		[
			-36,
			93
		],
		[
			6,
			104
		],
		[
			-192,
			217
		],
		[
			-103,
			63
		],
		[
			-114,
			41
		],
		[
			-60,
			-41
		],
		[
			-30,
			93
		],
		[
			42,
			31
		],
		[
			6,
			103
		],
		[
			84,
			156
		],
		[
			54,
			62
		],
		[
			-24,
			41
		],
		[
			36,
			94
		],
		[
			72,
			-11
		],
		[
			13,
			42
		],
		[
			84,
			62
		],
		[
			132,
			0
		],
		[
			84,
			-73
		],
		[
			132,
			-31
		],
		[
			24,
			-62
		],
		[
			67,
			145
		],
		[
			-6,
			52
		],
		[
			-61,
			145
		],
		[
			-54,
			41
		],
		[
			-72,
			11
		],
		[
			-60,
			-21
		],
		[
			-96,
			0
		],
		[
			-42,
			21
		],
		[
			-72,
			-11
		],
		[
			-73,
			83
		],
		[
			-54,
			42
		],
		[
			-138,
			10
		],
		[
			-42,
			41
		],
		[
			36,
			94
		],
		[
			-18,
			103
		],
		[
			48,
			124
		],
		[
			6,
			104
		],
		[
			-72,
			207
		],
		[
			-12,
			145
		],
		[
			24,
			73
		],
		[
			6,
			82
		],
		[
			-24,
			73
		],
		[
			42,
			52
		]
	],
	[
		[
			16372,
			75295
		],
		[
			162,
			-31
		],
		[
			36,
			62
		],
		[
			37,
			0
		],
		[
			30,
			52
		],
		[
			138,
			-52
		],
		[
			42,
			10
		],
		[
			36,
			52
		],
		[
			30,
			-31
		],
		[
			102,
			21
		],
		[
			54,
			-32
		],
		[
			18,
			0
		]
	],
	[
		[
			17057,
			75346
		],
		[
			7,
			-72
		],
		[
			-37,
			-93
		],
		[
			12,
			-73
		],
		[
			67,
			11
		],
		[
			-24,
			-83
		],
		[
			24,
			-42
		],
		[
			48,
			0
		],
		[
			60,
			-72
		],
		[
			-36,
			-93
		],
		[
			12,
			-83
		],
		[
			-18,
			-31
		],
		[
			84,
			-114
		],
		[
			36,
			-21
		],
		[
			90,
			-93
		],
		[
			72,
			-93
		],
		[
			66,
			20
		],
		[
			25,
			-20
		],
		[
			48,
			51
		],
		[
			-55,
			42
		],
		[
			-96,
			135
		],
		[
			78,
			62
		],
		[
			37,
			-11
		],
		[
			42,
			-62
		],
		[
			90,
			11
		],
		[
			-12,
			72
		],
		[
			-78,
			10
		],
		[
			-6,
			52
		],
		[
			66,
			93
		],
		[
			18,
			135
		],
		[
			-12,
			93
		],
		[
			-60,
			31
		],
		[
			-85,
			94
		],
		[
			-120,
			31
		],
		[
			-72,
			51
		],
		[
			-42,
			114
		],
		[
			-42,
			52
		],
		[
			12,
			93
		],
		[
			36,
			62
		],
		[
			12,
			83
		],
		[
			66,
			104
		],
		[
			66,
			41
		],
		[
			24,
			52
		],
		[
			91,
			0
		],
		[
			90,
			-41
		],
		[
			60,
			-63
		],
		[
			66,
			42
		],
		[
			84,
			-52
		],
		[
			-48,
			-93
		],
		[
			60,
			-31
		],
		[
			-24,
			-73
		],
		[
			6,
			-72
		],
		[
			84,
			-156
		],
		[
			127,
			-20
		],
		[
			42,
			-31
		],
		[
			114,
			-11
		],
		[
			6,
			-31
		],
		[
			78,
			0
		],
		[
			30,
			-41
		],
		[
			72,
			-21
		],
		[
			24,
			21
		],
		[
			-12,
			155
		],
		[
			78,
			31
		],
		[
			-12,
			52
		],
		[
			31,
			145
		],
		[
			30,
			73
		],
		[
			54,
			72
		],
		[
			54,
			-41
		],
		[
			84,
			0
		],
		[
			48,
			-52
		],
		[
			235,
			-124
		],
		[
			72,
			-63
		],
		[
			24,
			-82
		],
		[
			48,
			-52
		],
		[
			216,
			-93
		],
		[
			127,
			-11
		],
		[
			42,
			-41
		],
		[
			210,
			-73
		],
		[
			24,
			42
		],
		[
			-144,
			103
		],
		[
			12,
			52
		],
		[
			-30,
			41
		],
		[
			-132,
			42
		],
		[
			-151,
			21
		],
		[
			-84,
			31
		],
		[
			-24,
			93
		],
		[
			-36,
			72
		],
		[
			-150,
			125
		],
		[
			-79,
			0
		],
		[
			-90,
			20
		],
		[
			-54,
			-10
		],
		[
			-60,
			31
		],
		[
			0,
			83
		],
		[
			-66,
			62
		],
		[
			48,
			52
		],
		[
			30,
			-21
		],
		[
			90,
			11
		],
		[
			48,
			62
		],
		[
			60,
			0
		],
		[
			31,
			-31
		],
		[
			12,
			-83
		],
		[
			36,
			-52
		],
		[
			54,
			-21
		],
		[
			42,
			-52
		],
		[
			72,
			-31
		],
		[
			102,
			0
		],
		[
			120,
			21
		],
		[
			12,
			21
		],
		[
			199,
			31
		],
		[
			12,
			-31
		],
		[
			96,
			-31
		],
		[
			78,
			-104
		],
		[
			72,
			-31
		],
		[
			18,
			-41
		],
		[
			67,
			-52
		],
		[
			36,
			0
		],
		[
			132,
			-114
		],
		[
			138,
			0
		],
		[
			108,
			-166
		],
		[
			61,
			-145
		],
		[
			72,
			-124
		],
		[
			96,
			-124
		]
	],
	[
		[
			20635,
			74860
		],
		[
			-18,
			31
		],
		[
			36,
			83
		],
		[
			-48,
			72
		],
		[
			-54,
			124
		],
		[
			6,
			42
		],
		[
			-72,
			72
		],
		[
			-24,
			83
		],
		[
			-133,
			93
		],
		[
			-60,
			0
		],
		[
			-30,
			83
		],
		[
			-42,
			52
		],
		[
			-60,
			31
		],
		[
			-60,
			-41
		],
		[
			-18,
			83
		],
		[
			-66,
			62
		],
		[
			-79,
			20
		],
		[
			-30,
			52
		],
		[
			-66,
			52
		],
		[
			-30,
			0
		],
		[
			-36,
			62
		],
		[
			144,
			31
		],
		[
			115,
			114
		],
		[
			-12,
			93
		]
	],
	[
		[
			19998,
			76154
		],
		[
			-48,
			-83
		],
		[
			-25,
			125
		],
		[
			-180,
			0
		],
		[
			-30,
			31
		],
		[
			-72,
			10
		],
		[
			-30,
			83
		],
		[
			-36,
			0
		],
		[
			-84,
			41
		],
		[
			-91,
			0
		],
		[
			-24,
			21
		],
		[
			-120,
			11
		],
		[
			0,
			93
		],
		[
			-78,
			62
		],
		[
			-24,
			62
		],
		[
			-48,
			62
		],
		[
			-48,
			-21
		],
		[
			-79,
			0
		],
		[
			43,
			73
		],
		[
			-61,
			124
		],
		[
			-54,
			42
		],
		[
			-102,
			-21
		],
		[
			-222,
			72
		],
		[
			12,
			63
		],
		[
			36,
			20
		],
		[
			-12,
			94
		],
		[
			-42,
			31
		],
		[
			-85,
			10
		],
		[
			-36,
			31
		],
		[
			-36,
			93
		],
		[
			-30,
			31
		],
		[
			18,
			83
		],
		[
			72,
			114
		],
		[
			37,
			73
		],
		[
			66,
			10
		],
		[
			78,
			-73
		],
		[
			54,
			-10
		],
		[
			48,
			-83
		],
		[
			72,
			-20
		],
		[
			0,
			-52
		],
		[
			66,
			-42
		],
		[
			18,
			-62
		],
		[
			48,
			-10
		],
		[
			43,
			83
		],
		[
			48,
			-11
		],
		[
			54,
			21
		],
		[
			54,
			-93
		],
		[
			72,
			10
		],
		[
			6,
			-41
		],
		[
			96,
			83
		],
		[
			139,
			269
		],
		[
			-19,
			31
		]
	],
	[
		[
			19462,
			77594
		],
		[
			-78,
			52
		],
		[
			-60,
			20
		],
		[
			-30,
			63
		],
		[
			78,
			72
		],
		[
			-18,
			104
		],
		[
			102,
			-31
		],
		[
			55,
			62
		],
		[
			60,
			0
		],
		[
			18,
			52
		],
		[
			54,
			0
		],
		[
			-6,
			62
		],
		[
			-90,
			-21
		],
		[
			-42,
			-41
		],
		[
			-91,
			10
		],
		[
			-18,
			52
		],
		[
			-54,
			-31
		],
		[
			-66,
			31
		],
		[
			24,
			83
		],
		[
			102,
			10
		],
		[
			-6,
			31
		],
		[
			-96,
			-21
		],
		[
			-60,
			-31
		],
		[
			-6,
			83
		],
		[
			-30,
			104
		],
		[
			-90,
			-11
		],
		[
			-30,
			83
		],
		[
			-42,
			31
		],
		[
			-6,
			83
		],
		[
			-73,
			0
		],
		[
			-18,
			135
		],
		[
			-108,
			124
		],
		[
			-144,
			72
		],
		[
			6,
			11
		],
		[
			42,
			52
		],
		[
			0,
			51
		],
		[
			60,
			73
		],
		[
			12,
			31
		],
		[
			54,
			-10
		],
		[
			42,
			-73
		],
		[
			109,
			0
		],
		[
			6,
			0
		],
		[
			30,
			0
		],
		[
			36,
			-93
		],
		[
			96,
			-11
		],
		[
			18,
			-41
		],
		[
			30,
			-52
		],
		[
			42,
			-20
		]
	],
	[
		[
			19276,
			78744
		],
		[
			36,
			10
		],
		[
			30,
			62
		],
		[
			90,
			31
		],
		[
			30,
			52
		],
		[
			115,
			21
		],
		[
			24,
			31
		],
		[
			102,
			-11
		],
		[
			72,
			62
		],
		[
			18,
			-51
		],
		[
			60,
			-31
		],
		[
			133,
			41
		],
		[
			54,
			-52
		],
		[
			54,
			135
		],
		[
			36,
			-62
		],
		[
			42,
			0
		],
		[
			18,
			52
		],
		[
			66,
			10
		],
		[
			54,
			-42
		]
	],
	[
		[
			20310,
			79002
		],
		[
			24,
			94
		],
		[
			78,
			41
		],
		[
			19,
			-52
		],
		[
			114,
			-72
		],
		[
			48,
			-52
		],
		[
			36,
			0
		],
		[
			72,
			-41
		],
		[
			30,
			41
		],
		[
			114,
			-31
		],
		[
			67,
			93
		],
		[
			84,
			-31
		],
		[
			18,
			-135
		],
		[
			60,
			-10
		],
		[
			84,
			-103
		],
		[
			132,
			-21
		],
		[
			42,
			-31
		],
		[
			36,
			-62
		],
		[
			18,
			72
		],
		[
			-48,
			10
		],
		[
			0,
			52
		],
		[
			-96,
			73
		],
		[
			-90,
			52
		],
		[
			-66,
			20
		],
		[
			-24,
			52
		],
		[
			72,
			31
		],
		[
			180,
			-10
		],
		[
			54,
			62
		],
		[
			-162,
			-31
		],
		[
			-90,
			31
		],
		[
			-36,
			-10
		],
		[
			-96,
			51
		],
		[
			-91,
			-10
		]
	],
	[
		[
			20893,
			79075
		],
		[
			-12,
			0
		]
	],
	[
		[
			20881,
			79075
		],
		[
			-30,
			-73
		],
		[
			-54,
			52
		],
		[
			-96,
			-31
		],
		[
			-66,
			42
		],
		[
			-78,
			20
		],
		[
			-126,
			145
		],
		[
			-103,
			21
		],
		[
			12,
			41
		],
		[
			-84,
			73
		],
		[
			-12,
			62
		],
		[
			-48,
			10
		],
		[
			36,
			94
		],
		[
			-18,
			51
		]
	],
	[
		[
			20214,
			79582
		],
		[
			6,
			0
		]
	],
	[
		[
			20220,
			79582
		],
		[
			36,
			32
		],
		[
			-12,
			62
		],
		[
			-60,
			0
		],
		[
			-36,
			-73
		],
		[
			-78,
			21
		],
		[
			-12,
			83
		],
		[
			12,
			103
		],
		[
			-72,
			62
		]
	],
	[
		[
			19998,
			79883
		],
		[
			0,
			10
		],
		[
			36,
			42
		],
		[
			60,
			-31
		],
		[
			-18,
			82
		],
		[
			-36,
			31
		],
		[
			42,
			104
		],
		[
			36,
			10
		],
		[
			36,
			73
		],
		[
			36,
			41
		]
	],
	[
		[
			20190,
			80245
		],
		[
			-18,
			31
		]
	],
	[
		[
			20172,
			80276
		],
		[
			-12,
			94
		],
		[
			30,
			103
		],
		[
			48,
			11
		]
	],
	[
		[
			20238,
			80484
		],
		[
			12,
			-11
		]
	],
	[
		[
			20256,
			80473
		],
		[
			42,
			-41
		],
		[
			90,
			-83
		],
		[
			187,
			-62
		]
	],
	[
		[
			20575,
			80287
		],
		[
			24,
			-42
		],
		[
			42,
			21
		],
		[
			12,
			-52
		],
		[
			84,
			-20
		],
		[
			30,
			-83
		],
		[
			42,
			-11
		],
		[
			36,
			83
		],
		[
			-72,
			52
		],
		[
			6,
			83
		],
		[
			-90,
			10
		],
		[
			-18,
			11
		]
	],
	[
		[
			20671,
			80339
		],
		[
			-60,
			93
		],
		[
			-126,
			0
		],
		[
			-85,
			31
		],
		[
			-24,
			41
		],
		[
			67,
			11
		]
	],
	[
		[
			20443,
			80515
		],
		[
			132,
			10
		],
		[
			0,
			31
		],
		[
			-78,
			10
		]
	],
	[
		[
			20497,
			80566
		],
		[
			-109,
			11
		],
		[
			-24,
			52
		],
		[
			36,
			72
		],
		[
			61,
			31
		]
	],
	[
		[
			20461,
			80732
		],
		[
			120,
			114
		]
	],
	[
		[
			20581,
			80846
		],
		[
			78,
			10
		],
		[
			48,
			-31
		],
		[
			42,
			21
		],
		[
			102,
			-31
		],
		[
			115,
			-104
		],
		[
			108,
			-134
		],
		[
			18,
			52
		],
		[
			-60,
			62
		],
		[
			30,
			62
		],
		[
			-120,
			31
		],
		[
			-18,
			62
		],
		[
			-97,
			31
		],
		[
			-102,
			0
		],
		[
			-138,
			31
		]
	],
	[
		[
			20587,
			80908
		],
		[
			42,
			0
		],
		[
			12,
			52
		],
		[
			-54,
			41
		],
		[
			-54,
			11
		],
		[
			-12,
			93
		],
		[
			-84,
			0
		],
		[
			-19,
			41
		],
		[
			-84,
			11
		],
		[
			-30,
			93
		]
	],
	[
		[
			20304,
			81250
		],
		[
			54,
			114
		],
		[
			-12,
			41
		],
		[
			42,
			114
		],
		[
			109,
			83
		],
		[
			6,
			52
		],
		[
			126,
			-11
		],
		[
			84,
			42
		],
		[
			60,
			83
		],
		[
			30,
			72
		],
		[
			54,
			42
		],
		[
			0,
			83
		],
		[
			97,
			72
		],
		[
			-36,
			104
		],
		[
			48,
			20
		],
		[
			0,
			83
		],
		[
			-24,
			31
		],
		[
			18,
			62
		],
		[
			-18,
			63
		],
		[
			48,
			93
		],
		[
			24,
			10
		]
	],
	[
		[
			21014,
			82503
		],
		[
			36,
			0
		],
		[
			6,
			-10
		],
		[
			36,
			-42
		],
		[
			42,
			-10
		],
		[
			66,
			-52
		],
		[
			72,
			-10
		],
		[
			6,
			-42
		],
		[
			60,
			0
		],
		[
			61,
			73
		],
		[
			48,
			-10
		]
	],
	[
		[
			21447,
			82400
		],
		[
			6,
			0
		],
		[
			228,
			-42
		],
		[
			42,
			31
		],
		[
			72,
			-72
		],
		[
			36,
			0
		],
		[
			85,
			-83
		],
		[
			66,
			21
		],
		[
			42,
			-32
		],
		[
			48,
			-72
		],
		[
			6,
			-104
		],
		[
			-12,
			-51
		],
		[
			18,
			-125
		],
		[
			36,
			-51
		],
		[
			72,
			-32
		],
		[
			36,
			-41
		],
		[
			-18,
			-62
		],
		[
			-90,
			-52
		],
		[
			-42,
			-83
		],
		[
			60,
			-62
		],
		[
			24,
			52
		],
		[
			114,
			124
		],
		[
			36,
			83
		],
		[
			-6,
			41
		],
		[
			-102,
			42
		],
		[
			-54,
			72
		],
		[
			90,
			135
		],
		[
			133,
			-10
		],
		[
			12,
			51
		],
		[
			-73,
			114
		],
		[
			-48,
			11
		],
		[
			6,
			52
		],
		[
			91,
			41
		],
		[
			36,
			-166
		],
		[
			36,
			11
		],
		[
			24,
			-63
		],
		[
			72,
			0
		],
		[
			-24,
			-62
		],
		[
			60,
			-83
		],
		[
			60,
			42
		],
		[
			102,
			-42
		],
		[
			-24,
			-62
		],
		[
			36,
			-31
		],
		[
			109,
			-10
		],
		[
			30,
			-52
		],
		[
			108,
			21
		],
		[
			54,
			-124
		],
		[
			0,
			-52
		],
		[
			-78,
			-83
		],
		[
			-24,
			10
		],
		[
			-96,
			-124
		],
		[
			-6,
			-41
		],
		[
			-145,
			-114
		],
		[
			-102,
			-207
		],
		[
			-72,
			-73
		],
		[
			-60,
			-83
		],
		[
			12,
			-114
		],
		[
			84,
			11
		],
		[
			78,
			155
		],
		[
			48,
			0
		],
		[
			84,
			52
		],
		[
			30,
			52
		],
		[
			49,
			20
		],
		[
			78,
			73
		],
		[
			66,
			0
		],
		[
			-6,
			52
		],
		[
			18,
			165
		],
		[
			42,
			31
		],
		[
			30,
			73
		],
		[
			42,
			31
		],
		[
			42,
			-10
		],
		[
			30,
			31
		],
		[
			84,
			-11
		],
		[
			61,
			42
		],
		[
			6,
			51
		],
		[
			42,
			11
		],
		[
			-18,
			134
		],
		[
			-42,
			73
		],
		[
			42,
			52
		],
		[
			-18,
			83
		],
		[
			90,
			72
		]
	],
	[
		[
			23431,
			82037
		],
		[
			18,
			21
		]
	],
	[
		[
			23449,
			82058
		],
		[
			60,
			-42
		],
		[
			42,
			31
		],
		[
			24,
			0
		]
	],
	[
		[
			23575,
			82047
		],
		[
			30,
			-20
		],
		[
			66,
			41
		]
	],
	[
		[
			23671,
			82068
		],
		[
			36,
			0
		],
		[
			42,
			-10
		],
		[
			43,
			-21
		],
		[
			138,
			-21
		],
		[
			18,
			-20
		],
		[
			6,
			-11
		],
		[
			36,
			-41
		],
		[
			72,
			-42
		],
		[
			36,
			11
		],
		[
			66,
			-31
		],
		[
			24,
			-83
		]
	],
	[
		[
			24188,
			81799
		],
		[
			18,
			-31
		]
	],
	[
		[
			24206,
			81768
		],
		[
			0,
			20
		]
	],
	[
		[
			24206,
			81788
		],
		[
			97,
			32
		],
		[
			30,
			-73
		],
		[
			18,
			-104
		],
		[
			-36,
			-41
		],
		[
			102,
			-103
		],
		[
			-193,
			-166
		],
		[
			-48,
			-114
		],
		[
			18,
			-52
		],
		[
			-42,
			-52
		],
		[
			-42,
			-114
		],
		[
			0,
			-93
		],
		[
			-60,
			-41
		],
		[
			48,
			-62
		],
		[
			66,
			82
		],
		[
			0,
			42
		],
		[
			66,
			41
		],
		[
			30,
			83
		],
		[
			103,
			83
		],
		[
			12,
			104
		],
		[
			96,
			93
		],
		[
			42,
			62
		],
		[
			78,
			10
		],
		[
			78,
			145
		],
		[
			72,
			93
		],
		[
			79,
			52
		],
		[
			162,
			0
		],
		[
			60,
			21
		],
		[
			78,
			-31
		],
		[
			72,
			0
		],
		[
			97,
			-73
		],
		[
			0,
			-62
		],
		[
			138,
			0
		],
		[
			-18,
			73
		],
		[
			48,
			20
		],
		[
			54,
			-20
		]
	],
	[
		[
			25517,
			81612
		],
		[
			18,
			73
		]
	],
	[
		[
			25535,
			81685
		],
		[
			54,
			0
		],
		[
			-12,
			103
		]
	],
	[
		[
			25577,
			81788
		],
		[
			30,
			11
		],
		[
			42,
			0
		],
		[
			42,
			-52
		]
	],
	[
		[
			25691,
			81747
		],
		[
			6,
			-10
		],
		[
			37,
			0
		]
	],
	[
		[
			25734,
			81737
		],
		[
			18,
			0
		]
	],
	[
		[
			25752,
			81737
		],
		[
			42,
			0
		],
		[
			54,
			-11
		],
		[
			6,
			0
		],
		[
			0,
			11
		]
	],
	[
		[
			25854,
			81737
		],
		[
			0,
			10
		]
	],
	[
		[
			25854,
			81747
		],
		[
			6,
			0
		],
		[
			12,
			0
		],
		[
			18,
			10
		]
	],
	[
		[
			25890,
			81757
		],
		[
			12,
			63
		],
		[
			42,
			72
		],
		[
			12,
			21
		]
	],
	[
		[
			25956,
			81913
		],
		[
			90,
			-21
		],
		[
			12,
			41
		],
		[
			72,
			21
		]
	],
	[
		[
			26130,
			81954
		],
		[
			42,
			-83
		],
		[
			55,
			31
		],
		[
			54,
			-62
		],
		[
			36,
			31
		],
		[
			18,
			-72
		],
		[
			60,
			0
		],
		[
			0,
			103
		]
	],
	[
		[
			26395,
			81902
		],
		[
			18,
			11
		]
	],
	[
		[
			26413,
			81913
		],
		[
			42,
			31
		]
	],
	[
		[
			26461,
			81944
		],
		[
			12,
			0
		]
	],
	[
		[
			26473,
			81944
		],
		[
			48,
			62
		]
	],
	[
		[
			26521,
			82006
		],
		[
			-6,
			21
		]
	],
	[
		[
			26515,
			82027
		],
		[
			6,
			72
		],
		[
			30,
			62
		],
		[
			72,
			0
		]
	],
	[
		[
			26623,
			82161
		],
		[
			30,
			11
		],
		[
			61,
			20
		],
		[
			30,
			-62
		],
		[
			12,
			-114
		],
		[
			6,
			0
		],
		[
			24,
			-93
		],
		[
			48,
			0
		],
		[
			54,
			42
		],
		[
			126,
			0
		],
		[
			24,
			31
		],
		[
			54,
			-11
		],
		[
			42,
			-52
		],
		[
			18,
			52
		],
		[
			97,
			-41
		],
		[
			24,
			-83
		],
		[
			48,
			-10
		],
		[
			18,
			62
		],
		[
			102,
			31
		],
		[
			24,
			-21
		],
		[
			108,
			-21
		],
		[
			36,
			11
		]
	],
	[
		[
			27609,
			81913
		],
		[
			12,
			-11
		]
	],
	[
		[
			27621,
			81902
		],
		[
			67,
			21
		],
		[
			30,
			31
		],
		[
			120,
			-10
		],
		[
			114,
			52
		],
		[
			42,
			-11
		],
		[
			30,
			-83
		],
		[
			84,
			21
		],
		[
			13,
			83
		],
		[
			84,
			41
		]
	],
	[
		[
			28205,
			82047
		],
		[
			12,
			0
		],
		[
			30,
			0
		],
		[
			108,
			104
		],
		[
			6,
			21
		],
		[
			192,
			124
		],
		[
			85,
			31
		],
		[
			54,
			-21
		],
		[
			24,
			104
		],
		[
			90,
			31
		],
		[
			36,
			-41
		],
		[
			114,
			-11
		],
		[
			72,
			11
		],
		[
			175,
			10
		],
		[
			156,
			62
		],
		[
			120,
			-21
		],
		[
			-6,
			-51
		],
		[
			-84,
			-73
		],
		[
			36,
			-52
		],
		[
			96,
			-31
		],
		[
			24,
			-31
		],
		[
			97,
			31
		],
		[
			18,
			31
		],
		[
			90,
			52
		],
		[
			60,
			0
		],
		[
			72,
			31
		],
		[
			60,
			0
		],
		[
			48,
			-31
		],
		[
			79,
			21
		],
		[
			-6,
			-52
		],
		[
			144,
			-41
		],
		[
			96,
			10
		],
		[
			84,
			-62
		],
		[
			48,
			-11
		],
		[
			97,
			73
		],
		[
			48,
			114
		],
		[
			-18,
			52
		],
		[
			-127,
			31
		],
		[
			-18,
			51
		],
		[
			-48,
			0
		],
		[
			-174,
			104
		],
		[
			30,
			176
		],
		[
			48,
			62
		],
		[
			120,
			52
		],
		[
			84,
			0
		],
		[
			55,
			-62
		],
		[
			12,
			-62
		],
		[
			48,
			-93
		],
		[
			174,
			0
		],
		[
			42,
			-21
		],
		[
			90,
			10
		],
		[
			109,
			73
		],
		[
			108,
			-11
		],
		[
			66,
			11
		],
		[
			18,
			-42
		],
		[
			84,
			11
		],
		[
			30,
			41
		],
		[
			54,
			10
		]
	],
	[
		[
			31938,
			83125
		],
		[
			-6,
			-32
		],
		[
			67,
			-51
		],
		[
			-36,
			-114
		],
		[
			-7,
			-21
		],
		[
			-126,
			0
		],
		[
			12,
			104
		]
	],
	[
		[
			31842,
			83011
		],
		[
			30,
			134
		],
		[
			66,
			-20
		]
	],
	[
		[
			23256,
			57108
		],
		[
			-18,
			-73
		],
		[
			-96,
			-93
		],
		[
			18,
			-52
		],
		[
			90,
			-20
		],
		[
			12,
			-114
		],
		[
			49,
			-166
		],
		[
			-25,
			-72
		],
		[
			-90,
			-73
		],
		[
			12,
			-103
		],
		[
			-36,
			-21
		],
		[
			-18,
			-62
		],
		[
			-132,
			0
		],
		[
			-132,
			-21
		],
		[
			-36,
			21
		],
		[
			-97,
			0
		],
		[
			-30,
			52
		],
		[
			-72,
			51
		],
		[
			-66,
			11
		],
		[
			-120,
			-31
		]
	],
	[
		[
			22469,
			56342
		],
		[
			-90,
			103
		],
		[
			-6,
			31
		],
		[
			-73,
			52
		]
	],
	[
		[
			22300,
			56528
		],
		[
			-78,
			31
		],
		[
			-30,
			52
		],
		[
			-6,
			134
		],
		[
			-72,
			-20
		],
		[
			-198,
			-135
		]
	],
	[
		[
			21916,
			56590
		],
		[
			-157,
			-21
		],
		[
			-90,
			11
		]
	],
	[
		[
			21669,
			56580
		],
		[
			0,
			72
		],
		[
			-54,
			83
		],
		[
			18,
			42
		],
		[
			78,
			62
		],
		[
			12,
			155
		],
		[
			30,
			10
		],
		[
			-6,
			94
		],
		[
			-30,
			31
		],
		[
			12,
			83
		],
		[
			145,
			82
		],
		[
			96,
			42
		],
		[
			36,
			0
		],
		[
			60,
			72
		],
		[
			54,
			-51
		],
		[
			54,
			0
		],
		[
			18,
			51
		],
		[
			90,
			0
		],
		[
			115,
			-51
		],
		[
			90,
			-94
		],
		[
			48,
			-20
		],
		[
			78,
			10
		],
		[
			180,
			-83
		],
		[
			73,
			-10
		],
		[
			66,
			-31
		],
		[
			276,
			0
		],
		[
			48,
			-21
		]
	],
	[
		[
			33466,
			56052
		],
		[
			-36,
			51
		],
		[
			-61,
			21
		],
		[
			-42,
			-21
		],
		[
			-24,
			-93
		],
		[
			-72,
			-83
		],
		[
			-60,
			42
		],
		[
			-48,
			-42
		],
		[
			-72,
			-31
		],
		[
			-48,
			-83
		],
		[
			-85,
			11
		],
		[
			-12,
			165
		],
		[
			-54,
			63
		],
		[
			-72,
			-52
		],
		[
			-30,
			-73
		],
		[
			-66,
			-62
		],
		[
			-114,
			-83
		],
		[
			-72,
			-20
		],
		[
			-211,
			-166
		],
		[
			-144,
			-93
		],
		[
			-84,
			-104
		],
		[
			-78,
			-114
		],
		[
			0,
			-62
		],
		[
			66,
			-83
		],
		[
			-163,
			-62
		],
		[
			-36,
			-41
		],
		[
			-48,
			10
		],
		[
			-24,
			83
		],
		[
			-72,
			41
		],
		[
			42,
			104
		],
		[
			0,
			41
		],
		[
			-84,
			52
		],
		[
			-24,
			73
		],
		[
			30,
			51
		]
	],
	[
		[
			31668,
			55492
		],
		[
			6,
			21
		],
		[
			-102,
			114
		],
		[
			36,
			52
		],
		[
			-102,
			93
		],
		[
			-55,
			124
		],
		[
			-30,
			-52
		],
		[
			-66,
			-62
		],
		[
			-12,
			-51
		],
		[
			-66,
			20
		],
		[
			-60,
			-72
		],
		[
			-84,
			20
		],
		[
			-42,
			-31
		],
		[
			-97,
			-20
		],
		[
			-108,
			41
		],
		[
			18,
			124
		],
		[
			-54,
			-10
		],
		[
			-66,
			31
		],
		[
			-132,
			-10
		],
		[
			-18,
			-31
		],
		[
			-60,
			31
		],
		[
			6,
			52
		],
		[
			-24,
			82
		],
		[
			-49,
			42
		],
		[
			-60,
			103
		]
	],
	[
		[
			30447,
			56103
		],
		[
			79,
			11
		],
		[
			342,
			383
		],
		[
			72,
			0
		],
		[
			85,
			93
		],
		[
			78,
			-52
		],
		[
			36,
			52
		],
		[
			54,
			21
		],
		[
			30,
			52
		],
		[
			132,
			-11
		],
		[
			-12,
			42
		],
		[
			72,
			72
		],
		[
			60,
			-21
		],
		[
			163,
			-20
		],
		[
			90,
			0
		],
		[
			198,
			83
		],
		[
			91,
			0
		],
		[
			-6,
			51
		],
		[
			-109,
			94
		],
		[
			30,
			145
		],
		[
			133,
			20
		]
	],
	[
		[
			33436,
			73834
		],
		[
			30,
			-82
		],
		[
			108,
			-52
		],
		[
			120,
			41
		],
		[
			30,
			-21
		]
	],
	[
		[
			33724,
			73720
		],
		[
			-6,
			-279
		],
		[
			66,
			-31
		],
		[
			48,
			-73
		],
		[
			61,
			-31
		],
		[
			-43,
			-72
		],
		[
			-48,
			-166
		],
		[
			-102,
			-135
		],
		[
			78,
			-51
		],
		[
			54,
			-83
		],
		[
			12,
			-83
		],
		[
			30,
			-42
		],
		[
			91,
			-41
		],
		[
			66,
			10
		],
		[
			-6,
			-124
		],
		[
			72,
			-31
		],
		[
			42,
			21
		],
		[
			54,
			-21
		],
		[
			18,
			-73
		],
		[
			6,
			-155
		],
		[
			48,
			-93
		],
		[
			66,
			10
		],
		[
			0,
			62
		],
		[
			61,
			11
		],
		[
			120,
			-11
		],
		[
			12,
			-31
		],
		[
			66,
			0
		],
		[
			-108,
			-114
		],
		[
			-60,
			-10
		],
		[
			-6,
			-41
		],
		[
			-67,
			0
		],
		[
			0,
			-73
		],
		[
			-84,
			21
		],
		[
			-60,
			-93
		],
		[
			-30,
			31
		],
		[
			-108,
			0
		],
		[
			-12,
			31
		],
		[
			-90,
			52
		],
		[
			-24,
			82
		],
		[
			-103,
			-82
		],
		[
			-36,
			-52
		],
		[
			-72,
			41
		],
		[
			-54,
			73
		],
		[
			-42,
			0
		],
		[
			-6,
			83
		],
		[
			-48,
			103
		],
		[
			-144,
			-52
		],
		[
			-73,
			-41
		],
		[
			-120,
			31
		],
		[
			-30,
			-62
		],
		[
			18,
			-42
		],
		[
			-132,
			-124
		],
		[
			-54,
			-21
		],
		[
			-12,
			-41
		],
		[
			24,
			-72
		],
		[
			-211,
			0
		],
		[
			-102,
			-11
		],
		[
			-84,
			-93
		],
		[
			-24,
			-114
		],
		[
			-36,
			-41
		],
		[
			-84,
			-52
		],
		[
			0,
			-52
		],
		[
			-36,
			-72
		],
		[
			36,
			-52
		],
		[
			84,
			10
		],
		[
			72,
			-31
		],
		[
			48,
			21
		],
		[
			60,
			-21
		],
		[
			-30,
			-62
		],
		[
			-54,
			-62
		],
		[
			-78,
			-42
		],
		[
			-78,
			-20
		],
		[
			-66,
			-73
		],
		[
			-6,
			-52
		],
		[
			42,
			-51
		],
		[
			54,
			10
		],
		[
			24,
			-42
		],
		[
			54,
			-10
		],
		[
			42,
			-72
		],
		[
			156,
			-114
		],
		[
			-36,
			-42
		],
		[
			-78,
			-31
		],
		[
			-30,
			-52
		],
		[
			12,
			-72
		],
		[
			42,
			-52
		],
		[
			0,
			-93
		],
		[
			-18,
			-31
		],
		[
			6,
			-93
		],
		[
			54,
			-83
		],
		[
			6,
			-62
		],
		[
			-90,
			-145
		],
		[
			24,
			-83
		],
		[
			-18,
			-42
		],
		[
			-72,
			-62
		],
		[
			-6,
			-41
		],
		[
			-162,
			-62
		],
		[
			-43,
			-42
		],
		[
			-36,
			93
		],
		[
			-72,
			63
		],
		[
			-54,
			-32
		]
	],
	[
		[
			32269,
			69774
		],
		[
			-72,
			42
		],
		[
			-138,
			10
		],
		[
			-12,
			31
		],
		[
			-103,
			-72
		],
		[
			-54,
			41
		],
		[
			-54,
			-52
		],
		[
			-84,
			21
		],
		[
			-18,
			-52
		],
		[
			-78,
			-82
		],
		[
			-30,
			-11
		],
		[
			-114,
			11
		],
		[
			-67,
			-83
		],
		[
			-72,
			10
		],
		[
			-48,
			-52
		],
		[
			-108,
			-165
		],
		[
			-78,
			-187
		],
		[
			54,
			-72
		],
		[
			-18,
			-31
		],
		[
			-84,
			-21
		],
		[
			-36,
			31
		],
		[
			-67,
			-21
		],
		[
			-30,
			-93
		],
		[
			-24,
			21
		],
		[
			-132,
			0
		],
		[
			-114,
			-42
		],
		[
			-150,
			-103
		],
		[
			-31,
			-62
		],
		[
			37,
			-104
		],
		[
			60,
			-31
		],
		[
			-42,
			-83
		],
		[
			90,
			-52
		],
		[
			66,
			-103
		],
		[
			-42,
			-145
		],
		[
			-42,
			-52
		],
		[
			-108,
			-10
		],
		[
			-79,
			-94
		],
		[
			-54,
			-20
		],
		[
			-108,
			31
		],
		[
			-36,
			-21
		],
		[
			-72,
			10
		],
		[
			-6,
			52
		],
		[
			-84,
			-21
		],
		[
			-97,
			-103
		],
		[
			-84,
			10
		],
		[
			-66,
			-20
		],
		[
			-72,
			31
		],
		[
			-42,
			-63
		],
		[
			-78,
			11
		],
		[
			-54,
			-21
		],
		[
			-127,
			42
		],
		[
			-12,
			-42
		],
		[
			-66,
			-41
		],
		[
			-42,
			10
		],
		[
			18,
			124
		],
		[
			-114,
			-20
		],
		[
			-78,
			-83
		],
		[
			-121,
			0
		],
		[
			-54,
			41
		],
		[
			-78,
			-41
		],
		[
			-72,
			31
		],
		[
			-42,
			-73
		],
		[
			-18,
			-114
		],
		[
			-72,
			11
		],
		[
			-30,
			134
		],
		[
			-54,
			104
		]
	],
	[
		[
			28175,
			73120
		],
		[
			18,
			-11
		],
		[
			120,
			31
		],
		[
			12,
			21
		],
		[
			198,
			104
		],
		[
			18,
			62
		],
		[
			42,
			52
		],
		[
			229,
			41
		],
		[
			108,
			0
		],
		[
			54,
			-31
		],
		[
			18,
			-41
		],
		[
			-30,
			-104
		],
		[
			-90,
			-21
		]
	],
	[
		[
			28872,
			73223
		],
		[
			54,
			-10
		],
		[
			18,
			-62
		],
		[
			108,
			21
		],
		[
			133,
			-52
		],
		[
			36,
			62
		],
		[
			-24,
			93
		],
		[
			-108,
			73
		],
		[
			-85,
			82
		],
		[
			253,
			-20
		],
		[
			150,
			0
		],
		[
			114,
			20
		],
		[
			85,
			42
		],
		[
			84,
			72
		],
		[
			42,
			83
		],
		[
			24,
			83
		],
		[
			-24,
			93
		],
		[
			60,
			-10
		],
		[
			138,
			10
		],
		[
			181,
			73
		],
		[
			48,
			41
		],
		[
			48,
			-20
		],
		[
			198,
			62
		],
		[
			223,
			51
		],
		[
			132,
			-41
		],
		[
			84,
			0
		],
		[
			66,
			41
		],
		[
			54,
			-103
		],
		[
			55,
			10
		],
		[
			228,
			-134
		],
		[
			204,
			-73
		],
		[
			121,
			-52
		],
		[
			336,
			-114
		],
		[
			61,
			11
		],
		[
			42,
			-62
		],
		[
			66,
			31
		],
		[
			36,
			-21
		],
		[
			162,
			-31
		],
		[
			84,
			-31
		],
		[
			133,
			-11
		],
		[
			60,
			21
		],
		[
			60,
			62
		],
		[
			90,
			42
		],
		[
			150,
			31
		],
		[
			6,
			31
		],
		[
			109,
			31
		],
		[
			54,
			93
		],
		[
			54,
			21
		],
		[
			60,
			-10
		],
		[
			12,
			31
		],
		[
			60,
			-11
		],
		[
			66,
			42
		],
		[
			96,
			-11
		],
		[
			67,
			31
		]
	],
	[
		[
			20677,
			53183
		],
		[
			-54,
			-21
		],
		[
			-36,
			104
		],
		[
			-60,
			31
		],
		[
			-12,
			82
		],
		[
			78,
			11
		],
		[
			66,
			-114
		],
		[
			18,
			-93
		]
	],
	[
		[
			20148,
			53804
		],
		[
			-6,
			10
		]
	],
	[
		[
			20142,
			53814
		],
		[
			6,
			-10
		]
	],
	[
		[
			20148,
			53804
		],
		[
			48,
			-31
		],
		[
			96,
			0
		],
		[
			120,
			-52
		],
		[
			55,
			-93
		],
		[
			84,
			-83
		],
		[
			-84,
			-72
		],
		[
			-103,
			-31
		],
		[
			-78,
			-94
		],
		[
			24,
			-72
		],
		[
			78,
			-31
		],
		[
			73,
			-62
		],
		[
			90,
			-42
		],
		[
			18,
			-31
		],
		[
			-78,
			-83
		],
		[
			-6,
			-103
		],
		[
			84,
			-207
		],
		[
			-18,
			-94
		],
		[
			-66,
			-41
		],
		[
			-61,
			-83
		],
		[
			-84,
			11
		],
		[
			-228,
			0
		],
		[
			-78,
			-73
		],
		[
			-84,
			-10
		],
		[
			-151,
			10
		],
		[
			-102,
			31
		],
		[
			-90,
			0
		]
	],
	[
		[
			19607,
			52468
		],
		[
			-30,
			10
		],
		[
			-60,
			73
		],
		[
			-151,
			62
		],
		[
			-48,
			52
		],
		[
			-96,
			52
		],
		[
			-78,
			176
		],
		[
			0,
			145
		],
		[
			-150,
			83
		],
		[
			18,
			62
		],
		[
			-24,
			155
		],
		[
			12,
			52
		],
		[
			54,
			72
		],
		[
			-6,
			104
		],
		[
			-24,
			72
		],
		[
			-6,
			83
		],
		[
			-49,
			62
		],
		[
			-84,
			73
		],
		[
			-66,
			124
		],
		[
			-18,
			62
		],
		[
			-60,
			73
		],
		[
			6,
			134
		],
		[
			54,
			73
		],
		[
			18,
			62
		],
		[
			12,
			124
		],
		[
			54,
			156
		],
		[
			48,
			72
		],
		[
			61,
			42
		],
		[
			120,
			41
		],
		[
			60,
			145
		],
		[
			30,
			31
		],
		[
			102,
			11
		],
		[
			60,
			103
		],
		[
			48,
			21
		],
		[
			145,
			0
		],
		[
			36,
			-31
		],
		[
			162,
			-73
		],
		[
			138,
			-93
		],
		[
			30,
			-52
		],
		[
			175,
			-145
		],
		[
			60,
			-124
		],
		[
			-24,
			-41
		],
		[
			66,
			-94
		],
		[
			30,
			-83
		],
		[
			12,
			-145
		],
		[
			48,
			-145
		],
		[
			-30,
			-93
		],
		[
			-114,
			-93
		],
		[
			-6,
			-104
		]
	],
	[
		[
			21386,
			55264
		],
		[
			-30,
			-82
		],
		[
			-18,
			-125
		],
		[
			-30,
			-31
		],
		[
			-60,
			42
		],
		[
			-30,
			72
		],
		[
			72,
			73
		],
		[
			96,
			51
		]
	],
	[
		[
			21597,
			55813
		],
		[
			24,
			-20
		],
		[
			-12,
			-197
		],
		[
			36,
			-42
		],
		[
			-48,
			-124
		],
		[
			-60,
			-72
		],
		[
			-30,
			93
		],
		[
			-72,
			-21
		],
		[
			-97,
			-93
		],
		[
			-24,
			104
		],
		[
			30,
			41
		],
		[
			12,
			72
		],
		[
			37,
			21
		],
		[
			42,
			135
		],
		[
			48,
			72
		],
		[
			114,
			31
		]
	],
	[
		[
			22469,
			56342
		],
		[
			-96,
			-42
		],
		[
			-61,
			0
		],
		[
			-6,
			-52
		],
		[
			85,
			-51
		],
		[
			114,
			-94
		],
		[
			132,
			-31
		],
		[
			-48,
			-93
		],
		[
			54,
			-52
		],
		[
			132,
			-20
		],
		[
			73,
			10
		],
		[
			12,
			-52
		],
		[
			54,
			-93
		],
		[
			-18,
			-93
		],
		[
			42,
			-31
		],
		[
			102,
			-145
		],
		[
			78,
			134
		],
		[
			42,
			-93
		],
		[
			42,
			-10
		],
		[
			66,
			20
		],
		[
			133,
			104
		],
		[
			36,
			-10
		],
		[
			36,
			72
		],
		[
			24,
			-41
		],
		[
			48,
			-11
		],
		[
			36,
			-103
		],
		[
			42,
			0
		]
	],
	[
		[
			23383,
			53970
		],
		[
			-79,
			-42
		],
		[
			-240,
			-279
		],
		[
			-60,
			62
		]
	],
	[
		[
			23004,
			53711
		],
		[
			-72,
			176
		],
		[
			-139,
			166
		],
		[
			-18,
			0
		],
		[
			-114,
			93
		],
		[
			-132,
			72
		],
		[
			-48,
			42
		],
		[
			-114,
			41
		],
		[
			-85,
			0
		],
		[
			-36,
			-31
		],
		[
			-36,
			62
		],
		[
			-72,
			42
		],
		[
			-48,
			-42
		],
		[
			-48,
			42
		],
		[
			48,
			83
		],
		[
			-78,
			82
		],
		[
			-60,
			83
		],
		[
			-103,
			94
		],
		[
			-24,
			72
		],
		[
			-96,
			52
		],
		[
			-12,
			31
		],
		[
			-138,
			52
		],
		[
			18,
			176
		],
		[
			-6,
			52
		],
		[
			48,
			41
		],
		[
			60,
			10
		],
		[
			78,
			83
		],
		[
			0,
			93
		],
		[
			72,
			31
		],
		[
			12,
			52
		],
		[
			6,
			176
		],
		[
			-78,
			145
		],
		[
			-6,
			83
		],
		[
			-48,
			52
		],
		[
			-60,
			145
		],
		[
			0,
			93
		],
		[
			-18,
			83
		],
		[
			12,
			62
		],
		[
			0,
			280
		]
	],
	[
		[
			32967,
			83093
		],
		[
			84,
			11
		],
		[
			6,
			-42
		],
		[
			-72,
			0
		],
		[
			-18,
			31
		]
	],
	[
		[
			32251,
			83539
		],
		[
			-6,
			0
		],
		[
			-84,
			0
		]
	],
	[
		[
			32161,
			83539
		],
		[
			48,
			21
		],
		[
			6,
			51
		],
		[
			66,
			73
		],
		[
			0,
			-104
		],
		[
			-30,
			-41
		]
	],
	[
		[
			32203,
			84554
		],
		[
			-96,
			-11
		],
		[
			-169,
			-113
		],
		[
			55,
			-32
		],
		[
			78,
			32
		],
		[
			54,
			-145
		],
		[
			-66,
			-11
		],
		[
			-66,
			52
		],
		[
			-30,
			-62
		],
		[
			-85,
			21
		],
		[
			-36,
			-32
		],
		[
			-66,
			32
		],
		[
			-48,
			113
		],
		[
			24,
			42
		],
		[
			66,
			21
		],
		[
			18,
			41
		],
		[
			72,
			31
		],
		[
			283,
			62
		],
		[
			12,
			-41
		]
	],
	[
		[
			31656,
			84440
		],
		[
			-78,
			21
		],
		[
			-12,
			62
		],
		[
			-36,
			52
		],
		[
			42,
			72
		],
		[
			138,
			-124
		],
		[
			-54,
			-83
		]
	],
	[
		[
			32816,
			84699
		],
		[
			-138,
			-104
		],
		[
			-24,
			62
		],
		[
			120,
			42
		],
		[
			42,
			0
		]
	],
	[
		[
			31632,
			84823
		],
		[
			-72,
			52
		],
		[
			30,
			41
		],
		[
			72,
			-41
		],
		[
			-30,
			-52
		]
	],
	[
		[
			34518,
			85082
		],
		[
			-102,
			-93
		],
		[
			24,
			93
		],
		[
			78,
			0
		]
	],
	[
		[
			31439,
			83922
		],
		[
			-36,
			0
		],
		[
			-84,
			41
		],
		[
			-78,
			32
		],
		[
			-18,
			-42
		],
		[
			66,
			-31
		],
		[
			-36,
			-52
		],
		[
			-60,
			21
		]
	],
	[
		[
			31193,
			83891
		],
		[
			-6,
			0
		],
		[
			-42,
			62
		],
		[
			-169,
			-10
		],
		[
			-72,
			-42
		],
		[
			-48,
			31
		],
		[
			-60,
			94
		],
		[
			-90,
			103
		],
		[
			6,
			62
		],
		[
			-42,
			31
		],
		[
			-6,
			94
		],
		[
			-60,
			20
		],
		[
			-78,
			94
		],
		[
			-43,
			10
		],
		[
			-54,
			93
		],
		[
			-36,
			155
		],
		[
			-6,
			83
		],
		[
			-66,
			31
		],
		[
			-72,
			-20
		],
		[
			-78,
			31
		],
		[
			-102,
			-11
		],
		[
			6,
			83
		],
		[
			60,
			104
		],
		[
			0,
			93
		],
		[
			54,
			124
		],
		[
			108,
			93
		],
		[
			78,
			-20
		],
		[
			72,
			62
		],
		[
			103,
			31
		],
		[
			54,
			-31
		],
		[
			96,
			-10
		],
		[
			-18,
			-52
		],
		[
			48,
			-52
		],
		[
			12,
			-83
		],
		[
			186,
			-21
		],
		[
			85,
			-41
		],
		[
			204,
			-124
		],
		[
			54,
			-52
		],
		[
			60,
			-21
		],
		[
			30,
			-41
		],
		[
			-36,
			-62
		],
		[
			0,
			-73
		],
		[
			30,
			-41
		],
		[
			54,
			-11
		],
		[
			24,
			-82
		],
		[
			-90,
			-63
		],
		[
			72,
			-93
		],
		[
			12,
			-41
		],
		[
			61,
			10
		],
		[
			84,
			-21
		],
		[
			24,
			-41
		],
		[
			-78,
			-62
		],
		[
			-79,
			-11
		],
		[
			-72,
			-62
		],
		[
			-90,
			-41
		],
		[
			-102,
			0
		],
		[
			-36,
			-31
		],
		[
			-42,
			-124
		],
		[
			120,
			-21
		],
		[
			54,
			21
		],
		[
			66,
			82
		],
		[
			12,
			42
		],
		[
			108,
			0
		],
		[
			67,
			31
		],
		[
			102,
			-10
		],
		[
			42,
			41
		],
		[
			54,
			10
		],
		[
			48,
			-31
		],
		[
			-12,
			-134
		],
		[
			-66,
			-73
		],
		[
			-48,
			10
		],
		[
			-102,
			-41
		],
		[
			-103,
			0
		]
	],
	[
		[
			30796,
			85455
		],
		[
			96,
			-31
		],
		[
			54,
			-52
		],
		[
			55,
			41
		],
		[
			42,
			-62
		],
		[
			-6,
			-52
		],
		[
			-91,
			-41
		],
		[
			-150,
			62
		],
		[
			-30,
			114
		],
		[
			30,
			21
		]
	],
	[
		[
			33568,
			85548
		],
		[
			6,
			0
		],
		[
			-6,
			0
		]
	],
	[
		[
			34271,
			85683
		],
		[
			-6,
			0
		]
	],
	[
		[
			34265,
			85683
		],
		[
			6,
			0
		]
	],
	[
		[
			30477,
			86149
		],
		[
			-6,
			-11
		]
	],
	[
		[
			30471,
			86138
		],
		[
			0,
			11
		]
	],
	[
		[
			30471,
			86149
		],
		[
			6,
			0
		]
	],
	[
		[
			30483,
			86211
		],
		[
			-6,
			0
		]
	],
	[
		[
			30477,
			86211
		],
		[
			6,
			0
		]
	],
	[
		[
			33165,
			86273
		],
		[
			6,
			-72
		],
		[
			-42,
			0
		],
		[
			-12,
			62
		],
		[
			48,
			10
		]
	],
	[
		[
			35119,
			86294
		],
		[
			-66,
			-42
		],
		[
			-36,
			52
		],
		[
			12,
			73
		],
		[
			90,
			-83
		]
	],
	[
		[
			32888,
			86594
		],
		[
			0,
			-10
		]
	],
	[
		[
			32888,
			86584
		],
		[
			0,
			10
		]
	],
	[
		[
			33508,
			86739
		],
		[
			66,
			31
		],
		[
			72,
			0
		],
		[
			12,
			52
		],
		[
			66,
			10
		],
		[
			0,
			-165
		],
		[
			-48,
			-31
		],
		[
			-72,
			-135
		],
		[
			24,
			-73
		],
		[
			48,
			-62
		],
		[
			24,
			-83
		],
		[
			-156,
			-103
		],
		[
			-18,
			72
		],
		[
			-60,
			-10
		],
		[
			-60,
			62
		],
		[
			-73,
			0
		],
		[
			-36,
			21
		],
		[
			-108,
			-21
		],
		[
			-24,
			42
		],
		[
			-54,
			-11
		],
		[
			-18,
			-41
		],
		[
			-132,
			10
		],
		[
			-6,
			31
		],
		[
			108,
			166
		],
		[
			-6,
			93
		],
		[
			84,
			83
		],
		[
			90,
			-93
		],
		[
			187,
			-42
		],
		[
			54,
			31
		],
		[
			48,
			63
		],
		[
			-30,
			51
		],
		[
			18,
			52
		]
	],
	[
		[
			32774,
			86863
		],
		[
			36,
			-31
		],
		[
			48,
			-124
		],
		[
			-54,
			21
		],
		[
			-72,
			-31
		],
		[
			-24,
			62
		],
		[
			-84,
			10
		],
		[
			18,
			83
		],
		[
			132,
			10
		]
	],
	[
		[
			35179,
			87008
		],
		[
			6,
			-10
		]
	],
	[
		[
			35185,
			86998
		],
		[
			-6,
			10
		]
	],
	[
		[
			30574,
			86936
		],
		[
			-6,
			-10
		]
	],
	[
		[
			30568,
			86926
		],
		[
			-6,
			31
		]
	],
	[
		[
			30562,
			86957
		],
		[
			12,
			-21
		]
	],
	[
		[
			32792,
			87216
		],
		[
			48,
			-11
		],
		[
			18,
			-72
		],
		[
			-90,
			-73
		],
		[
			-54,
			21
		],
		[
			-126,
			0
		],
		[
			72,
			72
		],
		[
			132,
			63
		]
	],
	[
		[
			30778,
			87319
		],
		[
			-6,
			0
		]
	],
	[
		[
			30772,
			87319
		],
		[
			6,
			0
		]
	],
	[
		[
			34770,
			87433
		],
		[
			-12,
			0
		]
	],
	[
		[
			34758,
			87433
		],
		[
			6,
			0
		]
	],
	[
		[
			34764,
			87433
		],
		[
			6,
			0
		]
	],
	[
		[
			31896,
			87329
		],
		[
			-60,
			21
		],
		[
			0,
			52
		],
		[
			102,
			-10
		],
		[
			-42,
			-63
		]
	],
	[
		[
			31944,
			87423
		],
		[
			-6,
			10
		],
		[
			6,
			0
		],
		[
			0,
			-10
		]
	],
	[
		[
			34993,
			87454
		],
		[
			-42,
			-52
		],
		[
			-24,
			41
		],
		[
			36,
			52
		],
		[
			30,
			-41
		]
	],
	[
		[
			31746,
			87267
		],
		[
			78,
			-20
		],
		[
			96,
			-73
		],
		[
			109,
			-52
		],
		[
			48,
			21
		],
		[
			18,
			41
		],
		[
			72,
			-31
		],
		[
			12,
			-72
		],
		[
			102,
			-21
		],
		[
			24,
			-83
		],
		[
			-84,
			-20
		],
		[
			-6,
			-42
		],
		[
			90,
			-10
		],
		[
			24,
			-52
		],
		[
			90,
			-72
		],
		[
			49,
			0
		],
		[
			60,
			-32
		],
		[
			42,
			-134
		],
		[
			-12,
			-104
		],
		[
			-48,
			-10
		],
		[
			-18,
			-93
		],
		[
			-36,
			-31
		],
		[
			-79,
			82
		],
		[
			-90,
			21
		],
		[
			-78,
			-31
		],
		[
			60,
			-93
		],
		[
			-54,
			-62
		],
		[
			-18,
			-73
		],
		[
			-84,
			21
		],
		[
			-42,
			-62
		],
		[
			-48,
			-11
		],
		[
			-67,
			-113
		],
		[
			103,
			-52
		],
		[
			126,
			-31
		],
		[
			84,
			20
		],
		[
			72,
			63
		],
		[
			36,
			51
		],
		[
			79,
			-10
		],
		[
			84,
			10
		],
		[
			48,
			-62
		],
		[
			96,
			-31
		],
		[
			72,
			-52
		],
		[
			6,
			-83
		],
		[
			54,
			-10
		],
		[
			72,
			62
		],
		[
			12,
			145
		],
		[
			85,
			83
		],
		[
			12,
			-93
		],
		[
			84,
			52
		],
		[
			30,
			-114
		],
		[
			6,
			-145
		],
		[
			-54,
			10
		],
		[
			-30,
			-41
		],
		[
			42,
			-73
		],
		[
			-30,
			-72
		],
		[
			36,
			-31
		],
		[
			114,
			10
		],
		[
			72,
			-10
		],
		[
			18,
			93
		],
		[
			30,
			-21
		],
		[
			84,
			155
		],
		[
			43,
			0
		],
		[
			42,
			-51
		],
		[
			102,
			0
		],
		[
			24,
			31
		],
		[
			60,
			10
		],
		[
			48,
			73
		],
		[
			36,
			-52
		],
		[
			6,
			-21
		],
		[
			6,
			-72
		],
		[
			6,
			-21
		]
	],
	[
		[
			33772,
			85776
		],
		[
			-48,
			-52
		],
		[
			-84,
			-31
		],
		[
			-24,
			10
		],
		[
			-60,
			-51
		],
		[
			-84,
			-11
		],
		[
			-12,
			-62
		],
		[
			90,
			-52
		],
		[
			30,
			-124
		],
		[
			-30,
			-104
		],
		[
			132,
			52
		],
		[
			18,
			-62
		],
		[
			42,
			-52
		],
		[
			90,
			-10
		],
		[
			24,
			52
		],
		[
			-6,
			62
		],
		[
			-72,
			-10
		],
		[
			12,
			72
		],
		[
			-24,
			62
		],
		[
			-48,
			42
		],
		[
			-30,
			-11
		]
	],
	[
		[
			33688,
			85496
		],
		[
			12,
			31
		],
		[
			78,
			31
		],
		[
			78,
			-10
		],
		[
			49,
			62
		],
		[
			96,
			31
		],
		[
			42,
			42
		],
		[
			96,
			0
		],
		[
			36,
			51
		],
		[
			60,
			32
		],
		[
			30,
			-11
		],
		[
			0,
			-72
		]
	],
	[
		[
			34265,
			85683
		],
		[
			24,
			0
		],
		[
			-66,
			-218
		],
		[
			24,
			-155
		],
		[
			-24,
			-52
		],
		[
			-114,
			10
		],
		[
			-72,
			31
		],
		[
			-78,
			-103
		],
		[
			-103,
			31
		],
		[
			-102,
			-83
		],
		[
			-30,
			-114
		],
		[
			-102,
			-62
		],
		[
			-12,
			-114
		],
		[
			-48,
			-41
		],
		[
			-12,
			62
		],
		[
			-42,
			21
		],
		[
			-42,
			72
		],
		[
			-91,
			31
		],
		[
			-120,
			73
		],
		[
			-84,
			-42
		],
		[
			30,
			-52
		],
		[
			-96,
			-114
		],
		[
			24,
			-51
		],
		[
			114,
			10
		],
		[
			-30,
			-62
		],
		[
			6,
			-114
		],
		[
			72,
			-31
		],
		[
			0,
			-52
		],
		[
			-138,
			-31
		],
		[
			-24,
			-52
		],
		[
			90,
			-31
		],
		[
			0,
			-124
		],
		[
			-48,
			-21
		],
		[
			-66,
			-62
		],
		[
			-30,
			-103
		],
		[
			-54,
			0
		],
		[
			-36,
			-83
		],
		[
			54,
			-52
		],
		[
			-24,
			-93
		],
		[
			-90,
			-94
		],
		[
			102,
			-82
		],
		[
			78,
			-42
		],
		[
			-36,
			-62
		],
		[
			-18,
			-93
		],
		[
			-48,
			-42
		],
		[
			-127,
			0
		],
		[
			-72,
			-31
		],
		[
			-24,
			31
		],
		[
			0,
			83
		],
		[
			-42,
			0
		],
		[
			-24,
			42
		],
		[
			-48,
			10
		],
		[
			-42,
			73
		],
		[
			6,
			41
		],
		[
			60,
			10
		],
		[
			6,
			145
		],
		[
			-24,
			114
		],
		[
			-36,
			-20
		],
		[
			-84,
			113
		],
		[
			-54,
			0
		],
		[
			-48,
			73
		],
		[
			48,
			72
		],
		[
			60,
			-20
		],
		[
			30,
			-104
		],
		[
			108,
			83
		],
		[
			-6,
			52
		],
		[
			-48,
			0
		],
		[
			-84,
			114
		],
		[
			-114,
			-83
		],
		[
			-31,
			62
		],
		[
			79,
			83
		],
		[
			36,
			0
		],
		[
			102,
			-52
		],
		[
			24,
			42
		],
		[
			132,
			41
		],
		[
			18,
			-93
		],
		[
			72,
			62
		],
		[
			55,
			0
		],
		[
			108,
			41
		],
		[
			-42,
			42
		],
		[
			-199,
			62
		],
		[
			-6,
			41
		],
		[
			120,
			73
		],
		[
			73,
			-11
		],
		[
			66,
			-41
		],
		[
			30,
			10
		],
		[
			-18,
			156
		],
		[
			36,
			62
		],
		[
			54,
			52
		],
		[
			18,
			103
		],
		[
			-120,
			0
		],
		[
			0,
			-52
		],
		[
			-90,
			42
		],
		[
			6,
			72
		],
		[
			-133,
			218
		],
		[
			-36,
			21
		],
		[
			-42,
			82
		],
		[
			-24,
			83
		],
		[
			30,
			135
		],
		[
			-90,
			31
		],
		[
			-54,
			-52
		],
		[
			-60,
			-93
		],
		[
			-96,
			-52
		],
		[
			-139,
			-41
		],
		[
			-78,
			-11
		],
		[
			-132,
			63
		],
		[
			18,
			-114
		],
		[
			-48,
			-21
		],
		[
			-54,
			31
		],
		[
			-91,
			0
		],
		[
			-102,
			-52
		],
		[
			54,
			-52
		],
		[
			-66,
			-41
		],
		[
			-108,
			10
		],
		[
			-42,
			31
		],
		[
			-36,
			-41
		],
		[
			-42,
			10
		],
		[
			-60,
			-51
		],
		[
			-48,
			62
		],
		[
			-61,
			-62
		],
		[
			-54,
			31
		],
		[
			-18,
			51
		],
		[
			-48,
			31
		],
		[
			-54,
			83
		],
		[
			-30,
			94
		],
		[
			24,
			227
		],
		[
			-60,
			52
		],
		[
			-24,
			-10
		],
		[
			-48,
			62
		],
		[
			-48,
			-31
		],
		[
			-36,
			-104
		],
		[
			-85,
			-31
		],
		[
			-48,
			21
		],
		[
			-54,
			-31
		],
		[
			12,
			-83
		],
		[
			-48,
			-10
		],
		[
			-72,
			41
		],
		[
			-66,
			10
		],
		[
			-18,
			52
		],
		[
			-66,
			42
		],
		[
			-42,
			-21
		],
		[
			6,
			93
		],
		[
			-55,
			62
		],
		[
			-6,
			135
		],
		[
			-30,
			31
		],
		[
			42,
			124
		],
		[
			-30,
			31
		]
	],
	[
		[
			30471,
			86138
		],
		[
			6,
			11
		]
	],
	[
		[
			30471,
			86149
		],
		[
			12,
			62
		]
	],
	[
		[
			30477,
			86211
		],
		[
			6,
			10
		],
		[
			30,
			83
		],
		[
			49,
			62
		],
		[
			-42,
			93
		],
		[
			18,
			32
		],
		[
			78,
			-11
		],
		[
			-48,
			124
		],
		[
			6,
			135
		],
		[
			-30,
			52
		],
		[
			24,
			135
		]
	],
	[
		[
			30568,
			86926
		],
		[
			6,
			10
		]
	],
	[
		[
			30574,
			86936
		],
		[
			-12,
			21
		]
	],
	[
		[
			30562,
			86957
		],
		[
			-12,
			62
		],
		[
			48,
			83
		],
		[
			126,
			62
		],
		[
			48,
			134
		],
		[
			0,
			21
		]
	],
	[
		[
			30778,
			87319
		],
		[
			78,
			10
		],
		[
			120,
			11
		],
		[
			73,
			52
		],
		[
			78,
			20
		],
		[
			84,
			42
		],
		[
			48,
			-21
		],
		[
			30,
			31
		],
		[
			96,
			-10
		],
		[
			54,
			10
		],
		[
			43,
			-62
		],
		[
			126,
			-62
		],
		[
			48,
			0
		],
		[
			66,
			-73
		],
		[
			24,
			0
		]
	],
	[
		[
			34764,
			87433
		],
		[
			-60,
			62
		],
		[
			-12,
			-31
		],
		[
			66,
			-103
		],
		[
			54,
			10
		],
		[
			61,
			-31
		],
		[
			0,
			-62
		],
		[
			-31,
			-52
		],
		[
			19,
			-62
		],
		[
			48,
			-62
		],
		[
			78,
			-11
		],
		[
			60,
			42
		],
		[
			114,
			10
		],
		[
			60,
			31
		],
		[
			-42,
			-166
		]
	],
	[
		[
			35185,
			86998
		],
		[
			-6,
			-52
		],
		[
			78,
			-52
		],
		[
			54,
			-10
		],
		[
			-18,
			-10
		],
		[
			-6,
			0
		]
	],
	[
		[
			35287,
			86874
		],
		[
			-66,
			-104
		],
		[
			-60,
			31
		],
		[
			-84,
			0
		],
		[
			-66,
			-72
		],
		[
			-84,
			10
		],
		[
			-42,
			-52
		],
		[
			-49,
			52
		],
		[
			49,
			93
		],
		[
			-24,
			94
		],
		[
			-67,
			31
		],
		[
			-96,
			72
		],
		[
			-84,
			-21
		],
		[
			-42,
			-31
		],
		[
			0,
			-51
		],
		[
			60,
			-94
		],
		[
			-36,
			-51
		],
		[
			0,
			-52
		],
		[
			-126,
			10
		],
		[
			-42,
			-31
		],
		[
			-60,
			52
		],
		[
			12,
			72
		],
		[
			36,
			21
		],
		[
			12,
			62
		],
		[
			42,
			11
		],
		[
			6,
			103
		],
		[
			36,
			31
		],
		[
			132,
			11
		],
		[
			48,
			-21
		],
		[
			48,
			21
		],
		[
			30,
			103
		],
		[
			-48,
			52
		],
		[
			-84,
			41
		],
		[
			-36,
			73
		],
		[
			-78,
			72
		],
		[
			138,
			83
		],
		[
			42,
			42
		],
		[
			72,
			-52
		],
		[
			-6,
			-52
		]
	],
	[
		[
			33003,
			87619
		],
		[
			36,
			-41
		],
		[
			72,
			-21
		],
		[
			-36,
			-124
		],
		[
			6,
			-41
		],
		[
			-30,
			-73
		],
		[
			-12,
			-103
		],
		[
			-66,
			62
		],
		[
			-55,
			134
		],
		[
			-12,
			73
		],
		[
			12,
			93
		],
		[
			85,
			41
		]
	],
	[
		[
			31914,
			87547
		],
		[
			6,
			21
		]
	],
	[
		[
			31920,
			87568
		],
		[
			-18,
			62
		],
		[
			73,
			72
		],
		[
			6,
			62
		],
		[
			72,
			52
		],
		[
			84,
			83
		],
		[
			48,
			-41
		],
		[
			114,
			0
		],
		[
			-6,
			-114
		],
		[
			72,
			-52
		],
		[
			72,
			-10
		],
		[
			175,
			10
		],
		[
			84,
			83
		],
		[
			84,
			0
		],
		[
			6,
			-62
		],
		[
			54,
			0
		],
		[
			6,
			-52
		],
		[
			-96,
			-31
		],
		[
			-36,
			-104
		],
		[
			36,
			-124
		],
		[
			42,
			-73
		],
		[
			-12,
			-41
		],
		[
			-114,
			-41
		],
		[
			-48,
			-31
		],
		[
			-78,
			-11
		],
		[
			-139,
			11
		],
		[
			-66,
			-11
		],
		[
			-96,
			73
		],
		[
			-108,
			31
		],
		[
			-30,
			52
		],
		[
			-90,
			72
		],
		[
			-18,
			73
		],
		[
			-79,
			41
		]
	],
	[
		[
			33604,
			88096
		],
		[
			42,
			-93
		],
		[
			-54,
			-73
		],
		[
			-30,
			83
		],
		[
			6,
			72
		],
		[
			36,
			11
		]
	],
	[
		[
			34259,
			88210
		],
		[
			-6,
			0
		],
		[
			6,
			0
		]
	],
	[
		[
			34079,
			88344
		],
		[
			48,
			-31
		],
		[
			84,
			-124
		],
		[
			-84,
			-21
		],
		[
			-60,
			21
		],
		[
			-36,
			52
		],
		[
			6,
			52
		],
		[
			42,
			51
		]
	],
	[
		[
			33995,
			88365
		],
		[
			0,
			-31
		],
		[
			-54,
			-83
		],
		[
			6,
			-52
		],
		[
			66,
			-10
		],
		[
			102,
			-72
		],
		[
			-18,
			-83
		],
		[
			-42,
			-52
		],
		[
			-66,
			-145
		],
		[
			-54,
			0
		],
		[
			48,
			-104
		],
		[
			6,
			-114
		],
		[
			-18,
			-72
		],
		[
			42,
			-73
		],
		[
			72,
			-31
		],
		[
			-18,
			-82
		],
		[
			-90,
			20
		],
		[
			-103,
			-10
		],
		[
			-48,
			-52
		],
		[
			-42,
			0
		],
		[
			6,
			73
		],
		[
			-36,
			82
		],
		[
			-12,
			83
		],
		[
			-66,
			31
		],
		[
			-30,
			52
		],
		[
			-66,
			31
		],
		[
			-6,
			114
		],
		[
			42,
			11
		],
		[
			108,
			-52
		],
		[
			60,
			10
		],
		[
			66,
			42
		],
		[
			18,
			72
		],
		[
			-6,
			104
		],
		[
			-78,
			51
		],
		[
			18,
			83
		],
		[
			-12,
			135
		],
		[
			181,
			134
		],
		[
			24,
			-10
		]
	],
	[
		[
			35336,
			88842
		],
		[
			-6,
			0
		]
	],
	[
		[
			35330,
			88842
		],
		[
			6,
			0
		]
	],
	[
		[
			35330,
			88842
		],
		[
			6,
			0
		]
	],
	[
		[
			35107,
			88924
		],
		[
			6,
			0
		]
	],
	[
		[
			35113,
			88924
		],
		[
			-6,
			0
		]
	],
	[
		[
			35113,
			88924
		],
		[
			-6,
			0
		]
	],
	[
		[
			35107,
			88924
		],
		[
			6,
			0
		]
	],
	[
		[
			35937,
			88748
		],
		[
			78,
			-103
		],
		[
			-102,
			-42
		],
		[
			-54,
			83
		],
		[
			-91,
			0
		],
		[
			-150,
			-41
		],
		[
			-54,
			-42
		],
		[
			-18,
			-62
		],
		[
			-180,
			-238
		],
		[
			-18,
			-52
		],
		[
			42,
			-62
		],
		[
			48,
			10
		],
		[
			-12,
			-82
		],
		[
			-54,
			41
		],
		[
			-42,
			62
		],
		[
			60,
			135
		],
		[
			6,
			52
		],
		[
			-54,
			31
		],
		[
			-55,
			0
		],
		[
			-24,
			-83
		],
		[
			36,
			-52
		],
		[
			-54,
			-73
		],
		[
			-108,
			32
		],
		[
			-72,
			-42
		],
		[
			0,
			-124
		],
		[
			-66,
			41
		],
		[
			6,
			93
		],
		[
			54,
			0
		],
		[
			0,
			94
		],
		[
			-72,
			-42
		],
		[
			-30,
			11
		],
		[
			-60,
			-83
		],
		[
			-91,
			52
		],
		[
			-60,
			0
		],
		[
			-84,
			-42
		],
		[
			-48,
			-155
		],
		[
			-54,
			-62
		],
		[
			-66,
			-21
		],
		[
			-36,
			-145
		],
		[
			-42,
			93
		],
		[
			-36,
			10
		],
		[
			-19,
			-82
		],
		[
			31,
			-94
		],
		[
			-55,
			-10
		],
		[
			0,
			62
		],
		[
			-36,
			42
		],
		[
			0,
			114
		],
		[
			36,
			124
		],
		[
			67,
			-11
		],
		[
			36,
			73
		],
		[
			24,
			-41
		],
		[
			54,
			41
		],
		[
			42,
			135
		],
		[
			90,
			31
		],
		[
			30,
			41
		],
		[
			90,
			73
		],
		[
			60,
			-11
		],
		[
			55,
			42
		],
		[
			24,
			62
		],
		[
			-6,
			83
		],
		[
			-97,
			62
		],
		[
			36,
			62
		],
		[
			55,
			31
		],
		[
			108,
			0
		],
		[
			90,
			62
		],
		[
			36,
			62
		],
		[
			162,
			-62
		],
		[
			-66,
			-62
		],
		[
			-54,
			0
		],
		[
			-36,
			-52
		],
		[
			0,
			-72
		],
		[
			-36,
			0
		],
		[
			-72,
			-52
		],
		[
			12,
			-124
		],
		[
			162,
			0
		],
		[
			24,
			41
		],
		[
			66,
			10
		],
		[
			6,
			32
		],
		[
			205,
			124
		],
		[
			78,
			62
		],
		[
			78,
			-10
		],
		[
			108,
			31
		],
		[
			6,
			83
		],
		[
			49,
			72
		],
		[
			54,
			41
		],
		[
			66,
			-10
		],
		[
			-30,
			-93
		],
		[
			30,
			-42
		],
		[
			-6,
			-62
		]
	],
	[
		[
			33321,
			88552
		],
		[
			103,
			-21
		],
		[
			84,
			-166
		],
		[
			-36,
			-10
		],
		[
			-85,
			31
		],
		[
			-78,
			-135
		],
		[
			-24,
			-72
		],
		[
			-54,
			-11
		],
		[
			0,
			62
		],
		[
			30,
			42
		],
		[
			42,
			145
		],
		[
			-42,
			31
		],
		[
			-36,
			-10
		],
		[
			-84,
			103
		],
		[
			-48,
			83
		],
		[
			-90,
			52
		],
		[
			-12,
			31
		],
		[
			-109,
			0
		],
		[
			-48,
			41
		],
		[
			-60,
			-20
		],
		[
			30,
			-83
		],
		[
			60,
			-31
		],
		[
			-42,
			-52
		],
		[
			-48,
			10
		],
		[
			-90,
			-52
		],
		[
			-30,
			-41
		],
		[
			-90,
			62
		],
		[
			-24,
			42
		],
		[
			-109,
			51
		],
		[
			43,
			73
		],
		[
			-30,
			93
		],
		[
			0,
			83
		],
		[
			-43,
			72
		],
		[
			-66,
			0
		],
		[
			-72,
			42
		],
		[
			-66,
			62
		],
		[
			-30,
			62
		],
		[
			48,
			21
		],
		[
			42,
			-42
		],
		[
			72,
			0
		],
		[
			54,
			-41
		],
		[
			54,
			62
		],
		[
			97,
			-31
		],
		[
			60,
			52
		],
		[
			102,
			31
		],
		[
			-6,
			72
		],
		[
			30,
			104
		],
		[
			30,
			0
		],
		[
			66,
			52
		],
		[
			72,
			-114
		],
		[
			-60,
			0
		],
		[
			-24,
			-93
		],
		[
			54,
			0
		],
		[
			-24,
			-94
		],
		[
			-102,
			-31
		],
		[
			-48,
			21
		],
		[
			-48,
			-72
		],
		[
			18,
			-42
		],
		[
			78,
			42
		],
		[
			66,
			-42
		],
		[
			30,
			-62
		],
		[
			97,
			21
		],
		[
			12,
			-73
		],
		[
			60,
			0
		],
		[
			84,
			-41
		],
		[
			42,
			31
		],
		[
			96,
			-104
		],
		[
			42,
			-72
		],
		[
			-12,
			-104
		],
		[
			18,
			-52
		],
		[
			54,
			32
		]
	],
	[
		[
			33207,
			89567
		],
		[
			0,
			-11
		]
	],
	[
		[
			33207,
			89556
		],
		[
			0,
			11
		]
	],
	[
		[
			33207,
			89556
		],
		[
			0,
			11
		]
	],
	[
		[
			33207,
			89567
		],
		[
			0,
			51
		],
		[
			42,
			31
		],
		[
			42,
			-10
		],
		[
			48,
			-83
		],
		[
			-18,
			-83
		],
		[
			-66,
			-31
		],
		[
			-30,
			-114
		],
		[
			54,
			-83
		],
		[
			-24,
			-155
		],
		[
			-96,
			31
		],
		[
			-36,
			-62
		],
		[
			-24,
			62
		],
		[
			6,
			114
		],
		[
			-12,
			73
		],
		[
			78,
			114
		],
		[
			0,
			72
		],
		[
			36,
			62
		]
	],
	[
		[
			36147,
			89712
		],
		[
			42,
			-63
		],
		[
			-132,
			-31
		],
		[
			-72,
			-62
		],
		[
			-12,
			-83
		],
		[
			36,
			-114
		],
		[
			-102,
			-62
		],
		[
			-24,
			73
		],
		[
			-66,
			20
		],
		[
			-25,
			32
		],
		[
			12,
			82
		],
		[
			61,
			73
		],
		[
			12,
			83
		],
		[
			180,
			-11
		],
		[
			90,
			63
		]
	],
	[
		[
			30117,
			61344
		],
		[
			24,
			62
		]
	],
	[
		[
			30141,
			61406
		],
		[
			-24,
			-62
		]
	],
	[
		[
			27952,
			66574
		],
		[
			60,
			-103
		],
		[
			54,
			-21
		],
		[
			91,
			72
		],
		[
			114,
			31
		],
		[
			78,
			-20
		],
		[
			42,
			-125
		],
		[
			120,
			-20
		],
		[
			121,
			0
		],
		[
			48,
			155
		],
		[
			78,
			0
		],
		[
			66,
			-52
		],
		[
			24,
			-41
		],
		[
			114,
			31
		],
		[
			48,
			0
		],
		[
			42,
			41
		],
		[
			151,
			11
		],
		[
			48,
			-52
		],
		[
			-12,
			-52
		],
		[
			114,
			-186
		],
		[
			-60,
			-83
		],
		[
			30,
			-62
		],
		[
			84,
			0
		],
		[
			66,
			62
		],
		[
			48,
			-83
		],
		[
			43,
			41
		],
		[
			66,
			11
		],
		[
			66,
			-21
		],
		[
			42,
			-41
		],
		[
			12,
			-52
		],
		[
			42,
			-21
		],
		[
			144,
			0
		],
		[
			66,
			11
		],
		[
			49,
			93
		],
		[
			48,
			10
		],
		[
			48,
			-62
		],
		[
			60,
			10
		],
		[
			36,
			31
		],
		[
			48,
			-41
		],
		[
			72,
			0
		],
		[
			66,
			-52
		]
	],
	[
		[
			30429,
			65994
		],
		[
			-42,
			-52
		],
		[
			6,
			-72
		],
		[
			-72,
			-93
		],
		[
			-42,
			0
		],
		[
			-30,
			-52
		],
		[
			60,
			-31
		],
		[
			96,
			-114
		],
		[
			42,
			10
		],
		[
			103,
			-103
		],
		[
			-91,
			-62
		],
		[
			54,
			-94
		],
		[
			-96,
			-134
		],
		[
			-30,
			-114
		],
		[
			-60,
			-83
		],
		[
			72,
			-145
		],
		[
			48,
			0
		],
		[
			66,
			-52
		],
		[
			-36,
			-93
		],
		[
			85,
			-83
		],
		[
			-18,
			-31
		],
		[
			78,
			-62
		],
		[
			42,
			-83
		],
		[
			96,
			0
		],
		[
			48,
			-72
		],
		[
			24,
			-73
		],
		[
			-6,
			-62
		],
		[
			24,
			-42
		],
		[
			72,
			-51
		],
		[
			0,
			-94
		],
		[
			18,
			-31
		],
		[
			67,
			11
		],
		[
			42,
			41
		],
		[
			90,
			-72
		],
		[
			132,
			-52
		],
		[
			18,
			10
		],
		[
			102,
			-41
		],
		[
			115,
			0
		],
		[
			60,
			-21
		],
		[
			30,
			31
		],
		[
			72,
			11
		],
		[
			36,
			-32
		],
		[
			18,
			-93
		],
		[
			-30,
			-52
		],
		[
			-144,
			-20
		],
		[
			24,
			-62
		]
	],
	[
		[
			31572,
			63685
		],
		[
			-6,
			-42
		],
		[
			-91,
			-21
		],
		[
			61,
			-62
		],
		[
			114,
			31
		],
		[
			60,
			-103
		],
		[
			-66,
			-31
		],
		[
			-12,
			-42
		],
		[
			126,
			-31
		]
	],
	[
		[
			31758,
			63384
		],
		[
			36,
			42
		],
		[
			54,
			20
		],
		[
			78,
			83
		],
		[
			73,
			21
		]
	],
	[
		[
			31999,
			63550
		],
		[
			54,
			21
		],
		[
			18,
			-31
		],
		[
			-78,
			-73
		],
		[
			18,
			-72
		],
		[
			-79,
			-42
		],
		[
			-66,
			-93
		],
		[
			-84,
			-62
		],
		[
			-90,
			-31
		],
		[
			-78,
			-52
		],
		[
			-96,
			-31
		],
		[
			-36,
			-42
		],
		[
			60,
			-134
		],
		[
			90,
			-83
		],
		[
			-54,
			-62
		],
		[
			0,
			-52
		],
		[
			-96,
			-21
		],
		[
			-61,
			21
		],
		[
			-66,
			-10
		],
		[
			24,
			-62
		],
		[
			78,
			-42
		],
		[
			12,
			-93
		],
		[
			145,
			-93
		],
		[
			18,
			-31
		],
		[
			120,
			-21
		],
		[
			-6,
			-83
		],
		[
			78,
			0
		],
		[
			66,
			-114
		],
		[
			175,
			0
		]
	],
	[
		[
			32065,
			62162
		],
		[
			6,
			-52
		],
		[
			102,
			0
		],
		[
			36,
			21
		],
		[
			72,
			-52
		]
	],
	[
		[
			32281,
			62079
		],
		[
			-42,
			-51
		],
		[
			-66,
			-21
		],
		[
			-90,
			0
		],
		[
			-66,
			-104
		],
		[
			-79,
			-52
		],
		[
			-90,
			-31
		],
		[
			-72,
			-72
		],
		[
			-102,
			-124
		],
		[
			-36,
			-63
		],
		[
			-36,
			-10
		],
		[
			-151,
			-166
		],
		[
			-42,
			0
		],
		[
			-36,
			-72
		],
		[
			-156,
			-73
		],
		[
			-72,
			0
		],
		[
			-277,
			-114
		],
		[
			-132,
			52
		],
		[
			-60,
			73
		],
		[
			-90,
			62
		],
		[
			-48,
			10
		],
		[
			-145,
			62
		],
		[
			-102,
			-20
		],
		[
			-42,
			-31
		],
		[
			-66,
			10
		],
		[
			-42,
			62
		]
	],
	[
		[
			30141,
			61406
		],
		[
			-24,
			-62
		]
	],
	[
		[
			30117,
			61344
		],
		[
			42,
			-31
		],
		[
			102,
			10
		],
		[
			96,
			52
		],
		[
			102,
			-52
		],
		[
			79,
			-20
		],
		[
			48,
			-42
		],
		[
			42,
			0
		],
		[
			78,
			-103
		],
		[
			150,
			-83
		],
		[
			90,
			-21
		],
		[
			30,
			10
		]
	],
	[
		[
			27790,
			59614
		],
		[
			-42,
			-10
		],
		[
			-42,
			52
		],
		[
			18,
			103
		],
		[
			-42,
			104
		],
		[
			-42,
			10
		],
		[
			-103,
			-93
		],
		[
			-30,
			52
		],
		[
			-114,
			62
		],
		[
			-18,
			62
		],
		[
			-90,
			-83
		],
		[
			-30,
			52
		],
		[
			-109,
			0
		]
	],
	[
		[
			27146,
			59925
		],
		[
			-36,
			83
		],
		[
			-54,
			72
		],
		[
			-60,
			-10
		],
		[
			-222,
			280
		],
		[
			-115,
			-42
		],
		[
			-72,
			-10
		],
		[
			18,
			62
		],
		[
			-24,
			41
		],
		[
			-78,
			-62
		],
		[
			-54,
			42
		],
		[
			-96,
			114
		],
		[
			-12,
			-73
		],
		[
			-120,
			-41
		],
		[
			-85,
			31
		],
		[
			-18,
			62
		],
		[
			-96,
			62
		],
		[
			-24,
			31
		],
		[
			-60,
			0
		],
		[
			-66,
			52
		],
		[
			-60,
			-10
		],
		[
			-96,
			20
		],
		[
			-55,
			94
		],
		[
			-66,
			0
		],
		[
			-12,
			31
		],
		[
			-84,
			41
		],
		[
			-66,
			62
		],
		[
			60,
			114
		],
		[
			-84,
			114
		],
		[
			24,
			135
		],
		[
			-18,
			165
		],
		[
			258,
			21
		],
		[
			-18,
			93
		],
		[
			18,
			42
		],
		[
			-36,
			528
		],
		[
			18,
			21
		],
		[
			187,
			-104
		],
		[
			18,
			-41
		],
		[
			90,
			93
		],
		[
			36,
			62
		],
		[
			42,
			31
		],
		[
			108,
			-10
		],
		[
			73,
			41
		],
		[
			-25,
			187
		],
		[
			-72,
			93
		],
		[
			-60,
			52
		],
		[
			-96,
			31
		],
		[
			-42,
			41
		],
		[
			-235,
			-145
		],
		[
			-276,
			-62
		],
		[
			-187,
			-93
		],
		[
			-126,
			-31
		],
		[
			-18,
			51
		],
		[
			6,
			114
		],
		[
			-30,
			11
		],
		[
			-36,
			207
		],
		[
			-48,
			0
		],
		[
			-48,
			103
		],
		[
			-36,
			21
		],
		[
			0,
			104
		],
		[
			-42,
			0
		],
		[
			-121,
			62
		],
		[
			-54,
			-11
		],
		[
			-42,
			-113
		],
		[
			-72,
			0
		],
		[
			-72,
			-63
		],
		[
			-30,
			21
		],
		[
			-84,
			-41
		],
		[
			-84,
			20
		],
		[
			-91,
			-82
		],
		[
			-42,
			0
		],
		[
			-96,
			-52
		],
		[
			-102,
			0
		],
		[
			-60,
			52
		],
		[
			-12,
			51
		],
		[
			-84,
			-41
		],
		[
			-43,
			0
		],
		[
			-54,
			-114
		],
		[
			-138,
			-31
		],
		[
			-90,
			10
		],
		[
			-24,
			-41
		],
		[
			-108,
			-31
		],
		[
			-145,
			-124
		],
		[
			30,
			-32
		],
		[
			-42,
			-62
		],
		[
			-66,
			21
		]
	],
	[
		[
			23112,
			62245
		],
		[
			-54,
			31
		],
		[
			-126,
			0
		],
		[
			-66,
			62
		],
		[
			-12,
			42
		],
		[
			48,
			93
		],
		[
			102,
			93
		],
		[
			24,
			73
		],
		[
			0,
			72
		],
		[
			-30,
			83
		],
		[
			-48,
			-10
		],
		[
			-72,
			62
		],
		[
			-48,
			-11
		],
		[
			-55,
			21
		],
		[
			0,
			83
		],
		[
			127,
			52
		],
		[
			84,
			62
		],
		[
			72,
			-11
		],
		[
			48,
			63
		],
		[
			198,
			41
		],
		[
			61,
			21
		],
		[
			114,
			-31
		],
		[
			30,
			51
		],
		[
			-30,
			114
		],
		[
			-60,
			104
		],
		[
			-60,
			41
		],
		[
			-73,
			104
		],
		[
			-96,
			10
		]
	],
	[
		[
			37620,
			55306
		],
		[
			6,
			-21
		]
	],
	[
		[
			37626,
			55285
		],
		[
			-6,
			21
		]
	],
	[
		[
			37855,
			55523
		],
		[
			-48,
			11
		],
		[
			-78,
			-31
		],
		[
			-31,
			-104
		],
		[
			-36,
			-62
		]
	],
	[
		[
			37668,
			55327
		],
		[
			-48,
			-21
		]
	],
	[
		[
			37620,
			55306
		],
		[
			-60,
			10
		]
	],
	[
		[
			29648,
			52230
		],
		[
			-12,
			41
		],
		[
			-91,
			145
		],
		[
			-66,
			21
		],
		[
			-18,
			83
		],
		[
			24,
			83
		],
		[
			30,
			20
		],
		[
			85,
			249
		],
		[
			-36,
			83
		],
		[
			54,
			72
		],
		[
			48,
			145
		],
		[
			54,
			31
		],
		[
			0,
			135
		],
		[
			-42,
			124
		],
		[
			-6,
			73
		],
		[
			78,
			103
		],
		[
			-108,
			125
		],
		[
			-6,
			83
		],
		[
			-103,
			124
		],
		[
			-18,
			134
		],
		[
			30,
			21
		],
		[
			61,
			-10
		],
		[
			108,
			31
		],
		[
			66,
			41
		],
		[
			42,
			114
		],
		[
			-54,
			0
		],
		[
			-18,
			52
		],
		[
			30,
			41
		],
		[
			-6,
			63
		],
		[
			36,
			31
		],
		[
			36,
			72
		],
		[
			84,
			31
		],
		[
			18,
			73
		],
		[
			169,
			155
		],
		[
			120,
			145
		],
		[
			48,
			73
		],
		[
			-24,
			41
		],
		[
			-48,
			-41
		],
		[
			-60,
			0
		],
		[
			-6,
			41
		],
		[
			-108,
			83
		],
		[
			12,
			83
		],
		[
			-43,
			31
		],
		[
			-66,
			207
		]
	],
	[
		[
			29942,
			55482
		],
		[
			-12,
			72
		],
		[
			-48,
			11
		],
		[
			-24,
			41
		],
		[
			-6,
			0
		]
	],
	[
		[
			29852,
			55606
		],
		[
			18,
			31
		],
		[
			175,
			104
		],
		[
			-37,
			72
		],
		[
			55,
			114
		],
		[
			114,
			42
		],
		[
			30,
			41
		],
		[
			90,
			52
		]
	],
	[
		[
			30297,
			56062
		],
		[
			24,
			-10
		],
		[
			126,
			51
		]
	],
	[
		[
			36237,
			57253
		],
		[
			79,
			-73
		],
		[
			78,
			-10
		],
		[
			6,
			-41
		],
		[
			102,
			-31
		],
		[
			138,
			0
		],
		[
			90,
			-42
		],
		[
			151,
			-10
		],
		[
			78,
			62
		],
		[
			60,
			10
		],
		[
			114,
			-10
		],
		[
			90,
			-73
		],
		[
			115,
			-62
		],
		[
			144,
			-20
		],
		[
			12,
			31
		],
		[
			66,
			-11
		],
		[
			42,
			-93
		],
		[
			24,
			-217
		],
		[
			54,
			-11
		],
		[
			79,
			-62
		],
		[
			48,
			21
		],
		[
			102,
			-52
		],
		[
			18,
			-52
		],
		[
			12,
			-145
		],
		[
			48,
			-124
		],
		[
			30,
			0
		],
		[
			54,
			-176
		],
		[
			84,
			-83
		]
	],
	[
		[
			40338,
			90882
		],
		[
			-12,
			0
		]
	],
	[
		[
			40326,
			90882
		],
		[
			6,
			10
		]
	],
	[
		[
			40332,
			90892
		],
		[
			6,
			-10
		]
	],
	[
		[
			40338,
			90892
		],
		[
			0,
			-10
		]
	],
	[
		[
			40332,
			90892
		],
		[
			6,
			0
		]
	],
	[
		[
			40338,
			90944
		],
		[
			-12,
			-10
		]
	],
	[
		[
			40326,
			90934
		],
		[
			12,
			10
		]
	],
	[
		[
			40482,
			91224
		],
		[
			-6,
			0
		]
	],
	[
		[
			40476,
			91224
		],
		[
			6,
			0
		]
	],
	[
		[
			40506,
			90934
		],
		[
			-6,
			-11
		],
		[
			6,
			-62
		]
	],
	[
		[
			40506,
			90861
		],
		[
			-30,
			-10
		],
		[
			-6,
			0
		],
		[
			-114,
			10
		]
	],
	[
		[
			40356,
			90861
		],
		[
			0,
			11
		],
		[
			-18,
			20
		]
	],
	[
		[
			40338,
			90892
		],
		[
			-12,
			42
		]
	],
	[
		[
			40338,
			90944
		],
		[
			42,
			-21
		],
		[
			18,
			125
		]
	],
	[
		[
			40398,
			91048
		],
		[
			6,
			31
		]
	],
	[
		[
			40404,
			91079
		],
		[
			36,
			72
		]
	],
	[
		[
			40440,
			91151
		],
		[
			-12,
			62
		],
		[
			162,
			-10
		],
		[
			18,
			-52
		],
		[
			-24,
			-52
		],
		[
			24,
			-134
		],
		[
			-84,
			0
		],
		[
			-18,
			-31
		]
	],
	[
		[
			40476,
			91224
		],
		[
			6,
			0
		]
	],
	[
		[
			42322,
			94103
		],
		[
			0,
			-10
		]
	],
	[
		[
			42322,
			94093
		],
		[
			0,
			10
		]
	],
	[
		[
			42334,
			94144
		],
		[
			-6,
			-20
		]
	],
	[
		[
			42328,
			94124
		],
		[
			6,
			20
		]
	],
	[
		[
			42557,
			94258
		],
		[
			6,
			-10
		]
	],
	[
		[
			42563,
			94248
		],
		[
			-6,
			10
		]
	],
	[
		[
			41919,
			94393
		],
		[
			-6,
			0
		]
	],
	[
		[
			41913,
			94393
		],
		[
			6,
			0
		]
	],
	[
		[
			41913,
			94393
		],
		[
			-6,
			10
		]
	],
	[
		[
			41907,
			94403
		],
		[
			6,
			-10
		]
	],
	[
		[
			41925,
			94424
		],
		[
			-6,
			-10
		]
	],
	[
		[
			41919,
			94414
		],
		[
			6,
			10
		]
	],
	[
		[
			42033,
			94869
		],
		[
			-6,
			0
		]
	],
	[
		[
			42027,
			94869
		],
		[
			0,
			11
		]
	],
	[
		[
			42027,
			94880
		],
		[
			6,
			-11
		]
	],
	[
		[
			42039,
			94983
		],
		[
			-6,
			-10
		]
	],
	[
		[
			42033,
			94973
		],
		[
			6,
			10
		]
	],
	[
		[
			42033,
			94973
		],
		[
			6,
			10
		]
	],
	[
		[
			42039,
			94983
		],
		[
			-6,
			-10
		]
	],
	[
		[
			42184,
			95025
		],
		[
			-6,
			-11
		]
	],
	[
		[
			42178,
			95014
		],
		[
			6,
			11
		]
	],
	[
		[
			42196,
			95056
		],
		[
			0,
			10
		]
	],
	[
		[
			42196,
			95066
		],
		[
			0,
			-10
		]
	],
	[
		[
			42160,
			95097
		],
		[
			-6,
			0
		]
	],
	[
		[
			42154,
			95097
		],
		[
			6,
			0
		]
	],
	[
		[
			42154,
			95107
		],
		[
			6,
			-10
		]
	],
	[
		[
			42154,
			95097
		],
		[
			-6,
			-10
		]
	],
	[
		[
			42148,
			95087
		],
		[
			0,
			20
		]
	],
	[
		[
			42148,
			95107
		],
		[
			6,
			0
		]
	],
	[
		[
			42148,
			95118
		],
		[
			6,
			-11
		]
	],
	[
		[
			42148,
			95107
		],
		[
			0,
			11
		]
	],
	[
		[
			42100,
			95128
		],
		[
			6,
			-10
		]
	],
	[
		[
			42106,
			95118
		],
		[
			-6,
			10
		]
	],
	[
		[
			42106,
			95118
		],
		[
			6,
			10
		]
	],
	[
		[
			42112,
			95128
		],
		[
			-6,
			-10
		]
	],
	[
		[
			42070,
			95128
		],
		[
			-25,
			11
		]
	],
	[
		[
			42045,
			95139
		],
		[
			25,
			-11
		]
	],
	[
		[
			42623,
			95139
		],
		[
			0,
			10
		]
	],
	[
		[
			42623,
			95149
		],
		[
			0,
			-10
		]
	],
	[
		[
			42076,
			95252
		],
		[
			-6,
			-10
		]
	],
	[
		[
			42070,
			95242
		],
		[
			6,
			10
		]
	],
	[
		[
			42136,
			95356
		],
		[
			0,
			-10
		],
		[
			0,
			10
		]
	],
	[
		[
			42184,
			95480
		],
		[
			0,
			11
		]
	],
	[
		[
			42184,
			95491
		],
		[
			0,
			-11
		]
	],
	[
		[
			43200,
			95397
		],
		[
			-42,
			-10
		],
		[
			-24,
			-52
		],
		[
			-54,
			21
		],
		[
			0,
			41
		],
		[
			-54,
			52
		],
		[
			12,
			62
		],
		[
			42,
			-51
		],
		[
			54,
			0
		],
		[
			66,
			-63
		]
	],
	[
		[
			42051,
			95698
		],
		[
			31,
			0
		],
		[
			48,
			-11
		],
		[
			6,
			0
		],
		[
			-30,
			-31
		],
		[
			-55,
			42
		]
	],
	[
		[
			42076,
			96143
		],
		[
			-6,
			11
		]
	],
	[
		[
			42070,
			96154
		],
		[
			6,
			-11
		]
	],
	[
		[
			42220,
			96205
		],
		[
			114,
			104
		],
		[
			60,
			41
		],
		[
			24,
			-51
		],
		[
			-12,
			-52
		],
		[
			-42,
			-52
		],
		[
			-84,
			-186
		],
		[
			-30,
			-104
		],
		[
			-48,
			-41
		],
		[
			-36,
			20
		],
		[
			66,
			114
		],
		[
			-12,
			42
		],
		[
			18,
			93
		],
		[
			-18,
			72
		]
	],
	[
		[
			43007,
			96537
		],
		[
			-6,
			0
		],
		[
			6,
			0
		]
	],
	[
		[
			42220,
			96205
		],
		[
			-18,
			-83
		],
		[
			-30,
			-31
		],
		[
			-12,
			-114
		],
		[
			-54,
			-10
		],
		[
			-6,
			-72
		],
		[
			-79,
			-73
		],
		[
			-48,
			0
		],
		[
			-12,
			42
		],
		[
			84,
			62
		]
	],
	[
		[
			42045,
			95926
		],
		[
			25,
			51
		],
		[
			18,
			52
		]
	],
	[
		[
			42088,
			96029
		],
		[
			0,
			104
		],
		[
			-12,
			10
		]
	],
	[
		[
			42070,
			96154
		],
		[
			78,
			113
		],
		[
			78,
			21
		],
		[
			6,
			93
		],
		[
			-66,
			21
		],
		[
			12,
			62
		],
		[
			42,
			-41
		],
		[
			42,
			31
		],
		[
			18,
			93
		],
		[
			36,
			-62
		],
		[
			12,
			-73
		],
		[
			-30,
			-72
		],
		[
			-78,
			-135
		]
	],
	[
		[
			38065,
			96568
		],
		[
			0,
			10
		]
	],
	[
		[
			38065,
			96578
		],
		[
			0,
			-10
		]
	],
	[
		[
			41979,
			96485
		],
		[
			-6,
			0
		],
		[
			-18,
			83
		]
	],
	[
		[
			41955,
			96568
		],
		[
			54,
			21
		],
		[
			18,
			-42
		],
		[
			-48,
			-62
		]
	],
	[
		[
			42196,
			96599
		],
		[
			-24,
			-52
		],
		[
			-102,
			31
		]
	],
	[
		[
			42070,
			96578
		],
		[
			36,
			21
		],
		[
			90,
			0
		]
	],
	[
		[
			43741,
			96589
		],
		[
			-6,
			10
		]
	],
	[
		[
			43735,
			96599
		],
		[
			6,
			-10
		]
	],
	[
		[
			42070,
			96578
		],
		[
			0,
			42
		],
		[
			0,
			-42
		]
	],
	[
		[
			43200,
			96651
		],
		[
			6,
			-11
		]
	],
	[
		[
			43206,
			96640
		],
		[
			-6,
			11
		]
	],
	[
		[
			41943,
			96640
		],
		[
			0,
			21
		],
		[
			6,
			0
		],
		[
			-6,
			-21
		]
	],
	[
		[
			42370,
			96361
		],
		[
			-12,
			62
		],
		[
			48,
			31
		],
		[
			-18,
			103
		],
		[
			6,
			63
		],
		[
			36,
			0
		],
		[
			72,
			41
		],
		[
			-24,
			-114
		],
		[
			-6,
			-114
		],
		[
			-102,
			-72
		]
	],
	[
		[
			42070,
			96754
		],
		[
			-19,
			-10
		]
	],
	[
		[
			42051,
			96744
		],
		[
			19,
			10
		]
	],
	[
		[
			42076,
			96744
		],
		[
			0,
			10
		]
	],
	[
		[
			42076,
			96754
		],
		[
			0,
			-10
		]
	],
	[
		[
			41444,
			96827
		],
		[
			0,
			10
		]
	],
	[
		[
			41444,
			96837
		],
		[
			0,
			-10
		]
	],
	[
		[
			42076,
			96754
		],
		[
			-6,
			0
		]
	],
	[
		[
			42070,
			96754
		],
		[
			-19,
			-10
		]
	],
	[
		[
			42051,
			96744
		],
		[
			-36,
			0
		],
		[
			-24,
			52
		],
		[
			36,
			72
		],
		[
			67,
			-21
		],
		[
			-18,
			-93
		]
	],
	[
		[
			37861,
			96899
		],
		[
			12,
			11
		]
	],
	[
		[
			37873,
			96910
		],
		[
			-12,
			-11
		]
	],
	[
		[
			38023,
			96899
		],
		[
			96,
			-145
		],
		[
			-54,
			-176
		]
	],
	[
		[
			38065,
			96568
		],
		[
			-60,
			-93
		],
		[
			-42,
			20
		],
		[
			12,
			0
		],
		[
			-30,
			42
		],
		[
			-60,
			10
		],
		[
			-48,
			42
		],
		[
			-24,
			62
		],
		[
			-133,
			41
		],
		[
			24,
			114
		],
		[
			157,
			93
		]
	],
	[
		[
			37861,
			96899
		],
		[
			12,
			11
		]
	],
	[
		[
			37873,
			96910
		],
		[
			54,
			10
		],
		[
			18,
			-31
		],
		[
			78,
			10
		]
	],
	[
		[
			43921,
			96889
		],
		[
			18,
			-31
		],
		[
			139,
			0
		],
		[
			30,
			-42
		],
		[
			-42,
			-145
		],
		[
			-60,
			11
		],
		[
			-67,
			83
		],
		[
			-12,
			62
		],
		[
			-54,
			-31
		],
		[
			12,
			83
		],
		[
			36,
			10
		]
	],
	[
		[
			41360,
			96941
		],
		[
			-6,
			-11
		]
	],
	[
		[
			41354,
			96930
		],
		[
			0,
			11
		]
	],
	[
		[
			41354,
			96941
		],
		[
			6,
			0
		]
	],
	[
		[
			41354,
			96930
		],
		[
			0,
			11
		]
	],
	[
		[
			41114,
			97127
		],
		[
			-6,
			0
		]
	],
	[
		[
			41108,
			97127
		],
		[
			6,
			0
		]
	],
	[
		[
			41053,
			97127
		],
		[
			0,
			10
		],
		[
			0,
			-10
		]
	],
	[
		[
			43735,
			96599
		],
		[
			6,
			-10
		]
	],
	[
		[
			43741,
			96589
		],
		[
			-12,
			-94
		],
		[
			-36,
			-41
		],
		[
			-90,
			0
		],
		[
			-96,
			41
		],
		[
			-85,
			62
		],
		[
			0,
			83
		],
		[
			-24,
			62
		],
		[
			12,
			52
		],
		[
			42,
			11
		],
		[
			18,
			72
		],
		[
			-18,
			73
		],
		[
			-138,
			72
		],
		[
			-18,
			145
		],
		[
			162,
			10
		],
		[
			73,
			-31
		],
		[
			30,
			11
		],
		[
			48,
			-73
		],
		[
			6,
			114
		],
		[
			42,
			52
		],
		[
			30,
			-10
		],
		[
			36,
			-135
		],
		[
			-18,
			-73
		],
		[
			12,
			-72
		],
		[
			84,
			52
		],
		[
			30,
			62
		],
		[
			12,
			-166
		],
		[
			-18,
			-103
		],
		[
			-54,
			-21
		],
		[
			-36,
			-93
		],
		[
			0,
			-52
		]
	],
	[
		[
			43284,
			97220
		],
		[
			0,
			11
		]
	],
	[
		[
			43284,
			97231
		],
		[
			0,
			-11
		]
	],
	[
		[
			41859,
			97272
		],
		[
			-6,
			0
		]
	],
	[
		[
			41853,
			97272
		],
		[
			6,
			0
		]
	],
	[
		[
			41859,
			97272
		],
		[
			-6,
			0
		]
	],
	[
		[
			41853,
			97272
		],
		[
			6,
			0
		]
	],
	[
		[
			40693,
			97386
		],
		[
			42,
			21
		],
		[
			66,
			-11
		],
		[
			48,
			-51
		],
		[
			-12,
			-83
		],
		[
			-84,
			0
		],
		[
			-18,
			-21
		],
		[
			-72,
			31
		],
		[
			-30,
			41
		],
		[
			60,
			73
		]
	],
	[
		[
			40109,
			97821
		],
		[
			-6,
			0
		]
	],
	[
		[
			40103,
			97821
		],
		[
			6,
			0
		]
	],
	[
		[
			40735,
			98225
		],
		[
			-6,
			0
		]
	],
	[
		[
			40729,
			98225
		],
		[
			6,
			0
		]
	],
	[
		[
			40699,
			98287
		],
		[
			0,
			-10
		]
	],
	[
		[
			40699,
			98277
		],
		[
			0,
			10
		]
	],
	[
		[
			40939,
			98287
		],
		[
			-6,
			10
		],
		[
			6,
			-10
		]
	],
	[
		[
			41029,
			98370
		],
		[
			-6,
			0
		]
	],
	[
		[
			41023,
			98370
		],
		[
			6,
			0
		]
	],
	[
		[
			41023,
			98370
		],
		[
			-6,
			0
		]
	],
	[
		[
			41017,
			98370
		],
		[
			6,
			0
		]
	],
	[
		[
			41059,
			98370
		],
		[
			6,
			10
		]
	],
	[
		[
			41065,
			98380
		],
		[
			-6,
			-10
		]
	],
	[
		[
			40969,
			98401
		],
		[
			-30,
			-52
		]
	],
	[
		[
			40939,
			98349
		],
		[
			18,
			42
		],
		[
			12,
			10
		]
	],
	[
		[
			41546,
			98432
		],
		[
			-12,
			0
		]
	],
	[
		[
			41534,
			98432
		],
		[
			12,
			0
		]
	],
	[
		[
			39947,
			98473
		],
		[
			6,
			-10
		]
	],
	[
		[
			39953,
			98463
		],
		[
			-6,
			10
		]
	],
	[
		[
			39959,
			98473
		],
		[
			-6,
			-10
		]
	],
	[
		[
			39953,
			98463
		],
		[
			0,
			10
		],
		[
			6,
			0
		]
	],
	[
		[
			41318,
			98463
		],
		[
			-6,
			0
		],
		[
			-30,
			10
		]
	],
	[
		[
			41282,
			98473
		],
		[
			36,
			-10
		]
	],
	[
		[
			41589,
			98567
		],
		[
			6,
			-11
		],
		[
			-6,
			11
		]
	],
	[
		[
			40302,
			98629
		],
		[
			-6,
			-11
		]
	],
	[
		[
			40296,
			98618
		],
		[
			0,
			11
		],
		[
			6,
			0
		]
	],
	[
		[
			41312,
			98587
		],
		[
			78,
			63
		],
		[
			18,
			-63
		],
		[
			72,
			0
		],
		[
			18,
			-41
		],
		[
			85,
			-10
		],
		[
			-73,
			-83
		],
		[
			-60,
			-11
		],
		[
			-54,
			-82
		],
		[
			-42,
			82
		],
		[
			42,
			83
		],
		[
			-84,
			-20
		],
		[
			0,
			82
		]
	],
	[
		[
			40091,
			98660
		],
		[
			0,
			-10
		]
	],
	[
		[
			40091,
			98650
		],
		[
			-6,
			0
		]
	],
	[
		[
			40085,
			98650
		],
		[
			6,
			10
		]
	],
	[
		[
			40067,
			98660
		],
		[
			-6,
			-10
		]
	],
	[
		[
			40061,
			98650
		],
		[
			6,
			10
		]
	],
	[
		[
			41901,
			98660
		],
		[
			54,
			-52
		],
		[
			-66,
			-114
		],
		[
			-42,
			-41
		],
		[
			-48,
			62
		],
		[
			66,
			62
		],
		[
			-18,
			62
		],
		[
			54,
			21
		]
	],
	[
		[
			40061,
			98650
		],
		[
			6,
			10
		]
	],
	[
		[
			40067,
			98660
		],
		[
			24,
			0
		]
	],
	[
		[
			40091,
			98660
		],
		[
			-6,
			-10
		]
	],
	[
		[
			40091,
			98650
		],
		[
			36,
			10
		],
		[
			7,
			0
		],
		[
			6,
			-21
		],
		[
			6,
			-10
		],
		[
			30,
			-21
		],
		[
			48,
			52
		],
		[
			42,
			0
		],
		[
			30,
			-42
		]
	],
	[
		[
			40296,
			98618
		],
		[
			-42,
			-113
		],
		[
			54,
			0
		]
	],
	[
		[
			40308,
			98505
		],
		[
			-30,
			-52
		]
	],
	[
		[
			40278,
			98453
		],
		[
			-78,
			20
		],
		[
			-36,
			-62
		],
		[
			-97,
			0
		]
	],
	[
		[
			40067,
			98411
		],
		[
			-12,
			0
		],
		[
			42,
			52
		],
		[
			0,
			42
		],
		[
			-138,
			-32
		]
	],
	[
		[
			39959,
			98473
		],
		[
			-48,
			63
		]
	],
	[
		[
			39911,
			98536
		],
		[
			-42,
			51
		],
		[
			84,
			83
		],
		[
			60,
			11
		],
		[
			48,
			-31
		]
	],
	[
		[
			44799,
			98660
		],
		[
			-6,
			10
		]
	],
	[
		[
			44793,
			98670
		],
		[
			6,
			-10
		]
	],
	[
		[
			44793,
			98670
		],
		[
			6,
			-10
		]
	],
	[
		[
			42076,
			98836
		],
		[
			-18,
			-83
		],
		[
			-49,
			10
		],
		[
			0,
			63
		],
		[
			67,
			10
		]
	],
	[
		[
			43982,
			98908
		],
		[
			-49,
			-72
		],
		[
			6,
			-73
		],
		[
			-60,
			-20
		],
		[
			-6,
			114
		],
		[
			54,
			62
		],
		[
			55,
			-11
		]
	],
	[
		[
			39430,
			98940
		],
		[
			0,
			20
		]
	],
	[
		[
			39430,
			98960
		],
		[
			0,
			-20
		]
	],
	[
		[
			41384,
			98971
		],
		[
			-6,
			-11
		]
	],
	[
		[
			41378,
			98960
		],
		[
			6,
			11
		]
	],
	[
		[
			41492,
			99033
		],
		[
			-6,
			-11
		]
	],
	[
		[
			41486,
			99022
		],
		[
			6,
			11
		]
	],
	[
		[
			43951,
			98567
		],
		[
			-48,
			72
		],
		[
			79,
			52
		],
		[
			54,
			145
		],
		[
			66,
			31
		],
		[
			6,
			41
		],
		[
			54,
			11
		],
		[
			60,
			-21
		],
		[
			42,
			21
		],
		[
			30,
			83
		],
		[
			42,
			31
		],
		[
			36,
			-31
		],
		[
			97,
			0
		],
		[
			126,
			20
		],
		[
			-66,
			-114
		],
		[
			-60,
			-62
		],
		[
			-79,
			-114
		],
		[
			-78,
			-82
		],
		[
			-36,
			0
		],
		[
			-36,
			-104
		],
		[
			-60,
			-21
		],
		[
			-102,
			0
		],
		[
			-103,
			62
		],
		[
			-24,
			-20
		]
	],
	[
		[
			41631,
			98681
		],
		[
			-6,
			10
		],
		[
			-73,
			0
		],
		[
			-54,
			41
		]
	],
	[
		[
			41498,
			98732
		],
		[
			-48,
			52
		],
		[
			-6,
			62
		],
		[
			-66,
			114
		]
	],
	[
		[
			41378,
			98960
		],
		[
			6,
			11
		]
	],
	[
		[
			41384,
			98971
		],
		[
			66,
			0
		]
	],
	[
		[
			41450,
			98971
		],
		[
			36,
			51
		]
	],
	[
		[
			41492,
			99033
		],
		[
			103,
			83
		],
		[
			24,
			0
		],
		[
			114,
			-94
		],
		[
			36,
			21
		],
		[
			162,
			-93
		],
		[
			-6,
			-145
		],
		[
			-78,
			-73
		],
		[
			-36,
			11
		],
		[
			-42,
			-52
		],
		[
			-30,
			21
		],
		[
			-84,
			0
		],
		[
			-24,
			-31
		]
	],
	[
		[
			45581,
			99375
		],
		[
			-18,
			-11
		],
		[
			6,
			11
		],
		[
			6,
			0
		]
	],
	[
		[
			45575,
			99375
		],
		[
			6,
			0
		]
	],
	[
		[
			45659,
			99395
		],
		[
			-72,
			-20
		],
		[
			-12,
			0
		]
	],
	[
		[
			45575,
			99375
		],
		[
			60,
			62
		],
		[
			24,
			-42
		]
	],
	[
		[
			45695,
			99416
		],
		[
			-6,
			0
		],
		[
			0,
			10
		],
		[
			6,
			-10
		]
	],
	[
		[
			45629,
			99468
		],
		[
			-12,
			0
		]
	],
	[
		[
			45617,
			99468
		],
		[
			12,
			0
		]
	],
	[
		[
			45617,
			99468
		],
		[
			-54,
			-62
		],
		[
			-42,
			20
		]
	],
	[
		[
			45521,
			99426
		],
		[
			42,
			52
		],
		[
			54,
			-10
		]
	],
	[
		[
			45521,
			99426
		],
		[
			24,
			-41
		],
		[
			-24,
			-10
		],
		[
			-54,
			10
		]
	],
	[
		[
			45467,
			99385
		],
		[
			-42,
			21
		],
		[
			24,
			82
		],
		[
			66,
			11
		]
	],
	[
		[
			45515,
			99499
		],
		[
			6,
			-73
		]
	],
	[
		[
			41577,
			99644
		],
		[
			-13,
			0
		]
	],
	[
		[
			41564,
			99644
		],
		[
			13,
			0
		]
	],
	[
		[
			43266,
			99571
		],
		[
			-54,
			-20
		],
		[
			12,
			82
		],
		[
			36,
			0
		],
		[
			6,
			-62
		]
	],
	[
		[
			43278,
			99841
		],
		[
			-24,
			-52
		],
		[
			-42,
			31
		],
		[
			30,
			62
		],
		[
			36,
			-41
		]
	],
	[
		[
			41041,
			99965
		],
		[
			0,
			-10
		]
	],
	[
		[
			41041,
			99955
		],
		[
			0,
			10
		]
	],
	[
		[
			40482,
			99965
		],
		[
			-6,
			10
		]
	],
	[
		[
			40476,
			99975
		],
		[
			6,
			-10
		]
	],
	[
		[
			45346,
			100866
		],
		[
			-6,
			0
		]
	],
	[
		[
			45340,
			100866
		],
		[
			6,
			0
		]
	],
	[
		[
			45340,
			100887
		],
		[
			0,
			10
		]
	],
	[
		[
			45340,
			100897
		],
		[
			0,
			-10
		]
	],
	[
		[
			41655,
			101104
		],
		[
			-12,
			0
		],
		[
			12,
			0
		]
	],
	[
		[
			41895,
			101177
		],
		[
			-6,
			0
		]
	],
	[
		[
			41889,
			101177
		],
		[
			6,
			0
		]
	],
	[
		[
			41595,
			101249
		],
		[
			12,
			21
		]
	],
	[
		[
			41607,
			101270
		],
		[
			-12,
			-21
		]
	],
	[
		[
			41709,
			101228
		],
		[
			-6,
			11
		],
		[
			-12,
			-11
		],
		[
			-30,
			11
		],
		[
			-54,
			31
		]
	],
	[
		[
			41607,
			101270
		],
		[
			90,
			0
		],
		[
			12,
			-42
		]
	],
	[
		[
			44192,
			101259
		],
		[
			30,
			-31
		],
		[
			54,
			21
		],
		[
			12,
			-72
		],
		[
			-36,
			-11
		],
		[
			-18,
			-62
		],
		[
			-42,
			0
		],
		[
			-30,
			42
		],
		[
			-36,
			-63
		],
		[
			-72,
			-10
		],
		[
			6,
			62
		],
		[
			66,
			52
		],
		[
			0,
			72
		],
		[
			66,
			0
		]
	],
	[
		[
			42142,
			101342
		],
		[
			-6,
			0
		]
	],
	[
		[
			42136,
			101342
		],
		[
			6,
			0
		]
	],
	[
		[
			44901,
			101394
		],
		[
			151,
			-52
		],
		[
			48,
			11
		]
	],
	[
		[
			45100,
			101353
		],
		[
			30,
			-42
		],
		[
			18,
			-93
		],
		[
			18,
			-114
		],
		[
			36,
			31
		],
		[
			18,
			-62
		],
		[
			60,
			10
		],
		[
			48,
			125
		],
		[
			36,
			-21
		],
		[
			55,
			41
		],
		[
			12,
			-93
		],
		[
			48,
			-10
		],
		[
			-97,
			-197
		],
		[
			-48,
			-21
		]
	],
	[
		[
			45334,
			100907
		],
		[
			6,
			-10
		]
	],
	[
		[
			45340,
			100897
		],
		[
			0,
			-10
		]
	],
	[
		[
			45340,
			100887
		],
		[
			6,
			-21
		]
	],
	[
		[
			45340,
			100866
		],
		[
			-84,
			-31
		],
		[
			-54,
			10
		],
		[
			-66,
			42
		],
		[
			-36,
			72
		],
		[
			-36,
			0
		],
		[
			-6,
			-10
		],
		[
			-18,
			10
		],
		[
			-48,
			-21
		],
		[
			-55,
			83
		],
		[
			-60,
			0
		],
		[
			-12,
			-31
		],
		[
			-132,
			11
		],
		[
			-12,
			-42
		],
		[
			90,
			-52
		],
		[
			30,
			0
		],
		[
			48,
			-72
		],
		[
			0,
			-52
		],
		[
			-36,
			-31
		],
		[
			-114,
			-21
		],
		[
			-24,
			62
		],
		[
			-30,
			0
		],
		[
			-48,
			52
		],
		[
			-18,
			83
		],
		[
			-78,
			135
		],
		[
			-36,
			31
		],
		[
			-36,
			83
		],
		[
			-43,
			0
		],
		[
			12,
			82
		],
		[
			49,
			52
		],
		[
			6,
			62
		],
		[
			72,
			-41
		],
		[
			150,
			-62
		],
		[
			72,
			21
		],
		[
			30,
			62
		],
		[
			72,
			41
		]
	],
	[
		[
			44889,
			101394
		],
		[
			12,
			0
		]
	],
	[
		[
			44889,
			101394
		],
		[
			12,
			0
		]
	],
	[
		[
			43428,
			99198
		],
		[
			-66,
			-72
		],
		[
			-54,
			-83
		],
		[
			48,
			-10
		],
		[
			6,
			-114
		],
		[
			42,
			10
		],
		[
			18,
			73
		],
		[
			72,
			124
		],
		[
			73,
			0
		],
		[
			42,
			-52
		],
		[
			90,
			11
		],
		[
			-48,
			-125
		],
		[
			42,
			0
		],
		[
			-12,
			-145
		],
		[
			-144,
			-62
		],
		[
			-43,
			-52
		],
		[
			-54,
			-20
		],
		[
			-72,
			51
		],
		[
			-126,
			-10
		],
		[
			-60,
			31
		],
		[
			-60,
			0
		],
		[
			0,
			-197
		],
		[
			24,
			-83
		],
		[
			42,
			104
		],
		[
			114,
			-21
		],
		[
			36,
			-62
		],
		[
			96,
			-10
		],
		[
			36,
			41
		],
		[
			18,
			-62
		],
		[
			67,
			-10
		],
		[
			78,
			52
		],
		[
			24,
			-52
		],
		[
			-48,
			-42
		],
		[
			-18,
			-51
		],
		[
			42,
			-104
		],
		[
			-90,
			31
		],
		[
			-91,
			0
		],
		[
			-66,
			-72
		],
		[
			-96,
			-63
		],
		[
			-12,
			-31
		],
		[
			-72,
			-41
		],
		[
			30,
			-73
		],
		[
			204,
			-20
		],
		[
			61,
			-52
		],
		[
			48,
			41
		],
		[
			24,
			-31
		],
		[
			-54,
			-83
		],
		[
			-61,
			11
		],
		[
			-42,
			41
		],
		[
			-48,
			-41
		],
		[
			-72,
			0
		],
		[
			-6,
			-62
		],
		[
			-48,
			-31
		],
		[
			-6,
			-63
		],
		[
			-78,
			0
		],
		[
			-60,
			-31
		],
		[
			-6,
			62
		],
		[
			54,
			135
		],
		[
			-102,
			-10
		],
		[
			-67,
			103
		],
		[
			-18,
			-20
		],
		[
			-18,
			-135
		],
		[
			54,
			-10
		],
		[
			12,
			-73
		],
		[
			-90,
			-72
		],
		[
			-60,
			-11
		],
		[
			-30,
			-72
		],
		[
			156,
			-11
		],
		[
			24,
			-41
		],
		[
			-72,
			-124
		],
		[
			48,
			-21
		],
		[
			97,
			124
		],
		[
			42,
			-124
		],
		[
			-48,
			-21
		],
		[
			-48,
			-124
		],
		[
			-91,
			-93
		],
		[
			60,
			-11
		],
		[
			43,
			52
		],
		[
			96,
			62
		],
		[
			54,
			62
		],
		[
			54,
			32
		]
	],
	[
		[
			43242,
			97345
		],
		[
			-24,
			-63
		],
		[
			-12,
			-51
		],
		[
			78,
			0
		]
	],
	[
		[
			43284,
			97231
		],
		[
			0,
			-11
		]
	],
	[
		[
			43284,
			97220
		],
		[
			-30,
			-41
		]
	],
	[
		[
			43254,
			97179
		],
		[
			-24,
			-52
		],
		[
			6,
			-62
		],
		[
			-60,
			-41
		],
		[
			48,
			-73
		],
		[
			54,
			-21
		],
		[
			24,
			-51
		],
		[
			-84,
			-42
		],
		[
			-12,
			-83
		],
		[
			30,
			-93
		],
		[
			-30,
			-21
		]
	],
	[
		[
			43206,
			96640
		],
		[
			-6,
			11
		]
	],
	[
		[
			43200,
			96651
		],
		[
			-24,
			103
		],
		[
			-48,
			11
		],
		[
			-18,
			-114
		],
		[
			6,
			-94
		],
		[
			-60,
			63
		],
		[
			-109,
			41
		],
		[
			-12,
			-62
		],
		[
			60,
			-42
		],
		[
			12,
			-20
		]
	],
	[
		[
			43007,
			96537
		],
		[
			-36,
			-93
		],
		[
			-60,
			-52
		],
		[
			-78,
			-42
		],
		[
			66,
			-41
		]
	],
	[
		[
			42899,
			96309
		],
		[
			30,
			-73
		],
		[
			-24,
			-31
		],
		[
			6,
			-114
		],
		[
			0,
			-10
		],
		[
			12,
			-83
		],
		[
			48,
			-10
		],
		[
			6,
			-31
		],
		[
			-30,
			-73
		],
		[
			73,
			-31
		],
		[
			36,
			-41
		],
		[
			60,
			-11
		],
		[
			0,
			-41
		]
	],
	[
		[
			43116,
			95760
		],
		[
			-18,
			21
		],
		[
			-145,
			10
		],
		[
			-66,
			-41
		],
		[
			-108,
			0
		],
		[
			18,
			-125
		],
		[
			42,
			-51
		],
		[
			-6,
			-73
		],
		[
			48,
			-31
		],
		[
			42,
			-83
		],
		[
			0,
			-83
		],
		[
			30,
			-83
		],
		[
			-24,
			-51
		],
		[
			-36,
			31
		],
		[
			0,
			62
		],
		[
			-42,
			124
		],
		[
			-48,
			0
		],
		[
			-12,
			-114
		],
		[
			-54,
			-10
		],
		[
			-12,
			93
		],
		[
			-84,
			31
		],
		[
			-12,
			-62
		],
		[
			-54,
			10
		],
		[
			-6,
			-114
		],
		[
			84,
			-51
		],
		[
			-6,
			0
		],
		[
			-24,
			-21
		]
	],
	[
		[
			42623,
			95139
		],
		[
			36,
			-125
		],
		[
			-60,
			-41
		],
		[
			0,
			-42
		],
		[
			42,
			-72
		],
		[
			-48,
			-62
		],
		[
			-36,
			-114
		],
		[
			-91,
			10
		],
		[
			12,
			-52
		],
		[
			91,
			-72
		],
		[
			-43,
			-145
		],
		[
			31,
			-62
		],
		[
			0,
			-11
		],
		[
			-67,
			-20
		],
		[
			-18,
			-73
		],
		[
			36,
			-31
		],
		[
			67,
			31
		]
	],
	[
		[
			42575,
			94258
		],
		[
			-12,
			-10
		]
	],
	[
		[
			42557,
			94258
		],
		[
			0,
			-207
		],
		[
			-37,
			-10
		]
	],
	[
		[
			42520,
			94041
		],
		[
			12,
			31
		],
		[
			-6,
			0
		],
		[
			0,
			10
		],
		[
			-12,
			21
		],
		[
			-42,
			52
		],
		[
			-36,
			93
		],
		[
			-48,
			10
		],
		[
			-30,
			-62
		],
		[
			-24,
			-114
		]
	],
	[
		[
			42334,
			94082
		],
		[
			-12,
			11
		]
	],
	[
		[
			42322,
			94103
		],
		[
			6,
			21
		]
	],
	[
		[
			42328,
			94124
		],
		[
			6,
			20
		]
	],
	[
		[
			42334,
			94144
		],
		[
			-36,
			62
		],
		[
			48,
			125
		],
		[
			-60,
			83
		],
		[
			0,
			51
		],
		[
			-90,
			21
		],
		[
			-60,
			-21
		],
		[
			-6,
			-93
		],
		[
			-24,
			-41
		],
		[
			-73,
			93
		],
		[
			-102,
			-42
		]
	],
	[
		[
			41931,
			94382
		],
		[
			-12,
			11
		]
	],
	[
		[
			41913,
			94393
		],
		[
			-6,
			10
		]
	],
	[
		[
			41907,
			94403
		],
		[
			-6,
			11
		]
	],
	[
		[
			41901,
			94414
		],
		[
			18,
			0
		]
	],
	[
		[
			41919,
			94414
		],
		[
			6,
			10
		]
	],
	[
		[
			41925,
			94424
		],
		[
			-18,
			31
		]
	],
	[
		[
			41907,
			94455
		],
		[
			-36,
			124
		]
	],
	[
		[
			41871,
			94579
		],
		[
			24,
			42
		],
		[
			84,
			20
		],
		[
			-6,
			83
		]
	],
	[
		[
			41973,
			94724
		],
		[
			30,
			31
		],
		[
			12,
			83
		],
		[
			12,
			31
		]
	],
	[
		[
			42027,
			94869
		],
		[
			6,
			0
		]
	],
	[
		[
			42033,
			94869
		],
		[
			-6,
			11
		]
	],
	[
		[
			42027,
			94880
		],
		[
			0,
			31
		],
		[
			91,
			-11
		],
		[
			30,
			52
		]
	],
	[
		[
			42148,
			94952
		],
		[
			48,
			-41
		],
		[
			24,
			83
		],
		[
			-42,
			20
		]
	],
	[
		[
			42184,
			95025
		],
		[
			12,
			31
		]
	],
	[
		[
			42196,
			95056
		],
		[
			0,
			10
		]
	],
	[
		[
			42196,
			95066
		],
		[
			6,
			83
		],
		[
			-54,
			-31
		]
	],
	[
		[
			42148,
			95118
		],
		[
			-6,
			0
		],
		[
			-6,
			0
		]
	],
	[
		[
			42136,
			95118
		],
		[
			-24,
			10
		]
	],
	[
		[
			42112,
			95128
		],
		[
			-12,
			0
		]
	],
	[
		[
			42100,
			95128
		],
		[
			-30,
			0
		]
	],
	[
		[
			42045,
			95139
		],
		[
			25,
			82
		],
		[
			0,
			21
		]
	],
	[
		[
			42076,
			95252
		],
		[
			84,
			-82
		],
		[
			42,
			-21
		],
		[
			24,
			72
		],
		[
			-48,
			31
		],
		[
			-6,
			63
		],
		[
			-30,
			31
		],
		[
			-6,
			10
		]
	],
	[
		[
			42136,
			95356
		],
		[
			-6,
			10
		],
		[
			-6,
			11
		],
		[
			12,
			62
		],
		[
			48,
			41
		]
	],
	[
		[
			42184,
			95491
		],
		[
			60,
			-11
		],
		[
			30,
			52
		],
		[
			-6,
			83
		],
		[
			84,
			155
		],
		[
			6,
			166
		],
		[
			36,
			104
		],
		[
			30,
			41
		],
		[
			30,
			145
		],
		[
			48,
			83
		],
		[
			30,
			186
		],
		[
			31,
			114
		],
		[
			-12,
			83
		],
		[
			-55,
			31
		],
		[
			-24,
			-41
		],
		[
			-66,
			-11
		],
		[
			-30,
			63
		],
		[
			54,
			51
		],
		[
			-42,
			42
		],
		[
			24,
			103
		],
		[
			12,
			114
		],
		[
			30,
			52
		],
		[
			18,
			83
		],
		[
			0,
			103
		],
		[
			-60,
			-31
		],
		[
			-6,
			-51
		],
		[
			-84,
			-228
		],
		[
			-30,
			83
		],
		[
			30,
			51
		],
		[
			6,
			63
		],
		[
			36,
			82
		],
		[
			12,
			73
		],
		[
			48,
			21
		],
		[
			48,
			51
		],
		[
			30,
			21
		],
		[
			73,
			145
		],
		[
			-12,
			83
		],
		[
			-73,
			-176
		],
		[
			-72,
			-52
		],
		[
			-66,
			-104
		],
		[
			-6,
			-51
		],
		[
			-96,
			-249
		],
		[
			-6,
			73
		],
		[
			60,
			145
		],
		[
			-6,
			51
		],
		[
			36,
			52
		],
		[
			42,
			176
		],
		[
			-24,
			83
		],
		[
			78,
			104
		],
		[
			-48,
			10
		],
		[
			-18,
			-62
		],
		[
			-48,
			-31
		],
		[
			0,
			-52
		],
		[
			-156,
			-207
		],
		[
			-36,
			-31
		],
		[
			-18,
			72
		],
		[
			12,
			73
		],
		[
			-79,
			0
		],
		[
			-12,
			62
		],
		[
			18,
			52
		],
		[
			-48,
			62
		],
		[
			18,
			41
		],
		[
			61,
			-31
		],
		[
			-12,
			93
		],
		[
			-73,
			0
		],
		[
			-42,
			32
		],
		[
			-72,
			-52
		],
		[
			-114,
			20
		],
		[
			120,
			-103
		],
		[
			60,
			21
		],
		[
			6,
			-83
		],
		[
			24,
			-83
		],
		[
			60,
			-42
		],
		[
			-12,
			-227
		],
		[
			-24,
			20
		],
		[
			0,
			156
		],
		[
			-42,
			-11
		],
		[
			-18,
			-51
		],
		[
			-84,
			-21
		],
		[
			-48,
			10
		],
		[
			-30,
			-72
		],
		[
			-6,
			-156
		],
		[
			-66,
			-124
		],
		[
			-84,
			52
		],
		[
			-24,
			83
		],
		[
			42,
			52
		],
		[
			-36,
			41
		],
		[
			-12,
			-83
		],
		[
			-73,
			-52
		],
		[
			0,
			-207
		],
		[
			-72,
			-41
		]
	],
	[
		[
			41444,
			96837
		],
		[
			0,
			52
		],
		[
			-60,
			52
		]
	],
	[
		[
			41384,
			96941
		],
		[
			-24,
			0
		]
	],
	[
		[
			41354,
			96941
		],
		[
			-60,
			20
		],
		[
			-102,
			0
		]
	],
	[
		[
			41192,
			96961
		],
		[
			-24,
			176
		],
		[
			-54,
			-10
		]
	],
	[
		[
			41108,
			97127
		],
		[
			-55,
			0
		]
	],
	[
		[
			41053,
			97127
		],
		[
			-30,
			0
		],
		[
			-48,
			52
		],
		[
			-12,
			52
		]
	],
	[
		[
			40963,
			97231
		],
		[
			0,
			62
		],
		[
			42,
			10
		],
		[
			18,
			52
		],
		[
			42,
			31
		],
		[
			85,
			10
		],
		[
			102,
			-41
		],
		[
			78,
			0
		],
		[
			-6,
			41
		],
		[
			-96,
			-20
		],
		[
			18,
			62
		],
		[
			-48,
			20
		],
		[
			6,
			125
		],
		[
			-127,
			124
		],
		[
			-12,
			-72
		],
		[
			55,
			-42
		],
		[
			-6,
			-103
		],
		[
			-67,
			-11
		],
		[
			-84,
			-72
		],
		[
			-60,
			-104
		],
		[
			-6,
			124
		],
		[
			12,
			83
		],
		[
			-72,
			21
		],
		[
			-30,
			-31
		],
		[
			-72,
			21
		],
		[
			-18,
			-21
		],
		[
			-72,
			10
		],
		[
			-24,
			-103
		],
		[
			-55,
			-31
		],
		[
			-60,
			62
		],
		[
			-72,
			0
		],
		[
			-54,
			41
		],
		[
			18,
			73
		],
		[
			-102,
			31
		],
		[
			-30,
			41
		],
		[
			-90,
			31
		],
		[
			-30,
			-20
		],
		[
			-12,
			62
		],
		[
			-25,
			124
		]
	],
	[
		[
			40103,
			97821
		],
		[
			0,
			114
		],
		[
			43,
			-21
		],
		[
			0,
			93
		],
		[
			48,
			52
		],
		[
			-115,
			52
		],
		[
			-12,
			41
		],
		[
			97,
			114
		],
		[
			108,
			11
		],
		[
			24,
			20
		],
		[
			90,
			-10
		],
		[
			30,
			41
		],
		[
			42,
			-20
		],
		[
			157,
			20
		],
		[
			48,
			-20
		],
		[
			36,
			-31
		]
	],
	[
		[
			40699,
			98277
		],
		[
			30,
			-52
		]
	],
	[
		[
			40729,
			98225
		],
		[
			6,
			0
		]
	],
	[
		[
			40735,
			98225
		],
		[
			78,
			-83
		],
		[
			18,
			73
		],
		[
			126,
			31
		],
		[
			-18,
			31
		],
		[
			0,
			10
		]
	],
	[
		[
			40939,
			98287
		],
		[
			42,
			52
		],
		[
			42,
			-11
		],
		[
			36,
			42
		]
	],
	[
		[
			41059,
			98370
		],
		[
			6,
			10
		]
	],
	[
		[
			41065,
			98380
		],
		[
			133,
			62
		],
		[
			60,
			-20
		],
		[
			42,
			-187
		],
		[
			42,
			-83
		],
		[
			30,
			-62
		],
		[
			30,
			52
		],
		[
			-36,
			10
		],
		[
			-36,
			145
		],
		[
			36,
			31
		],
		[
			42,
			-20
		],
		[
			24,
			-62
		],
		[
			36,
			31
		],
		[
			24,
			72
		],
		[
			-6,
			62
		]
	],
	[
		[
			41486,
			98411
		],
		[
			48,
			21
		]
	],
	[
		[
			41546,
			98432
		],
		[
			73,
			31
		],
		[
			48,
			0
		],
		[
			48,
			-62
		],
		[
			36,
			52
		],
		[
			126,
			-52
		],
		[
			0,
			-93
		],
		[
			42,
			-93
		],
		[
			12,
			-73
		],
		[
			60,
			-21
		],
		[
			30,
			176
		],
		[
			-30,
			176
		],
		[
			18,
			52
		],
		[
			-12,
			83
		],
		[
			73,
			73
		],
		[
			42,
			0
		],
		[
			12,
			-63
		],
		[
			42,
			-31
		],
		[
			0,
			239
		],
		[
			66,
			-31
		],
		[
			120,
			10
		],
		[
			36,
			21
		],
		[
			54,
			-21
		],
		[
			24,
			52
		],
		[
			-84,
			62
		],
		[
			-120,
			-21
		],
		[
			-72,
			0
		],
		[
			-48,
			-31
		],
		[
			-66,
			41
		],
		[
			36,
			104
		],
		[
			-24,
			62
		],
		[
			0,
			73
		],
		[
			-79,
			-21
		],
		[
			-12,
			-62
		],
		[
			-54,
			-83
		],
		[
			-30,
			0
		],
		[
			-108,
			52
		],
		[
			-60,
			62
		],
		[
			12,
			52
		],
		[
			-30,
			93
		],
		[
			36,
			93
		],
		[
			-42,
			10
		],
		[
			-205,
			0
		],
		[
			0,
			42
		],
		[
			0,
			10
		],
		[
			-36,
			93
		],
		[
			30,
			32
		],
		[
			54,
			124
		]
	],
	[
		[
			41577,
			99644
		],
		[
			-19,
			21
		],
		[
			-90,
			0
		],
		[
			-36,
			41
		],
		[
			12,
			186
		],
		[
			60,
			156
		],
		[
			-54,
			0
		],
		[
			-18,
			-42
		],
		[
			-84,
			-83
		],
		[
			-42,
			-10
		],
		[
			36,
			-83
		],
		[
			-48,
			-52
		],
		[
			-24,
			-62
		],
		[
			-6,
			0
		]
	],
	[
		[
			41264,
			99716
		],
		[
			-42,
			0
		],
		[
			-18,
			62
		],
		[
			-54,
			42
		],
		[
			84,
			93
		],
		[
			-12,
			83
		],
		[
			-54,
			-41
		],
		[
			-36,
			-21
		]
	],
	[
		[
			41132,
			99934
		],
		[
			-91,
			31
		]
	],
	[
		[
			41041,
			99955
		],
		[
			-48,
			41
		],
		[
			-12,
			10
		],
		[
			-12,
			11
		],
		[
			-66,
			20
		],
		[
			-60,
			-93
		],
		[
			-72,
			21
		],
		[
			-84,
			-42
		],
		[
			-60,
			21
		],
		[
			-31,
			-41
		],
		[
			-36,
			52
		],
		[
			-72,
			10
		],
		[
			-6,
			0
		]
	],
	[
		[
			40482,
			99965
		],
		[
			-6,
			10
		]
	],
	[
		[
			40476,
			99975
		],
		[
			6,
			52
		],
		[
			48,
			41
		],
		[
			36,
			73
		],
		[
			6,
			21
		],
		[
			6,
			20
		],
		[
			6,
			0
		],
		[
			-6,
			11
		]
	],
	[
		[
			40578,
			100193
		],
		[
			18,
			31
		],
		[
			109,
			-11
		],
		[
			24,
			-31
		],
		[
			66,
			0
		],
		[
			60,
			176
		],
		[
			-18,
			32
		],
		[
			54,
			176
		],
		[
			138,
			93
		],
		[
			42,
			0
		]
	],
	[
		[
			41071,
			100659
		],
		[
			43,
			-62
		],
		[
			-6,
			-104
		],
		[
			30,
			-62
		],
		[
			60,
			-21
		],
		[
			96,
			-62
		],
		[
			132,
			-114
		],
		[
			72,
			-10
		],
		[
			30,
			-42
		],
		[
			73,
			0
		],
		[
			42,
			31
		],
		[
			12,
			52
		],
		[
			-97,
			-41
		],
		[
			-60,
			21
		],
		[
			-66,
			51
		],
		[
			-90,
			135
		],
		[
			-72,
			31
		],
		[
			-12,
			62
		],
		[
			42,
			73
		],
		[
			90,
			31
		],
		[
			6,
			83
		],
		[
			78,
			31
		],
		[
			30,
			51
		],
		[
			97,
			31
		],
		[
			18,
			94
		],
		[
			-61,
			20
		],
		[
			12,
			73
		],
		[
			67,
			52
		],
		[
			18,
			41
		]
	],
	[
		[
			41655,
			101104
		],
		[
			-18,
			0
		],
		[
			-24,
			10
		]
	],
	[
		[
			41613,
			101114
		],
		[
			84,
			73
		],
		[
			12,
			41
		]
	],
	[
		[
			41709,
			101228
		],
		[
			18,
			0
		],
		[
			84,
			-31
		],
		[
			78,
			-20
		]
	],
	[
		[
			41895,
			101177
		],
		[
			78,
			-31
		],
		[
			30,
			20
		],
		[
			103,
			11
		],
		[
			-6,
			31
		],
		[
			36,
			134
		]
	],
	[
		[
			42142,
			101342
		],
		[
			66,
			-20
		],
		[
			84,
			51
		],
		[
			42,
			63
		]
	],
	[
		[
			42334,
			101436
		],
		[
			12,
			0
		]
	],
	[
		[
			42346,
			101436
		],
		[
			-36,
			-125
		],
		[
			60,
			0
		],
		[
			0,
			-259
		],
		[
			-24,
			-62
		],
		[
			-60,
			-62
		],
		[
			-36,
			31
		],
		[
			-48,
			-10
		],
		[
			18,
			-83
		],
		[
			48,
			-42
		],
		[
			48,
			-10
		],
		[
			0,
			-124
		],
		[
			-24,
			-31
		],
		[
			6,
			-125
		],
		[
			-12,
			-31
		],
		[
			-60,
			-10
		],
		[
			-48,
			21
		],
		[
			-24,
			-31
		],
		[
			-54,
			41
		],
		[
			-42,
			-103
		],
		[
			162,
			-11
		],
		[
			18,
			-52
		],
		[
			-120,
			0
		],
		[
			96,
			-72
		],
		[
			30,
			-83
		],
		[
			-48,
			-41
		],
		[
			-18,
			-125
		],
		[
			-42,
			-82
		],
		[
			72,
			-21
		],
		[
			-18,
			72
		],
		[
			72,
			114
		],
		[
			66,
			-10
		],
		[
			-36,
			-62
		],
		[
			36,
			-52
		],
		[
			-30,
			-52
		],
		[
			-42,
			11
		],
		[
			-6,
			-104
		],
		[
			-42,
			-31
		],
		[
			72,
			-135
		],
		[
			-24,
			-31
		],
		[
			-72,
			0
		],
		[
			-48,
			-62
		],
		[
			-66,
			-52
		],
		[
			-37,
			-155
		],
		[
			-6,
			-83
		],
		[
			-42,
			31
		],
		[
			-30,
			-103
		],
		[
			-48,
			-52
		],
		[
			48,
			-42
		],
		[
			18,
			31
		],
		[
			115,
			31
		],
		[
			42,
			73
		],
		[
			-6,
			83
		],
		[
			30,
			124
		],
		[
			66,
			73
		],
		[
			78,
			0
		],
		[
			120,
			62
		],
		[
			60,
			-21
		],
		[
			36,
			31
		],
		[
			67,
			-31
		],
		[
			42,
			62
		],
		[
			-72,
			42
		],
		[
			-37,
			51
		],
		[
			-54,
			-10
		],
		[
			-54,
			31
		],
		[
			-36,
			52
		],
		[
			18,
			52
		],
		[
			72,
			31
		],
		[
			12,
			83
		],
		[
			42,
			31
		],
		[
			43,
			-31
		],
		[
			6,
			-63
		],
		[
			54,
			-10
		],
		[
			18,
			42
		],
		[
			66,
			41
		],
		[
			18,
			72
		],
		[
			96,
			21
		],
		[
			120,
			-103
		],
		[
			12,
			-94
		],
		[
			-24,
			-51
		],
		[
			12,
			-94
		],
		[
			66,
			52
		],
		[
			55,
			0
		],
		[
			42,
			-31
		],
		[
			0,
			-72
		],
		[
			-139,
			-83
		],
		[
			139,
			20
		],
		[
			48,
			-20
		],
		[
			24,
			-62
		],
		[
			-60,
			-31
		],
		[
			48,
			-135
		],
		[
			-126,
			31
		],
		[
			-37,
			83
		],
		[
			-90,
			-83
		],
		[
			-96,
			-52
		],
		[
			-12,
			-31
		],
		[
			-120,
			-62
		],
		[
			-12,
			-52
		],
		[
			204,
			114
		],
		[
			138,
			52
		],
		[
			19,
			-62
		],
		[
			-121,
			-52
		],
		[
			54,
			-31
		],
		[
			145,
			83
		],
		[
			42,
			10
		],
		[
			18,
			-145
		],
		[
			-6,
			-145
		],
		[
			78,
			83
		],
		[
			-12,
			41
		],
		[
			42,
			73
		],
		[
			30,
			-31
		],
		[
			114,
			10
		],
		[
			-24,
			52
		],
		[
			-6,
			83
		],
		[
			48,
			41
		],
		[
			12,
			83
		],
		[
			48,
			-135
		],
		[
			67,
			63
		],
		[
			48,
			82
		],
		[
			24,
			73
		],
		[
			42,
			-10
		],
		[
			78,
			93
		],
		[
			96,
			10
		],
		[
			-30,
			-62
		],
		[
			-6,
			-93
		],
		[
			-78,
			-52
		],
		[
			-84,
			-114
		],
		[
			-84,
			-83
		],
		[
			-42,
			0
		],
		[
			-43,
			-41
		],
		[
			-48,
			-11
		]
	],
	[
		[
			42334,
			101436
		],
		[
			12,
			0
		]
	],
	[
		[
			44210,
			101767
		],
		[
			84,
			-93
		],
		[
			-24,
			-31
		],
		[
			-78,
			93
		],
		[
			18,
			31
		]
	],
	[
		[
			44661,
			101829
		],
		[
			66,
			-31
		],
		[
			96,
			-72
		],
		[
			-30,
			-73
		],
		[
			-36,
			31
		],
		[
			-66,
			-10
		],
		[
			-6,
			41
		],
		[
			-90,
			52
		],
		[
			-6,
			52
		],
		[
			72,
			10
		]
	],
	[
		[
			44018,
			102285
		],
		[
			12,
			-11
		]
	],
	[
		[
			44030,
			102274
		],
		[
			-12,
			0
		]
	],
	[
		[
			44018,
			102274
		],
		[
			0,
			11
		]
	],
	[
		[
			43476,
			102306
		],
		[
			0,
			-11
		]
	],
	[
		[
			43476,
			102295
		],
		[
			0,
			11
		]
	],
	[
		[
			43717,
			102337
		],
		[
			-6,
			-11
		]
	],
	[
		[
			43711,
			102326
		],
		[
			6,
			11
		]
	],
	[
		[
			43711,
			102326
		],
		[
			12,
			-31
		],
		[
			84,
			0
		],
		[
			78,
			-62
		],
		[
			-12,
			93
		]
	],
	[
		[
			43873,
			102326
		],
		[
			12,
			0
		]
	],
	[
		[
			43885,
			102326
		],
		[
			60,
			-20
		],
		[
			37,
			-42
		],
		[
			36,
			21
		]
	],
	[
		[
			44018,
			102285
		],
		[
			0,
			-11
		]
	],
	[
		[
			44018,
			102274
		],
		[
			36,
			-62
		],
		[
			60,
			21
		],
		[
			6,
			-62
		],
		[
			-48,
			-10
		],
		[
			54,
			-104
		],
		[
			-12,
			-93
		],
		[
			24,
			-31
		],
		[
			-6,
			-83
		],
		[
			30,
			-21
		],
		[
			-24,
			-103
		],
		[
			48,
			-114
		],
		[
			-48,
			-63
		],
		[
			6,
			-72
		],
		[
			60,
			-41
		],
		[
			-72,
			-42
		],
		[
			-12,
			52
		],
		[
			-126,
			10
		],
		[
			-115,
			83
		],
		[
			0,
			52
		],
		[
			-36,
			62
		],
		[
			-36,
			-62
		],
		[
			18,
			-114
		],
		[
			54,
			-41
		],
		[
			24,
			-73
		],
		[
			91,
			-10
		],
		[
			24,
			-114
		],
		[
			-67,
			-114
		],
		[
			-60,
			10
		],
		[
			-36,
			-52
		],
		[
			-42,
			63
		],
		[
			-90,
			41
		],
		[
			12,
			-62
		],
		[
			42,
			-62
		],
		[
			48,
			10
		],
		[
			30,
			-31
		],
		[
			90,
			10
		],
		[
			12,
			-93
		],
		[
			67,
			31
		],
		[
			90,
			-114
		],
		[
			-42,
			-41
		]
	],
	[
		[
			44072,
			100835
		],
		[
			30,
			-52
		],
		[
			-24,
			-41
		],
		[
			-48,
			0
		],
		[
			-6,
			-94
		],
		[
			-36,
			-62
		],
		[
			-25,
			21
		],
		[
			-60,
			-21
		],
		[
			-60,
			21
		],
		[
			0,
			-62
		],
		[
			48,
			-11
		],
		[
			12,
			-103
		],
		[
			79,
			21
		],
		[
			-31,
			-83
		],
		[
			-30,
			-249
		],
		[
			-30,
			-72
		],
		[
			-54,
			41
		],
		[
			-78,
			-41
		],
		[
			-114,
			52
		],
		[
			-42,
			41
		],
		[
			-60,
			-41
		],
		[
			-24,
			51
		],
		[
			-61,
			52
		],
		[
			-36,
			-83
		],
		[
			30,
			-41
		],
		[
			103,
			-21
		],
		[
			0,
			-52
		],
		[
			-73,
			-31
		],
		[
			-60,
			52
		],
		[
			-66,
			-21
		],
		[
			-36,
			31
		],
		[
			-72,
			-10
		],
		[
			-36,
			73
		],
		[
			-42,
			10
		],
		[
			-42,
			103
		],
		[
			-18,
			145
		],
		[
			-72,
			-10
		],
		[
			54,
			93
		],
		[
			-36,
			52
		],
		[
			-24,
			93
		],
		[
			42,
			62
		],
		[
			-12,
			52
		],
		[
			18,
			124
		],
		[
			-48,
			-10
		],
		[
			0,
			-93
		],
		[
			-37,
			0
		],
		[
			-36,
			52
		],
		[
			54,
			165
		],
		[
			-6,
			52
		],
		[
			-42,
			52
		],
		[
			6,
			124
		],
		[
			36,
			11
		],
		[
			-24,
			93
		],
		[
			55,
			10
		],
		[
			0,
			135
		],
		[
			96,
			72
		],
		[
			12,
			42
		],
		[
			60,
			72
		],
		[
			36,
			-31
		],
		[
			-12,
			-62
		],
		[
			6,
			-176
		],
		[
			30,
			-41
		],
		[
			72,
			0
		],
		[
			72,
			-104
		],
		[
			36,
			31
		],
		[
			-66,
			83
		],
		[
			-90,
			31
		],
		[
			-12,
			104
		],
		[
			12,
			124
		],
		[
			42,
			62
		],
		[
			0,
			104
		],
		[
			30,
			10
		],
		[
			18,
			103
		],
		[
			6,
			135
		],
		[
			-30,
			10
		],
		[
			-12,
			83
		],
		[
			48,
			42
		],
		[
			6,
			114
		]
	],
	[
		[
			43398,
			102223
		],
		[
			-12,
			41
		]
	],
	[
		[
			43386,
			102264
		],
		[
			66,
			31
		],
		[
			24,
			0
		]
	],
	[
		[
			43476,
			102306
		],
		[
			115,
			0
		],
		[
			90,
			-125
		],
		[
			18,
			21
		],
		[
			-18,
			124
		]
	],
	[
		[
			43681,
			102326
		],
		[
			12,
			11
		],
		[
			18,
			-11
		]
	],
	[
		[
			43717,
			102337
		],
		[
			-6,
			10
		]
	],
	[
		[
			43711,
			102347
		],
		[
			6,
			-10
		]
	],
	[
		[
			43873,
			102326
		],
		[
			0,
			21
		],
		[
			12,
			-21
		]
	],
	[
		[
			45364,
			102513
		],
		[
			-6,
			-31
		]
	],
	[
		[
			45358,
			102482
		],
		[
			6,
			31
		]
	],
	[
		[
			44390,
			102792
		],
		[
			-6,
			11
		]
	],
	[
		[
			44384,
			102803
		],
		[
			6,
			-11
		]
	],
	[
		[
			44390,
			102792
		],
		[
			-6,
			11
		]
	],
	[
		[
			45455,
			103155
		],
		[
			-6,
			0
		]
	],
	[
		[
			45449,
			103155
		],
		[
			6,
			0
		]
	],
	[
		[
			45196,
			103279
		],
		[
			-6,
			10
		]
	],
	[
		[
			45190,
			103289
		],
		[
			6,
			-10
		]
	],
	[
		[
			45166,
			103300
		],
		[
			12,
			0
		]
	],
	[
		[
			45178,
			103300
		],
		[
			-12,
			0
		]
	],
	[
		[
			44709,
			103310
		],
		[
			-6,
			0
		]
	],
	[
		[
			44703,
			103310
		],
		[
			6,
			0
		]
	],
	[
		[
			45166,
			103300
		],
		[
			12,
			0
		]
	],
	[
		[
			44709,
			103321
		],
		[
			-12,
			0
		]
	],
	[
		[
			44697,
			103321
		],
		[
			12,
			0
		]
	],
	[
		[
			45178,
			103300
		],
		[
			12,
			-11
		]
	],
	[
		[
			45196,
			103279
		],
		[
			42,
			-31
		],
		[
			54,
			52
		],
		[
			18,
			-52
		],
		[
			66,
			10
		],
		[
			36,
			-20
		],
		[
			-54,
			-21
		],
		[
			18,
			-62
		],
		[
			73,
			0
		]
	],
	[
		[
			45455,
			103155
		],
		[
			-12,
			-52
		],
		[
			-121,
			0
		],
		[
			-66,
			-41
		],
		[
			24,
			-52
		],
		[
			72,
			0
		],
		[
			42,
			-228
		],
		[
			-48,
			0
		],
		[
			-90,
			62
		],
		[
			-24,
			-31
		],
		[
			-96,
			52
		],
		[
			6,
			-62
		],
		[
			42,
			-83
		],
		[
			42,
			-42
		],
		[
			0,
			-51
		],
		[
			36,
			-52
		],
		[
			-222,
			21
		],
		[
			-103,
			-63
		],
		[
			133,
			-20
		],
		[
			102,
			20
		],
		[
			36,
			-62
		],
		[
			-18,
			-72
		],
		[
			-36,
			-52
		],
		[
			-42,
			-10
		],
		[
			-60,
			-94
		],
		[
			-84,
			-10
		],
		[
			-31,
			-83
		],
		[
			-66,
			-103
		],
		[
			30,
			-52
		],
		[
			67,
			10
		],
		[
			48,
			-62
		],
		[
			48,
			52
		],
		[
			36,
			-114
		],
		[
			-78,
			-31
		],
		[
			-66,
			-73
		],
		[
			-37,
			52
		],
		[
			-42,
			-21
		],
		[
			-60,
			31
		],
		[
			-138,
			32
		],
		[
			-12,
			62
		],
		[
			-42,
			0
		],
		[
			-60,
			-42
		],
		[
			-18,
			-52
		],
		[
			-66,
			-62
		],
		[
			-169,
			42
		],
		[
			12,
			62
		],
		[
			-90,
			-10
		],
		[
			0,
			51
		],
		[
			48,
			62
		],
		[
			6,
			114
		],
		[
			-36,
			31
		],
		[
			6,
			83
		],
		[
			72,
			-10
		],
		[
			42,
			21
		],
		[
			-12,
			217
		],
		[
			54,
			-10
		],
		[
			49,
			72
		],
		[
			-31,
			73
		],
		[
			37,
			31
		],
		[
			18,
			83
		],
		[
			6,
			124
		],
		[
			-91,
			62
		],
		[
			30,
			93
		],
		[
			85,
			31
		],
		[
			18,
			73
		],
		[
			-54,
			21
		]
	],
	[
		[
			44481,
			103093
		],
		[
			54,
			31
		],
		[
			78,
			-11
		],
		[
			42,
			73
		],
		[
			12,
			31
		]
	],
	[
		[
			44667,
			103217
		],
		[
			60,
			31
		],
		[
			-18,
			62
		]
	],
	[
		[
			44703,
			103310
		],
		[
			6,
			11
		]
	],
	[
		[
			44709,
			103321
		],
		[
			-12,
			0
		]
	],
	[
		[
			44697,
			103321
		],
		[
			6,
			20
		],
		[
			12,
			11
		]
	],
	[
		[
			44715,
			103352
		],
		[
			66,
			41
		],
		[
			72,
			0
		],
		[
			36,
			-83
		],
		[
			-30,
			-228
		],
		[
			18,
			-72
		],
		[
			42,
			52
		],
		[
			18,
			62
		],
		[
			37,
			31
		],
		[
			-6,
			83
		],
		[
			54,
			83
		],
		[
			48,
			41
		],
		[
			24,
			-83
		],
		[
			36,
			-21
		],
		[
			48,
			42
		]
	],
	[
		[
			44787,
			103476
		],
		[
			-6,
			0
		],
		[
			6,
			0
		]
	],
	[
		[
			20400,
			50707
		],
		[
			-12,
			-31
		],
		[
			-72,
			11
		],
		[
			18,
			83
		],
		[
			42,
			-11
		],
		[
			24,
			-52
		]
	],
	[
		[
			20803,
			48325
		],
		[
			-54,
			73
		],
		[
			-66,
			186
		],
		[
			6,
			62
		],
		[
			42,
			94
		],
		[
			0,
			93
		],
		[
			90,
			155
		],
		[
			54,
			124
		],
		[
			79,
			52
		],
		[
			30,
			52
		],
		[
			-6,
			104
		],
		[
			60,
			103
		],
		[
			24,
			145
		],
		[
			-12,
			73
		],
		[
			48,
			72
		],
		[
			186,
			124
		],
		[
			48,
			52
		],
		[
			36,
			0
		],
		[
			73,
			114
		],
		[
			18,
			73
		],
		[
			96,
			145
		],
		[
			90,
			72
		],
		[
			102,
			104
		],
		[
			18,
			-11
		],
		[
			72,
			94
		],
		[
			6,
			51
		],
		[
			-18,
			114
		],
		[
			49,
			93
		],
		[
			24,
			104
		],
		[
			36,
			83
		],
		[
			30,
			10
		],
		[
			18,
			125
		],
		[
			-18,
			124
		],
		[
			0,
			124
		],
		[
			-30,
			73
		],
		[
			48,
			82
		],
		[
			84,
			21
		],
		[
			48,
			31
		],
		[
			18,
			104
		],
		[
			96,
			62
		],
		[
			96,
			41
		],
		[
			43,
			125
		],
		[
			-12,
			62
		],
		[
			6,
			197
		],
		[
			78,
			93
		],
		[
			42,
			83
		],
		[
			114,
			83
		],
		[
			36,
			-11
		],
		[
			60,
			62
		],
		[
			132,
			0
		],
		[
			73,
			52
		],
		[
			60,
			0
		],
		[
			84,
			31
		],
		[
			54,
			145
		],
		[
			24,
			145
		],
		[
			60,
			52
		],
		[
			0,
			114
		],
		[
			42,
			41
		],
		[
			0,
			83
		],
		[
			-60,
			145
		],
		[
			-102,
			73
		],
		[
			-60,
			124
		],
		[
			-84,
			41
		],
		[
			90,
			52
		],
		[
			0,
			197
		]
	],
	[
		[
			26184,
			56207
		],
		[
			85,
			-62
		],
		[
			132,
			-52
		],
		[
			132,
			-104
		],
		[
			6,
			-41
		],
		[
			-42,
			-62
		],
		[
			162,
			-155
		],
		[
			139,
			-52
		],
		[
			6,
			-83
		],
		[
			42,
			-21
		],
		[
			66,
			11
		],
		[
			42,
			-63
		],
		[
			78,
			-31
		],
		[
			42,
			-62
		],
		[
			72,
			-41
		],
		[
			49,
			10
		],
		[
			90,
			-135
		],
		[
			12,
			73
		],
		[
			108,
			135
		],
		[
			102,
			10
		],
		[
			60,
			52
		],
		[
			181,
			10
		],
		[
			108,
			31
		],
		[
			30,
			-10
		],
		[
			72,
			41
		],
		[
			72,
			0
		],
		[
			30,
			-20
		],
		[
			91,
			10
		],
		[
			132,
			114
		]
	],
	[
		[
			28283,
			55710
		],
		[
			66,
			-42
		],
		[
			72,
			94
		],
		[
			84,
			31
		],
		[
			115,
			62
		],
		[
			36,
			-31
		],
		[
			126,
			72
		],
		[
			102,
			21
		],
		[
			96,
			-21
		],
		[
			181,
			73
		],
		[
			48,
			-104
		],
		[
			162,
			-124
		],
		[
			48,
			52
		],
		[
			54,
			-52
		],
		[
			205,
			-83
		],
		[
			174,
			-52
		]
	],
	[
		[
			25355,
			55731
		],
		[
			54,
			20
		],
		[
			66,
			-10
		],
		[
			36,
			62
		],
		[
			72,
			73
		],
		[
			-18,
			145
		],
		[
			-60,
			-32
		],
		[
			-18,
			63
		],
		[
			-12,
			134
		],
		[
			12,
			73
		]
	],
	[
		[
			25487,
			56259
		],
		[
			42,
			-73
		]
	],
	[
		[
			25529,
			56186
		],
		[
			102,
			52
		]
	],
	[
		[
			25631,
			56238
		],
		[
			-12,
			31
		]
	],
	[
		[
			25619,
			56269
		],
		[
			-6,
			10
		]
	],
	[
		[
			25613,
			56279
		],
		[
			60,
			-41
		],
		[
			-18,
			-41
		]
	],
	[
		[
			25655,
			56197
		],
		[
			30,
			-21
		],
		[
			43,
			52
		],
		[
			42,
			-21
		],
		[
			18,
			-104
		],
		[
			174,
			42
		],
		[
			96,
			41
		],
		[
			96,
			-62
		],
		[
			30,
			83
		]
	],
	[
		[
			27477,
			58983
		],
		[
			18,
			-83
		],
		[
			78,
			-11
		],
		[
			12,
			-51
		],
		[
			-48,
			-42
		],
		[
			60,
			-41
		],
		[
			49,
			41
		],
		[
			0,
			83
		],
		[
			96,
			-31
		],
		[
			-18,
			-104
		],
		[
			48,
			-51
		],
		[
			72,
			-11
		]
	],
	[
		[
			26690,
			58019
		],
		[
			-67,
			21
		],
		[
			-132,
			10
		],
		[
			-120,
			-31
		],
		[
			-126,
			0
		],
		[
			-12,
			-72
		],
		[
			-6,
			0
		],
		[
			-67,
			-52
		],
		[
			-48,
			0
		],
		[
			-18,
			-41
		],
		[
			-78,
			-31
		],
		[
			-90,
			10
		]
	],
	[
		[
			25926,
			57833
		],
		[
			-24,
			62
		],
		[
			0,
			104
		],
		[
			-36,
			51
		],
		[
			-36,
			-20
		],
		[
			-30,
			-104
		],
		[
			-139,
			-72
		],
		[
			-48,
			62
		],
		[
			-96,
			31
		],
		[
			-102,
			-31
		],
		[
			-96,
			10
		],
		[
			-103,
			104
		],
		[
			-90,
			-11
		],
		[
			-48,
			-103
		],
		[
			30,
			-73
		],
		[
			60,
			-93
		],
		[
			42,
			-21
		],
		[
			12,
			-186
		],
		[
			-36,
			-21
		],
		[
			42,
			-93
		],
		[
			-90,
			21
		],
		[
			-36,
			-83
		],
		[
			-60,
			-10
		],
		[
			-54,
			31
		],
		[
			-96,
			-21
		],
		[
			-42,
			21
		],
		[
			-157,
			186
		],
		[
			-54,
			10
		],
		[
			-132,
			-41
		],
		[
			-24,
			-52
		]
	],
	[
		[
			24483,
			57491
		],
		[
			-66,
			0
		],
		[
			-96,
			73
		],
		[
			-91,
			176
		],
		[
			-18,
			62
		],
		[
			-120,
			-21
		],
		[
			-72,
			83
		],
		[
			6,
			104
		],
		[
			-36,
			20
		],
		[
			-6,
			156
		],
		[
			-60,
			62
		],
		[
			108,
			41
		],
		[
			18,
			62
		]
	],
	[
		[
			24050,
			58309
		],
		[
			-54,
			52
		],
		[
			-96,
			11
		],
		[
			-42,
			-32
		],
		[
			-79,
			94
		],
		[
			-48,
			20
		],
		[
			-162,
			-20
		],
		[
			-66,
			31
		],
		[
			-102,
			-11
		],
		[
			-48,
			104
		]
	],
	[
		[
			23353,
			58558
		],
		[
			-42,
			41
		],
		[
			84,
			145
		],
		[
			0,
			63
		],
		[
			-54,
			41
		],
		[
			-127,
			10
		],
		[
			-114,
			62
		],
		[
			0,
			73
		],
		[
			-48,
			104
		],
		[
			-6,
			82
		],
		[
			-36,
			73
		],
		[
			12,
			62
		],
		[
			-120,
			114
		],
		[
			-72,
			114
		],
		[
			-43,
			93
		],
		[
			6,
			41
		],
		[
			55,
			83
		],
		[
			0,
			62
		],
		[
			-37,
			145
		],
		[
			-42,
			104
		],
		[
			-12,
			104
		],
		[
			18,
			31
		],
		[
			6,
			145
		],
		[
			36,
			41
		],
		[
			67,
			-21
		],
		[
			30,
			42
		],
		[
			42,
			-21
		],
		[
			36,
			52
		],
		[
			-114,
			62
		],
		[
			12,
			83
		]
	],
	[
		[
			22890,
			60588
		],
		[
			6,
			114
		],
		[
			36,
			21
		],
		[
			48,
			82
		]
	],
	[
		[
			22980,
			60805
		],
		[
			-54,
			31
		],
		[
			-72,
			-10
		],
		[
			-67,
			-31
		],
		[
			-36,
			41
		],
		[
			-96,
			32
		],
		[
			-12,
			-21
		],
		[
			-90,
			41
		],
		[
			-42,
			-10
		],
		[
			-54,
			-52
		],
		[
			-193,
			-21
		],
		[
			-36,
			94
		],
		[
			72,
			41
		],
		[
			-18,
			41
		],
		[
			-66,
			52
		],
		[
			-36,
			73
		],
		[
			-36,
			0
		],
		[
			-144,
			114
		],
		[
			-102,
			10
		],
		[
			24,
			62
		],
		[
			54,
			11
		],
		[
			18,
			51
		],
		[
			-12,
			83
		],
		[
			84,
			42
		],
		[
			36,
			124
		],
		[
			6,
			83
		],
		[
			84,
			0
		],
		[
			12,
			41
		],
		[
			96,
			62
		],
		[
			157,
			83
		],
		[
			96,
			-31
		],
		[
			36,
			31
		],
		[
			42,
			93
		],
		[
			-60,
			83
		],
		[
			42,
			42
		],
		[
			30,
			-11
		],
		[
			90,
			31
		],
		[
			30,
			52
		],
		[
			60,
			-52
		],
		[
			133,
			0
		],
		[
			66,
			104
		],
		[
			66,
			0
		],
		[
			24,
			31
		]
	],
	[
		[
			37897,
			68055
		],
		[
			-12,
			0
		]
	],
	[
		[
			37885,
			68055
		],
		[
			12,
			0
		]
	],
	[
		[
			38053,
			68356
		],
		[
			0,
			10
		]
	],
	[
		[
			38053,
			68366
		],
		[
			0,
			-10
		]
	],
	[
		[
			38071,
			68387
		],
		[
			-6,
			0
		]
	],
	[
		[
			38065,
			68387
		],
		[
			6,
			0
		]
	],
	[
		[
			37999,
			69174
		],
		[
			-6,
			-42
		],
		[
			-60,
			-165
		],
		[
			-30,
			-176
		],
		[
			-6,
			-156
		],
		[
			42,
			-93
		],
		[
			114,
			-52
		],
		[
			-42,
			-52
		],
		[
			60,
			-51
		]
	],
	[
		[
			38065,
			68387
		],
		[
			-12,
			-21
		]
	],
	[
		[
			38053,
			68356
		],
		[
			-24,
			-52
		]
	],
	[
		[
			38029,
			68304
		],
		[
			-24,
			-52
		],
		[
			6,
			0
		],
		[
			-30,
			-72
		],
		[
			-48,
			-21
		],
		[
			-6,
			0
		],
		[
			0,
			-11
		],
		[
			0,
			-10
		],
		[
			0,
			-31
		],
		[
			6,
			-10
		]
	],
	[
		[
			37933,
			68097
		],
		[
			-36,
			-42
		]
	],
	[
		[
			37897,
			68055
		],
		[
			-12,
			0
		]
	],
	[
		[
			37885,
			68055
		],
		[
			-24,
			-72
		]
	],
	[
		[
			37861,
			67983
		],
		[
			-72,
			31
		],
		[
			-121,
			21
		],
		[
			0,
			124
		],
		[
			-42,
			134
		],
		[
			-114,
			-10
		],
		[
			-36,
			-31
		],
		[
			-132,
			-10
		],
		[
			-12,
			-42
		],
		[
			-66,
			0
		],
		[
			-43,
			-41
		],
		[
			-36,
			10
		],
		[
			-48,
			-41
		],
		[
			-66,
			10
		],
		[
			-42,
			-52
		],
		[
			-48,
			-20
		],
		[
			-48,
			20
		],
		[
			-90,
			-20
		],
		[
			6,
			-63
		],
		[
			-54,
			-72
		],
		[
			-43,
			-21
		],
		[
			-72,
			21
		],
		[
			-96,
			-31
		],
		[
			-66,
			31
		],
		[
			150,
			93
		],
		[
			66,
			93
		],
		[
			-72,
			42
		],
		[
			-78,
			10
		],
		[
			-66,
			-31
		],
		[
			-78,
			0
		],
		[
			-120,
			62
		],
		[
			-55,
			11
		],
		[
			55,
			103
		],
		[
			0,
			145
		],
		[
			108,
			-41
		],
		[
			48,
			-52
		],
		[
			114,
			-10
		],
		[
			120,
			51
		],
		[
			67,
			135
		],
		[
			30,
			21
		],
		[
			78,
			124
		],
		[
			-48,
			104
		],
		[
			-54,
			10
		],
		[
			-12,
			93
		],
		[
			-73,
			52
		],
		[
			-54,
			93
		],
		[
			36,
			42
		],
		[
			54,
			-11
		],
		[
			-12,
			114
		],
		[
			12,
			135
		],
		[
			79,
			52
		],
		[
			42,
			-42
		],
		[
			36,
			42
		],
		[
			78,
			20
		],
		[
			12,
			-52
		],
		[
			78,
			11
		],
		[
			72,
			-11
		],
		[
			211,
			-176
		],
		[
			114,
			31
		],
		[
			66,
			-31
		],
		[
			66,
			63
		],
		[
			24,
			93
		],
		[
			193,
			-42
		],
		[
			42,
			-31
		],
		[
			66,
			-10
		],
		[
			84,
			-62
		]
	],
	[
		[
			37217,
			66605
		],
		[
			-6,
			0
		]
	],
	[
		[
			37211,
			66605
		],
		[
			6,
			0
		]
	],
	[
		[
			38805,
			70520
		],
		[
			0,
			-10
		]
	],
	[
		[
			38805,
			70510
		],
		[
			-6,
			0
		]
	],
	[
		[
			38799,
			70510
		],
		[
			6,
			10
		]
	],
	[
		[
			39015,
			70717
		],
		[
			-6,
			-10
		]
	],
	[
		[
			39009,
			70707
		],
		[
			6,
			10
		]
	],
	[
		[
			39406,
			71276
		],
		[
			-6,
			0
		]
	],
	[
		[
			39400,
			71276
		],
		[
			6,
			0
		]
	],
	[
		[
			39484,
			71369
		],
		[
			-6,
			-10
		]
	],
	[
		[
			39478,
			71359
		],
		[
			0,
			10
		]
	],
	[
		[
			39478,
			71369
		],
		[
			6,
			0
		]
	],
	[
		[
			39520,
			71401
		],
		[
			-6,
			0
		]
	],
	[
		[
			39514,
			71401
		],
		[
			6,
			0
		]
	],
	[
		[
			39616,
			71546
		],
		[
			0,
			-11
		]
	],
	[
		[
			39616,
			71535
		],
		[
			-6,
			0
		]
	],
	[
		[
			39610,
			71535
		],
		[
			0,
			11
		]
	],
	[
		[
			39610,
			71546
		],
		[
			6,
			0
		]
	],
	[
		[
			35702,
			73503
		],
		[
			-6,
			0
		]
	],
	[
		[
			35696,
			73503
		],
		[
			12,
			10
		],
		[
			-6,
			-10
		]
	],
	[
		[
			35798,
			73503
		],
		[
			-6,
			0
		]
	],
	[
		[
			35792,
			73503
		],
		[
			6,
			0
		]
	],
	[
		[
			38354,
			73700
		],
		[
			-6,
			-11
		]
	],
	[
		[
			38348,
			73689
		],
		[
			0,
			11
		]
	],
	[
		[
			38348,
			73700
		],
		[
			6,
			0
		]
	],
	[
		[
			33995,
			73679
		],
		[
			-6,
			0
		]
	],
	[
		[
			33989,
			73679
		],
		[
			6,
			10
		],
		[
			0,
			-10
		]
	],
	[
		[
			33977,
			73689
		],
		[
			12,
			-10
		]
	],
	[
		[
			33989,
			73679
		],
		[
			30,
			10
		]
	],
	[
		[
			34019,
			73689
		],
		[
			6,
			0
		]
	],
	[
		[
			34025,
			73689
		],
		[
			18,
			-82
		],
		[
			36,
			-11
		],
		[
			66,
			52
		],
		[
			6,
			0
		],
		[
			60,
			52
		],
		[
			60,
			-62
		],
		[
			115,
			0
		],
		[
			30,
			-31
		],
		[
			72,
			72
		],
		[
			102,
			-31
		],
		[
			66,
			-62
		],
		[
			168,
			-11
		],
		[
			67,
			21
		],
		[
			42,
			-31
		],
		[
			36,
			10
		],
		[
			60,
			32
		],
		[
			48,
			-73
		],
		[
			114,
			-52
		],
		[
			151,
			11
		],
		[
			6,
			-42
		],
		[
			48,
			-21
		],
		[
			96,
			94
		],
		[
			120,
			-11
		],
		[
			18,
			-10
		],
		[
			48,
			0
		],
		[
			18,
			0
		]
	],
	[
		[
			35702,
			73503
		],
		[
			24,
			10
		],
		[
			24,
			-20
		],
		[
			42,
			10
		]
	],
	[
		[
			35798,
			73503
		],
		[
			6,
			0
		],
		[
			79,
			0
		],
		[
			150,
			-31
		],
		[
			102,
			10
		],
		[
			108,
			62
		],
		[
			36,
			0
		],
		[
			55,
			-62
		],
		[
			144,
			73
		],
		[
			6,
			103
		]
	],
	[
		[
			36484,
			73658
		],
		[
			30,
			21
		],
		[
			96,
			41
		],
		[
			66,
			0
		],
		[
			12,
			-51
		],
		[
			78,
			-21
		],
		[
			67,
			-73
		],
		[
			102,
			32
		],
		[
			144,
			-52
		],
		[
			66,
			10
		]
	],
	[
		[
			37145,
			73565
		],
		[
			90,
			-62
		],
		[
			103,
			21
		],
		[
			102,
			93
		],
		[
			102,
			52
		],
		[
			102,
			103
		],
		[
			72,
			-31
		],
		[
			127,
			31
		],
		[
			60,
			0
		],
		[
			108,
			-31
		],
		[
			96,
			-52
		],
		[
			109,
			52
		],
		[
			66,
			-10
		],
		[
			54,
			31
		],
		[
			18,
			-62
		]
	],
	[
		[
			38354,
			73700
		],
		[
			-6,
			0
		]
	],
	[
		[
			38348,
			73700
		],
		[
			0,
			-11
		]
	],
	[
		[
			38348,
			73689
		],
		[
			12,
			0
		],
		[
			-12,
			-72
		],
		[
			90,
			-52
		],
		[
			72,
			-21
		],
		[
			108,
			-10
		],
		[
			54,
			52
		],
		[
			139,
			-52
		],
		[
			12,
			-72
		],
		[
			114,
			-135
		],
		[
			72,
			-145
		],
		[
			102,
			-104
		],
		[
			115,
			-62
		],
		[
			126,
			-52
		],
		[
			36,
			-62
		],
		[
			-42,
			-103
		],
		[
			0,
			-114
		],
		[
			36,
			-145
		],
		[
			78,
			-114
		],
		[
			36,
			-114
		],
		[
			-30,
			-83
		],
		[
			0,
			-52
		],
		[
			66,
			-145
		],
		[
			30,
			11
		],
		[
			42,
			-42
		],
		[
			49,
			-10
		],
		[
			12,
			-83
		],
		[
			-97,
			10
		],
		[
			-24,
			-82
		],
		[
			60,
			-21
		],
		[
			-18,
			-114
		],
		[
			54,
			-83
		]
	],
	[
		[
			39640,
			71618
		],
		[
			-12,
			-21
		],
		[
			-6,
			-10
		]
	],
	[
		[
			39622,
			71587
		],
		[
			6,
			0
		],
		[
			-12,
			-41
		]
	],
	[
		[
			39610,
			71535
		],
		[
			6,
			0
		]
	],
	[
		[
			39616,
			71535
		],
		[
			-84,
			-83
		],
		[
			-6,
			0
		]
	],
	[
		[
			39526,
			71452
		],
		[
			-12,
			-51
		]
	],
	[
		[
			39520,
			71401
		],
		[
			-36,
			-32
		]
	],
	[
		[
			39484,
			71369
		],
		[
			-6,
			0
		]
	],
	[
		[
			39478,
			71359
		],
		[
			-30,
			-52
		],
		[
			-48,
			-31
		]
	],
	[
		[
			39406,
			71276
		],
		[
			-18,
			-93
		]
	],
	[
		[
			39388,
			71183
		],
		[
			-54,
			-83
		]
	],
	[
		[
			39334,
			71100
		],
		[
			12,
			0
		],
		[
			-12,
			0
		]
	],
	[
		[
			39334,
			71100
		],
		[
			-12,
			-21
		],
		[
			-6,
			0
		],
		[
			-30,
			-41
		],
		[
			-6,
			0
		],
		[
			-6,
			0
		],
		[
			-6,
			0
		],
		[
			-6,
			0
		],
		[
			-6,
			0
		],
		[
			-24,
			41
		],
		[
			-85,
			-82
		],
		[
			-12,
			-52
		],
		[
			12,
			-114
		],
		[
			-60,
			-42
		]
	],
	[
		[
			39087,
			70789
		],
		[
			-30,
			-31
		],
		[
			-24,
			-20
		]
	],
	[
		[
			39033,
			70738
		],
		[
			-6,
			-11
		],
		[
			-12,
			-10
		]
	],
	[
		[
			39015,
			70717
		],
		[
			-6,
			-10
		]
	],
	[
		[
			39009,
			70707
		],
		[
			-42,
			-11
		],
		[
			0,
			-10
		],
		[
			-6,
			-10
		],
		[
			-96,
			-73
		],
		[
			0,
			-31
		],
		[
			-66,
			-52
		],
		[
			0,
			-10
		]
	],
	[
		[
			38805,
			70510
		],
		[
			-108,
			-93
		],
		[
			-67,
			-83
		],
		[
			-6,
			-31
		],
		[
			-12,
			-11
		],
		[
			-72,
			-20
		],
		[
			-108,
			-104
		],
		[
			-66,
			135
		],
		[
			-6,
			93
		],
		[
			48,
			41
		],
		[
			-12,
			42
		],
		[
			-90,
			-73
		],
		[
			-6,
			-72
		],
		[
			60,
			-31
		],
		[
			-6,
			-73
		],
		[
			48,
			-72
		],
		[
			6,
			-104
		],
		[
			-156,
			-269
		],
		[
			-145,
			-311
		],
		[
			-72,
			-186
		],
		[
			-36,
			-114
		]
	],
	[
		[
			37861,
			67983
		],
		[
			-54,
			-104
		],
		[
			6,
			-62
		],
		[
			-60,
			-31
		],
		[
			-6,
			-73
		],
		[
			-37,
			0
		],
		[
			-66,
			-82
		],
		[
			-30,
			-83
		],
		[
			-54,
			-62
		],
		[
			-36,
			0
		],
		[
			-18,
			-73
		],
		[
			-84,
			-62
		],
		[
			0,
			-83
		],
		[
			-42,
			0
		],
		[
			6,
			-72
		],
		[
			-36,
			-31
		],
		[
			-36,
			-73
		],
		[
			-12,
			-93
		],
		[
			-85,
			-62
		],
		[
			-60,
			-73
		],
		[
			0,
			-41
		],
		[
			42,
			-62
		],
		[
			-6,
			-73
		],
		[
			24,
			-83
		]
	],
	[
		[
			37211,
			66605
		],
		[
			-12,
			-155
		]
	],
	[
		[
			37199,
			66450
		],
		[
			18,
			-93
		],
		[
			-60,
			-114
		],
		[
			-36,
			-42
		],
		[
			-6,
			-114
		],
		[
			-36,
			-82
		],
		[
			-24,
			-11
		],
		[
			-48,
			-103
		],
		[
			-66,
			-42
		],
		[
			-66,
			-103
		],
		[
			-115,
			-62
		],
		[
			-12,
			-114
		],
		[
			-66,
			-11
		],
		[
			-36,
			-83
		],
		[
			-36,
			-31
		],
		[
			-36,
			-83
		],
		[
			-108,
			-103
		],
		[
			-66,
			-42
		],
		[
			-121,
			-41
		],
		[
			-114,
			-135
		],
		[
			-30,
			21
		],
		[
			-102,
			-10
		],
		[
			-48,
			-52
		],
		[
			-96,
			-135
		],
		[
			-72,
			-31
		]
	],
	[
		[
			35817,
			64834
		],
		[
			-37,
			11
		]
	],
	[
		[
			35780,
			64845
		],
		[
			-84,
			-52
		],
		[
			-84,
			72
		],
		[
			-18,
			73
		],
		[
			-36,
			31
		],
		[
			-108,
			41
		],
		[
			-24,
			42
		],
		[
			-54,
			10
		],
		[
			-12,
			42
		],
		[
			-67,
			51
		],
		[
			-90,
			-31
		],
		[
			-78,
			52
		],
		[
			-66,
			-21
		],
		[
			-108,
			31
		],
		[
			-84,
			-51
		],
		[
			-73,
			0
		],
		[
			-6,
			93
		],
		[
			-54,
			62
		],
		[
			-30,
			93
		],
		[
			-72,
			21
		],
		[
			-30,
			31
		],
		[
			-6,
			72
		],
		[
			-90,
			114
		],
		[
			-30,
			114
		],
		[
			18,
			31
		],
		[
			30,
			176
		],
		[
			12,
			156
		],
		[
			-48,
			52
		],
		[
			-66,
			-32
		],
		[
			12,
			145
		],
		[
			-6,
			52
		],
		[
			-42,
			62
		],
		[
			-133,
			94
		],
		[
			-84,
			10
		],
		[
			-96,
			217
		],
		[
			-144,
			104
		],
		[
			-97,
			-31
		],
		[
			-114,
			10
		],
		[
			-84,
			42
		],
		[
			-42,
			0
		],
		[
			-54,
			103
		],
		[
			-102,
			-10
		],
		[
			-91,
			83
		],
		[
			-42,
			-11
		],
		[
			-54,
			52
		],
		[
			-48,
			11
		],
		[
			-120,
			-42
		],
		[
			-18,
			-62
		],
		[
			-48,
			-31
		],
		[
			-121,
			10
		],
		[
			-48,
			-62
		],
		[
			-78,
			31
		],
		[
			-84,
			-20
		],
		[
			-72,
			0
		],
		[
			-24,
			31
		],
		[
			-54,
			-42
		],
		[
			-60,
			21
		],
		[
			-49,
			41
		],
		[
			-18,
			-31
		],
		[
			-108,
			-62
		],
		[
			-60,
			10
		],
		[
			-48,
			-41
		],
		[
			-90,
			-10
		],
		[
			-6,
			-83
		],
		[
			-60,
			0
		],
		[
			-24,
			-42
		],
		[
			24,
			-124
		],
		[
			-97,
			-135
		],
		[
			-6,
			-145
		],
		[
			31,
			-72
		],
		[
			-55,
			-21
		],
		[
			-24,
			-41
		],
		[
			-84,
			10
		],
		[
			-24,
			73
		],
		[
			-48,
			51
		],
		[
			-114,
			52
		],
		[
			-114,
			-41
		],
		[
			-73,
			21
		],
		[
			-24,
			31
		],
		[
			-120,
			41
		],
		[
			-60,
			41
		],
		[
			-180,
			11
		],
		[
			-36,
			41
		],
		[
			-73,
			42
		],
		[
			-36,
			-21
		],
		[
			42,
			-124
		],
		[
			-30,
			-52
		],
		[
			-54,
			-21
		],
		[
			-24,
			-52
		],
		[
			-108,
			-41
		],
		[
			-90,
			10
		],
		[
			-66,
			-62
		],
		[
			-30,
			-52
		],
		[
			-49,
			0
		],
		[
			-60,
			-93
		]
	],
	[
		[
			33724,
			73720
		],
		[
			42,
			52
		],
		[
			48,
			-52
		],
		[
			48,
			-20
		],
		[
			115,
			-11
		]
	],
	[
		[
			17725,
			51039
		],
		[
			18,
			-83
		],
		[
			-60,
			0
		],
		[
			-24,
			-31
		],
		[
			-60,
			31
		],
		[
			0,
			62
		],
		[
			42,
			21
		],
		[
			42,
			-31
		],
		[
			42,
			31
		]
	],
	[
		[
			14436,
			54115
		],
		[
			-6,
			0
		]
	],
	[
		[
			14430,
			54115
		],
		[
			6,
			0
		]
	],
	[
		[
			14430,
			54115
		],
		[
			6,
			0
		]
	],
	[
		[
			16715,
			54363
		],
		[
			-18,
			-134
		],
		[
			-42,
			52
		],
		[
			60,
			82
		]
	],
	[
		[
			14791,
			54374
		],
		[
			-6,
			-11
		],
		[
			6,
			11
		]
	],
	[
		[
			16739,
			54477
		],
		[
			0,
			-10
		]
	],
	[
		[
			16739,
			54467
		],
		[
			0,
			10
		]
	],
	[
		[
			16679,
			54467
		],
		[
			0,
			10
		]
	],
	[
		[
			16679,
			54477
		],
		[
			0,
			-10
		]
	],
	[
		[
			16745,
			54446
		],
		[
			-6,
			0
		],
		[
			6,
			0
		]
	],
	[
		[
			16739,
			54477
		],
		[
			0,
			-10
		]
	],
	[
		[
			14779,
			54384
		],
		[
			-36,
			10
		]
	],
	[
		[
			14743,
			54394
		],
		[
			36,
			-10
		]
	],
	[
		[
			14737,
			54405
		],
		[
			6,
			-11
		]
	],
	[
		[
			14743,
			54394
		],
		[
			-6,
			11
		]
	],
	[
		[
			14989,
			54498
		],
		[
			12,
			10
		]
	],
	[
		[
			15001,
			54508
		],
		[
			-12,
			-10
		]
	],
	[
		[
			15025,
			54519
		],
		[
			-6,
			0
		]
	],
	[
		[
			15019,
			54519
		],
		[
			6,
			0
		]
	],
	[
		[
			15031,
			54550
		],
		[
			-6,
			-31
		]
	],
	[
		[
			15019,
			54519
		],
		[
			-6,
			20
		]
	],
	[
		[
			15013,
			54539
		],
		[
			18,
			11
		]
	],
	[
		[
			15031,
			54550
		],
		[
			-18,
			-11
		]
	],
	[
		[
			15013,
			54539
		],
		[
			18,
			11
		]
	],
	[
		[
			14953,
			54581
		],
		[
			6,
			-10
		]
	],
	[
		[
			14959,
			54571
		],
		[
			-6,
			10
		]
	],
	[
		[
			14959,
			54571
		],
		[
			-6,
			10
		]
	],
	[
		[
			14953,
			54581
		],
		[
			6,
			-10
		]
	],
	[
		[
			14971,
			54643
		],
		[
			18,
			10
		],
		[
			-18,
			-10
		]
	],
	[
		[
			15085,
			54653
		],
		[
			6,
			0
		]
	],
	[
		[
			15091,
			54653
		],
		[
			-6,
			0
		]
	],
	[
		[
			15085,
			54653
		],
		[
			6,
			0
		]
	],
	[
		[
			16859,
			54809
		],
		[
			-6,
			-11
		]
	],
	[
		[
			16853,
			54798
		],
		[
			6,
			11
		]
	],
	[
		[
			12314,
			54664
		],
		[
			-12,
			10
		]
	],
	[
		[
			12302,
			54674
		],
		[
			12,
			-10
		]
	],
	[
		[
			12302,
			54674
		],
		[
			-18,
			10
		],
		[
			30,
			-20
		]
	],
	[
		[
			16775,
			55016
		],
		[
			0,
			10
		]
	],
	[
		[
			16775,
			55026
		],
		[
			0,
			-10
		]
	],
	[
		[
			12290,
			54809
		],
		[
			-12,
			0
		]
	],
	[
		[
			12278,
			54809
		],
		[
			12,
			0
		]
	],
	[
		[
			16913,
			55119
		],
		[
			-66,
			-62
		]
	],
	[
		[
			16847,
			55057
		],
		[
			-42,
			-41
		],
		[
			60,
			-83
		],
		[
			-36,
			-10
		],
		[
			-30,
			-114
		],
		[
			18,
			-31
		],
		[
			36,
			20
		]
	],
	[
		[
			16853,
			54798
		],
		[
			6,
			11
		]
	],
	[
		[
			16859,
			54809
		],
		[
			-48,
			-62
		],
		[
			-36,
			-42
		],
		[
			36,
			-103
		],
		[
			-126,
			-104
		],
		[
			-6,
			-21
		]
	],
	[
		[
			16679,
			54477
		],
		[
			0,
			-10
		]
	],
	[
		[
			16679,
			54467
		],
		[
			-54,
			-41
		],
		[
			-18,
			62
		]
	],
	[
		[
			16607,
			54488
		],
		[
			6,
			72
		],
		[
			30,
			52
		],
		[
			-79,
			62
		]
	],
	[
		[
			16564,
			54674
		],
		[
			49,
			135
		],
		[
			108,
			145
		],
		[
			18,
			52
		],
		[
			36,
			10
		]
	],
	[
		[
			16775,
			55016
		],
		[
			0,
			10
		]
	],
	[
		[
			16775,
			55026
		],
		[
			-6,
			31
		]
	],
	[
		[
			16769,
			55057
		],
		[
			12,
			52
		],
		[
			6,
			42
		],
		[
			48,
			41
		],
		[
			6,
			21
		],
		[
			66,
			-42
		],
		[
			6,
			-52
		]
	],
	[
		[
			12380,
			55037
		],
		[
			6,
			10
		]
	],
	[
		[
			12386,
			55047
		],
		[
			-6,
			-10
		]
	],
	[
		[
			20106,
			55927
		],
		[
			72,
			-186
		],
		[
			-36,
			-83
		],
		[
			-30,
			0
		],
		[
			-42,
			93
		],
		[
			0,
			145
		],
		[
			36,
			31
		]
	],
	[
		[
			13745,
			55720
		],
		[
			-24,
			0
		]
	],
	[
		[
			13721,
			55720
		],
		[
			6,
			0
		]
	],
	[
		[
			13727,
			55720
		],
		[
			18,
			0
		]
	],
	[
		[
			15542,
			56000
		],
		[
			0,
			10
		],
		[
			0,
			-10
		]
	],
	[
		[
			13191,
			56600
		],
		[
			-6,
			11
		]
	],
	[
		[
			13185,
			56611
		],
		[
			6,
			-11
		]
	],
	[
		[
			13215,
			56632
		],
		[
			-6,
			0
		]
	],
	[
		[
			13209,
			56632
		],
		[
			6,
			0
		]
	],
	[
		[
			15981,
			56828
		],
		[
			-6,
			0
		]
	],
	[
		[
			15975,
			56828
		],
		[
			6,
			0
		]
	],
	[
		[
			19974,
			57056
		],
		[
			78,
			-41
		],
		[
			66,
			0
		],
		[
			108,
			-135
		],
		[
			150,
			-135
		],
		[
			97,
			-41
		],
		[
			54,
			-52
		],
		[
			60,
			-20
		],
		[
			0,
			-73
		],
		[
			-84,
			-62
		],
		[
			60,
			-52
		],
		[
			54,
			11
		],
		[
			54,
			-21
		],
		[
			-6,
			-104
		],
		[
			24,
			-83
		],
		[
			42,
			-10
		],
		[
			90,
			62
		],
		[
			54,
			0
		],
		[
			18,
			-41
		],
		[
			0,
			-218
		],
		[
			49,
			-165
		],
		[
			12,
			-114
		],
		[
			66,
			-125
		],
		[
			6,
			-51
		],
		[
			-48,
			-52
		],
		[
			-115,
			-31
		],
		[
			-6,
			-62
		],
		[
			103,
			-73
		],
		[
			30,
			-52
		],
		[
			18,
			-93
		],
		[
			-18,
			-31
		],
		[
			-72,
			0
		],
		[
			-67,
			-52
		],
		[
			-96,
			93
		],
		[
			-36,
			11
		],
		[
			-6,
			103
		],
		[
			-30,
			21
		],
		[
			-6,
			114
		],
		[
			-66,
			41
		],
		[
			-24,
			52
		],
		[
			-42,
			0
		],
		[
			-108,
			114
		],
		[
			-79,
			-83
		],
		[
			-66,
			135
		],
		[
			-6,
			52
		],
		[
			36,
			93
		],
		[
			-24,
			83
		],
		[
			-84,
			41
		],
		[
			18,
			207
		],
		[
			54,
			31
		],
		[
			0,
			52
		],
		[
			-72,
			62
		],
		[
			-66,
			-41
		],
		[
			-96,
			41
		],
		[
			-78,
			125
		],
		[
			-55,
			20
		],
		[
			-78,
			156
		],
		[
			-42,
			31
		],
		[
			12,
			51
		],
		[
			-24,
			73
		],
		[
			30,
			93
		],
		[
			157,
			145
		]
	],
	[
		[
			16979,
			57129
		],
		[
			6,
			0
		]
	],
	[
		[
			16985,
			57129
		],
		[
			-6,
			0
		]
	],
	[
		[
			15001,
			54674
		],
		[
			-36,
			-31
		],
		[
			-42,
			-93
		],
		[
			-72,
			41
		],
		[
			-30,
			-72
		],
		[
			30,
			-42
		],
		[
			-24,
			-83
		],
		[
			-36,
			-20
		]
	],
	[
		[
			14791,
			54374
		],
		[
			-12,
			10
		]
	],
	[
		[
			14779,
			54384
		],
		[
			-36,
			42
		],
		[
			-109,
			-52
		],
		[
			-66,
			-62
		],
		[
			-66,
			0
		],
		[
			-78,
			-73
		],
		[
			-36,
			31
		],
		[
			-84,
			11
		],
		[
			-72,
			-52
		],
		[
			-97,
			72
		],
		[
			-66,
			0
		],
		[
			-66,
			-31
		],
		[
			6,
			-103
		],
		[
			-48,
			-94
		],
		[
			-36,
			-20
		],
		[
			-24,
			-83
		],
		[
			-42,
			-62
		],
		[
			-54,
			0
		],
		[
			-60,
			-42
		],
		[
			-36,
			-62
		],
		[
			-103,
			10
		],
		[
			-60,
			-10
		],
		[
			-36,
			42
		],
		[
			-54,
			-21
		],
		[
			-6,
			62
		],
		[
			-138,
			0
		],
		[
			24,
			166
		]
	],
	[
		[
			13336,
			54053
		],
		[
			0,
			72
		]
	],
	[
		[
			13336,
			54125
		],
		[
			60,
			166
		],
		[
			66,
			72
		],
		[
			12,
			63
		],
		[
			48,
			41
		]
	],
	[
		[
			13522,
			54467
		],
		[
			120,
			10
		],
		[
			36,
			-20
		],
		[
			79,
			82
		],
		[
			-54,
			228
		],
		[
			-103,
			187
		],
		[
			-84,
			93
		],
		[
			-54,
			41
		],
		[
			-162,
			11
		],
		[
			36,
			145
		],
		[
			6,
			72
		],
		[
			84,
			42
		],
		[
			18,
			31
		],
		[
			54,
			0
		],
		[
			54,
			72
		],
		[
			199,
			83
		],
		[
			36,
			52
		],
		[
			12,
			62
		],
		[
			-54,
			62
		]
	],
	[
		[
			13745,
			55720
		],
		[
			-18,
			0
		]
	],
	[
		[
			13727,
			55720
		],
		[
			-6,
			0
		]
	],
	[
		[
			13721,
			55720
		],
		[
			-103,
			-21
		],
		[
			-42,
			32
		],
		[
			-66,
			-21
		],
		[
			-78,
			31
		],
		[
			-78,
			10
		],
		[
			-102,
			-20
		],
		[
			-30,
			-94
		],
		[
			-97,
			-165
		],
		[
			-12,
			-104
		],
		[
			-108,
			-186
		],
		[
			-102,
			-114
		],
		[
			-66,
			-104
		],
		[
			-145,
			-103
		],
		[
			-36,
			-42
		],
		[
			-120,
			-62
		],
		[
			-66,
			-83
		],
		[
			-126,
			21
		],
		[
			-66,
			114
		]
	],
	[
		[
			12290,
			54809
		],
		[
			-61,
			41
		],
		[
			55,
			62
		]
	],
	[
		[
			12284,
			54912
		],
		[
			96,
			125
		]
	],
	[
		[
			12386,
			55047
		],
		[
			-42,
			72
		],
		[
			6,
			73
		],
		[
			48,
			83
		],
		[
			66,
			83
		]
	],
	[
		[
			12464,
			55358
		],
		[
			78,
			103
		],
		[
			6,
			31
		]
	],
	[
		[
			12548,
			55492
		],
		[
			0,
			11
		],
		[
			54,
			83
		],
		[
			24,
			31
		],
		[
			-6,
			93
		],
		[
			-30,
			41
		],
		[
			-90,
			0
		],
		[
			-42,
			42
		],
		[
			6,
			51
		],
		[
			96,
			94
		],
		[
			54,
			31
		],
		[
			-18,
			197
		],
		[
			30,
			51
		],
		[
			6,
			156
		],
		[
			121,
			31
		],
		[
			36,
			41
		],
		[
			60,
			-62
		]
	],
	[
		[
			12849,
			56383
		],
		[
			30,
			21
		],
		[
			102,
			10
		],
		[
			60,
			104
		],
		[
			42,
			10
		],
		[
			42,
			62
		],
		[
			66,
			10
		]
	],
	[
		[
			13191,
			56600
		],
		[
			-6,
			11
		]
	],
	[
		[
			13185,
			56611
		],
		[
			24,
			21
		]
	],
	[
		[
			13215,
			56632
		],
		[
			37,
			20
		],
		[
			72,
			83
		],
		[
			54,
			0
		],
		[
			12,
			-62
		],
		[
			-18,
			-62
		],
		[
			-66,
			-93
		],
		[
			6,
			-135
		],
		[
			-54,
			-166
		],
		[
			54,
			-103
		],
		[
			54,
			-11
		],
		[
			24,
			52
		],
		[
			-30,
			42
		],
		[
			42,
			72
		],
		[
			24,
			114
		],
		[
			36,
			21
		],
		[
			24,
			103
		],
		[
			-24,
			73
		],
		[
			186,
			20
		],
		[
			67,
			73
		],
		[
			0,
			52
		],
		[
			66,
			20
		],
		[
			84,
			52
		],
		[
			120,
			135
		],
		[
			36,
			0
		],
		[
			96,
			124
		],
		[
			139,
			0
		],
		[
			54,
			73
		],
		[
			126,
			0
		],
		[
			24,
			31
		],
		[
			90,
			10
		],
		[
			12,
			-52
		],
		[
			-6,
			-145
		],
		[
			-54,
			-196
		],
		[
			6,
			-94
		],
		[
			48,
			-20
		],
		[
			30,
			-104
		],
		[
			42,
			-93
		],
		[
			43,
			-218
		],
		[
			-25,
			-186
		],
		[
			6,
			-52
		],
		[
			73,
			-145
		],
		[
			6,
			-83
		],
		[
			36,
			-20
		],
		[
			18,
			-63
		],
		[
			114,
			-62
		],
		[
			84,
			-114
		],
		[
			6,
			-31
		],
		[
			-36,
			-165
		],
		[
			60,
			-104
		],
		[
			54,
			0
		],
		[
			18,
			-52
		],
		[
			-42,
			-93
		],
		[
			-18,
			-93
		],
		[
			72,
			-93
		],
		[
			18,
			-73
		],
		[
			0,
			-83
		],
		[
			-42,
			-41
		],
		[
			-72,
			-21
		]
	],
	[
		[
			16979,
			57129
		],
		[
			-24,
			51
		]
	],
	[
		[
			16955,
			57180
		],
		[
			48,
			156
		],
		[
			54,
			10
		]
	],
	[
		[
			17057,
			57346
		],
		[
			73,
			-62
		],
		[
			-79,
			-135
		],
		[
			-66,
			-20
		]
	],
	[
		[
			15987,
			57502
		],
		[
			-12,
			0
		]
	],
	[
		[
			15975,
			57502
		],
		[
			12,
			0
		]
	],
	[
		[
			15266,
			57512
		],
		[
			-12,
			-10
		]
	],
	[
		[
			15254,
			57502
		],
		[
			6,
			10
		]
	],
	[
		[
			15260,
			57512
		],
		[
			6,
			0
		]
	],
	[
		[
			15248,
			57605
		],
		[
			-6,
			10
		]
	],
	[
		[
			15242,
			57615
		],
		[
			6,
			-10
		]
	],
	[
		[
			15308,
			57750
		],
		[
			-6,
			0
		]
	],
	[
		[
			15302,
			57750
		],
		[
			6,
			0
		]
	],
	[
		[
			16516,
			57885
		],
		[
			-12,
			10
		]
	],
	[
		[
			16504,
			57895
		],
		[
			12,
			-10
		]
	],
	[
		[
			13690,
			57750
		],
		[
			-24,
			-10
		]
	],
	[
		[
			13666,
			57740
		],
		[
			24,
			10
		]
	],
	[
		[
			17605,
			58040
		],
		[
			6,
			21
		]
	],
	[
		[
			17611,
			58061
		],
		[
			-6,
			-21
		]
	],
	[
		[
			17629,
			58050
		],
		[
			24,
			32
		]
	],
	[
		[
			17653,
			58082
		],
		[
			-24,
			-32
		]
	],
	[
		[
			17635,
			58082
		],
		[
			0,
			10
		]
	],
	[
		[
			17635,
			58092
		],
		[
			0,
			-10
		]
	],
	[
		[
			13745,
			57916
		],
		[
			-61,
			31
		],
		[
			6,
			41
		],
		[
			85,
			0
		],
		[
			12,
			21
		],
		[
			120,
			-10
		],
		[
			36,
			31
		],
		[
			66,
			-21
		],
		[
			-12,
			-72
		],
		[
			-60,
			10
		],
		[
			-30,
			-42
		],
		[
			-12,
			-72
		],
		[
			-54,
			-21
		],
		[
			-48,
			-52
		],
		[
			6,
			125
		],
		[
			-54,
			31
		]
	],
	[
		[
			13805,
			58082
		],
		[
			-6,
			0
		],
		[
			6,
			0
		]
	],
	[
		[
			13805,
			58082
		],
		[
			0,
			10
		]
	],
	[
		[
			13805,
			58092
		],
		[
			0,
			-10
		]
	],
	[
		[
			17484,
			58869
		],
		[
			-6,
			0
		]
	],
	[
		[
			17478,
			58869
		],
		[
			6,
			0
		]
	],
	[
		[
			17478,
			58869
		],
		[
			6,
			0
		]
	],
	[
		[
			13805,
			58092
		],
		[
			48,
			52
		],
		[
			-18,
			41
		],
		[
			-66,
			-31
		],
		[
			-79,
			-62
		],
		[
			19,
			93
		],
		[
			48,
			10
		],
		[
			0,
			104
		],
		[
			42,
			41
		],
		[
			30,
			83
		],
		[
			-18,
			31
		],
		[
			12,
			83
		],
		[
			84,
			104
		],
		[
			108,
			52
		],
		[
			18,
			51
		],
		[
			72,
			31
		],
		[
			79,
			-51
		],
		[
			60,
			51
		],
		[
			-18,
			42
		],
		[
			60,
			72
		],
		[
			6,
			42
		],
		[
			54,
			0
		],
		[
			42,
			83
		],
		[
			90,
			-114
		],
		[
			-66,
			-135
		],
		[
			-72,
			-103
		],
		[
			-36,
			-73
		],
		[
			-12,
			-93
		],
		[
			-72,
			-31
		],
		[
			-43,
			-104
		],
		[
			-48,
			-10
		],
		[
			67,
			-104
		],
		[
			-12,
			-93
		],
		[
			-121,
			-104
		],
		[
			-66,
			-20
		],
		[
			0,
			83
		],
		[
			-48,
			20
		],
		[
			-12,
			-51
		],
		[
			-66,
			-21
		],
		[
			-66,
			31
		]
	],
	[
		[
			17418,
			59138
		],
		[
			6,
			21
		]
	],
	[
		[
			17424,
			59159
		],
		[
			-6,
			-21
		]
	],
	[
		[
			16625,
			58071
		],
		[
			-30,
			-72
		],
		[
			-79,
			-114
		]
	],
	[
		[
			16516,
			57885
		],
		[
			-12,
			10
		]
	],
	[
		[
			16504,
			57895
		],
		[
			-54,
			-10
		],
		[
			-24,
			-83
		],
		[
			-42,
			-52
		],
		[
			-54,
			-186
		],
		[
			-78,
			-104
		],
		[
			-36,
			0
		],
		[
			-18,
			-103
		],
		[
			-66,
			-114
		],
		[
			6,
			-73
		],
		[
			-30,
			-83
		],
		[
			-73,
			-103
		],
		[
			-18,
			0
		],
		[
			-42,
			-156
		]
	],
	[
		[
			15975,
			56828
		],
		[
			-12,
			-83
		],
		[
			-60,
			11
		],
		[
			-60,
			-42
		],
		[
			-12,
			-51
		],
		[
			30,
			-63
		],
		[
			-18,
			-62
		],
		[
			-138,
			21
		],
		[
			-78,
			-52
		],
		[
			-37,
			-93
		],
		[
			-24,
			-135
		],
		[
			-24,
			-62
		],
		[
			36,
			-72
		],
		[
			-6,
			-52
		],
		[
			-42,
			-52
		],
		[
			12,
			-41
		]
	],
	[
		[
			15542,
			56000
		],
		[
			-42,
			-62
		],
		[
			6,
			-42
		],
		[
			-42,
			-93
		],
		[
			-78,
			0
		],
		[
			-36,
			41
		],
		[
			-30,
			-20
		],
		[
			-60,
			20
		],
		[
			-102,
			11
		],
		[
			-97,
			-21
		],
		[
			-30,
			52
		],
		[
			-96,
			21
		],
		[
			-72,
			51
		],
		[
			-78,
			125
		],
		[
			-30,
			93
		],
		[
			6,
			83
		],
		[
			-30,
			62
		],
		[
			30,
			155
		],
		[
			-54,
			52
		],
		[
			18,
			114
		],
		[
			-6,
			93
		],
		[
			66,
			93
		],
		[
			48,
			42
		],
		[
			54,
			165
		],
		[
			30,
			11
		],
		[
			96,
			155
		],
		[
			54,
			11
		],
		[
			36,
			51
		],
		[
			61,
			-10
		],
		[
			84,
			62
		],
		[
			42,
			-31
		],
		[
			72,
			0
		],
		[
			84,
			21
		],
		[
			36,
			41
		],
		[
			96,
			-21
		],
		[
			85,
			52
		],
		[
			138,
			11
		],
		[
			60,
			51
		],
		[
			60,
			0
		],
		[
			54,
			63
		]
	],
	[
		[
			15975,
			57502
		],
		[
			12,
			0
		]
	],
	[
		[
			15987,
			57502
		],
		[
			36,
			20
		]
	],
	[
		[
			16023,
			57522
		],
		[
			24,
			-10
		],
		[
			61,
			41
		],
		[
			-13,
			114
		],
		[
			-66,
			-114
		],
		[
			-48,
			-31
		],
		[
			-66,
			-20
		],
		[
			6,
			72
		],
		[
			-48,
			21
		],
		[
			-18,
			-73
		],
		[
			-114,
			-10
		],
		[
			-48,
			-104
		],
		[
			-36,
			21
		],
		[
			-49,
			-41
		],
		[
			-66,
			20
		]
	],
	[
		[
			15542,
			57408
		],
		[
			-48,
			52
		],
		[
			-42,
			-31
		],
		[
			-60,
			62
		],
		[
			-126,
			21
		]
	],
	[
		[
			15260,
			57512
		],
		[
			-6,
			-10
		]
	],
	[
		[
			15254,
			57502
		],
		[
			-30,
			20
		],
		[
			24,
			83
		]
	],
	[
		[
			15248,
			57605
		],
		[
			-6,
			10
		]
	],
	[
		[
			15242,
			57615
		],
		[
			18,
			63
		],
		[
			42,
			72
		]
	],
	[
		[
			15308,
			57750
		],
		[
			90,
			104
		],
		[
			66,
			51
		],
		[
			0,
			114
		],
		[
			90,
			104
		],
		[
			73,
			31
		],
		[
			54,
			52
		],
		[
			60,
			21
		],
		[
			60,
			93
		],
		[
			96,
			83
		],
		[
			66,
			31
		]
	],
	[
		[
			15963,
			58434
		],
		[
			78,
			62
		],
		[
			6,
			10
		],
		[
			103,
			31
		],
		[
			48,
			62
		],
		[
			90,
			0
		],
		[
			-12,
			52
		],
		[
			30,
			62
		],
		[
			42,
			21
		],
		[
			60,
			83
		],
		[
			60,
			-10
		],
		[
			30,
			-21
		],
		[
			42,
			83
		],
		[
			49,
			41
		],
		[
			84,
			52
		],
		[
			48,
			10
		],
		[
			0,
			83
		],
		[
			42,
			0
		],
		[
			66,
			42
		],
		[
			36,
			62
		],
		[
			102,
			0
		],
		[
			60,
			-94
		],
		[
			30,
			-134
		],
		[
			-36,
			-31
		],
		[
			43,
			-93
		],
		[
			-61,
			-52
		],
		[
			0,
			-42
		],
		[
			-60,
			-62
		],
		[
			-24,
			-62
		],
		[
			-138,
			-197
		],
		[
			-60,
			-103
		],
		[
			-96,
			-218
		]
	],
	[
		[
			16751,
			59438
		],
		[
			-6,
			0
		]
	],
	[
		[
			16745,
			59438
		],
		[
			6,
			0
		]
	],
	[
		[
			17130,
			59563
		],
		[
			6,
			10
		],
		[
			-6,
			-10
		]
	],
	[
		[
			17130,
			59563
		],
		[
			-24,
			-42
		],
		[
			54,
			-134
		],
		[
			-12,
			-42
		],
		[
			-66,
			10
		],
		[
			-73,
			-82
		],
		[
			-120,
			-11
		],
		[
			-156,
			11
		],
		[
			-42,
			93
		],
		[
			48,
			72
		],
		[
			6,
			0
		]
	],
	[
		[
			16751,
			59438
		],
		[
			54,
			31
		],
		[
			0,
			52
		],
		[
			168,
			93
		],
		[
			54,
			0
		],
		[
			37,
			31
		],
		[
			66,
			-82
		]
	],
	[
		[
			17526,
			59904
		],
		[
			67,
			-10
		],
		[
			30,
			-93
		],
		[
			-6,
			-114
		],
		[
			-97,
			-83
		],
		[
			-60,
			124
		],
		[
			42,
			197
		],
		[
			24,
			-21
		]
	],
	[
		[
			21380,
			60163
		],
		[
			6,
			11
		]
	],
	[
		[
			21386,
			60174
		],
		[
			-6,
			-11
		]
	],
	[
		[
			17070,
			59666
		],
		[
			-73,
			0
		],
		[
			-24,
			104
		],
		[
			-54,
			-42
		]
	],
	[
		[
			16919,
			59728
		],
		[
			0,
			73
		],
		[
			60,
			41
		],
		[
			42,
			124
		],
		[
			24,
			-145
		],
		[
			-12,
			-103
		],
		[
			37,
			-52
		]
	],
	[
		[
			17220,
			60039
		],
		[
			-6,
			-10
		]
	],
	[
		[
			17214,
			60029
		],
		[
			6,
			10
		]
	],
	[
		[
			17232,
			60029
		],
		[
			-18,
			0
		]
	],
	[
		[
			17214,
			60029
		],
		[
			6,
			10
		]
	],
	[
		[
			17220,
			60039
		],
		[
			12,
			-10
		]
	],
	[
		[
			16697,
			60080
		],
		[
			-18,
			-41
		],
		[
			-78,
			-21
		],
		[
			6,
			73
		],
		[
			78,
			20
		],
		[
			12,
			-31
		]
	],
	[
		[
			17430,
			60122
		],
		[
			-12,
			10
		]
	],
	[
		[
			17418,
			60132
		],
		[
			66,
			114
		],
		[
			36,
			0
		],
		[
			0,
			-72
		],
		[
			-54,
			-63
		],
		[
			-36,
			11
		]
	],
	[
		[
			17418,
			60132
		],
		[
			12,
			-10
		]
	],
	[
		[
			17430,
			60122
		],
		[
			36,
			-62
		],
		[
			-54,
			-187
		],
		[
			-30,
			-155
		],
		[
			18,
			-73
		],
		[
			-12,
			-103
		],
		[
			-60,
			10
		],
		[
			-36,
			42
		],
		[
			-18,
			124
		],
		[
			-30,
			72
		],
		[
			-54,
			31
		],
		[
			42,
			177
		],
		[
			36,
			82
		],
		[
			-18,
			31
		],
		[
			12,
			94
		],
		[
			72,
			103
		],
		[
			48,
			-41
		],
		[
			-6,
			-104
		],
		[
			42,
			-31
		]
	],
	[
		[
			13721,
			60236
		],
		[
			-6,
			10
		]
	],
	[
		[
			13715,
			60246
		],
		[
			6,
			-10
		]
	],
	[
		[
			13498,
			60267
		],
		[
			6,
			10
		]
	],
	[
		[
			13504,
			60277
		],
		[
			-6,
			-10
		]
	],
	[
		[
			13678,
			60319
		],
		[
			0,
			-11
		]
	],
	[
		[
			13678,
			60308
		],
		[
			0,
			11
		]
	],
	[
		[
			13264,
			60329
		],
		[
			-6,
			0
		]
	],
	[
		[
			13258,
			60329
		],
		[
			-6,
			0
		]
	],
	[
		[
			13252,
			60329
		],
		[
			6,
			0
		]
	],
	[
		[
			13258,
			60329
		],
		[
			6,
			0
		]
	],
	[
		[
			13264,
			60329
		],
		[
			-6,
			0
		]
	],
	[
		[
			13252,
			60329
		],
		[
			12,
			0
		]
	],
	[
		[
			13943,
			60433
		],
		[
			-6,
			-11
		]
	],
	[
		[
			13937,
			60422
		],
		[
			6,
			11
		]
	],
	[
		[
			12614,
			60453
		],
		[
			-12,
			11
		],
		[
			12,
			-11
		]
	],
	[
		[
			12614,
			60453
		],
		[
			12,
			11
		]
	],
	[
		[
			12626,
			60464
		],
		[
			-12,
			-11
		]
	],
	[
		[
			17520,
			60764
		],
		[
			-12,
			-10
		]
	],
	[
		[
			17508,
			60754
		],
		[
			12,
			10
		]
	],
	[
		[
			17526,
			60754
		],
		[
			-6,
			10
		]
	],
	[
		[
			17520,
			60764
		],
		[
			6,
			-10
		]
	],
	[
		[
			17605,
			60795
		],
		[
			12,
			0
		]
	],
	[
		[
			17617,
			60795
		],
		[
			-18,
			-21
		]
	],
	[
		[
			17599,
			60774
		],
		[
			6,
			21
		]
	],
	[
		[
			17635,
			60826
		],
		[
			-18,
			-31
		]
	],
	[
		[
			17617,
			60795
		],
		[
			0,
			10
		],
		[
			18,
			21
		]
	],
	[
		[
			13137,
			60443
		],
		[
			-108,
			52
		]
	],
	[
		[
			13029,
			60495
		],
		[
			42,
			31
		]
	],
	[
		[
			13071,
			60526
		],
		[
			24,
			72
		],
		[
			114,
			-20
		],
		[
			-6,
			-63
		],
		[
			-36,
			-72
		],
		[
			-30,
			0
		]
	],
	[
		[
			17526,
			60754
		],
		[
			6,
			-42
		],
		[
			67,
			62
		]
	],
	[
		[
			17599,
			60774
		],
		[
			78,
			31
		]
	],
	[
		[
			17677,
			60805
		],
		[
			-60,
			-176
		],
		[
			6,
			-31
		],
		[
			-97,
			-31
		],
		[
			37,
			-72
		],
		[
			-6,
			-114
		],
		[
			-43,
			0
		],
		[
			-42,
			-93
		],
		[
			-36,
			-32
		],
		[
			-66,
			63
		],
		[
			-18,
			124
		],
		[
			18,
			62
		],
		[
			-72,
			10
		],
		[
			-36,
			31
		],
		[
			72,
			145
		],
		[
			84,
			52
		],
		[
			30,
			42
		],
		[
			78,
			-31
		]
	],
	[
		[
			12759,
			60598
		],
		[
			6,
			0
		]
	],
	[
		[
			12765,
			60598
		],
		[
			-6,
			0
		]
	],
	[
		[
			13101,
			60702
		],
		[
			-6,
			0
		],
		[
			6,
			10
		]
	],
	[
		[
			13101,
			60712
		],
		[
			0,
			-10
		]
	],
	[
		[
			14033,
			60919
		],
		[
			-18,
			11
		]
	],
	[
		[
			14015,
			60930
		],
		[
			18,
			-11
		]
	],
	[
		[
			13215,
			60992
		],
		[
			-6,
			0
		]
	],
	[
		[
			13209,
			60992
		],
		[
			6,
			10
		]
	],
	[
		[
			13215,
			61002
		],
		[
			0,
			-10
		]
	],
	[
		[
			13246,
			61013
		],
		[
			0,
			-11
		]
	],
	[
		[
			13246,
			61002
		],
		[
			0,
			11
		]
	],
	[
		[
			12692,
			60733
		],
		[
			24,
			10
		],
		[
			12,
			0
		]
	],
	[
		[
			12728,
			60743
		],
		[
			73,
			42
		],
		[
			24,
			62
		],
		[
			-42,
			31
		]
	],
	[
		[
			12783,
			60878
		],
		[
			18,
			83
		],
		[
			102,
			41
		],
		[
			30,
			31
		],
		[
			120,
			21
		],
		[
			-18,
			-114
		],
		[
			-120,
			-207
		],
		[
			-78,
			-73
		],
		[
			-78,
			0
		],
		[
			-67,
			73
		]
	],
	[
		[
			17725,
			61344
		],
		[
			0,
			10
		]
	],
	[
		[
			17725,
			61354
		],
		[
			0,
			-10
		]
	],
	[
		[
			14941,
			61323
		],
		[
			-6,
			0
		]
	],
	[
		[
			14935,
			61323
		],
		[
			6,
			11
		]
	],
	[
		[
			14941,
			61334
		],
		[
			0,
			-11
		]
	],
	[
		[
			15344,
			61416
		],
		[
			6,
			0
		]
	],
	[
		[
			15350,
			61416
		],
		[
			-6,
			0
		]
	],
	[
		[
			16895,
			61582
		],
		[
			-6,
			-10
		]
	],
	[
		[
			16889,
			61572
		],
		[
			0,
			10
		],
		[
			6,
			0
		]
	],
	[
		[
			17725,
			61344
		],
		[
			0,
			10
		]
	],
	[
		[
			17725,
			61354
		],
		[
			-72,
			21
		],
		[
			6,
			62
		],
		[
			54,
			11
		],
		[
			0,
			62
		],
		[
			72,
			93
		],
		[
			126,
			0
		],
		[
			151,
			52
		],
		[
			54,
			41
		],
		[
			30,
			-62
		],
		[
			-60,
			-41
		],
		[
			-30,
			-52
		],
		[
			-67,
			-52
		],
		[
			6,
			-31
		],
		[
			-84,
			-93
		],
		[
			-12,
			-42
		],
		[
			-54,
			-52
		],
		[
			-90,
			83
		],
		[
			-30,
			-10
		]
	],
	[
		[
			19661,
			61883
		],
		[
			6,
			0
		]
	],
	[
		[
			19667,
			61883
		],
		[
			6,
			0
		]
	],
	[
		[
			19673,
			61883
		],
		[
			-12,
			0
		]
	],
	[
		[
			17100,
			62100
		],
		[
			-6,
			0
		]
	],
	[
		[
			17094,
			62100
		],
		[
			6,
			0
		]
	],
	[
		[
			20184,
			62297
		],
		[
			12,
			0
		]
	],
	[
		[
			20196,
			62297
		],
		[
			-12,
			0
		]
	],
	[
		[
			13739,
			62048
		],
		[
			78,
			-31
		],
		[
			-36,
			-52
		],
		[
			-48,
			21
		],
		[
			6,
			62
		]
	],
	[
		[
			14737,
			62193
		],
		[
			54,
			-10
		],
		[
			-24,
			-73
		],
		[
			-90,
			21
		],
		[
			60,
			62
		]
	],
	[
		[
			9963,
			61924
		],
		[
			-6,
			-10
		],
		[
			0,
			10
		]
	],
	[
		[
			9957,
			61924
		],
		[
			6,
			0
		]
	],
	[
		[
			13829,
			62173
		],
		[
			12,
			0
		]
	],
	[
		[
			13841,
			62173
		],
		[
			-12,
			0
		]
	],
	[
		[
			13961,
			62173
		],
		[
			6,
			20
		]
	],
	[
		[
			13967,
			62193
		],
		[
			-6,
			-20
		]
	],
	[
		[
			13510,
			62266
		],
		[
			-6,
			10
		]
	],
	[
		[
			13504,
			62276
		],
		[
			6,
			-10
		]
	],
	[
		[
			14382,
			62328
		],
		[
			-12,
			-21
		]
	],
	[
		[
			14370,
			62307
		],
		[
			12,
			21
		]
	],
	[
		[
			13787,
			62390
		],
		[
			-60,
			-72
		],
		[
			-37,
			-11
		],
		[
			-42,
			-83
		],
		[
			-48,
			83
		],
		[
			-96,
			-31
		]
	],
	[
		[
			13504,
			62276
		],
		[
			-24,
			93
		],
		[
			18,
			31
		]
	],
	[
		[
			13498,
			62400
		],
		[
			6,
			0
		]
	],
	[
		[
			13504,
			62400
		],
		[
			54,
			31
		],
		[
			84,
			21
		],
		[
			42,
			-83
		],
		[
			31,
			42
		],
		[
			72,
			-21
		]
	],
	[
		[
			14370,
			62307
		],
		[
			24,
			-72
		],
		[
			-60,
			-114
		],
		[
			-175,
			31
		],
		[
			-18,
			-52
		],
		[
			-90,
			21
		],
		[
			6,
			72
		],
		[
			-90,
			0
		]
	],
	[
		[
			13967,
			62193
		],
		[
			-6,
			-20
		]
	],
	[
		[
			13961,
			62173
		],
		[
			-36,
			10
		],
		[
			-66,
			-31
		],
		[
			-18,
			21
		]
	],
	[
		[
			13841,
			62173
		],
		[
			-6,
			41
		],
		[
			-96,
			21
		],
		[
			-18,
			31
		],
		[
			66,
			124
		]
	],
	[
		[
			13787,
			62390
		],
		[
			66,
			52
		],
		[
			60,
			-31
		],
		[
			12,
			62
		],
		[
			60,
			0
		],
		[
			126,
			-62
		],
		[
			36,
			-73
		],
		[
			67,
			-10
		],
		[
			66,
			21
		],
		[
			42,
			-73
		],
		[
			48,
			31
		]
	],
	[
		[
			13504,
			62400
		],
		[
			-6,
			0
		]
	],
	[
		[
			13498,
			62400
		],
		[
			6,
			0
		]
	],
	[
		[
			18681,
			62815
		],
		[
			-12,
			-94
		],
		[
			-54,
			0
		],
		[
			-18,
			63
		],
		[
			84,
			31
		]
	],
	[
		[
			18561,
			63042
		],
		[
			-36,
			-93
		],
		[
			-55,
			-31
		],
		[
			-138,
			-176
		],
		[
			-108,
			-93
		],
		[
			-42,
			-104
		],
		[
			-78,
			-93
		],
		[
			-127,
			-62
		],
		[
			-48,
			-41
		],
		[
			-36,
			-63
		],
		[
			-66,
			-51
		],
		[
			-102,
			-52
		],
		[
			-36,
			-42
		],
		[
			-84,
			-41
		],
		[
			12,
			62
		],
		[
			84,
			73
		],
		[
			0,
			83
		],
		[
			30,
			93
		],
		[
			54,
			52
		],
		[
			66,
			20
		],
		[
			114,
			73
		],
		[
			24,
			41
		],
		[
			151,
			135
		],
		[
			24,
			52
		],
		[
			174,
			176
		],
		[
			60,
			-21
		],
		[
			42,
			21
		],
		[
			85,
			82
		],
		[
			36,
			0
		]
	],
	[
		[
			9410,
			62680
		],
		[
			-6,
			0
		]
	],
	[
		[
			9404,
			62680
		],
		[
			6,
			0
		]
	],
	[
		[
			9404,
			62680
		],
		[
			6,
			0
		]
	],
	[
		[
			15374,
			63053
		],
		[
			-6,
			0
		]
	],
	[
		[
			15368,
			63053
		],
		[
			6,
			0
		]
	],
	[
		[
			9404,
			62742
		],
		[
			-6,
			10
		]
	],
	[
		[
			9398,
			62752
		],
		[
			6,
			-10
		]
	],
	[
		[
			9398,
			62752
		],
		[
			6,
			-10
		]
	],
	[
		[
			18789,
			63364
		],
		[
			12,
			-83
		],
		[
			-42,
			-73
		],
		[
			-24,
			0
		],
		[
			-36,
			73
		],
		[
			6,
			41
		],
		[
			84,
			42
		]
	],
	[
		[
			23353,
			58558
		],
		[
			-30,
			-135
		],
		[
			-97,
			-165
		],
		[
			-12,
			-104
		],
		[
			42,
			-93
		],
		[
			79,
			-114
		],
		[
			-139,
			-93
		],
		[
			-30,
			-73
		],
		[
			-132,
			52
		],
		[
			-18,
			-83
		],
		[
			96,
			0
		],
		[
			84,
			-124
		],
		[
			60,
			-42
		],
		[
			-60,
			-82
		],
		[
			66,
			-52
		],
		[
			67,
			-83
		],
		[
			-43,
			-114
		]
	],
	[
		[
			23286,
			57253
		],
		[
			-78,
			52
		],
		[
			-60,
			0
		],
		[
			-78,
			41
		],
		[
			-42,
			42
		],
		[
			-72,
			-21
		],
		[
			-48,
			41
		],
		[
			-48,
			73
		],
		[
			-109,
			-31
		],
		[
			6,
			72
		],
		[
			42,
			42
		],
		[
			-18,
			93
		],
		[
			-66,
			31
		],
		[
			-108,
			93
		],
		[
			-156,
			31
		],
		[
			-72,
			73
		],
		[
			-55,
			0
		],
		[
			-48,
			31
		],
		[
			-18,
			83
		],
		[
			-66,
			72
		],
		[
			-48,
			114
		],
		[
			-66,
			73
		],
		[
			-6,
			134
		],
		[
			-42,
			21
		],
		[
			-6,
			83
		],
		[
			-54,
			21
		],
		[
			0,
			-73
		],
		[
			-24,
			-135
		],
		[
			18,
			-62
		],
		[
			84,
			-197
		],
		[
			72,
			-134
		],
		[
			78,
			-31
		],
		[
			30,
			-114
		],
		[
			36,
			-11
		],
		[
			66,
			32
		],
		[
			43,
			-52
		],
		[
			-37,
			-104
		],
		[
			-36,
			21
		],
		[
			-132,
			-62
		],
		[
			-186,
			10
		],
		[
			-96,
			52
		],
		[
			-12,
			145
		],
		[
			-73,
			72
		],
		[
			6,
			187
		],
		[
			-24,
			103
		],
		[
			-66,
			63
		],
		[
			6,
			82
		],
		[
			78,
			145
		],
		[
			91,
			218
		],
		[
			54,
			83
		],
		[
			12,
			72
		],
		[
			78,
			52
		],
		[
			48,
			93
		],
		[
			6,
			52
		],
		[
			54,
			124
		],
		[
			150,
			239
		],
		[
			12,
			51
		],
		[
			91,
			104
		],
		[
			90,
			72
		],
		[
			24,
			73
		],
		[
			-36,
			21
		],
		[
			-42,
			-73
		],
		[
			-133,
			-83
		],
		[
			-60,
			-83
		],
		[
			-12,
			-62
		],
		[
			-198,
			-310
		],
		[
			-12,
			-135
		],
		[
			-108,
			-93
		],
		[
			-79,
			-166
		],
		[
			-66,
			41
		],
		[
			-66,
			0
		],
		[
			-42,
			176
		],
		[
			42,
			94
		],
		[
			12,
			83
		],
		[
			-30,
			82
		],
		[
			-120,
			197
		],
		[
			-54,
			-72
		],
		[
			24,
			-62
		],
		[
			66,
			-73
		],
		[
			12,
			-93
		],
		[
			-12,
			-62
		],
		[
			-36,
			-31
		],
		[
			-18,
			-104
		],
		[
			12,
			-62
		],
		[
			54,
			-83
		],
		[
			42,
			-10
		],
		[
			102,
			-104
		],
		[
			-48,
			-155
		],
		[
			-18,
			0
		],
		[
			-66,
			-156
		],
		[
			-90,
			-51
		],
		[
			42,
			-156
		],
		[
			-6,
			-31
		],
		[
			48,
			-124
		],
		[
			-24,
			-21
		],
		[
			48,
			-217
		],
		[
			-6,
			-83
		],
		[
			-48,
			-21
		],
		[
			-96,
			52
		],
		[
			-42,
			0
		],
		[
			-48,
			52
		],
		[
			-73,
			31
		],
		[
			-78,
			-52
		],
		[
			42,
			-62
		],
		[
			66,
			-52
		],
		[
			67,
			10
		],
		[
			96,
			-51
		],
		[
			42,
			-73
		],
		[
			-12,
			-72
		],
		[
			-84,
			-94
		],
		[
			18,
			-51
		],
		[
			-66,
			-21
		],
		[
			-24,
			-124
		],
		[
			-55,
			-125
		],
		[
			-24,
			-176
		],
		[
			-120,
			-155
		],
		[
			-30,
			-73
		],
		[
			-12,
			-113
		],
		[
			-54,
			31
		],
		[
			-186,
			10
		],
		[
			-31,
			31
		],
		[
			-54,
			-10
		],
		[
			-48,
			31
		],
		[
			18,
			103
		],
		[
			-42,
			83
		],
		[
			-12,
			155
		],
		[
			-42,
			125
		],
		[
			12,
			62
		],
		[
			-66,
			166
		],
		[
			-6,
			51
		],
		[
			-72,
			94
		],
		[
			-84,
			31
		],
		[
			-67,
			83
		],
		[
			-30,
			145
		],
		[
			-72,
			196
		],
		[
			-36,
			-103
		],
		[
			66,
			-166
		],
		[
			6,
			-52
		],
		[
			42,
			-103
		],
		[
			103,
			-94
		],
		[
			30,
			-103
		],
		[
			30,
			-42
		],
		[
			18,
			-145
		],
		[
			30,
			-155
		],
		[
			-24,
			-83
		],
		[
			-126,
			11
		],
		[
			-67,
			20
		],
		[
			-120,
			135
		],
		[
			-138,
			104
		],
		[
			-60,
			62
		],
		[
			-60,
			0
		],
		[
			-6,
			51
		],
		[
			-61,
			52
		],
		[
			19,
			104
		],
		[
			-6,
			145
		],
		[
			-43,
			83
		],
		[
			-30,
			-83
		],
		[
			12,
			-52
		],
		[
			-24,
			-83
		],
		[
			-6,
			-134
		],
		[
			36,
			-32
		],
		[
			-60,
			-155
		],
		[
			-6,
			-52
		],
		[
			-54,
			0
		],
		[
			-72,
			-83
		],
		[
			-48,
			-31
		],
		[
			-30,
			-93
		],
		[
			96,
			-166
		],
		[
			72,
			-196
		],
		[
			36,
			-125
		],
		[
			30,
			-20
		],
		[
			0,
			-93
		],
		[
			-24,
			-42
		],
		[
			-54,
			0
		],
		[
			-60,
			114
		],
		[
			-126,
			10
		],
		[
			-36,
			114
		],
		[
			-84,
			11
		],
		[
			6,
			-42
		],
		[
			-103,
			0
		],
		[
			-12,
			83
		],
		[
			-96,
			-21
		],
		[
			-60,
			21
		],
		[
			24,
			135
		],
		[
			-36,
			-11
		],
		[
			-24,
			83
		],
		[
			-48,
			62
		],
		[
			-72,
			42
		],
		[
			-60,
			72
		],
		[
			42,
			62
		],
		[
			-36,
			31
		],
		[
			48,
			218
		],
		[
			-6,
			72
		],
		[
			78,
			145
		],
		[
			-6,
			52
		],
		[
			-60,
			31
		],
		[
			-36,
			94
		],
		[
			54,
			93
		],
		[
			-24,
			72
		],
		[
			42,
			62
		],
		[
			18,
			73
		],
		[
			102,
			72
		],
		[
			72,
			104
		],
		[
			0,
			41
		],
		[
			48,
			94
		],
		[
			0,
			51
		],
		[
			54,
			114
		],
		[
			91,
			73
		],
		[
			24,
			83
		],
		[
			120,
			93
		],
		[
			36,
			62
		],
		[
			102,
			73
		],
		[
			60,
			93
		],
		[
			0,
			145
		],
		[
			42,
			83
		],
		[
			97,
			51
		],
		[
			108,
			31
		],
		[
			78,
			-10
		],
		[
			90,
			42
		],
		[
			72,
			62
		],
		[
			42,
			10
		],
		[
			133,
			93
		],
		[
			84,
			83
		],
		[
			-24,
			73
		],
		[
			78,
			196
		],
		[
			60,
			73
		],
		[
			30,
			62
		],
		[
			120,
			104
		],
		[
			91,
			51
		],
		[
			144,
			42
		],
		[
			108,
			62
		],
		[
			60,
			72
		],
		[
			96,
			42
		],
		[
			48,
			41
		]
	],
	[
		[
			21380,
			60163
		],
		[
			6,
			11
		]
	],
	[
		[
			21386,
			60174
		],
		[
			115,
			124
		],
		[
			-48,
			21
		],
		[
			-151,
			-135
		],
		[
			-84,
			-21
		],
		[
			-168,
			-114
		],
		[
			-72,
			0
		],
		[
			-109,
			-41
		],
		[
			-72,
			-42
		],
		[
			-36,
			52
		],
		[
			42,
			166
		],
		[
			-48,
			-41
		],
		[
			-36,
			-63
		],
		[
			-108,
			-114
		],
		[
			-30,
			-103
		],
		[
			-72,
			-52
		],
		[
			-24,
			-83
		],
		[
			-79,
			-134
		],
		[
			12,
			-73
		],
		[
			-12,
			-62
		],
		[
			-54,
			-93
		],
		[
			-132,
			-114
		],
		[
			-138,
			-21
		],
		[
			-54,
			-41
		],
		[
			-109,
			-21
		],
		[
			-162,
			-124
		],
		[
			-24,
			-42
		],
		[
			-66,
			-31
		],
		[
			-108,
			-145
		],
		[
			-6,
			-72
		],
		[
			-42,
			-104
		],
		[
			-36,
			0
		],
		[
			-79,
			-52
		],
		[
			-54,
			-82
		],
		[
			-30,
			-145
		],
		[
			-102,
			-63
		],
		[
			-48,
			21
		],
		[
			-12,
			83
		],
		[
			-54,
			-21
		],
		[
			24,
			-114
		],
		[
			-54,
			-31
		],
		[
			18,
			-72
		],
		[
			0,
			-104
		],
		[
			-48,
			-103
		],
		[
			-61,
			31
		],
		[
			-48,
			-21
		],
		[
			-12,
			-73
		],
		[
			-36,
			-20
		],
		[
			-42,
			-73
		],
		[
			-60,
			-10
		],
		[
			-24,
			31
		],
		[
			-54,
			-62
		],
		[
			-48,
			52
		],
		[
			-90,
			62
		],
		[
			0,
			93
		],
		[
			-18,
			104
		],
		[
			-61,
			0
		],
		[
			-54,
			-249
		],
		[
			24,
			-62
		],
		[
			-6,
			-83
		],
		[
			18,
			-83
		],
		[
			-36,
			-114
		],
		[
			42,
			-124
		],
		[
			67,
			-52
		],
		[
			18,
			-52
		],
		[
			6,
			-114
		],
		[
			18,
			-62
		],
		[
			24,
			-186
		],
		[
			6,
			-114
		],
		[
			24,
			-62
		],
		[
			42,
			20
		],
		[
			0,
			-93
		],
		[
			36,
			-72
		],
		[
			-60,
			-83
		],
		[
			84,
			0
		],
		[
			60,
			-21
		],
		[
			24,
			-62
		],
		[
			156,
			-186
		],
		[
			0,
			-31
		],
		[
			73,
			-42
		],
		[
			66,
			-103
		],
		[
			6,
			-73
		],
		[
			36,
			-31
		],
		[
			36,
			-93
		],
		[
			-6,
			-62
		],
		[
			30,
			-62
		],
		[
			-12,
			-83
		],
		[
			-60,
			-104
		],
		[
			-138,
			10
		],
		[
			-25,
			-41
		],
		[
			-66,
			-52
		],
		[
			-60,
			-10
		],
		[
			-60,
			-42
		],
		[
			-42,
			0
		],
		[
			-48,
			-41
		],
		[
			-48,
			-104
		],
		[
			-54,
			-10
		],
		[
			-48,
			-83
		],
		[
			-127,
			-176
		],
		[
			30,
			-83
		],
		[
			-18,
			-93
		],
		[
			-48,
			-31
		],
		[
			-24,
			-93
		],
		[
			0,
			-62
		],
		[
			-42,
			-94
		],
		[
			-6,
			-72
		],
		[
			-72,
			-52
		],
		[
			30,
			-93
		],
		[
			6,
			-290
		],
		[
			24,
			-73
		],
		[
			72,
			-51
		],
		[
			0,
			-83
		]
	],
	[
		[
			18380,
			53825
		],
		[
			0,
			-11
		],
		[
			-42,
			-62
		],
		[
			-30,
			73
		],
		[
			-90,
			-31
		],
		[
			6,
			-31
		],
		[
			-48,
			-207
		],
		[
			6,
			-114
		],
		[
			24,
			-42
		],
		[
			-6,
			-72
		],
		[
			-72,
			-21
		],
		[
			0,
			-62
		],
		[
			-48,
			-135
		],
		[
			-18,
			-145
		],
		[
			-91,
			-134
		]
	],
	[
		[
			17971,
			52831
		],
		[
			-78,
			-73
		],
		[
			-6,
			-103
		],
		[
			-30,
			-104
		],
		[
			-30,
			-41
		],
		[
			12,
			-52
		],
		[
			-84,
			-83
		],
		[
			-78,
			-31
		],
		[
			-30,
			31
		],
		[
			-78,
			10
		],
		[
			-6,
			-62
		],
		[
			96,
			-83
		],
		[
			90,
			0
		],
		[
			30,
			42
		],
		[
			66,
			0
		],
		[
			36,
			-114
		],
		[
			96,
			-125
		],
		[
			36,
			-82
		],
		[
			37,
			-145
		],
		[
			-24,
			-83
		],
		[
			-145,
			-176
		],
		[
			0,
			-21
		],
		[
			-90,
			-83
		],
		[
			-6,
			-62
		],
		[
			-126,
			-62
		],
		[
			-114,
			-93
		],
		[
			-79,
			0
		],
		[
			-180,
			31
		],
		[
			-126,
			-31
		],
		[
			-115,
			0
		],
		[
			-120,
			-73
		],
		[
			-48,
			-62
		],
		[
			-144,
			-31
		],
		[
			-78,
			0
		],
		[
			-91,
			21
		],
		[
			-144,
			72
		],
		[
			-36,
			104
		],
		[
			36,
			93
		],
		[
			-18,
			62
		],
		[
			30,
			73
		],
		[
			-42,
			134
		],
		[
			30,
			42
		],
		[
			-24,
			114
		],
		[
			36,
			31
		],
		[
			18,
			124
		],
		[
			-18,
			72
		],
		[
			30,
			63
		],
		[
			36,
			10
		],
		[
			121,
			145
		],
		[
			54,
			10
		],
		[
			6,
			62
		],
		[
			42,
			21
		],
		[
			96,
			10
		],
		[
			36,
			42
		],
		[
			48,
			176
		],
		[
			12,
			104
		],
		[
			-6,
			290
		],
		[
			18,
			41
		],
		[
			-18,
			228
		],
		[
			60,
			186
		],
		[
			-18,
			145
		],
		[
			-30,
			83
		],
		[
			-18,
			114
		],
		[
			12,
			52
		],
		[
			120,
			83
		],
		[
			6,
			72
		],
		[
			31,
			31
		],
		[
			36,
			166
		],
		[
			6,
			93
		],
		[
			36,
			62
		],
		[
			0,
			166
		],
		[
			24,
			31
		],
		[
			6,
			93
		],
		[
			24,
			42
		],
		[
			-72,
			145
		],
		[
			42,
			10
		],
		[
			180,
			114
		],
		[
			78,
			114
		],
		[
			36,
			31
		],
		[
			97,
			197
		],
		[
			6,
			52
		],
		[
			90,
			93
		],
		[
			0,
			52
		],
		[
			84,
			124
		],
		[
			90,
			0
		],
		[
			60,
			62
		],
		[
			120,
			93
		],
		[
			37,
			11
		],
		[
			36,
			93
		],
		[
			66,
			10
		],
		[
			84,
			52
		],
		[
			30,
			72
		],
		[
			60,
			63
		],
		[
			0,
			82
		],
		[
			78,
			104
		],
		[
			42,
			21
		],
		[
			-18,
			93
		],
		[
			-36,
			0
		],
		[
			-24,
			-73
		],
		[
			-66,
			-20
		],
		[
			-54,
			-145
		],
		[
			-42,
			-42
		],
		[
			-42,
			0
		],
		[
			-132,
			-186
		],
		[
			-127,
			-104
		],
		[
			-144,
			-93
		],
		[
			-30,
			31
		],
		[
			-42,
			-10
		],
		[
			-24,
			-73
		],
		[
			-139,
			-93
		],
		[
			-36,
			-10
		],
		[
			-18,
			83
		],
		[
			36,
			41
		],
		[
			-54,
			72
		],
		[
			48,
			73
		],
		[
			-12,
			41
		],
		[
			-78,
			-51
		],
		[
			-78,
			-11
		],
		[
			-96,
			104
		],
		[
			-48,
			31
		],
		[
			-12,
			114
		],
		[
			36,
			207
		],
		[
			-18,
			52
		],
		[
			30,
			103
		],
		[
			24,
			11
		],
		[
			24,
			124
		],
		[
			42,
			31
		],
		[
			102,
			135
		],
		[
			36,
			155
		],
		[
			91,
			145
		],
		[
			72,
			21
		],
		[
			42,
			83
		],
		[
			72,
			62
		],
		[
			-48,
			62
		],
		[
			-78,
			-83
		],
		[
			-91,
			-10
		],
		[
			-48,
			-42
		],
		[
			-30,
			-72
		],
		[
			-48,
			-21
		],
		[
			-78,
			-93
		],
		[
			-66,
			-21
		],
		[
			-84,
			-93
		],
		[
			-30,
			-52
		],
		[
			-42,
			10
		],
		[
			-24,
			83
		],
		[
			36,
			52
		],
		[
			-36,
			83
		],
		[
			30,
			124
		],
		[
			54,
			93
		],
		[
			6,
			52
		],
		[
			48,
			104
		],
		[
			132,
			124
		],
		[
			30,
			73
		],
		[
			72,
			72
		],
		[
			12,
			52
		],
		[
			54,
			103
		],
		[
			85,
			125
		],
		[
			120,
			31
		],
		[
			42,
			93
		],
		[
			-60,
			-10
		],
		[
			-84,
			-73
		],
		[
			24,
			155
		]
	],
	[
		[
			17629,
			58050
		],
		[
			24,
			32
		]
	],
	[
		[
			17653,
			58082
		],
		[
			6,
			20
		]
	],
	[
		[
			17659,
			58102
		],
		[
			-24,
			-10
		]
	],
	[
		[
			17635,
			58082
		],
		[
			-24,
			-21
		]
	],
	[
		[
			17611,
			58061
		],
		[
			-6,
			-21
		]
	],
	[
		[
			17605,
			58040
		],
		[
			-30,
			42
		],
		[
			72,
			72
		],
		[
			-12,
			41
		],
		[
			-90,
			-155
		],
		[
			-67,
			-62
		],
		[
			24,
			-31
		],
		[
			-120,
			-218
		],
		[
			-90,
			-124
		],
		[
			-36,
			21
		],
		[
			-60,
			-31
		],
		[
			24,
			-52
		]
	],
	[
		[
			17220,
			57543
		],
		[
			-48,
			-124
		],
		[
			-78,
			-83
		],
		[
			-37,
			10
		]
	],
	[
		[
			17057,
			57346
		],
		[
			-42,
			42
		],
		[
			-48,
			-11
		],
		[
			0,
			83
		],
		[
			48,
			93
		],
		[
			73,
			73
		],
		[
			-12,
			52
		],
		[
			228,
			362
		],
		[
			42,
			83
		],
		[
			0,
			52
		],
		[
			30,
			83
		],
		[
			126,
			114
		],
		[
			30,
			82
		],
		[
			139,
			176
		],
		[
			66,
			-41
		],
		[
			54,
			31
		],
		[
			48,
			0
		],
		[
			30,
			-41
		],
		[
			-18,
			-62
		],
		[
			90,
			-42
		],
		[
			36,
			83
		],
		[
			-78,
			10
		],
		[
			78,
			125
		],
		[
			-48,
			51
		],
		[
			-66,
			-31
		],
		[
			-84,
			73
		],
		[
			-30,
			52
		],
		[
			30,
			41
		],
		[
			84,
			186
		],
		[
			108,
			197
		],
		[
			24,
			0
		],
		[
			49,
			93
		],
		[
			-12,
			52
		],
		[
			30,
			52
		],
		[
			54,
			31
		],
		[
			6,
			52
		],
		[
			-60,
			21
		],
		[
			-67,
			-31
		],
		[
			-54,
			-73
		],
		[
			-30,
			-10
		],
		[
			-54,
			-94
		],
		[
			-72,
			-41
		],
		[
			-36,
			-52
		],
		[
			-60,
			-20
		],
		[
			12,
			-52
		],
		[
			-24,
			-52
		],
		[
			-60,
			-31
		],
		[
			-24,
			-83
		],
		[
			-61,
			-31
		],
		[
			-48,
			10
		],
		[
			79,
			145
		],
		[
			18,
			114
		],
		[
			-24,
			11
		]
	],
	[
		[
			17557,
			59273
		],
		[
			54,
			72
		],
		[
			30,
			93
		],
		[
			48,
			31
		],
		[
			48,
			83
		],
		[
			-6,
			31
		],
		[
			84,
			93
		],
		[
			0,
			73
		],
		[
			78,
			41
		],
		[
			-30,
			145
		],
		[
			-84,
			73
		],
		[
			96,
			0
		],
		[
			96,
			52
		],
		[
			12,
			41
		],
		[
			91,
			-21
		],
		[
			18,
			73
		],
		[
			30,
			0
		],
		[
			66,
			52
		],
		[
			-72,
			103
		],
		[
			-60,
			-103
		],
		[
			-55,
			31
		],
		[
			-60,
			-52
		],
		[
			-162,
			31
		],
		[
			-72,
			-62
		],
		[
			-12,
			-42
		],
		[
			-96,
			0
		],
		[
			-30,
			42
		],
		[
			42,
			72
		],
		[
			-12,
			31
		],
		[
			90,
			177
		],
		[
			-36,
			31
		],
		[
			-24,
			-42
		]
	],
	[
		[
			17629,
			60422
		],
		[
			6,
			187
		],
		[
			30,
			103
		],
		[
			12,
			93
		]
	],
	[
		[
			17677,
			60805
		],
		[
			18,
			94
		],
		[
			42,
			20
		],
		[
			72,
			104
		],
		[
			48,
			21
		],
		[
			24,
			-42
		],
		[
			42,
			52
		],
		[
			90,
			-73
		],
		[
			61,
			11
		],
		[
			48,
			62
		],
		[
			72,
			31
		],
		[
			84,
			-10
		],
		[
			186,
			93
		],
		[
			12,
			52
		],
		[
			-60,
			10
		],
		[
			-84,
			-52
		],
		[
			-12,
			-41
		],
		[
			-60,
			-31
		],
		[
			-96,
			41
		],
		[
			-60,
			-31
		],
		[
			-72,
			-103
		],
		[
			-49,
			82
		],
		[
			-42,
			0
		],
		[
			-18,
			63
		],
		[
			54,
			93
		],
		[
			30,
			155
		],
		[
			43,
			31
		],
		[
			12,
			52
		],
		[
			48,
			21
		],
		[
			48,
			72
		],
		[
			78,
			52
		],
		[
			66,
			10
		],
		[
			-66,
			94
		],
		[
			-12,
			51
		],
		[
			36,
			62
		],
		[
			60,
			42
		],
		[
			24,
			72
		],
		[
			42,
			11
		],
		[
			96,
			72
		],
		[
			37,
			-72
		],
		[
			72,
			31
		],
		[
			48,
			-11
		],
		[
			114,
			52
		],
		[
			162,
			-10
		],
		[
			97,
			52
		],
		[
			36,
			-11
		],
		[
			30,
			-62
		],
		[
			78,
			-10
		],
		[
			36,
			62
		],
		[
			84,
			-31
		],
		[
			84,
			-10
		],
		[
			18,
			-32
		],
		[
			91,
			11
		],
		[
			42,
			41
		],
		[
			84,
			-165
		],
		[
			66,
			0
		]
	],
	[
		[
			19661,
			61883
		],
		[
			6,
			0
		]
	],
	[
		[
			19667,
			61883
		],
		[
			6,
			0
		]
	],
	[
		[
			19673,
			61883
		],
		[
			60,
			62
		],
		[
			54,
			0
		],
		[
			60,
			31
		],
		[
			54,
			-11
		],
		[
			151,
			104
		],
		[
			24,
			72
		],
		[
			48,
			63
		],
		[
			60,
			31
		],
		[
			12,
			62
		]
	],
	[
		[
			20196,
			62297
		],
		[
			48,
			72
		],
		[
			48,
			21
		],
		[
			48,
			62
		],
		[
			12,
			52
		],
		[
			85,
			83
		],
		[
			42,
			155
		]
	],
	[
		[
			10636,
			62494
		],
		[
			-48,
			-52
		],
		[
			-36,
			-83
		],
		[
			-54,
			21
		],
		[
			-108,
			-11
		],
		[
			-24,
			31
		],
		[
			-61,
			0
		],
		[
			-90,
			-31
		],
		[
			-54,
			-83
		],
		[
			-84,
			-72
		],
		[
			36,
			-124
		],
		[
			-18,
			-52
		],
		[
			12,
			-83
		],
		[
			-66,
			-10
		],
		[
			-54,
			-31
		],
		[
			-24,
			10
		]
	],
	[
		[
			9963,
			61924
		],
		[
			-6,
			0
		]
	],
	[
		[
			9957,
			61924
		],
		[
			-90,
			10
		],
		[
			-55,
			125
		],
		[
			-78,
			31
		],
		[
			-60,
			-11
		],
		[
			-30,
			-62
		],
		[
			-42,
			11
		],
		[
			6,
			82
		],
		[
			48,
			52
		],
		[
			-42,
			62
		],
		[
			-12,
			166
		],
		[
			12,
			41
		],
		[
			-66,
			83
		],
		[
			42,
			31
		],
		[
			24,
			83
		],
		[
			54,
			31
		]
	],
	[
		[
			9668,
			62659
		],
		[
			78,
			11
		],
		[
			24,
			72
		],
		[
			91,
			0
		],
		[
			60,
			-31
		],
		[
			54,
			41
		],
		[
			60,
			-10
		]
	],
	[
		[
			10035,
			62742
		],
		[
			12,
			-52
		],
		[
			84,
			0
		],
		[
			24,
			-51
		],
		[
			60,
			10
		],
		[
			78,
			52
		],
		[
			30,
			72
		],
		[
			115,
			42
		],
		[
			36,
			41
		],
		[
			60,
			21
		],
		[
			72,
			-11
		],
		[
			36,
			-62
		],
		[
			120,
			11
		],
		[
			42,
			72
		],
		[
			49,
			0
		],
		[
			60,
			83
		],
		[
			78,
			-104
		],
		[
			54,
			11
		],
		[
			24,
			-31
		],
		[
			-6,
			-125
		],
		[
			-180,
			11
		],
		[
			-36,
			-52
		],
		[
			-43,
			41
		],
		[
			-60,
			11
		],
		[
			-132,
			-42
		],
		[
			-60,
			-93
		],
		[
			42,
			-10
		],
		[
			72,
			-62
		],
		[
			-30,
			-31
		]
	],
	[
		[
			20467,
			62804
		],
		[
			-67,
			-134
		],
		[
			-72,
			-94
		],
		[
			-30,
			0
		],
		[
			-54,
			-72
		],
		[
			-72,
			0
		],
		[
			-48,
			-31
		],
		[
			-30,
			-124
		],
		[
			-72,
			-63
		],
		[
			-6,
			-93
		],
		[
			-54,
			-41
		],
		[
			6,
			-52
		],
		[
			-85,
			-52
		],
		[
			-78,
			-41
		],
		[
			-96,
			0
		],
		[
			-84,
			31
		],
		[
			-72,
			93
		],
		[
			-127,
			0
		],
		[
			-36,
			-31
		],
		[
			-78,
			21
		],
		[
			-78,
			0
		],
		[
			-102,
			20
		],
		[
			-78,
			63
		],
		[
			-103,
			-11
		],
		[
			-6,
			-83
		],
		[
			-30,
			-31
		],
		[
			-126,
			11
		],
		[
			-12,
			-21
		],
		[
			-96,
			10
		],
		[
			30,
			52
		],
		[
			6,
			73
		],
		[
			-24,
			114
		],
		[
			-48,
			82
		],
		[
			-78,
			31
		],
		[
			-48,
			-20
		],
		[
			-67,
			-125
		],
		[
			-60,
			-51
		],
		[
			-30,
			176
		],
		[
			30,
			0
		],
		[
			30,
			114
		],
		[
			72,
			114
		],
		[
			67,
			0
		],
		[
			42,
			82
		],
		[
			48,
			-10
		],
		[
			66,
			-93
		],
		[
			66,
			-52
		],
		[
			78,
			10
		],
		[
			66,
			52
		],
		[
			61,
			-20
		],
		[
			12,
			51
		],
		[
			48,
			-20
		],
		[
			54,
			20
		],
		[
			60,
			73
		],
		[
			78,
			20
		],
		[
			36,
			104
		],
		[
			108,
			52
		],
		[
			54,
			-21
		],
		[
			169,
			62
		],
		[
			-42,
			62
		],
		[
			-193,
			-93
		],
		[
			-84,
			31
		],
		[
			-126,
			-31
		],
		[
			-72,
			-103
		],
		[
			-169,
			-114
		],
		[
			-54,
			41
		],
		[
			-60,
			-21
		],
		[
			-42,
			63
		],
		[
			-30,
			103
		],
		[
			-84,
			93
		],
		[
			24,
			62
		],
		[
			96,
			73
		],
		[
			66,
			-41
		],
		[
			-24,
			113
		],
		[
			60,
			125
		],
		[
			66,
			93
		],
		[
			0,
			31
		],
		[
			151,
			135
		],
		[
			66,
			31
		]
	],
	[
		[
			15067,
			63529
		],
		[
			12,
			0
		]
	],
	[
		[
			15079,
			63529
		],
		[
			-12,
			0
		]
	],
	[
		[
			12133,
			63436
		],
		[
			6,
			10
		]
	],
	[
		[
			12139,
			63446
		],
		[
			-6,
			-10
		]
	],
	[
		[
			15067,
			63529
		],
		[
			-66,
			42
		],
		[
			12,
			72
		],
		[
			48,
			-41
		],
		[
			18,
			-73
		]
	],
	[
		[
			15368,
			63053
		],
		[
			6,
			0
		]
	],
	[
		[
			15374,
			63053
		],
		[
			48,
			-62
		],
		[
			42,
			-176
		],
		[
			0,
			-63
		],
		[
			84,
			-93
		],
		[
			73,
			42
		],
		[
			24,
			-31
		]
	],
	[
		[
			15645,
			62670
		],
		[
			102,
			-42
		],
		[
			72,
			42
		],
		[
			186,
			-11
		],
		[
			72,
			11
		],
		[
			55,
			-21
		],
		[
			60,
			-93
		],
		[
			54,
			-21
		],
		[
			36,
			93
		],
		[
			48,
			-20
		],
		[
			114,
			0
		],
		[
			6,
			-42
		],
		[
			102,
			-93
		],
		[
			43,
			-104
		],
		[
			102,
			-31
		],
		[
			66,
			-41
		],
		[
			108,
			41
		],
		[
			66,
			-72
		],
		[
			-18,
			-42
		],
		[
			60,
			-41
		],
		[
			48,
			0
		],
		[
			67,
			-83
		]
	],
	[
		[
			17094,
			62100
		],
		[
			6,
			0
		]
	],
	[
		[
			17100,
			62100
		],
		[
			-18,
			-83
		],
		[
			150,
			-21
		],
		[
			24,
			73
		],
		[
			42,
			-62
		],
		[
			-6,
			-187
		],
		[
			-24,
			-51
		],
		[
			-96,
			20
		],
		[
			24,
			42
		],
		[
			-72,
			41
		],
		[
			18,
			-155
		],
		[
			42,
			-31
		],
		[
			48,
			20
		],
		[
			24,
			-51
		],
		[
			-42,
			-83
		],
		[
			-30,
			-135
		],
		[
			-60,
			-52
		],
		[
			-109,
			31
		],
		[
			-78,
			-10
		],
		[
			-48,
			31
		],
		[
			0,
			135
		]
	],
	[
		[
			16889,
			61572
		],
		[
			36,
			21
		],
		[
			-24,
			72
		],
		[
			-42,
			0
		],
		[
			-6,
			-52
		],
		[
			-60,
			42
		],
		[
			-24,
			-52
		],
		[
			36,
			-42
		],
		[
			0,
			-72
		],
		[
			-60,
			-41
		],
		[
			-66,
			31
		],
		[
			-24,
			-125
		],
		[
			-72,
			-72
		],
		[
			18,
			-42
		],
		[
			66,
			11
		],
		[
			156,
			114
		],
		[
			198,
			10
		],
		[
			24,
			-21
		],
		[
			-30,
			-103
		],
		[
			-60,
			-93
		],
		[
			-60,
			-42
		],
		[
			-66,
			-21
		],
		[
			-78,
			-72
		],
		[
			-18,
			-42
		],
		[
			-181,
			-82
		],
		[
			-24,
			-31
		],
		[
			-114,
			-52
		],
		[
			-60,
			-52
		],
		[
			-90,
			-21
		],
		[
			-36,
			-52
		],
		[
			-78,
			0
		],
		[
			-211,
			52
		],
		[
			24,
			73
		],
		[
			108,
			114
		],
		[
			6,
			51
		],
		[
			49,
			0
		],
		[
			18,
			63
		],
		[
			-36,
			51
		],
		[
			-73,
			-10
		],
		[
			-48,
			31
		],
		[
			-54,
			-31
		],
		[
			-36,
			10
		],
		[
			-120,
			-114
		],
		[
			-90,
			-145
		],
		[
			-66,
			-51
		],
		[
			-61,
			-21
		],
		[
			-90,
			0
		],
		[
			-138,
			41
		],
		[
			-48,
			-82
		],
		[
			-84,
			-52
		],
		[
			-175,
			-145
		],
		[
			-78,
			-11
		],
		[
			-72,
			31
		],
		[
			-72,
			63
		],
		[
			-48,
			-42
		],
		[
			-145,
			-21
		],
		[
			-84,
			11
		],
		[
			-54,
			-52
		],
		[
			-6,
			-41
		],
		[
			-78,
			-21
		],
		[
			-48,
			10
		],
		[
			-42,
			42
		],
		[
			-84,
			-42
		],
		[
			-18,
			31
		],
		[
			-133,
			0
		]
	],
	[
		[
			14063,
			60484
		],
		[
			-60,
			11
		],
		[
			-18,
			-42
		]
	],
	[
		[
			13985,
			60453
		],
		[
			-30,
			-20
		]
	],
	[
		[
			13955,
			60433
		],
		[
			-12,
			0
		]
	],
	[
		[
			13943,
			60433
		],
		[
			-60,
			41
		],
		[
			-78,
			-10
		],
		[
			-12,
			-83
		],
		[
			-36,
			-83
		]
	],
	[
		[
			13757,
			60298
		],
		[
			-42,
			-52
		]
	],
	[
		[
			13715,
			60246
		],
		[
			-12,
			0
		],
		[
			-25,
			62
		]
	],
	[
		[
			13678,
			60308
		],
		[
			0,
			11
		]
	],
	[
		[
			13678,
			60319
		],
		[
			-102,
			-11
		],
		[
			-36,
			31
		],
		[
			-36,
			-62
		]
	],
	[
		[
			13504,
			60277
		],
		[
			-24,
			0
		]
	],
	[
		[
			13480,
			60277
		],
		[
			-120,
			42
		],
		[
			-18,
			134
		],
		[
			-36,
			-41
		],
		[
			-66,
			0
		],
		[
			6,
			114
		],
		[
			-24,
			0
		],
		[
			-19,
			93
		],
		[
			-72,
			10
		]
	],
	[
		[
			13131,
			60629
		],
		[
			-30,
			73
		]
	],
	[
		[
			13101,
			60712
		],
		[
			30,
			176
		]
	],
	[
		[
			13131,
			60888
		],
		[
			66,
			114
		],
		[
			12,
			-10
		]
	],
	[
		[
			13209,
			60992
		],
		[
			6,
			0
		]
	],
	[
		[
			13215,
			60992
		],
		[
			0,
			10
		]
	],
	[
		[
			13215,
			61002
		],
		[
			31,
			0
		]
	],
	[
		[
			13246,
			61002
		],
		[
			0,
			11
		]
	],
	[
		[
			13246,
			61013
		],
		[
			66,
			20
		]
	],
	[
		[
			13312,
			61033
		],
		[
			90,
			-31
		],
		[
			6,
			0
		],
		[
			156,
			0
		],
		[
			24,
			-72
		],
		[
			24,
			41
		],
		[
			66,
			-41
		],
		[
			31,
			-114
		],
		[
			36,
			-42
		],
		[
			102,
			-10
		],
		[
			18,
			72
		],
		[
			-42,
			32
		]
	],
	[
		[
			13823,
			60868
		],
		[
			-18,
			113
		],
		[
			90,
			21
		],
		[
			120,
			-72
		]
	],
	[
		[
			14015,
			60930
		],
		[
			18,
			-11
		]
	],
	[
		[
			14033,
			60919
		],
		[
			54,
			21
		],
		[
			72,
			-52
		],
		[
			73,
			83
		],
		[
			108,
			-41
		],
		[
			102,
			10
		],
		[
			84,
			62
		],
		[
			102,
			0
		],
		[
			37,
			-21
		],
		[
			24,
			42
		],
		[
			54,
			10
		],
		[
			24,
			52
		],
		[
			54,
			0
		],
		[
			30,
			31
		],
		[
			156,
			31
		],
		[
			24,
			31
		],
		[
			96,
			11
		],
		[
			55,
			72
		],
		[
			18,
			155
		],
		[
			72,
			-51
		],
		[
			84,
			10
		],
		[
			-6,
			41
		]
	],
	[
		[
			15344,
			61416
		],
		[
			-90,
			11
		],
		[
			-24,
			41
		],
		[
			-72,
			-20
		],
		[
			-31,
			31
		],
		[
			-102,
			-52
		],
		[
			-84,
			-93
		]
	],
	[
		[
			14941,
			61334
		],
		[
			0,
			-11
		]
	],
	[
		[
			14935,
			61323
		],
		[
			-84,
			52
		],
		[
			-12,
			-41
		],
		[
			-60,
			-73
		],
		[
			-54,
			0
		],
		[
			-48,
			-41
		],
		[
			-97,
			-21
		],
		[
			-30,
			21
		],
		[
			-126,
			0
		],
		[
			-186,
			-94
		],
		[
			-103,
			11
		],
		[
			-54,
			62
		],
		[
			-30,
			72
		],
		[
			24,
			135
		],
		[
			60,
			42
		],
		[
			42,
			62
		],
		[
			79,
			31
		],
		[
			96,
			72
		],
		[
			54,
			83
		],
		[
			12,
			93
		],
		[
			42,
			31
		],
		[
			0,
			52
		],
		[
			36,
			31
		],
		[
			42,
			104
		],
		[
			151,
			0
		],
		[
			48,
			-21
		],
		[
			120,
			0
		],
		[
			84,
			21
		],
		[
			72,
			114
		],
		[
			60,
			31
		],
		[
			67,
			0
		],
		[
			60,
			93
		],
		[
			48,
			21
		],
		[
			36,
			62
		],
		[
			-66,
			145
		],
		[
			-36,
			0
		],
		[
			-121,
			-114
		],
		[
			-120,
			-10
		],
		[
			-54,
			-42
		],
		[
			-96,
			-31
		],
		[
			-120,
			0
		],
		[
			-115,
			-72
		],
		[
			-18,
			31
		],
		[
			-90,
			41
		],
		[
			-36,
			0
		],
		[
			-30,
			52
		]
	],
	[
		[
			14382,
			62328
		],
		[
			66,
			31
		],
		[
			-48,
			114
		],
		[
			-150,
			52
		],
		[
			0,
			51
		],
		[
			-73,
			-20
		],
		[
			-30,
			62
		],
		[
			-168,
			72
		],
		[
			-24,
			52
		],
		[
			-96,
			-21
		],
		[
			-78,
			0
		],
		[
			-48,
			-31
		],
		[
			-127,
			0
		],
		[
			-54,
			52
		],
		[
			-96,
			0
		],
		[
			-54,
			42
		],
		[
			-66,
			0
		],
		[
			-42,
			62
		],
		[
			36,
			145
		],
		[
			96,
			10
		],
		[
			60,
			31
		],
		[
			72,
			104
		],
		[
			54,
			51
		],
		[
			-48,
			42
		],
		[
			-102,
			-42
		],
		[
			-30,
			32
		],
		[
			0,
			207
		],
		[
			102,
			20
		],
		[
			48,
			31
		],
		[
			72,
			-31
		],
		[
			61,
			0
		],
		[
			30,
			83
		],
		[
			84,
			-20
		],
		[
			126,
			-73
		]
	],
	[
		[
			13955,
			63436
		],
		[
			36,
			-10
		],
		[
			-54,
			186
		],
		[
			24,
			104
		],
		[
			48,
			10
		]
	],
	[
		[
			14009,
			63726
		],
		[
			84,
			-21
		],
		[
			12,
			83
		],
		[
			60,
			31
		],
		[
			37,
			-20
		],
		[
			84,
			0
		],
		[
			18,
			41
		],
		[
			114,
			72
		],
		[
			66,
			-31
		],
		[
			30,
			63
		],
		[
			54,
			-21
		],
		[
			36,
			-104
		],
		[
			61,
			0
		],
		[
			102,
			-41
		],
		[
			108,
			-11
		],
		[
			36,
			-31
		],
		[
			12,
			-62
		],
		[
			-66,
			-72
		],
		[
			102,
			-83
		],
		[
			30,
			41
		],
		[
			78,
			-51
		],
		[
			85,
			-114
		],
		[
			48,
			-114
		],
		[
			54,
			-52
		],
		[
			66,
			-10
		],
		[
			12,
			-135
		],
		[
			36,
			-31
		]
	],
	[
		[
			12350,
			64213
		],
		[
			0,
			-11
		]
	],
	[
		[
			12350,
			64202
		],
		[
			0,
			11
		]
	],
	[
		[
			12398,
			64223
		],
		[
			-12,
			0
		]
	],
	[
		[
			12386,
			64223
		],
		[
			6,
			0
		]
	],
	[
		[
			12392,
			64223
		],
		[
			6,
			11
		]
	],
	[
		[
			12398,
			64234
		],
		[
			0,
			-11
		]
	],
	[
		[
			12500,
			63840
		],
		[
			-102,
			-176
		],
		[
			-30,
			-62
		],
		[
			-48,
			-31
		],
		[
			-36,
			51
		],
		[
			-145,
			-176
		]
	],
	[
		[
			12139,
			63446
		],
		[
			-6,
			-10
		]
	],
	[
		[
			12133,
			63436
		],
		[
			-90,
			-93
		],
		[
			-24,
			41
		],
		[
			-36,
			-41
		],
		[
			0,
			-52
		],
		[
			-72,
			21
		],
		[
			-72,
			-21
		],
		[
			-139,
			-83
		]
	],
	[
		[
			11700,
			63208
		],
		[
			-18,
			93
		],
		[
			-54,
			21
		],
		[
			-6,
			-93
		],
		[
			-48,
			-73
		],
		[
			-54,
			0
		]
	],
	[
		[
			11520,
			63156
		],
		[
			12,
			73
		],
		[
			-48,
			31
		],
		[
			-78,
			0
		],
		[
			-72,
			-31
		],
		[
			-6,
			-93
		],
		[
			-43,
			-73
		],
		[
			-42,
			0
		],
		[
			-36,
			114
		],
		[
			109,
			176
		],
		[
			36,
			11
		],
		[
			36,
			-42
		],
		[
			84,
			31
		],
		[
			-12,
			62
		],
		[
			66,
			11
		],
		[
			60,
			145
		],
		[
			96,
			31
		],
		[
			30,
			52
		],
		[
			-18,
			51
		],
		[
			30,
			62
		],
		[
			61,
			0
		],
		[
			54,
			73
		],
		[
			42,
			41
		],
		[
			60,
			-10
		],
		[
			30,
			21
		],
		[
			18,
			72
		],
		[
			84,
			0
		],
		[
			36,
			73
		],
		[
			54,
			31
		],
		[
			60,
			72
		]
	],
	[
		[
			12223,
			64140
		],
		[
			43,
			0
		]
	],
	[
		[
			12266,
			64140
		],
		[
			48,
			31
		]
	],
	[
		[
			12314,
			64171
		],
		[
			36,
			31
		]
	],
	[
		[
			12350,
			64202
		],
		[
			0,
			11
		]
	],
	[
		[
			12350,
			64213
		],
		[
			36,
			10
		]
	],
	[
		[
			12392,
			64223
		],
		[
			6,
			0
		]
	],
	[
		[
			12398,
			64223
		],
		[
			0,
			11
		]
	],
	[
		[
			12398,
			64234
		],
		[
			84,
			0
		],
		[
			36,
			20
		]
	],
	[
		[
			12518,
			64254
		],
		[
			36,
			21
		],
		[
			84,
			-52
		],
		[
			6,
			-103
		],
		[
			-54,
			-94
		],
		[
			-30,
			-103
		],
		[
			-60,
			-83
		]
	],
	[
		[
			12656,
			64368
		],
		[
			6,
			0
		]
	],
	[
		[
			12662,
			64368
		],
		[
			-6,
			0
		]
	],
	[
		[
			12650,
			64368
		],
		[
			0,
			-10
		],
		[
			-6,
			0
		],
		[
			6,
			10
		]
	],
	[
		[
			12662,
			64368
		],
		[
			-6,
			0
		]
	],
	[
		[
			12656,
			64368
		],
		[
			-6,
			0
		]
	],
	[
		[
			12650,
			64368
		],
		[
			12,
			0
		]
	],
	[
		[
			30297,
			56062
		],
		[
			24,
			52
		],
		[
			-30,
			62
		],
		[
			-48,
			21
		],
		[
			-24,
			72
		],
		[
			-60,
			62
		],
		[
			36,
			73
		],
		[
			-24,
			31
		],
		[
			66,
			103
		],
		[
			-48,
			73
		],
		[
			72,
			31
		],
		[
			18,
			62
		],
		[
			66,
			83
		],
		[
			-18,
			52
		],
		[
			-102,
			10
		],
		[
			-78,
			-10
		],
		[
			-115,
			31
		],
		[
			43,
			145
		],
		[
			36,
			52
		],
		[
			-12,
			51
		],
		[
			-79,
			104
		],
		[
			-18,
			52
		],
		[
			121,
			51
		],
		[
			-6,
			52
		],
		[
			-97,
			21
		],
		[
			6,
			155
		],
		[
			73,
			31
		],
		[
			24,
			114
		]
	],
	[
		[
			30123,
			57698
		],
		[
			126,
			0
		],
		[
			18,
			-20
		],
		[
			138,
			0
		],
		[
			78,
			82
		],
		[
			61,
			11
		],
		[
			108,
			-83
		],
		[
			6,
			-31
		],
		[
			84,
			-62
		],
		[
			54,
			10
		],
		[
			42,
			-41
		],
		[
			42,
			10
		],
		[
			157,
			0
		],
		[
			96,
			31
		],
		[
			96,
			0
		],
		[
			24,
			31
		],
		[
			42,
			-62
		],
		[
			144,
			0
		],
		[
			12,
			41
		],
		[
			73,
			63
		],
		[
			144,
			-83
		],
		[
			36,
			-62
		],
		[
			60,
			-31
		],
		[
			132,
			-135
		],
		[
			157,
			-93
		],
		[
			78,
			-11
		]
	],
	[
		[
			24760,
			56569
		],
		[
			-6,
			-72
		],
		[
			-55,
			-104
		],
		[
			-96,
			11
		],
		[
			36,
			-73
		],
		[
			36,
			-10
		],
		[
			-72,
			-228
		]
	],
	[
		[
			23256,
			57108
		],
		[
			79,
			-31
		],
		[
			54,
			0
		],
		[
			54,
			-31
		],
		[
			222,
			0
		],
		[
			72,
			-11
		],
		[
			91,
			21
		],
		[
			60,
			-31
		],
		[
			72,
			42
		],
		[
			96,
			-21
		],
		[
			66,
			-42
		],
		[
			96,
			-114
		],
		[
			127,
			-82
		],
		[
			36,
			20
		],
		[
			96,
			-93
		],
		[
			114,
			-41
		],
		[
			108,
			-94
		],
		[
			61,
			-31
		]
	],
	[
		[
			24483,
			57491
		],
		[
			24,
			-155
		],
		[
			66,
			-21
		],
		[
			6,
			-62
		],
		[
			-18,
			-114
		],
		[
			54,
			-124
		]
	],
	[
		[
			24615,
			57015
		],
		[
			-48,
			-31
		],
		[
			-12,
			-62
		],
		[
			54,
			-63
		],
		[
			0,
			-82
		],
		[
			-72,
			-52
		]
	],
	[
		[
			24537,
			56725
		],
		[
			-84,
			52
		],
		[
			-48,
			62
		],
		[
			-126,
			41
		],
		[
			-73,
			52
		],
		[
			-96,
			124
		],
		[
			-90,
			42
		],
		[
			-192,
			0
		],
		[
			-24,
			31
		],
		[
			-133,
			0
		],
		[
			-42,
			31
		],
		[
			-54,
			0
		],
		[
			-48,
			31
		],
		[
			-84,
			-11
		],
		[
			-126,
			73
		],
		[
			-31,
			0
		]
	],
	[
		[
			28283,
			55710
		],
		[
			60,
			103
		],
		[
			-48,
			63
		],
		[
			72,
			72
		],
		[
			42,
			10
		],
		[
			18,
			73
		],
		[
			-6,
			0
		],
		[
			-96,
			93
		],
		[
			-42,
			114
		],
		[
			-36,
			197
		],
		[
			18,
			62
		],
		[
			96,
			41
		],
		[
			114,
			31
		],
		[
			-6,
			83
		],
		[
			-36,
			31
		],
		[
			-234,
			-83
		],
		[
			-30,
			-20
		],
		[
			-42,
			31
		],
		[
			-43,
			-21
		],
		[
			-36,
			21
		],
		[
			-60,
			-42
		],
		[
			-42,
			21
		],
		[
			-54,
			73
		],
		[
			-66,
			0
		],
		[
			-30,
			62
		],
		[
			36,
			62
		]
	],
	[
		[
			29600,
			57781
		],
		[
			66,
			-41
		],
		[
			156,
			0
		],
		[
			30,
			20
		],
		[
			84,
			-31
		],
		[
			60,
			0
		],
		[
			55,
			-31
		],
		[
			72,
			0
		]
	],
	[
		[
			35780,
			64845
		],
		[
			37,
			-11
		]
	],
	[
		[
			35817,
			64834
		],
		[
			48,
			0
		],
		[
			-73,
			-238
		],
		[
			-42,
			-186
		],
		[
			-66,
			-31
		],
		[
			-78,
			51
		],
		[
			18,
			52
		],
		[
			-12,
			62
		],
		[
			-102,
			21
		],
		[
			-138,
			10
		],
		[
			-61,
			-124
		],
		[
			-6,
			-52
		],
		[
			67,
			-62
		],
		[
			186,
			10
		],
		[
			42,
			52
		],
		[
			66,
			-31
		],
		[
			114,
			0
		],
		[
			31,
			-21
		],
		[
			6,
			-93
		],
		[
			-97,
			-103
		],
		[
			-60,
			-42
		],
		[
			-96,
			-20
		],
		[
			-102,
			-94
		],
		[
			-36,
			-196
		],
		[
			36,
			-114
		],
		[
			102,
			0
		],
		[
			18,
			-42
		]
	],
	[
		[
			35582,
			63643
		],
		[
			0,
			-10
		],
		[
			-42,
			-42
		],
		[
			-6,
			-51
		],
		[
			-84,
			-94
		],
		[
			-12,
			-51
		],
		[
			-78,
			-52
		],
		[
			-6,
			-62
		],
		[
			-103,
			-94
		],
		[
			-60,
			-134
		],
		[
			-120,
			-11
		],
		[
			-48,
			-41
		],
		[
			-114,
			-52
		],
		[
			-30,
			11
		],
		[
			-61,
			-42
		],
		[
			-90,
			-103
		],
		[
			-48,
			-94
		],
		[
			-102,
			-51
		],
		[
			-114,
			-114
		],
		[
			-121,
			-52
		],
		[
			-24,
			-31
		],
		[
			-66,
			-21
		],
		[
			-24,
			-31
		],
		[
			-48,
			-166
		],
		[
			-66,
			-124
		],
		[
			-60,
			0
		],
		[
			-295,
			155
		],
		[
			-216,
			-41
		],
		[
			-36,
			-21
		]
	],
	[
		[
			33508,
			62224
		],
		[
			-24,
			62
		],
		[
			42,
			94
		],
		[
			-145,
			20
		],
		[
			-6,
			31
		],
		[
			-108,
			-20
		],
		[
			-48,
			20
		],
		[
			-42,
			-31
		],
		[
			-66,
			52
		],
		[
			-60,
			-21
		],
		[
			-24,
			63
		],
		[
			-157,
			-31
		],
		[
			-108,
			10
		],
		[
			-6,
			-62
		],
		[
			-66,
			0
		],
		[
			-84,
			41
		],
		[
			-36,
			-10
		],
		[
			-36,
			41
		],
		[
			-139,
			11
		],
		[
			0,
			-21
		],
		[
			-120,
			-31
		],
		[
			6,
			-42
		]
	],
	[
		[
			32281,
			62400
		],
		[
			0,
			-93
		],
		[
			-126,
			21
		],
		[
			-144,
			-52
		],
		[
			54,
			-114
		]
	],
	[
		[
			33508,
			62224
		],
		[
			-54,
			-51
		],
		[
			-55,
			-11
		],
		[
			-72,
			-52
		],
		[
			-90,
			63
		],
		[
			-138,
			0
		],
		[
			-48,
			-32
		],
		[
			-151,
			-10
		],
		[
			-132,
			-72
		],
		[
			-126,
			-52
		],
		[
			-301,
			0
		],
		[
			-60,
			72
		]
	],
	[
		[
			26184,
			56207
		],
		[
			31,
			72
		],
		[
			102,
			21
		],
		[
			-24,
			83
		],
		[
			18,
			41
		],
		[
			48,
			11
		],
		[
			-30,
			238
		],
		[
			-42,
			-31
		],
		[
			-48,
			41
		],
		[
			-49,
			-10
		],
		[
			-108,
			31
		],
		[
			-18,
			-41
		],
		[
			-78,
			-11
		],
		[
			-60,
			42
		],
		[
			-24,
			-31
		],
		[
			-36,
			124
		],
		[
			-60,
			0
		],
		[
			-42,
			83
		]
	],
	[
		[
			25764,
			56870
		],
		[
			-79,
			31
		],
		[
			-6,
			41
		],
		[
			133,
			31
		],
		[
			12,
			0
		],
		[
			84,
			-31
		],
		[
			102,
			0
		],
		[
			48,
			-20
		],
		[
			78,
			31
		],
		[
			24,
			82
		],
		[
			247,
			21
		],
		[
			36,
			52
		],
		[
			-48,
			104
		],
		[
			54,
			62
		],
		[
			78,
			31
		],
		[
			-42,
			52
		],
		[
			24,
			51
		],
		[
			-30,
			52
		],
		[
			-114,
			-21
		],
		[
			-90,
			-51
		],
		[
			-66,
			-21
		],
		[
			-37,
			-52
		],
		[
			-78,
			0
		],
		[
			54,
			73
		],
		[
			-18,
			72
		],
		[
			24,
			83
		],
		[
			-36,
			10
		],
		[
			-72,
			83
		],
		[
			-18,
			42
		],
		[
			-84,
			72
		],
		[
			-18,
			83
		]
	],
	[
		[
			25764,
			56870
		],
		[
			-109,
			-73
		],
		[
			-216,
			-10
		],
		[
			-6,
			72
		],
		[
			-54,
			-10
		],
		[
			-24,
			73
		],
		[
			-54,
			20
		],
		[
			-48,
			62
		],
		[
			0,
			83
		],
		[
			-79,
			-10
		],
		[
			-78,
			10
		],
		[
			-30,
			-114
		],
		[
			36,
			-62
		],
		[
			-48,
			-31
		],
		[
			-72,
			0
		],
		[
			-24,
			-52
		],
		[
			-48,
			-10
		],
		[
			-36,
			41
		],
		[
			-84,
			21
		],
		[
			6,
			83
		],
		[
			-55,
			52
		],
		[
			-126,
			0
		]
	],
	[
		[
			25421,
			56279
		],
		[
			66,
			-20
		]
	],
	[
		[
			24760,
			56569
		],
		[
			96,
			-51
		],
		[
			78,
			0
		],
		[
			144,
			-62
		],
		[
			30,
			-32
		],
		[
			133,
			-31
		],
		[
			42,
			11
		],
		[
			150,
			-73
		],
		[
			-12,
			-52
		]
	],
	[
		[
			25655,
			56197
		],
		[
			24,
			51
		],
		[
			-66,
			31
		]
	],
	[
		[
			25619,
			56269
		],
		[
			12,
			-31
		]
	],
	[
		[
			25631,
			56238
		],
		[
			-54,
			-10
		],
		[
			-48,
			-42
		]
	],
	[
		[
			25529,
			56186
		],
		[
			-6,
			52
		],
		[
			-48,
			41
		],
		[
			-54,
			0
		]
	],
	[
		[
			25421,
			56279
		],
		[
			18,
			52
		],
		[
			-120,
			73
		],
		[
			-97,
			0
		],
		[
			-120,
			41
		],
		[
			-12,
			21
		],
		[
			-138,
			62
		],
		[
			-114,
			10
		],
		[
			-145,
			83
		],
		[
			-84,
			73
		],
		[
			-72,
			31
		]
	],
	[
		[
			25896,
			31661
		],
		[
			-6,
			10
		]
	],
	[
		[
			25890,
			31671
		],
		[
			6,
			-10
		]
	],
	[
		[
			23491,
			32075
		],
		[
			12,
			0
		]
	],
	[
		[
			23503,
			32075
		],
		[
			6,
			0
		]
	],
	[
		[
			23509,
			32075
		],
		[
			-18,
			0
		]
	],
	[
		[
			23437,
			32241
		],
		[
			-60,
			0
		],
		[
			-30,
			-72
		],
		[
			36,
			-73
		],
		[
			54,
			0
		],
		[
			30,
			-72
		],
		[
			42,
			-21
		],
		[
			12,
			-52
		],
		[
			66,
			-62
		],
		[
			-42,
			-83
		],
		[
			-84,
			-10
		],
		[
			-48,
			20
		],
		[
			-36,
			-41
		],
		[
			-91,
			31
		],
		[
			-24,
			41
		],
		[
			18,
			73
		],
		[
			-60,
			62
		],
		[
			-24,
			52
		],
		[
			6,
			93
		],
		[
			-66,
			21
		],
		[
			-36,
			41
		],
		[
			-60,
			-10
		],
		[
			-48,
			21
		],
		[
			-18,
			-31
		],
		[
			-108,
			-11
		],
		[
			-24,
			62
		],
		[
			30,
			52
		],
		[
			-67,
			93
		],
		[
			-6,
			52
		],
		[
			79,
			73
		],
		[
			-6,
			62
		],
		[
			114,
			-42
		],
		[
			72,
			21
		],
		[
			18,
			-41
		],
		[
			84,
			0
		],
		[
			60,
			-63
		],
		[
			30,
			0
		],
		[
			24,
			-72
		],
		[
			91,
			31
		],
		[
			30,
			-41
		],
		[
			18,
			-94
		],
		[
			24,
			-10
		]
	],
	[
		[
			23286,
			33463
		],
		[
			12,
			21
		]
	],
	[
		[
			23298,
			33484
		],
		[
			-12,
			-21
		]
	],
	[
		[
			25890,
			31671
		],
		[
			6,
			-20
		],
		[
			-30,
			-62
		],
		[
			-54,
			31
		],
		[
			-18,
			-11
		]
	],
	[
		[
			25794,
			31609
		],
		[
			-60,
			-52
		]
	],
	[
		[
			25734,
			31557
		],
		[
			-97,
			-20
		],
		[
			-54,
			-62
		],
		[
			-24,
			-83
		],
		[
			0,
			-104
		],
		[
			-84,
			-72
		],
		[
			-84,
			-21
		],
		[
			-132,
			-124
		],
		[
			-37,
			-11
		],
		[
			-54,
			-82
		],
		[
			-90,
			-73
		],
		[
			-108,
			-41
		],
		[
			-36,
			41
		],
		[
			-66,
			-31
		],
		[
			-48,
			-62
		],
		[
			-12,
			-73
		],
		[
			-73,
			0
		],
		[
			-126,
			104
		],
		[
			-132,
			31
		],
		[
			-24,
			-10
		],
		[
			-72,
			186
		],
		[
			18,
			21
		],
		[
			186,
			52
		],
		[
			18,
			113
		],
		[
			-18,
			73
		],
		[
			-72,
			-31
		],
		[
			-30,
			-62
		],
		[
			-54,
			-31
		],
		[
			-6,
			-52
		],
		[
			-60,
			-52
		],
		[
			-78,
			-93
		],
		[
			-73,
			41
		],
		[
			-18,
			83
		],
		[
			-36,
			83
		],
		[
			-48,
			41
		],
		[
			-114,
			-62
		],
		[
			-30,
			104
		],
		[
			-72,
			-10
		],
		[
			-12,
			82
		],
		[
			42,
			104
		],
		[
			-30,
			83
		],
		[
			-115,
			103
		],
		[
			0,
			73
		],
		[
			-66,
			21
		],
		[
			-12,
			31
		],
		[
			-102,
			93
		]
	],
	[
		[
			23599,
			31858
		],
		[
			18,
			52
		],
		[
			-36,
			82
		],
		[
			-72,
			83
		]
	],
	[
		[
			23503,
			32075
		],
		[
			-12,
			0
		]
	],
	[
		[
			23491,
			32075
		],
		[
			-54,
			42
		],
		[
			0,
			124
		]
	],
	[
		[
			23437,
			32241
		],
		[
			42,
			-21
		],
		[
			90,
			73
		],
		[
			-18,
			72
		],
		[
			12,
			94
		],
		[
			-66,
			103
		],
		[
			-60,
			10
		],
		[
			18,
			73
		],
		[
			60,
			31
		],
		[
			6,
			155
		],
		[
			48,
			63
		],
		[
			18,
			62
		],
		[
			-6,
			103
		],
		[
			-30,
			11
		],
		[
			-6,
			93
		],
		[
			-42,
			103
		],
		[
			12,
			63
		],
		[
			48,
			10
		],
		[
			24,
			-31
		],
		[
			168,
			31
		],
		[
			0,
			41
		],
		[
			67,
			31
		],
		[
			30,
			-41
		],
		[
			48,
			21
		],
		[
			90,
			0
		],
		[
			24,
			72
		],
		[
			54,
			21
		],
		[
			42,
			-73
		],
		[
			60,
			11
		],
		[
			60,
			52
		],
		[
			0,
			31
		],
		[
			115,
			51
		],
		[
			90,
			-31
		],
		[
			36,
			-51
		],
		[
			84,
			31
		],
		[
			120,
			0
		],
		[
			36,
			-83
		],
		[
			205,
			20
		],
		[
			102,
			-31
		],
		[
			126,
			0
		],
		[
			24,
			-82
		],
		[
			36,
			-21
		],
		[
			37,
			-104
		],
		[
			6,
			-62
		],
		[
			-43,
			-72
		],
		[
			-54,
			-52
		],
		[
			-6,
			-73
		],
		[
			66,
			52
		],
		[
			49,
			0
		],
		[
			18,
			-93
		],
		[
			108,
			0
		],
		[
			36,
			-31
		],
		[
			54,
			0
		],
		[
			-30,
			-93
		],
		[
			12,
			-63
		],
		[
			78,
			-134
		],
		[
			0,
			-62
		],
		[
			90,
			-52
		],
		[
			0,
			-42
		],
		[
			-60,
			-103
		],
		[
			24,
			-31
		],
		[
			151,
			21
		],
		[
			72,
			51
		],
		[
			72,
			0
		],
		[
			90,
			21
		],
		[
			60,
			93
		],
		[
			84,
			31
		],
		[
			121,
			-10
		],
		[
			36,
			-31
		],
		[
			138,
			-21
		],
		[
			66,
			21
		],
		[
			60,
			-31
		],
		[
			0,
			-62
		],
		[
			-66,
			-21
		],
		[
			0,
			-62
		],
		[
			-48,
			-11
		],
		[
			-60,
			-124
		],
		[
			-60,
			-72
		],
		[
			-6,
			-104
		],
		[
			-54,
			-10
		],
		[
			-30,
			-52
		],
		[
			-73,
			-62
		],
		[
			-36,
			-11
		],
		[
			-216,
			-176
		]
	],
	[
		[
			22222,
			27322
		],
		[
			78,
			-21
		],
		[
			0,
			-62
		],
		[
			-42,
			-62
		],
		[
			-48,
			51
		],
		[
			12,
			94
		]
	],
	[
		[
			26690,
			30677
		],
		[
			-25,
			-93
		],
		[
			-42,
			-73
		],
		[
			12,
			-51
		],
		[
			91,
			20
		],
		[
			0,
			-124
		],
		[
			60,
			-52
		],
		[
			78,
			-31
		],
		[
			18,
			-52
		],
		[
			54,
			-62
		],
		[
			-24,
			-103
		],
		[
			-66,
			-73
		],
		[
			-24,
			-124
		],
		[
			42,
			-104
		],
		[
			-24,
			-51
		],
		[
			12,
			-63
		],
		[
			36,
			-31
		],
		[
			126,
			0
		],
		[
			145,
			73
		],
		[
			42,
			-10
		],
		[
			96,
			41
		],
		[
			90,
			-10
		],
		[
			36,
			-145
		],
		[
			0,
			-94
		],
		[
			78,
			-62
		],
		[
			175,
			-114
		],
		[
			48,
			-134
		],
		[
			42,
			-11
		],
		[
			30,
			-72
		],
		[
			90,
			-42
		],
		[
			66,
			21
		],
		[
			18,
			31
		],
		[
			132,
			21
		],
		[
			49,
			31
		],
		[
			96,
			135
		],
		[
			84,
			51
		],
		[
			96,
			42
		],
		[
			84,
			21
		],
		[
			127,
			0
		],
		[
			54,
			93
		],
		[
			78,
			0
		],
		[
			60,
			31
		],
		[
			84,
			72
		],
		[
			169,
			31
		],
		[
			12,
			-82
		],
		[
			-31,
			-32
		],
		[
			55,
			-93
		],
		[
			-6,
			-31
		],
		[
			54,
			-134
		],
		[
			48,
			-42
		],
		[
			90,
			31
		],
		[
			42,
			-21
		],
		[
			90,
			0
		],
		[
			60,
			52
		],
		[
			169,
			-83
		],
		[
			84,
			63
		],
		[
			42,
			-21
		],
		[
			30,
			52
		],
		[
			114,
			93
		]
	],
	[
		[
			29936,
			29362
		],
		[
			48,
			0
		],
		[
			12,
			-197
		],
		[
			-108,
			-83
		],
		[
			-24,
			-41
		],
		[
			-78,
			-73
		],
		[
			6,
			-31
		],
		[
			-48,
			-72
		],
		[
			48,
			-52
		],
		[
			84,
			-42
		],
		[
			6,
			-72
		],
		[
			-78,
			-52
		],
		[
			0,
			-62
		],
		[
			-48,
			-62
		],
		[
			36,
			-73
		],
		[
			18,
			-93
		],
		[
			36,
			-62
		],
		[
			-54,
			-52
		]
	],
	[
		[
			29792,
			28243
		],
		[
			-132,
			-228
		],
		[
			-72,
			-41
		],
		[
			-91,
			10
		],
		[
			-192,
			-82
		],
		[
			-36,
			-63
		],
		[
			-78,
			42
		],
		[
			-30,
			-93
		],
		[
			-30,
			-31
		],
		[
			0,
			-83
		],
		[
			-67,
			-104
		],
		[
			12,
			-72
		],
		[
			55,
			-31
		],
		[
			36,
			-177
		],
		[
			-24,
			-72
		],
		[
			18,
			-135
		],
		[
			-6,
			-114
		],
		[
			-48,
			-82
		]
	],
	[
		[
			29107,
			26887
		],
		[
			-12,
			-145
		],
		[
			-85,
			-83
		],
		[
			-96,
			-21
		],
		[
			-48,
			10
		],
		[
			-78,
			-51
		],
		[
			-60,
			20
		],
		[
			-60,
			-10
		],
		[
			-30,
			21
		],
		[
			-121,
			-114
		],
		[
			12,
			-42
		],
		[
			-60,
			-62
		],
		[
			-30,
			73
		],
		[
			-114,
			-11
		],
		[
			-48,
			31
		],
		[
			-60,
			-62
		],
		[
			-12,
			-41
		]
	],
	[
		[
			28205,
			26400
		],
		[
			-48,
			31
		],
		[
			-18,
			-31
		],
		[
			-151,
			20
		],
		[
			-54,
			63
		],
		[
			-24,
			-42
		],
		[
			-54,
			-21
		],
		[
			-30,
			-62
		],
		[
			-90,
			-103
		],
		[
			-24,
			-156
		],
		[
			48,
			-51
		],
		[
			-66,
			-31
		],
		[
			-6,
			-114
		],
		[
			24,
			-125
		],
		[
			-24,
			-31
		],
		[
			-85,
			-20
		],
		[
			-12,
			-52
		],
		[
			-108,
			-93
		],
		[
			-54,
			-63
		]
	],
	[
		[
			27429,
			25519
		],
		[
			-48,
			21
		]
	],
	[
		[
			27381,
			25540
		],
		[
			-30,
			-10
		]
	],
	[
		[
			27351,
			25530
		],
		[
			-24,
			0
		]
	],
	[
		[
			27327,
			25530
		],
		[
			-30,
			10
		]
	],
	[
		[
			27297,
			25540
		],
		[
			6,
			-31
		]
	],
	[
		[
			27303,
			25509
		],
		[
			0,
			-10
		]
	],
	[
		[
			27303,
			25499
		],
		[
			-42,
			-21
		]
	],
	[
		[
			27261,
			25478
		],
		[
			-48,
			-10
		],
		[
			6,
			-145
		],
		[
			-30,
			-21
		],
		[
			-37,
			62
		],
		[
			-126,
			0
		],
		[
			-54,
			-41
		],
		[
			-84,
			-11
		],
		[
			-162,
			-72
		],
		[
			-73,
			0
		],
		[
			-36,
			-21
		],
		[
			-198,
			-31
		],
		[
			-36,
			52
		],
		[
			-90,
			207
		],
		[
			-127,
			248
		],
		[
			-78,
			125
		],
		[
			121,
			-93
		],
		[
			72,
			20
		],
		[
			-30,
			62
		],
		[
			-85,
			-31
		],
		[
			-102,
			62
		],
		[
			30,
			156
		],
		[
			30,
			72
		],
		[
			18,
			94
		],
		[
			48,
			103
		],
		[
			31,
			31
		],
		[
			36,
			93
		],
		[
			78,
			42
		],
		[
			18,
			31
		],
		[
			96,
			83
		],
		[
			30,
			62
		],
		[
			-12,
			155
		],
		[
			42,
			-41
		],
		[
			60,
			10
		],
		[
			145,
			145
		],
		[
			78,
			11
		],
		[
			60,
			82
		],
		[
			12,
			52
		],
		[
			108,
			31
		],
		[
			54,
			62
		],
		[
			72,
			52
		],
		[
			85,
			-31
		],
		[
			60,
			62
		],
		[
			-6,
			-10
		],
		[
			-78,
			-31
		],
		[
			-67,
			21
		],
		[
			-96,
			-21
		],
		[
			-54,
			-62
		],
		[
			-60,
			-42
		],
		[
			-54,
			21
		],
		[
			-54,
			-52
		],
		[
			-121,
			-21
		],
		[
			-48,
			-113
		],
		[
			-60,
			-21
		],
		[
			-90,
			10
		],
		[
			-120,
			259
		],
		[
			-114,
			166
		],
		[
			-187,
			238
		],
		[
			-96,
			155
		],
		[
			-12,
			73
		],
		[
			102,
			93
		],
		[
			6,
			-21
		]
	],
	[
		[
			26034,
			27839
		],
		[
			42,
			63
		],
		[
			-6,
			51
		],
		[
			48,
			104
		],
		[
			-12,
			72
		],
		[
			-132,
			249
		],
		[
			-36,
			114
		],
		[
			12,
			41
		],
		[
			84,
			42
		],
		[
			18,
			-42
		],
		[
			84,
			-10
		],
		[
			48,
			31
		],
		[
			121,
			31
		],
		[
			102,
			186
		],
		[
			-24,
			21
		],
		[
			-78,
			-52
		],
		[
			-24,
			-41
		],
		[
			-72,
			-52
		],
		[
			-49,
			31
		],
		[
			6,
			73
		],
		[
			-114,
			41
		],
		[
			-6,
			-72
		],
		[
			-72,
			-42
		],
		[
			-36,
			-52
		],
		[
			-114,
			-10
		],
		[
			-145,
			83
		],
		[
			-42,
			0
		],
		[
			-78,
			41
		],
		[
			-72,
			11
		],
		[
			-42,
			-42
		],
		[
			-108,
			-20
		],
		[
			-72,
			-31
		],
		[
			-30,
			10
		],
		[
			-163,
			0
		],
		[
			-96,
			-21
		],
		[
			-42,
			-31
		],
		[
			-42,
			-124
		],
		[
			-253,
			41
		],
		[
			-132,
			-31
		],
		[
			-108,
			-52
		],
		[
			42,
			-62
		],
		[
			-108,
			-20
		],
		[
			-169,
			-73
		],
		[
			-36,
			-72
		],
		[
			-54,
			-31
		],
		[
			-36,
			-52
		],
		[
			54,
			-52
		],
		[
			-144,
			-104
		],
		[
			-48,
			-114
		],
		[
			18,
			-134
		],
		[
			66,
			-11
		],
		[
			30,
			-51
		],
		[
			-18,
			-104
		],
		[
			-30,
			-31
		],
		[
			-30,
			41
		],
		[
			-102,
			-20
		],
		[
			-24,
			-104
		],
		[
			-73,
			-41
		],
		[
			-66,
			83
		],
		[
			36,
			124
		],
		[
			-114,
			103
		],
		[
			-90,
			63
		],
		[
			-126,
			62
		],
		[
			-103,
			0
		],
		[
			-78,
			-135
		],
		[
			-102,
			-93
		],
		[
			-48,
			41
		],
		[
			-60,
			21
		],
		[
			-102,
			-52
		],
		[
			-73,
			-62
		],
		[
			-6,
			52
		],
		[
			-72,
			31
		],
		[
			-90,
			0
		],
		[
			-30,
			-124
		],
		[
			-30,
			-73
		],
		[
			-144,
			52
		],
		[
			-66,
			93
		],
		[
			96,
			83
		],
		[
			-6,
			83
		],
		[
			66,
			62
		],
		[
			12,
			52
		]
	],
	[
		[
			22541,
			27881
		],
		[
			60,
			72
		],
		[
			30,
			0
		],
		[
			0,
			83
		],
		[
			24,
			104
		],
		[
			66,
			41
		],
		[
			66,
			0
		],
		[
			24,
			52
		],
		[
			0,
			72
		],
		[
			25,
			31
		],
		[
			48,
			-10
		],
		[
			48,
			21
		],
		[
			36,
			72
		],
		[
			-18,
			31
		],
		[
			54,
			63
		],
		[
			48,
			113
		],
		[
			30,
			-20
		],
		[
			72,
			10
		],
		[
			60,
			93
		],
		[
			12,
			52
		],
		[
			78,
			52
		],
		[
			73,
			0
		],
		[
			90,
			114
		],
		[
			72,
			10
		],
		[
			66,
			-21
		],
		[
			102,
			11
		],
		[
			42,
			-11
		],
		[
			55,
			32
		],
		[
			114,
			93
		],
		[
			84,
			93
		],
		[
			12,
			41
		],
		[
			54,
			11
		],
		[
			36,
			41
		],
		[
			54,
			124
		],
		[
			84,
			63
		],
		[
			43,
			82
		],
		[
			78,
			11
		],
		[
			54,
			-31
		],
		[
			234,
			238
		],
		[
			18,
			41
		],
		[
			97,
			63
		],
		[
			24,
			113
		],
		[
			36,
			21
		],
		[
			24,
			62
		],
		[
			6,
			321
		],
		[
			-54,
			156
		],
		[
			0,
			93
		],
		[
			60,
			83
		],
		[
			36,
			0
		],
		[
			-6,
			-83
		],
		[
			36,
			-62
		],
		[
			24,
			-83
		],
		[
			54,
			62
		],
		[
			0,
			155
		],
		[
			24,
			83
		],
		[
			132,
			83
		],
		[
			30,
			0
		],
		[
			49,
			62
		],
		[
			60,
			114
		],
		[
			96,
			114
		],
		[
			132,
			73
		],
		[
			60,
			62
		],
		[
			18,
			186
		],
		[
			78,
			83
		],
		[
			109,
			52
		],
		[
			90,
			10
		],
		[
			102,
			104
		],
		[
			30,
			0
		],
		[
			84,
			62
		],
		[
			24,
			-52
		],
		[
			73,
			0
		],
		[
			66,
			42
		],
		[
			60,
			-73
		],
		[
			102,
			41
		],
		[
			54,
			0
		],
		[
			150,
			42
		],
		[
			24,
			52
		],
		[
			97,
			10
		],
		[
			12,
			21
		]
	],
	[
		[
			26762,
			31827
		],
		[
			54,
			20
		],
		[
			90,
			-145
		],
		[
			271,
			-165
		],
		[
			0,
			-73
		],
		[
			-43,
			-103
		],
		[
			-48,
			-11
		],
		[
			-78,
			-114
		],
		[
			6,
			-93
		],
		[
			-36,
			-124
		],
		[
			-78,
			-52
		],
		[
			-48,
			-10
		],
		[
			-90,
			-93
		],
		[
			-72,
			-187
		]
	],
	[
		[
			29708,
			32334
		],
		[
			-54,
			-10
		],
		[
			0,
			-73
		],
		[
			-36,
			-10
		],
		[
			-54,
			-62
		],
		[
			-25,
			-155
		],
		[
			49,
			-83
		],
		[
			-67,
			-31
		],
		[
			-12,
			-63
		],
		[
			30,
			-72
		],
		[
			133,
			-31
		],
		[
			114,
			-73
		],
		[
			12,
			-31
		],
		[
			90,
			-51
		],
		[
			0,
			-73
		],
		[
			-30,
			-104
		],
		[
			18,
			-41
		],
		[
			-30,
			-114
		],
		[
			12,
			-145
		],
		[
			54,
			-52
		]
	],
	[
		[
			29912,
			31060
		],
		[
			-66,
			-20
		],
		[
			-12,
			-31
		],
		[
			-66,
			0
		],
		[
			-54,
			-63
		],
		[
			-42,
			0
		],
		[
			-78,
			-72
		],
		[
			-169,
			-114
		],
		[
			-36,
			-93
		],
		[
			-48,
			-31
		],
		[
			6,
			-52
		],
		[
			-42,
			-31
		],
		[
			36,
			-62
		],
		[
			-138,
			-62
		],
		[
			-36,
			-52
		],
		[
			-54,
			-11
		],
		[
			-6,
			-62
		],
		[
			48,
			-62
		],
		[
			108,
			104
		],
		[
			114,
			41
		],
		[
			12,
			-41
		],
		[
			211,
			10
		],
		[
			36,
			-124
		]
	],
	[
		[
			29636,
			30232
		],
		[
			54,
			52
		],
		[
			78,
			10
		],
		[
			18,
			-93
		],
		[
			-18,
			-73
		],
		[
			126,
			-124
		],
		[
			12,
			-62
		],
		[
			-84,
			-31
		],
		[
			-30,
			10
		],
		[
			-42,
			-62
		],
		[
			78,
			-104
		],
		[
			-6,
			-72
		],
		[
			72,
			-104
		],
		[
			42,
			-124
		],
		[
			0,
			-93
		]
	],
	[
		[
			26762,
			31827
		],
		[
			36,
			62
		],
		[
			78,
			31
		],
		[
			24,
			31
		],
		[
			102,
			41
		],
		[
			229,
			63
		],
		[
			84,
			51
		],
		[
			90,
			83
		],
		[
			102,
			42
		],
		[
			48,
			-21
		],
		[
			48,
			21
		],
		[
			61,
			62
		],
		[
			54,
			0
		],
		[
			102,
			-156
		],
		[
			48,
			-31
		],
		[
			30,
			-114
		],
		[
			-72,
			-31
		],
		[
			-30,
			-62
		],
		[
			30,
			-62
		],
		[
			36,
			83
		],
		[
			108,
			93
		],
		[
			0,
			62
		],
		[
			-96,
			73
		],
		[
			-90,
			124
		],
		[
			-42,
			21
		],
		[
			-30,
			186
		],
		[
			-42,
			73
		],
		[
			-157,
			93
		],
		[
			-12,
			52
		],
		[
			60,
			41
		],
		[
			79,
			-10
		],
		[
			84,
			-52
		],
		[
			30,
			10
		],
		[
			72,
			-134
		],
		[
			54,
			-11
		],
		[
			228,
			52
		],
		[
			49,
			-83
		],
		[
			156,
			-41
		],
		[
			6,
			-104
		],
		[
			84,
			-62
		],
		[
			90,
			-31
		],
		[
			307,
			-10
		],
		[
			114,
			20
		],
		[
			72,
			-41
		],
		[
			121,
			10
		],
		[
			216,
			83
		],
		[
			295,
			156
		],
		[
			30,
			-73
		],
		[
			60,
			-83
		]
	],
	[
		[
			29924,
			32169
		],
		[
			-6,
			0
		]
	],
	[
		[
			29918,
			32169
		],
		[
			6,
			0
		]
	],
	[
		[
			31830,
			30190
		],
		[
			0,
			-103
		],
		[
			-42,
			-83
		],
		[
			-66,
			-83
		],
		[
			36,
			-21
		],
		[
			54,
			-103
		],
		[
			12,
			-62
		],
		[
			-18,
			-52
		],
		[
			-78,
			-93
		],
		[
			24,
			-145
		],
		[
			66,
			-52
		],
		[
			66,
			-21
		],
		[
			0,
			-83
		],
		[
			54,
			-31
		],
		[
			0,
			-41
		],
		[
			97,
			31
		],
		[
			18,
			-73
		],
		[
			-72,
			-10
		],
		[
			-43,
			-83
		],
		[
			-168,
			-10
		],
		[
			-30,
			-31
		],
		[
			-156,
			-21
		],
		[
			-151,
			-41
		],
		[
			-180,
			51
		],
		[
			-120,
			-31
		],
		[
			-271,
			-31
		],
		[
			-96,
			42
		],
		[
			-60,
			-145
		],
		[
			-90,
			-62
		],
		[
			-78,
			-32
		],
		[
			-12,
			-113
		],
		[
			-49,
			-63
		],
		[
			-54,
			-20
		],
		[
			-12,
			-83
		]
	],
	[
		[
			30411,
			28492
		],
		[
			-30,
			-83
		],
		[
			-48,
			-73
		],
		[
			-216,
			-82
		],
		[
			-133,
			-21
		],
		[
			-114,
			-31
		],
		[
			-78,
			41
		]
	],
	[
		[
			29708,
			32334
		],
		[
			66,
			-10
		],
		[
			18,
			-31
		],
		[
			96,
			-73
		],
		[
			30,
			-51
		]
	],
	[
		[
			29918,
			32169
		],
		[
			6,
			0
		]
	],
	[
		[
			29924,
			32169
		],
		[
			0,
			31
		],
		[
			-180,
			134
		],
		[
			-108,
			125
		],
		[
			102,
			103
		],
		[
			66,
			42
		],
		[
			114,
			10
		],
		[
			151,
			62
		],
		[
			126,
			62
		],
		[
			282,
			83
		]
	],
	[
		[
			30477,
			32821
		],
		[
			18,
			-52
		],
		[
			-36,
			-72
		],
		[
			-54,
			-62
		],
		[
			0,
			-42
		],
		[
			-66,
			-41
		],
		[
			-36,
			31
		],
		[
			-36,
			-124
		],
		[
			114,
			0
		],
		[
			-72,
			-83
		],
		[
			54,
			-42
		],
		[
			48,
			-83
		],
		[
			115,
			52
		],
		[
			-13,
			-93
		],
		[
			25,
			-52
		],
		[
			36,
			0
		],
		[
			102,
			-83
		],
		[
			-163,
			-165
		],
		[
			175,
			-176
		],
		[
			90,
			-11
		],
		[
			36,
			-41
		],
		[
			-66,
			-93
		],
		[
			-6,
			-94
		],
		[
			48,
			-103
		],
		[
			54,
			-62
		],
		[
			60,
			-21
		],
		[
			84,
			-114
		],
		[
			-24,
			-31
		],
		[
			-6,
			-83
		],
		[
			49,
			-31
		],
		[
			6,
			-62
		],
		[
			156,
			-52
		],
		[
			78,
			31
		],
		[
			30,
			-21
		],
		[
			66,
			21
		],
		[
			30,
			42
		],
		[
			72,
			-42
		],
		[
			79,
			-10
		],
		[
			-18,
			-114
		],
		[
			24,
			-104
		],
		[
			36,
			-72
		],
		[
			-6,
			-62
		],
		[
			36,
			-83
		],
		[
			132,
			-52
		],
		[
			-24,
			-83
		],
		[
			30,
			-83
		],
		[
			66,
			-114
		],
		[
			30,
			0
		]
	],
	[
		[
			32125,
			31879
		],
		[
			-6,
			10
		]
	],
	[
		[
			32119,
			31889
		],
		[
			-18,
			21
		]
	],
	[
		[
			32149,
			31899
		],
		[
			-24,
			-20
		]
	],
	[
		[
			32119,
			31889
		],
		[
			6,
			-10
		]
	],
	[
		[
			33039,
			31226
		],
		[
			-60,
			-10
		]
	],
	[
		[
			32979,
			31216
		],
		[
			-680,
			383
		],
		[
			-78,
			31
		],
		[
			-42,
			62
		],
		[
			-120,
			104
		],
		[
			-48,
			62
		],
		[
			24,
			62
		],
		[
			60,
			0
		],
		[
			24,
			-31
		]
	],
	[
		[
			32071,
			31930
		],
		[
			-24,
			21
		]
	],
	[
		[
			32047,
			31951
		],
		[
			-6,
			10
		]
	],
	[
		[
			32041,
			31961
		],
		[
			-24,
			0
		]
	],
	[
		[
			32017,
			31961
		],
		[
			12,
			11
		]
	],
	[
		[
			32017,
			31961
		],
		[
			-24,
			63
		]
	],
	[
		[
			32979,
			31216
		],
		[
			60,
			10
		]
	],
	[
		[
			32786,
			30760
		],
		[
			-180,
			-21
		],
		[
			-60,
			-145
		],
		[
			-30,
			-41
		],
		[
			-91,
			-73
		],
		[
			-6,
			-51
		],
		[
			-42,
			-11
		],
		[
			-36,
			-62
		],
		[
			-126,
			-52
		],
		[
			-48,
			42
		],
		[
			-186,
			-104
		],
		[
			-49,
			-52
		],
		[
			-102,
			0
		]
	],
	[
		[
			30477,
			32821
		],
		[
			211,
			41
		],
		[
			90,
			-20
		],
		[
			12,
			-114
		],
		[
			36,
			-73
		],
		[
			150,
			-124
		],
		[
			55,
			0
		],
		[
			24,
			31
		],
		[
			30,
			-93
		],
		[
			36,
			-10
		],
		[
			144,
			-104
		],
		[
			138,
			-73
		],
		[
			181,
			-186
		],
		[
			156,
			-135
		],
		[
			72,
			-31
		],
		[
			30,
			-62
		],
		[
			121,
			-72
		],
		[
			120,
			-52
		],
		[
			126,
			-104
		],
		[
			30,
			-51
		],
		[
			114,
			-21
		],
		[
			91,
			-62
		],
		[
			192,
			-104
		],
		[
			295,
			-176
		],
		[
			48,
			-10
		]
	],
	[
		[
			31728,
			28471
		],
		[
			-30,
			62
		],
		[
			-138,
			42
		],
		[
			-121,
			-94
		],
		[
			-42,
			11
		],
		[
			-66,
			-52
		],
		[
			0,
			-93
		],
		[
			-72,
			-11
		],
		[
			-30,
			-72
		],
		[
			-235,
			-10
		],
		[
			-96,
			41
		],
		[
			-42,
			52
		],
		[
			6,
			41
		],
		[
			-78,
			21
		],
		[
			-78,
			-10
		],
		[
			-120,
			93
		],
		[
			-54,
			-11
		],
		[
			-67,
			21
		],
		[
			-54,
			-10
		]
	],
	[
		[
			22986,
			20848
		],
		[
			72,
			-10
		],
		[
			12,
			-31
		]
	],
	[
		[
			23070,
			20807
		],
		[
			-24,
			-31
		]
	],
	[
		[
			23046,
			20776
		],
		[
			-30,
			-104
		],
		[
			-72,
			-41
		],
		[
			-72,
			72
		],
		[
			-6,
			52
		],
		[
			72,
			42
		],
		[
			-18,
			62
		]
	],
	[
		[
			22920,
			20859
		],
		[
			66,
			-11
		]
	],
	[
		[
			27736,
			25157
		],
		[
			6,
			-135
		],
		[
			-36,
			-62
		],
		[
			36,
			-145
		],
		[
			90,
			-176
		],
		[
			54,
			-41
		],
		[
			150,
			83
		],
		[
			72,
			0
		],
		[
			31,
			93
		],
		[
			84,
			41
		],
		[
			42,
			52
		],
		[
			72,
			0
		],
		[
			24,
			-83
		],
		[
			-60,
			-31
		],
		[
			12,
			-83
		],
		[
			-42,
			-124
		],
		[
			-108,
			-31
		],
		[
			6,
			-104
		],
		[
			-24,
			-41
		],
		[
			-24,
			-114
		],
		[
			66,
			-31
		],
		[
			174,
			-124
		],
		[
			-18,
			-42
		],
		[
			42,
			-52
		],
		[
			66,
			-10
		],
		[
			24,
			-62
		],
		[
			-12,
			-62
		],
		[
			12,
			-73
		],
		[
			42,
			-52
		],
		[
			12,
			-103
		],
		[
			54,
			-104
		],
		[
			37,
			11
		],
		[
			66,
			-63
		]
	],
	[
		[
			28686,
			23489
		],
		[
			36,
			-20
		],
		[
			54,
			-104
		],
		[
			-150,
			-72
		],
		[
			-121,
			10
		],
		[
			-168,
			-155
		],
		[
			-54,
			-73
		],
		[
			36,
			-62
		],
		[
			48,
			-10
		],
		[
			18,
			-94
		],
		[
			-42,
			-82
		],
		[
			108,
			-83
		],
		[
			-12,
			-73
		],
		[
			-36,
			-41
		]
	],
	[
		[
			28403,
			22630
		],
		[
			-42,
			21
		],
		[
			-36,
			-52
		]
	],
	[
		[
			28325,
			22599
		],
		[
			-42,
			-21
		],
		[
			-6,
			-52
		],
		[
			-48,
			-62
		],
		[
			48,
			-62
		]
	],
	[
		[
			28277,
			22402
		],
		[
			-24,
			-52
		],
		[
			36,
			-124
		],
		[
			-42,
			-93
		],
		[
			24,
			-62
		],
		[
			-36,
			-125
		],
		[
			36,
			-51
		],
		[
			-24,
			-42
		],
		[
			0,
			-155
		],
		[
			18,
			-93
		],
		[
			6,
			-125
		],
		[
			24,
			-72
		],
		[
			-18,
			-42
		],
		[
			-78,
			-72
		]
	],
	[
		[
			28199,
			21294
		],
		[
			-42,
			-93
		],
		[
			-49,
			-11
		],
		[
			-12,
			-93
		],
		[
			-102,
			31
		],
		[
			-72,
			104
		],
		[
			-30,
			-11
		],
		[
			-66,
			42
		],
		[
			-54,
			72
		],
		[
			-30,
			0
		],
		[
			-84,
			73
		],
		[
			-97,
			20
		],
		[
			-36,
			-51
		],
		[
			-66,
			-42
		],
		[
			-66,
			-93
		],
		[
			-90,
			10
		],
		[
			-6,
			31
		],
		[
			-66,
			11
		],
		[
			-85,
			103
		],
		[
			-204,
			-186
		],
		[
			-30,
			-62
		],
		[
			-84,
			-11
		],
		[
			-24,
			-62
		],
		[
			-54,
			-51
		],
		[
			-97,
			-11
		],
		[
			-120,
			124
		],
		[
			-72,
			21
		],
		[
			-60,
			-62
		],
		[
			-36,
			21
		],
		[
			-96,
			-62
		],
		[
			-42,
			-63
		],
		[
			-115,
			0
		],
		[
			-48,
			-31
		],
		[
			-48,
			31
		],
		[
			-42,
			-20
		],
		[
			-84,
			-114
		],
		[
			-30,
			-124
		],
		[
			-72,
			-52
		],
		[
			-48,
			0
		],
		[
			-61,
			-31
		],
		[
			-12,
			51
		],
		[
			-48,
			-62
		],
		[
			-48,
			-10
		],
		[
			-18,
			-62
		],
		[
			-78,
			-31
		],
		[
			-24,
			-93
		],
		[
			-36,
			31
		],
		[
			-30,
			-31
		],
		[
			-72,
			20
		],
		[
			-139,
			0
		],
		[
			-48,
			42
		],
		[
			24,
			72
		],
		[
			-78,
			0
		],
		[
			-36,
			-62
		],
		[
			12,
			-62
		],
		[
			-72,
			-21
		],
		[
			-78,
			11
		],
		[
			-114,
			-104
		],
		[
			-67,
			10
		],
		[
			-36,
			73
		],
		[
			-78,
			10
		],
		[
			-12,
			31
		],
		[
			-72,
			-52
		],
		[
			-108,
			52
		],
		[
			-30,
			-10
		],
		[
			-90,
			41
		],
		[
			-97,
			0
		],
		[
			-54,
			-41
		]
	],
	[
		[
			24140,
			20455
		],
		[
			-48,
			21
		],
		[
			-30,
			-21
		],
		[
			-42,
			83
		],
		[
			-156,
			-42
		],
		[
			-36,
			31
		],
		[
			-79,
			0
		],
		[
			-36,
			-20
		],
		[
			-138,
			-11
		]
	],
	[
		[
			23575,
			20496
		],
		[
			-42,
			135
		],
		[
			-84,
			0
		],
		[
			-18,
			31
		],
		[
			-66,
			21
		],
		[
			-79,
			-11
		],
		[
			-90,
			-72
		],
		[
			-66,
			62
		]
	],
	[
		[
			23130,
			20662
		],
		[
			-24,
			31
		]
	],
	[
		[
			23106,
			20693
		],
		[
			-12,
			21
		]
	],
	[
		[
			23094,
			20714
		],
		[
			36,
			21
		]
	],
	[
		[
			23130,
			20735
		],
		[
			-12,
			31
		]
	],
	[
		[
			23118,
			20766
		],
		[
			-6,
			10
		]
	],
	[
		[
			23112,
			20776
		],
		[
			-12,
			52
		],
		[
			-54,
			41
		],
		[
			-60,
			-21
		]
	],
	[
		[
			22986,
			20848
		],
		[
			-114,
			42
		],
		[
			36,
			72
		],
		[
			0,
			73
		],
		[
			-42,
			41
		],
		[
			-36,
			166
		],
		[
			6,
			62
		],
		[
			84,
			0
		],
		[
			18,
			31
		],
		[
			114,
			21
		],
		[
			24,
			-10
		],
		[
			48,
			51
		],
		[
			126,
			-10
		],
		[
			36,
			21
		],
		[
			157,
			-21
		],
		[
			36,
			52
		],
		[
			90,
			10
		],
		[
			24,
			-52
		],
		[
			72,
			-31
		],
		[
			145,
			-10
		],
		[
			126,
			83
		],
		[
			66,
			114
		],
		[
			84,
			41
		],
		[
			18,
			83
		],
		[
			42,
			-10
		],
		[
			90,
			20
		],
		[
			103,
			94
		],
		[
			60,
			93
		],
		[
			186,
			165
		],
		[
			30,
			73
		],
		[
			84,
			41
		],
		[
			42,
			-31
		],
		[
			13,
			-51
		],
		[
			54,
			0
		],
		[
			66,
			41
		],
		[
			42,
			-21
		],
		[
			72,
			42
		],
		[
			108,
			103
		],
		[
			18,
			0
		],
		[
			133,
			104
		],
		[
			96,
			93
		],
		[
			84,
			10
		],
		[
			120,
			94
		],
		[
			60,
			31
		],
		[
			42,
			93
		],
		[
			60,
			62
		],
		[
			37,
			104
		],
		[
			78,
			41
		],
		[
			42,
			104
		],
		[
			36,
			20
		],
		[
			36,
			73
		],
		[
			72,
			93
		],
		[
			18,
			83
		],
		[
			42,
			41
		],
		[
			24,
			62
		],
		[
			42,
			187
		],
		[
			24,
			31
		],
		[
			18,
			93
		],
		[
			49,
			62
		],
		[
			24,
			83
		],
		[
			30,
			31
		],
		[
			6,
			156
		],
		[
			24,
			31
		],
		[
			0,
			83
		],
		[
			36,
			51
		],
		[
			-12,
			73
		],
		[
			42,
			176
		],
		[
			36,
			103
		],
		[
			54,
			94
		],
		[
			30,
			10
		],
		[
			12,
			73
		],
		[
			-42,
			341
		],
		[
			12,
			83
		],
		[
			84,
			-62
		],
		[
			48,
			10
		],
		[
			109,
			-10
		],
		[
			120,
			93
		],
		[
			54,
			0
		],
		[
			72,
			42
		],
		[
			36,
			82
		],
		[
			60,
			63
		],
		[
			78,
			20
		],
		[
			43,
			-51
		],
		[
			36,
			10
		],
		[
			12,
			72
		]
	],
	[
		[
			27231,
			25374
		],
		[
			72,
			11
		],
		[
			30,
			-21
		],
		[
			198,
			0
		],
		[
			84,
			10
		],
		[
			109,
			-93
		],
		[
			12,
			-124
		]
	],
	[
		[
			22751,
			16716
		],
		[
			48,
			-21
		],
		[
			73,
			21
		],
		[
			18,
			-41
		],
		[
			-36,
			-73
		],
		[
			-55,
			42
		],
		[
			-42,
			-21
		],
		[
			-6,
			93
		]
	],
	[
		[
			19360,
			17224
		],
		[
			0,
			-11
		]
	],
	[
		[
			19360,
			17213
		],
		[
			0,
			11
		]
	],
	[
		[
			19505,
			17286
		],
		[
			-67,
			-83
		],
		[
			-78,
			10
		]
	],
	[
		[
			19360,
			17224
		],
		[
			48,
			51
		],
		[
			48,
			21
		],
		[
			49,
			-10
		]
	],
	[
		[
			18278,
			17555
		],
		[
			-6,
			0
		],
		[
			6,
			0
		]
	],
	[
		[
			19222,
			17596
		],
		[
			0,
			42
		],
		[
			72,
			52
		],
		[
			102,
			-31
		],
		[
			73,
			-73
		],
		[
			-91,
			0
		],
		[
			-18,
			-52
		],
		[
			-60,
			31
		],
		[
			-54,
			0
		],
		[
			-24,
			31
		]
	],
	[
		[
			21717,
			17928
		],
		[
			0,
			-11
		]
	],
	[
		[
			21717,
			17917
		],
		[
			-6,
			0
		]
	],
	[
		[
			21711,
			17917
		],
		[
			6,
			11
		]
	],
	[
		[
			21723,
			17928
		],
		[
			-6,
			-11
		]
	],
	[
		[
			21717,
			17928
		],
		[
			6,
			0
		]
	],
	[
		[
			19108,
			18715
		],
		[
			6,
			0
		]
	],
	[
		[
			19114,
			18715
		],
		[
			-6,
			0
		]
	],
	[
		[
			19096,
			18715
		],
		[
			-6,
			0
		]
	],
	[
		[
			19090,
			18715
		],
		[
			6,
			0
		]
	],
	[
		[
			19438,
			18860
		],
		[
			6,
			-10
		]
	],
	[
		[
			19444,
			18850
		],
		[
			-6,
			10
		]
	],
	[
		[
			19108,
			18715
		],
		[
			-12,
			0
		]
	],
	[
		[
			19096,
			18715
		],
		[
			-6,
			0
		]
	],
	[
		[
			19090,
			18715
		],
		[
			-12,
			10
		],
		[
			-60,
			42
		],
		[
			-24,
			62
		],
		[
			60,
			10
		],
		[
			-24,
			73
		],
		[
			48,
			41
		],
		[
			48,
			-31
		],
		[
			-18,
			-93
		],
		[
			6,
			-114
		]
	],
	[
		[
			23070,
			20807
		],
		[
			18,
			0
		]
	],
	[
		[
			23088,
			20807
		],
		[
			24,
			-31
		]
	],
	[
		[
			23118,
			20766
		],
		[
			12,
			-31
		]
	],
	[
		[
			23130,
			20735
		],
		[
			-36,
			-21
		]
	],
	[
		[
			23094,
			20714
		],
		[
			12,
			-21
		]
	],
	[
		[
			23106,
			20693
		],
		[
			24,
			-31
		]
	],
	[
		[
			23575,
			20496
		],
		[
			48,
			-51
		],
		[
			6,
			-52
		]
	],
	[
		[
			23629,
			20393
		],
		[
			24,
			-135
		],
		[
			60,
			0
		],
		[
			60,
			-52
		],
		[
			55,
			-93
		],
		[
			18,
			-72
		],
		[
			72,
			-31
		],
		[
			36,
			10
		],
		[
			42,
			-52
		],
		[
			6,
			-103
		],
		[
			-12,
			-83
		],
		[
			-36,
			-62
		],
		[
			-144,
			-32
		],
		[
			-79,
			-31
		],
		[
			-18,
			21
		],
		[
			-96,
			-41
		],
		[
			-48,
			-52
		],
		[
			-36,
			-83
		],
		[
			-36,
			-41
		],
		[
			-84,
			-11
		],
		[
			-36,
			21
		],
		[
			-24,
			62
		],
		[
			-121,
			-114
		],
		[
			-48,
			0
		],
		[
			-12,
			-62
		],
		[
			-36,
			-31
		],
		[
			-60,
			10
		],
		[
			-114,
			94
		],
		[
			-30,
			0
		],
		[
			-84,
			-63
		],
		[
			-103,
			-20
		],
		[
			-84,
			-83
		],
		[
			30,
			-31
		],
		[
			-24,
			-166
		],
		[
			60,
			-31
		],
		[
			0,
			-62
		],
		[
			36,
			-31
		],
		[
			0,
			-93
		],
		[
			36,
			-83
		],
		[
			-48,
			-42
		],
		[
			-36,
			-93
		],
		[
			24,
			-62
		],
		[
			84,
			0
		],
		[
			97,
			-31
		],
		[
			48,
			0
		],
		[
			60,
			-31
		]
	],
	[
		[
			23028,
			18508
		],
		[
			36,
			0
		],
		[
			54,
			-93
		],
		[
			30,
			0
		],
		[
			36,
			-63
		],
		[
			54,
			-31
		],
		[
			-6,
			-41
		],
		[
			-54,
			-52
		],
		[
			-96,
			-41
		],
		[
			60,
			-135
		]
	],
	[
		[
			23142,
			18052
		],
		[
			-66,
			-52
		],
		[
			60,
			-51
		],
		[
			72,
			-32
		],
		[
			-42,
			-113
		],
		[
			12,
			-73
		],
		[
			-42,
			-93
		],
		[
			12,
			-42
		]
	],
	[
		[
			23148,
			17596
		],
		[
			-162,
			-31
		],
		[
			-84,
			-41
		],
		[
			-60,
			-52
		],
		[
			-67,
			-103
		],
		[
			61,
			-114
		],
		[
			-19,
			-94
		],
		[
			-24,
			-10
		],
		[
			-42,
			-104
		],
		[
			-6,
			-82
		],
		[
			-96,
			-156
		],
		[
			-108,
			21
		],
		[
			-102,
			0
		],
		[
			-30,
			-73
		],
		[
			-91,
			-41
		],
		[
			-24,
			-62
		],
		[
			-30,
			31
		],
		[
			-114,
			0
		],
		[
			-6,
			52
		],
		[
			-108,
			-11
		],
		[
			-126,
			42
		],
		[
			-73,
			0
		],
		[
			-42,
			-62
		],
		[
			-54,
			-31
		],
		[
			-18,
			-52
		],
		[
			-66,
			-11
		],
		[
			-48,
			-51
		],
		[
			-48,
			-125
		],
		[
			-78,
			-51
		],
		[
			-6,
			-42
		],
		[
			-42,
			-31
		],
		[
			-115,
			-10
		],
		[
			-72,
			72
		],
		[
			-66,
			0
		],
		[
			0,
			42
		],
		[
			-126,
			20
		],
		[
			-66,
			-31
		],
		[
			-115,
			52
		],
		[
			-78,
			52
		],
		[
			-96,
			0
		],
		[
			-30,
			31
		],
		[
			0,
			62
		],
		[
			60,
			52
		],
		[
			12,
			52
		],
		[
			-48,
			134
		],
		[
			-48,
			94
		],
		[
			-102,
			0
		],
		[
			-66,
			31
		],
		[
			-67,
			0
		],
		[
			-72,
			72
		],
		[
			-18,
			62
		],
		[
			60,
			31
		],
		[
			12,
			62
		],
		[
			85,
			-20
		],
		[
			90,
			0
		],
		[
			-24,
			-62
		],
		[
			36,
			-42
		],
		[
			60,
			-21
		],
		[
			48,
			11
		],
		[
			72,
			-21
		],
		[
			24,
			52
		],
		[
			-60,
			72
		],
		[
			12,
			42
		],
		[
			138,
			10
		],
		[
			37,
			-31
		],
		[
			108,
			-21
		],
		[
			120,
			0
		],
		[
			-18,
			-51
		],
		[
			24,
			-83
		],
		[
			30,
			-11
		],
		[
			168,
			31
		],
		[
			-72,
			63
		],
		[
			-48,
			0
		],
		[
			-12,
			51
		],
		[
			60,
			83
		],
		[
			84,
			-20
		],
		[
			73,
			82
		],
		[
			78,
			-51
		],
		[
			78,
			82
		],
		[
			72,
			0
		],
		[
			36,
			83
		],
		[
			102,
			0
		],
		[
			72,
			-114
		],
		[
			55,
			11
		],
		[
			-55,
			93
		],
		[
			43,
			62
		],
		[
			84,
			0
		],
		[
			42,
			31
		]
	],
	[
		[
			22036,
			17503
		],
		[
			6,
			0
		],
		[
			0,
			31
		]
	],
	[
		[
			22042,
			17534
		],
		[
			-6,
			-31
		]
	],
	[
		[
			22036,
			17503
		],
		[
			-126,
			0
		],
		[
			-49,
			-31
		],
		[
			-78,
			21
		],
		[
			-30,
			-52
		],
		[
			-54,
			0
		],
		[
			6,
			155
		],
		[
			-54,
			31
		],
		[
			-6,
			145
		],
		[
			42,
			63
		],
		[
			6,
			0
		],
		[
			18,
			82
		]
	],
	[
		[
			21711,
			17917
		],
		[
			6,
			0
		]
	],
	[
		[
			21723,
			17928
		],
		[
			72,
			52
		],
		[
			18,
			72
		],
		[
			85,
			42
		],
		[
			132,
			10
		],
		[
			18,
			21
		],
		[
			18,
			20
		],
		[
			-30,
			-31
		],
		[
			-156,
			-10
		],
		[
			-6,
			0
		],
		[
			-67,
			-42
		],
		[
			-18,
			-51
		],
		[
			-54,
			-52
		],
		[
			-30,
			10
		],
		[
			-78,
			-62
		],
		[
			-24,
			31
		],
		[
			-78,
			0
		],
		[
			84,
			-83
		],
		[
			-6,
			-238
		],
		[
			78,
			-62
		],
		[
			-42,
			-186
		],
		[
			-66,
			10
		],
		[
			-84,
			-73
		],
		[
			-48,
			42
		],
		[
			-55,
			0
		],
		[
			-30,
			-31
		],
		[
			-72,
			20
		],
		[
			-72,
			-20
		],
		[
			-66,
			-52
		],
		[
			-90,
			0
		],
		[
			-78,
			21
		],
		[
			-66,
			51
		],
		[
			-79,
			32
		],
		[
			-42,
			-32
		],
		[
			-258,
			-10
		],
		[
			0,
			52
		],
		[
			-48,
			41
		],
		[
			-12,
			52
		],
		[
			-61,
			52
		],
		[
			0,
			-93
		],
		[
			-42,
			-31
		],
		[
			-60,
			31
		],
		[
			-108,
			-42
		],
		[
			-72,
			-10
		],
		[
			-60,
			72
		],
		[
			-42,
			-41
		],
		[
			30,
			-83
		],
		[
			72,
			-21
		],
		[
			-30,
			-165
		],
		[
			-60,
			0
		],
		[
			-18,
			-62
		],
		[
			-48,
			51
		],
		[
			-31,
			83
		],
		[
			7,
			135
		],
		[
			-91,
			21
		],
		[
			12,
			62
		],
		[
			-72,
			51
		],
		[
			-162,
			42
		],
		[
			0,
			83
		],
		[
			42,
			10
		],
		[
			144,
			-31
		],
		[
			36,
			104
		],
		[
			0,
			72
		],
		[
			36,
			31
		],
		[
			61,
			-10
		],
		[
			48,
			72
		],
		[
			84,
			73
		],
		[
			84,
			21
		],
		[
			54,
			-21
		],
		[
			132,
			-21
		],
		[
			79,
			104
		],
		[
			-6,
			103
		],
		[
			-19,
			62
		],
		[
			25,
			125
		],
		[
			-25,
			83
		],
		[
			-42,
			62
		],
		[
			6,
			103
		],
		[
			-18,
			62
		],
		[
			-66,
			145
		],
		[
			-36,
			42
		],
		[
			-138,
			-11
		],
		[
			-114,
			21
		],
		[
			-18,
			42
		],
		[
			-181,
			-11
		],
		[
			-30,
			52
		],
		[
			-96,
			-10
		],
		[
			-126,
			10
		],
		[
			-109,
			-41
		]
	],
	[
		[
			19444,
			18850
		],
		[
			-6,
			10
		]
	],
	[
		[
			19438,
			18860
		],
		[
			-36,
			-41
		],
		[
			-84,
			-32
		],
		[
			-60,
			21
		],
		[
			-30,
			-41
		],
		[
			-42,
			20
		],
		[
			30,
			73
		],
		[
			30,
			10
		],
		[
			-36,
			125
		],
		[
			36,
			41
		],
		[
			30,
			-21
		],
		[
			48,
			62
		],
		[
			-48,
			156
		],
		[
			138,
			41
		],
		[
			18,
			-21
		],
		[
			139,
			83
		],
		[
			54,
			11
		],
		[
			48,
			83
		],
		[
			72,
			0
		],
		[
			78,
			20
		],
		[
			12,
			73
		],
		[
			48,
			20
		],
		[
			0,
			52
		],
		[
			48,
			31
		],
		[
			91,
			0
		],
		[
			54,
			-31
		],
		[
			72,
			11
		],
		[
			90,
			145
		],
		[
			18,
			-21
		],
		[
			162,
			0
		],
		[
			19,
			62
		],
		[
			102,
			0
		],
		[
			18,
			52
		],
		[
			-18,
			52
		],
		[
			18,
			72
		],
		[
			-60,
			42
		],
		[
			12,
			41
		],
		[
			96,
			72
		],
		[
			-48,
			83
		],
		[
			-24,
			73
		],
		[
			72,
			41
		],
		[
			24,
			62
		],
		[
			54,
			0
		],
		[
			36,
			-51
		],
		[
			126,
			10
		],
		[
			54,
			-52
		],
		[
			91,
			31
		],
		[
			114,
			-10
		],
		[
			6,
			-135
		],
		[
			-36,
			-41
		],
		[
			24,
			-52
		],
		[
			138,
			21
		],
		[
			18,
			-21
		],
		[
			151,
			93
		],
		[
			84,
			21
		],
		[
			66,
			93
		],
		[
			-42,
			52
		],
		[
			30,
			72
		],
		[
			48,
			0
		],
		[
			60,
			-41
		],
		[
			-12,
			-62
		],
		[
			54,
			-31
		],
		[
			126,
			21
		],
		[
			151,
			-11
		],
		[
			-6,
			124
		],
		[
			-48,
			52
		],
		[
			60,
			83
		],
		[
			102,
			73
		],
		[
			114,
			0
		],
		[
			78,
			41
		],
		[
			48,
			52
		],
		[
			55,
			93
		],
		[
			36,
			31
		],
		[
			102,
			155
		],
		[
			-18,
			73
		],
		[
			78,
			72
		],
		[
			12,
			63
		],
		[
			96,
			-63
		],
		[
			36,
			-41
		],
		[
			78,
			-10
		],
		[
			30,
			-62
		],
		[
			43,
			-32
		],
		[
			0,
			-103
		],
		[
			54,
			-31
		]
	],
	[
		[
			24952,
			17482
		],
		[
			0,
			-10
		]
	],
	[
		[
			24952,
			17472
		],
		[
			-12,
			-10
		]
	],
	[
		[
			24940,
			17462
		],
		[
			-6,
			0
		]
	],
	[
		[
			24934,
			17462
		],
		[
			0,
			10
		]
	],
	[
		[
			24934,
			17472
		],
		[
			0,
			10
		]
	],
	[
		[
			24934,
			17482
		],
		[
			12,
			0
		]
	],
	[
		[
			24946,
			17482
		],
		[
			6,
			0
		]
	],
	[
		[
			24856,
			17482
		],
		[
			12,
			0
		]
	],
	[
		[
			24868,
			17482
		],
		[
			-12,
			-10
		]
	],
	[
		[
			24856,
			17472
		],
		[
			-12,
			10
		]
	],
	[
		[
			24844,
			17482
		],
		[
			-12,
			11
		]
	],
	[
		[
			24832,
			17493
		],
		[
			-6,
			0
		]
	],
	[
		[
			24826,
			17493
		],
		[
			0,
			10
		]
	],
	[
		[
			24826,
			17503
		],
		[
			6,
			11
		]
	],
	[
		[
			24832,
			17514
		],
		[
			30,
			10
		]
	],
	[
		[
			24862,
			17524
		],
		[
			12,
			10
		]
	],
	[
		[
			24874,
			17534
		],
		[
			-18,
			-52
		]
	],
	[
		[
			24874,
			17534
		],
		[
			-12,
			-10
		]
	],
	[
		[
			24862,
			17524
		],
		[
			-30,
			-10
		]
	],
	[
		[
			24832,
			17514
		],
		[
			42,
			20
		]
	],
	[
		[
			24772,
			17545
		],
		[
			0,
			-11
		]
	],
	[
		[
			24772,
			17534
		],
		[
			-12,
			0
		]
	],
	[
		[
			24760,
			17534
		],
		[
			-6,
			0
		]
	],
	[
		[
			24754,
			17534
		],
		[
			-7,
			0
		]
	],
	[
		[
			24747,
			17534
		],
		[
			25,
			11
		]
	],
	[
		[
			24820,
			17503
		],
		[
			-48,
			-10
		]
	],
	[
		[
			24772,
			17493
		],
		[
			-6,
			-11
		]
	],
	[
		[
			24766,
			17482
		],
		[
			-12,
			-10
		]
	],
	[
		[
			24754,
			17472
		],
		[
			-19,
			10
		]
	],
	[
		[
			24735,
			17482
		],
		[
			-6,
			0
		]
	],
	[
		[
			24729,
			17482
		],
		[
			6,
			32
		]
	],
	[
		[
			24735,
			17514
		],
		[
			-6,
			-32
		]
	],
	[
		[
			24729,
			17482
		],
		[
			6,
			0
		]
	],
	[
		[
			24735,
			17482
		],
		[
			0,
			32
		]
	],
	[
		[
			24735,
			17514
		],
		[
			6,
			10
		]
	],
	[
		[
			24741,
			17524
		],
		[
			13,
			10
		]
	],
	[
		[
			24754,
			17534
		],
		[
			6,
			0
		]
	],
	[
		[
			24772,
			17534
		],
		[
			6,
			0
		]
	],
	[
		[
			24772,
			17534
		],
		[
			30,
			11
		]
	],
	[
		[
			24802,
			17545
		],
		[
			0,
			10
		]
	],
	[
		[
			24802,
			17555
		],
		[
			18,
			-52
		]
	],
	[
		[
			24802,
			17555
		],
		[
			0,
			-10
		]
	],
	[
		[
			24802,
			17545
		],
		[
			-24,
			-11
		]
	],
	[
		[
			24778,
			17534
		],
		[
			-6,
			11
		]
	],
	[
		[
			24772,
			17545
		],
		[
			30,
			10
		]
	],
	[
		[
			28199,
			21294
		],
		[
			54,
			0
		],
		[
			72,
			-73
		],
		[
			96,
			-31
		],
		[
			24,
			-31
		],
		[
			6,
			-103
		],
		[
			-48,
			-31
		],
		[
			12,
			-125
		],
		[
			108,
			-31
		],
		[
			121,
			-83
		],
		[
			84,
			-10
		],
		[
			-66,
			-135
		],
		[
			90,
			-62
		],
		[
			18,
			-52
		],
		[
			72,
			-72
		],
		[
			-78,
			-52
		],
		[
			-6,
			-52
		],
		[
			-48,
			-51
		],
		[
			24,
			-104
		],
		[
			-24,
			-73
		],
		[
			-121,
			-155
		],
		[
			-42,
			-41
		],
		[
			24,
			-52
		],
		[
			-42,
			-42
		],
		[
			-60,
			-103
		],
		[
			54,
			-73
		],
		[
			-30,
			-72
		],
		[
			-30,
			0
		],
		[
			-48,
			-62
		],
		[
			12,
			-62
		]
	],
	[
		[
			28427,
			19461
		],
		[
			-24,
			-83
		],
		[
			0,
			-156
		],
		[
			30,
			-62
		],
		[
			24,
			-134
		],
		[
			-18,
			-42
		],
		[
			-138,
			-186
		],
		[
			-114,
			-83
		],
		[
			-73,
			-73
		],
		[
			-36,
			-113
		],
		[
			-30,
			-52
		],
		[
			18,
			-73
		],
		[
			-78,
			-103
		],
		[
			-60,
			-104
		],
		[
			-12,
			-93
		]
	],
	[
		[
			27916,
			18104
		],
		[
			-54,
			114
		],
		[
			-126,
			72
		],
		[
			-157,
			11
		],
		[
			-150,
			-62
		],
		[
			0,
			-73
		],
		[
			36,
			-31
		],
		[
			12,
			-145
		],
		[
			-24,
			-83
		],
		[
			-72,
			31
		],
		[
			-36,
			-31
		],
		[
			-66,
			62
		],
		[
			-108,
			-31
		]
	],
	[
		[
			27171,
			17938
		],
		[
			-43,
			-10
		],
		[
			-42,
			-52
		],
		[
			-156,
			-10
		],
		[
			-24,
			41
		],
		[
			-66,
			52
		],
		[
			-36,
			0
		],
		[
			-30,
			-52
		],
		[
			12,
			-62
		],
		[
			-96,
			-114
		]
	],
	[
		[
			26690,
			17731
		],
		[
			-12,
			-10
		]
	],
	[
		[
			26678,
			17721
		],
		[
			-19,
			10
		],
		[
			-72,
			-135
		],
		[
			-36,
			11
		],
		[
			-30,
			-93
		]
	],
	[
		[
			26521,
			17514
		],
		[
			18,
			-32
		],
		[
			-18,
			-103
		]
	],
	[
		[
			26521,
			17379
		],
		[
			36,
			-42
		]
	],
	[
		[
			26557,
			17337
		],
		[
			-6,
			-10
		]
	],
	[
		[
			26551,
			17327
		],
		[
			-18,
			0
		]
	],
	[
		[
			26533,
			17327
		],
		[
			0,
			10
		]
	],
	[
		[
			26533,
			17337
		],
		[
			-24,
			-20
		]
	],
	[
		[
			26509,
			17317
		],
		[
			-12,
			-42
		],
		[
			-66,
			-31
		],
		[
			0,
			-52
		],
		[
			-102,
			-72
		],
		[
			12,
			-186
		],
		[
			-199,
			-52
		],
		[
			-138,
			10
		],
		[
			-36,
			-52
		],
		[
			-54,
			0
		],
		[
			-48,
			83
		],
		[
			-108,
			156
		],
		[
			-42,
			20
		],
		[
			-175,
			31
		],
		[
			-66,
			-62
		],
		[
			-168,
			-10
		],
		[
			-30,
			-52
		],
		[
			-109,
			-52
		],
		[
			-114,
			21
		],
		[
			-78,
			52
		],
		[
			-108,
			103
		],
		[
			-121,
			145
		],
		[
			-84,
			125
		],
		[
			-54,
			165
		],
		[
			138,
			-31
		]
	],
	[
		[
			24747,
			17534
		],
		[
			-6,
			-10
		]
	],
	[
		[
			24741,
			17524
		],
		[
			-6,
			-10
		]
	],
	[
		[
			24729,
			17482
		],
		[
			6,
			0
		]
	],
	[
		[
			24754,
			17472
		],
		[
			12,
			10
		]
	],
	[
		[
			24766,
			17482
		],
		[
			-12,
			-10
		]
	],
	[
		[
			24754,
			17472
		],
		[
			18,
			21
		]
	],
	[
		[
			24772,
			17493
		],
		[
			48,
			10
		]
	],
	[
		[
			24820,
			17503
		],
		[
			6,
			0
		]
	],
	[
		[
			24826,
			17503
		],
		[
			6,
			-10
		]
	],
	[
		[
			24826,
			17493
		],
		[
			6,
			0
		]
	],
	[
		[
			24832,
			17493
		],
		[
			12,
			-11
		]
	],
	[
		[
			24844,
			17482
		],
		[
			12,
			0
		]
	],
	[
		[
			24856,
			17482
		],
		[
			0,
			-10
		]
	],
	[
		[
			24856,
			17472
		],
		[
			12,
			10
		]
	],
	[
		[
			24868,
			17482
		],
		[
			66,
			0
		]
	],
	[
		[
			24934,
			17482
		],
		[
			12,
			0
		]
	],
	[
		[
			24946,
			17482
		],
		[
			-12,
			0
		]
	],
	[
		[
			24934,
			17482
		],
		[
			0,
			-10
		]
	],
	[
		[
			24952,
			17472
		],
		[
			0,
			10
		]
	],
	[
		[
			24952,
			17482
		],
		[
			-60,
			125
		],
		[
			-54,
			-11
		],
		[
			-139,
			21
		],
		[
			-60,
			93
		],
		[
			-6,
			73
		],
		[
			24,
			124
		],
		[
			30,
			31
		],
		[
			24,
			83
		],
		[
			-12,
			73
		],
		[
			-36,
			20
		],
		[
			-24,
			-124
		],
		[
			-72,
			-93
		],
		[
			-60,
			-42
		],
		[
			-36,
			-51
		],
		[
			-36,
			0
		],
		[
			-60,
			51
		],
		[
			-72,
			0
		],
		[
			-43,
			104
		],
		[
			13,
			52
		],
		[
			-55,
			20
		],
		[
			-30,
			-72
		],
		[
			-36,
			-31
		],
		[
			18,
			-83
		],
		[
			30,
			0
		],
		[
			139,
			-114
		],
		[
			42,
			-72
		],
		[
			-96,
			-42
		],
		[
			-55,
			-41
		],
		[
			-144,
			-11
		],
		[
			-132,
			31
		],
		[
			-379,
			63
		],
		[
			-108,
			-73
		],
		[
			-187,
			41
		],
		[
			-114,
			-41
		],
		[
			-18,
			10
		]
	],
	[
		[
			25397,
			16592
		],
		[
			-6,
			-11
		]
	],
	[
		[
			25391,
			16581
		],
		[
			0,
			11
		]
	],
	[
		[
			25391,
			16592
		],
		[
			6,
			0
		]
	],
	[
		[
			25577,
			16592
		],
		[
			-6,
			-11
		]
	],
	[
		[
			25571,
			16581
		],
		[
			-6,
			21
		]
	],
	[
		[
			25565,
			16602
		],
		[
			12,
			-10
		]
	],
	[
		[
			25565,
			16602
		],
		[
			-6,
			0
		]
	],
	[
		[
			25559,
			16602
		],
		[
			6,
			0
		]
	],
	[
		[
			25421,
			16612
		],
		[
			-12,
			-10
		]
	],
	[
		[
			25409,
			16602
		],
		[
			6,
			10
		]
	],
	[
		[
			25415,
			16612
		],
		[
			12,
			0
		]
	],
	[
		[
			25427,
			16612
		],
		[
			-6,
			0
		]
	],
	[
		[
			25421,
			16623
		],
		[
			-12,
			-11
		]
	],
	[
		[
			25409,
			16612
		],
		[
			6,
			11
		]
	],
	[
		[
			25415,
			16623
		],
		[
			6,
			0
		]
	],
	[
		[
			25421,
			16633
		],
		[
			0,
			-10
		]
	],
	[
		[
			25415,
			16623
		],
		[
			6,
			21
		]
	],
	[
		[
			25421,
			16644
		],
		[
			0,
			-11
		]
	],
	[
		[
			25445,
			16654
		],
		[
			-24,
			-31
		]
	],
	[
		[
			25421,
			16623
		],
		[
			0,
			10
		]
	],
	[
		[
			25421,
			16633
		],
		[
			12,
			21
		]
	],
	[
		[
			25433,
			16654
		],
		[
			12,
			0
		]
	],
	[
		[
			25439,
			16664
		],
		[
			6,
			-10
		]
	],
	[
		[
			25445,
			16654
		],
		[
			-18,
			0
		]
	],
	[
		[
			25427,
			16654
		],
		[
			6,
			0
		]
	],
	[
		[
			25433,
			16654
		],
		[
			6,
			10
		]
	],
	[
		[
			26395,
			16820
		],
		[
			-12,
			0
		]
	],
	[
		[
			26383,
			16820
		],
		[
			0,
			31
		]
	],
	[
		[
			26383,
			16851
		],
		[
			-6,
			0
		]
	],
	[
		[
			26377,
			16851
		],
		[
			12,
			10
		]
	],
	[
		[
			26389,
			16861
		],
		[
			0,
			-10
		]
	],
	[
		[
			26389,
			16851
		],
		[
			6,
			-31
		]
	],
	[
		[
			27171,
			17938
		],
		[
			36,
			-21
		],
		[
			54,
			-72
		]
	],
	[
		[
			27261,
			17845
		],
		[
			60,
			-93
		],
		[
			42,
			-21
		],
		[
			72,
			-83
		],
		[
			36,
			-103
		],
		[
			0,
			-52
		],
		[
			60,
			-145
		],
		[
			-12,
			-52
		],
		[
			90,
			0
		],
		[
			24,
			-41
		],
		[
			67,
			-11
		],
		[
			-6,
			-93
		],
		[
			-30,
			-124
		],
		[
			-55,
			-42
		],
		[
			-48,
			-114
		],
		[
			-36,
			-10
		],
		[
			-6,
			-104
		],
		[
			-60,
			-113
		],
		[
			-18,
			-104
		],
		[
			18,
			-52
		]
	],
	[
		[
			27459,
			16488
		],
		[
			-42,
			11
		],
		[
			-48,
			-52
		],
		[
			-96,
			-42
		],
		[
			-54,
			42
		],
		[
			-193,
			-11
		],
		[
			-90,
			-41
		],
		[
			-90,
			-93
		],
		[
			-42,
			-135
		],
		[
			12,
			-72
		],
		[
			36,
			-31
		],
		[
			84,
			-32
		],
		[
			-18,
			-41
		],
		[
			-96,
			-10
		],
		[
			-54,
			41
		],
		[
			-103,
			-52
		],
		[
			-60,
			73
		],
		[
			-48,
			-42
		],
		[
			-78,
			-10
		],
		[
			-42,
			-72
		],
		[
			-144,
			72
		],
		[
			-78,
			0
		],
		[
			-55,
			93
		],
		[
			-72,
			-62
		],
		[
			-66,
			10
		],
		[
			-102,
			-51
		],
		[
			-42,
			-83
		],
		[
			78,
			-62
		],
		[
			-30,
			-73
		],
		[
			-102,
			52
		],
		[
			-72,
			21
		],
		[
			-73,
			0
		],
		[
			-66,
			-21
		],
		[
			0,
			-83
		]
	],
	[
		[
			25613,
			15732
		],
		[
			-66,
			31
		],
		[
			-108,
			11
		],
		[
			-144,
			113
		],
		[
			-60,
			21
		],
		[
			-55,
			52
		],
		[
			-60,
			10
		],
		[
			-30,
			-31
		],
		[
			-36,
			62
		],
		[
			72,
			31
		],
		[
			12,
			63
		],
		[
			-42,
			196
		],
		[
			-60,
			114
		],
		[
			-18,
			0
		]
	],
	[
		[
			25018,
			16405
		],
		[
			66,
			62
		],
		[
			66,
			-20
		],
		[
			42,
			20
		],
		[
			43,
			94
		],
		[
			96,
			51
		],
		[
			54,
			156
		],
		[
			66,
			-31
		],
		[
			-12,
			-73
		]
	],
	[
		[
			25439,
			16664
		],
		[
			-6,
			-10
		]
	],
	[
		[
			25433,
			16654
		],
		[
			-6,
			0
		]
	],
	[
		[
			25427,
			16654
		],
		[
			6,
			0
		]
	],
	[
		[
			25433,
			16654
		],
		[
			-12,
			-10
		]
	],
	[
		[
			25421,
			16644
		],
		[
			-6,
			-11
		],
		[
			0,
			-10
		]
	],
	[
		[
			25409,
			16612
		],
		[
			-6,
			0
		],
		[
			6,
			0
		]
	],
	[
		[
			25409,
			16612
		],
		[
			-12,
			-20
		]
	],
	[
		[
			25397,
			16592
		],
		[
			-6,
			0
		]
	],
	[
		[
			25391,
			16581
		],
		[
			18,
			21
		]
	],
	[
		[
			25415,
			16612
		],
		[
			6,
			0
		]
	],
	[
		[
			25427,
			16612
		],
		[
			60,
			0
		],
		[
			48,
			-51
		],
		[
			24,
			41
		]
	],
	[
		[
			25559,
			16602
		],
		[
			12,
			-21
		]
	],
	[
		[
			25571,
			16581
		],
		[
			6,
			11
		]
	],
	[
		[
			25577,
			16592
		],
		[
			12,
			-11
		],
		[
			-6,
			11
		],
		[
			-54,
			103
		],
		[
			60,
			11
		],
		[
			60,
			-31
		],
		[
			85,
			-114
		],
		[
			126,
			0
		],
		[
			30,
			83
		],
		[
			90,
			0
		],
		[
			48,
			72
		],
		[
			102,
			10
		],
		[
			0,
			31
		],
		[
			85,
			73
		],
		[
			84,
			31
		],
		[
			66,
			0
		],
		[
			18,
			-41
		]
	],
	[
		[
			26395,
			16820
		],
		[
			-6,
			31
		]
	],
	[
		[
			26389,
			16861
		],
		[
			-6,
			-10
		]
	],
	[
		[
			26377,
			16851
		],
		[
			-30,
			62
		],
		[
			66,
			62
		],
		[
			-54,
			124
		],
		[
			48,
			21
		],
		[
			48,
			124
		],
		[
			48,
			11
		],
		[
			6,
			62
		]
	],
	[
		[
			26509,
			17317
		],
		[
			24,
			20
		]
	],
	[
		[
			26533,
			17327
		],
		[
			18,
			0
		]
	],
	[
		[
			26557,
			17337
		],
		[
			-36,
			42
		]
	],
	[
		[
			28187,
			15722
		],
		[
			-12,
			0
		]
	],
	[
		[
			28175,
			15722
		],
		[
			12,
			0
		]
	],
	[
		[
			27916,
			18104
		],
		[
			6,
			-10
		],
		[
			24,
			-52
		],
		[
			36,
			0
		],
		[
			30,
			-52
		],
		[
			48,
			-31
		],
		[
			24,
			-62
		],
		[
			6,
			-104
		],
		[
			43,
			-21
		],
		[
			138,
			-10
		],
		[
			48,
			52
		],
		[
			24,
			124
		],
		[
			30,
			42
		],
		[
			210,
			51
		],
		[
			61,
			0
		],
		[
			66,
			42
		],
		[
			90,
			-11
		],
		[
			120,
			-62
		],
		[
			48,
			-41
		],
		[
			30,
			10
		],
		[
			66,
			-31
		],
		[
			55,
			0
		],
		[
			6,
			-72
		],
		[
			42,
			-83
		]
	],
	[
		[
			29167,
			17783
		],
		[
			-18,
			-21
		],
		[
			72,
			-166
		],
		[
			18,
			-165
		],
		[
			-24,
			-31
		],
		[
			-12,
			-104
		],
		[
			18,
			-72
		],
		[
			-18,
			-94
		],
		[
			-30,
			-62
		],
		[
			48,
			-52
		],
		[
			42,
			-114
		],
		[
			60,
			-62
		],
		[
			6,
			-93
		]
	],
	[
		[
			29329,
			16747
		],
		[
			-18,
			-31
		],
		[
			-84,
			21
		],
		[
			-114,
			-52
		],
		[
			-151,
			31
		],
		[
			-204,
			31
		],
		[
			-90,
			-166
		],
		[
			-30,
			-176
		],
		[
			-49,
			-51
		],
		[
			-18,
			-83
		],
		[
			24,
			-73
		],
		[
			73,
			-103
		],
		[
			54,
			-31
		],
		[
			72,
			-83
		],
		[
			30,
			-104
		],
		[
			-24,
			-103
		],
		[
			-24,
			-32
		],
		[
			-96,
			11
		],
		[
			-109,
			-42
		],
		[
			-60,
			-72
		],
		[
			-102,
			41
		],
		[
			-84,
			0
		],
		[
			-42,
			42
		],
		[
			-96,
			0
		]
	],
	[
		[
			28187,
			15722
		],
		[
			-54,
			93
		],
		[
			-55,
			124
		],
		[
			-60,
			93
		],
		[
			-36,
			32
		],
		[
			-60,
			124
		],
		[
			-66,
			72
		],
		[
			-144,
			135
		],
		[
			-72,
			93
		],
		[
			-67,
			21
		],
		[
			-54,
			-31
		],
		[
			-60,
			10
		]
	],
	[
		[
			29329,
			16747
		],
		[
			72,
			10
		],
		[
			78,
			-20
		],
		[
			6,
			-42
		],
		[
			72,
			-51
		],
		[
			79,
			-156
		],
		[
			60,
			-31
		],
		[
			18,
			-41
		],
		[
			60,
			0
		],
		[
			84,
			-104
		],
		[
			-42,
			-103
		],
		[
			-12,
			-94
		],
		[
			-36,
			-20
		]
	],
	[
		[
			29768,
			16095
		],
		[
			6,
			-63
		],
		[
			54,
			-31
		],
		[
			-12,
			-51
		],
		[
			48,
			-63
		],
		[
			24,
			-124
		],
		[
			-54,
			-10
		],
		[
			-24,
			-42
		],
		[
			-48,
			-176
		],
		[
			-54,
			-41
		]
	],
	[
		[
			29708,
			15494
		],
		[
			-72,
			-62
		],
		[
			-85,
			-42
		],
		[
			-18,
			-72
		],
		[
			-36,
			-42
		],
		[
			6,
			-72
		],
		[
			-126,
			104
		],
		[
			-66,
			-21
		],
		[
			-102,
			-62
		],
		[
			-60,
			-11
		],
		[
			-30,
			21
		],
		[
			-73,
			-31
		],
		[
			-48,
			-41
		]
	],
	[
		[
			28998,
			15163
		],
		[
			-120,
			-52
		],
		[
			-54,
			62
		],
		[
			-48,
			21
		],
		[
			-84,
			0
		],
		[
			-36,
			-63
		],
		[
			-67,
			42
		],
		[
			-60,
			-42
		],
		[
			-108,
			52
		],
		[
			-24,
			83
		],
		[
			-60,
			93
		],
		[
			-54,
			52
		],
		[
			-66,
			166
		],
		[
			-42,
			145
		]
	],
	[
		[
			30640,
			15463
		],
		[
			138,
			-21
		],
		[
			78,
			-62
		],
		[
			30,
			-72
		],
		[
			60,
			-94
		],
		[
			12,
			-83
		],
		[
			55,
			-82
		],
		[
			156,
			10
		],
		[
			54,
			62
		],
		[
			96,
			21
		]
	],
	[
		[
			31319,
			15142
		],
		[
			84,
			-124
		]
	],
	[
		[
			31403,
			15018
		],
		[
			6,
			-21
		]
	],
	[
		[
			31409,
			14997
		],
		[
			36,
			-31
		]
	],
	[
		[
			31445,
			14966
		],
		[
			12,
			-11
		]
	],
	[
		[
			31457,
			14955
		],
		[
			55,
			-72
		]
	],
	[
		[
			31512,
			14883
		],
		[
			90,
			-10
		],
		[
			30,
			-52
		],
		[
			-42,
			-125
		],
		[
			0,
			-165
		],
		[
			-24,
			-42
		],
		[
			-72,
			-51
		],
		[
			-109,
			0
		],
		[
			-78,
			31
		],
		[
			-60,
			-11
		],
		[
			-36,
			-41
		],
		[
			-168,
			-62
		],
		[
			-133,
			0
		],
		[
			-6,
			-52
		],
		[
			-72,
			62
		],
		[
			-84,
			-31
		],
		[
			-138,
			-73
		],
		[
			-72,
			21
		],
		[
			-109,
			11
		],
		[
			-114,
			-11
		],
		[
			-78,
			-21
		],
		[
			-54,
			63
		],
		[
			-241,
			10
		],
		[
			-84,
			41
		],
		[
			-36,
			-10
		],
		[
			-66,
			31
		],
		[
			-48,
			0
		],
		[
			-132,
			42
		],
		[
			-139,
			-21
		],
		[
			-84,
			31
		],
		[
			-48,
			114
		],
		[
			-48,
			41
		],
		[
			-48,
			114
		],
		[
			-78,
			114
		],
		[
			-127,
			104
		],
		[
			-60,
			20
		],
		[
			-72,
			83
		],
		[
			0,
			42
		],
		[
			126,
			83
		]
	],
	[
		[
			29708,
			15494
		],
		[
			168,
			31
		],
		[
			144,
			-52
		],
		[
			31,
			-31
		],
		[
			84,
			11
		],
		[
			78,
			-11
		],
		[
			42,
			-72
		],
		[
			36,
			83
		],
		[
			84,
			31
		],
		[
			54,
			-11
		],
		[
			78,
			21
		],
		[
			61,
			-31
		],
		[
			72,
			0
		]
	],
	[
		[
			31890,
			15805
		],
		[
			48,
			10
		]
	],
	[
		[
			31938,
			15815
		],
		[
			12,
			-31
		],
		[
			85,
			-52
		],
		[
			18,
			-41
		],
		[
			60,
			-11
		],
		[
			18,
			-72
		],
		[
			-6,
			-104
		],
		[
			-66,
			-31
		],
		[
			42,
			-72
		]
	],
	[
		[
			32101,
			15401
		],
		[
			-90,
			-73
		],
		[
			-73,
			-31
		],
		[
			-24,
			21
		],
		[
			-72,
			-104
		],
		[
			-48,
			-145
		],
		[
			-120,
			-145
		],
		[
			-54,
			62
		],
		[
			-66,
			21
		],
		[
			-12,
			-72
		],
		[
			-30,
			-52
		]
	],
	[
		[
			31512,
			14883
		],
		[
			-55,
			72
		]
	],
	[
		[
			31457,
			14955
		],
		[
			-12,
			11
		]
	],
	[
		[
			31445,
			14966
		],
		[
			-36,
			31
		]
	],
	[
		[
			31409,
			14997
		],
		[
			-6,
			21
		]
	],
	[
		[
			31403,
			15018
		],
		[
			-84,
			124
		]
	],
	[
		[
			30640,
			15463
		],
		[
			-18,
			52
		],
		[
			12,
			72
		],
		[
			-42,
			73
		],
		[
			12,
			51
		],
		[
			48,
			21
		],
		[
			60,
			-10
		],
		[
			12,
			62
		],
		[
			42,
			0
		],
		[
			18,
			52
		],
		[
			72,
			-11
		],
		[
			138,
			42
		],
		[
			0,
			-52
		],
		[
			73,
			-83
		],
		[
			66,
			42
		],
		[
			72,
			103
		]
	],
	[
		[
			31205,
			15877
		],
		[
			42,
			-21
		],
		[
			66,
			21
		],
		[
			42,
			-10
		],
		[
			66,
			52
		],
		[
			121,
			0
		],
		[
			90,
			31
		],
		[
			78,
			-94
		],
		[
			36,
			31
		],
		[
			54,
			-10
		],
		[
			42,
			-52
		],
		[
			48,
			-20
		]
	],
	[
		[
			30014,
			18363
		],
		[
			-6,
			-93
		],
		[
			31,
			-114
		],
		[
			66,
			-83
		],
		[
			0,
			-52
		],
		[
			48,
			-52
		],
		[
			18,
			-83
		],
		[
			-90,
			-72
		],
		[
			-36,
			41
		],
		[
			-67,
			0
		],
		[
			85,
			-124
		],
		[
			90,
			-83
		],
		[
			48,
			-72
		],
		[
			36,
			-104
		],
		[
			30,
			-31
		],
		[
			84,
			-31
		],
		[
			108,
			-155
		],
		[
			61,
			-166
		],
		[
			42,
			-42
		],
		[
			102,
			-196
		],
		[
			42,
			-21
		],
		[
			60,
			21
		],
		[
			0,
			-104
		]
	],
	[
		[
			30766,
			16747
		],
		[
			48,
			-72
		],
		[
			18,
			-63
		],
		[
			0,
			-145
		],
		[
			54,
			-196
		],
		[
			72,
			-94
		],
		[
			55,
			0
		],
		[
			30,
			-51
		],
		[
			-12,
			-62
		],
		[
			30,
			-63
		],
		[
			48,
			31
		],
		[
			72,
			-31
		],
		[
			30,
			-72
		],
		[
			-6,
			-52
		]
	],
	[
		[
			29167,
			17783
		],
		[
			132,
			83
		],
		[
			42,
			124
		],
		[
			72,
			10
		],
		[
			96,
			73
		],
		[
			85,
			83
		],
		[
			84,
			62
		],
		[
			150,
			72
		],
		[
			18,
			94
		],
		[
			30,
			41
		],
		[
			-12,
			52
		],
		[
			60,
			10
		],
		[
			84,
			-83
		],
		[
			6,
			-41
		]
	],
	[
		[
			31908,
			17172
		],
		[
			0,
			-52
		],
		[
			97,
			-21
		],
		[
			84,
			52
		],
		[
			78,
			-135
		],
		[
			-6,
			-103
		],
		[
			-36,
			-114
		],
		[
			-114,
			-124
		],
		[
			-24,
			-63
		],
		[
			90,
			-31
		],
		[
			30,
			-72
		]
	],
	[
		[
			32107,
			16509
		],
		[
			-6,
			-42
		],
		[
			66,
			-82
		],
		[
			-12,
			-63
		],
		[
			-54,
			-41
		],
		[
			-30,
			21
		],
		[
			-36,
			-62
		],
		[
			-66,
			51
		],
		[
			-85,
			-41
		],
		[
			-24,
			-73
		],
		[
			90,
			-82
		],
		[
			55,
			0
		],
		[
			54,
			-73
		],
		[
			-24,
			-52
		],
		[
			-54,
			0
		],
		[
			-37,
			-103
		],
		[
			-54,
			-62
		]
	],
	[
		[
			30766,
			16747
		],
		[
			24,
			10
		]
	],
	[
		[
			30790,
			16757
		],
		[
			102,
			125
		],
		[
			42,
			-11
		],
		[
			0,
			176
		],
		[
			54,
			63
		],
		[
			-18,
			103
		],
		[
			-42,
			73
		],
		[
			-18,
			93
		],
		[
			-48,
			103
		],
		[
			-18,
			125
		],
		[
			-90,
			-42
		],
		[
			24,
			94
		],
		[
			-36,
			10
		],
		[
			-66,
			145
		],
		[
			-30,
			300
		]
	],
	[
		[
			30646,
			18114
		],
		[
			102,
			42
		],
		[
			42,
			0
		]
	],
	[
		[
			30790,
			18156
		],
		[
			48,
			41
		],
		[
			54,
			-72
		],
		[
			24,
			-94
		],
		[
			30,
			11
		],
		[
			85,
			-93
		],
		[
			6,
			-125
		],
		[
			42,
			0
		],
		[
			36,
			-124
		],
		[
			108,
			-83
		],
		[
			84,
			-93
		],
		[
			48,
			52
		],
		[
			-42,
			114
		],
		[
			54,
			41
		],
		[
			90,
			-93
		],
		[
			43,
			-104
		],
		[
			102,
			-165
		],
		[
			72,
			20
		],
		[
			60,
			-31
		],
		[
			0,
			-72
		],
		[
			96,
			-52
		],
		[
			6,
			-31
		],
		[
			-60,
			-83
		],
		[
			6,
			-31
		],
		[
			84,
			10
		],
		[
			42,
			73
		]
	],
	[
		[
			31668,
			18352
		],
		[
			42,
			-31
		],
		[
			12,
			-82
		],
		[
			-42,
			-63
		],
		[
			126,
			-41
		]
	],
	[
		[
			31806,
			18135
		],
		[
			-60,
			-62
		],
		[
			120,
			-135
		],
		[
			103,
			-93
		],
		[
			-55,
			-31
		],
		[
			49,
			-155
		],
		[
			-31,
			-73
		],
		[
			24,
			-176
		],
		[
			-12,
			-124
		],
		[
			-42,
			-73
		],
		[
			6,
			-41
		]
	],
	[
		[
			30790,
			18156
		],
		[
			6,
			103
		],
		[
			144,
			187
		],
		[
			259,
			-125
		],
		[
			114,
			11
		],
		[
			156,
			0
		],
		[
			199,
			20
		]
	],
	[
		[
			32714,
			16789
		],
		[
			6,
			-94
		]
	],
	[
		[
			32720,
			16695
		],
		[
			6,
			-20
		]
	],
	[
		[
			32726,
			16675
		],
		[
			30,
			-52
		],
		[
			60,
			-31
		]
	],
	[
		[
			32816,
			16592
		],
		[
			-36,
			-31
		],
		[
			-138,
			31
		],
		[
			-66,
			-83
		],
		[
			-60,
			10
		],
		[
			-48,
			-41
		],
		[
			-43,
			0
		],
		[
			-60,
			52
		],
		[
			-60,
			0
		],
		[
			0,
			-125
		],
		[
			-84,
			21
		],
		[
			-54,
			73
		],
		[
			-60,
			10
		]
	],
	[
		[
			31806,
			18135
		],
		[
			163,
			31
		],
		[
			54,
			-41
		],
		[
			78,
			-31
		],
		[
			36,
			10
		],
		[
			102,
			-52
		],
		[
			72,
			-124
		],
		[
			-30,
			-73
		],
		[
			42,
			-62
		],
		[
			48,
			-31
		],
		[
			48,
			-72
		],
		[
			-24,
			-156
		],
		[
			36,
			-103
		],
		[
			37,
			20
		],
		[
			102,
			11
		],
		[
			60,
			-21
		],
		[
			48,
			-41
		],
		[
			-30,
			-73
		],
		[
			-54,
			-62
		],
		[
			-30,
			-83
		],
		[
			180,
			21
		],
		[
			-36,
			-135
		],
		[
			-54,
			-41
		],
		[
			-18,
			52
		],
		[
			-66,
			-21
		],
		[
			6,
			-114
		],
		[
			54,
			-21
		],
		[
			6,
			-52
		],
		[
			54,
			-31
		],
		[
			24,
			-51
		]
	],
	[
		[
			34488,
			17669
		],
		[
			-18,
			-62
		]
	],
	[
		[
			34470,
			17607
		],
		[
			-90,
			-62
		],
		[
			42,
			-52
		]
	],
	[
		[
			34422,
			17493
		],
		[
			-6,
			-31
		]
	],
	[
		[
			34416,
			17462
		],
		[
			12,
			-73
		],
		[
			54,
			-52
		],
		[
			-18,
			-72
		]
	],
	[
		[
			34452,
			17265
		],
		[
			-36,
			31
		]
	],
	[
		[
			34416,
			17296
		],
		[
			72,
			-114
		],
		[
			-24,
			-83
		],
		[
			72,
			-103
		],
		[
			-42,
			-21
		],
		[
			-66,
			10
		],
		[
			-30,
			-20
		],
		[
			-6,
			-73
		],
		[
			84,
			-31
		],
		[
			-54,
			-72
		],
		[
			12,
			-52
		],
		[
			42,
			20
		],
		[
			24,
			-31
		],
		[
			-12,
			-82
		],
		[
			60,
			-94
		],
		[
			-36,
			-103
		],
		[
			-36,
			-52
		],
		[
			-90,
			-41
		],
		[
			-43,
			-42
		],
		[
			-54,
			-93
		],
		[
			-72,
			-73
		],
		[
			-120,
			0
		],
		[
			-114,
			-20
		],
		[
			-48,
			-42
		],
		[
			-97,
			-41
		],
		[
			-228,
			-156
		]
	],
	[
		[
			33610,
			15887
		],
		[
			-54,
			63
		],
		[
			-18,
			93
		],
		[
			-54,
			-21
		],
		[
			-54,
			31
		],
		[
			-31,
			62
		],
		[
			37,
			62
		],
		[
			24,
			156
		],
		[
			66,
			21
		],
		[
			30,
			113
		],
		[
			138,
			11
		],
		[
			-18,
			93
		],
		[
			-60,
			62
		],
		[
			-36,
			83
		],
		[
			-60,
			73
		],
		[
			-121,
			-63
		],
		[
			-66,
			-10
		],
		[
			-30,
			-31
		],
		[
			-72,
			10
		]
	],
	[
		[
			33231,
			16695
		],
		[
			-12,
			-20
		]
	],
	[
		[
			33219,
			16675
		],
		[
			-18,
			-11
		]
	],
	[
		[
			33201,
			16664
		],
		[
			-18,
			-10
		]
	],
	[
		[
			33183,
			16654
		],
		[
			18,
			-10
		]
	],
	[
		[
			33201,
			16644
		],
		[
			-12,
			-11
		]
	],
	[
		[
			33189,
			16633
		],
		[
			-6,
			0
		]
	],
	[
		[
			33183,
			16633
		],
		[
			-12,
			11
		]
	],
	[
		[
			33171,
			16644
		],
		[
			-12,
			-11
		]
	],
	[
		[
			33159,
			16633
		],
		[
			18,
			-21
		]
	],
	[
		[
			33177,
			16612
		],
		[
			-48,
			-31
		]
	],
	[
		[
			33129,
			16581
		],
		[
			-6,
			21
		]
	],
	[
		[
			33123,
			16602
		],
		[
			-36,
			-62
		],
		[
			-48,
			41
		],
		[
			-72,
			-82
		]
	],
	[
		[
			32967,
			16499
		],
		[
			-36,
			0
		]
	],
	[
		[
			32931,
			16499
		],
		[
			-19,
			-11
		]
	],
	[
		[
			32912,
			16488
		],
		[
			-12,
			11
		]
	],
	[
		[
			32900,
			16499
		],
		[
			12,
			20
		]
	],
	[
		[
			32912,
			16519
		],
		[
			-24,
			42
		],
		[
			-6,
			0
		],
		[
			-66,
			31
		]
	],
	[
		[
			31668,
			18352
		],
		[
			78,
			32
		],
		[
			72,
			134
		],
		[
			78,
			52
		],
		[
			79,
			-62
		],
		[
			6,
			72
		],
		[
			36,
			62
		],
		[
			78,
			32
		],
		[
			42,
			72
		],
		[
			60,
			52
		],
		[
			-42,
			83
		],
		[
			24,
			31
		],
		[
			96,
			51
		],
		[
			54,
			0
		],
		[
			24,
			125
		],
		[
			-60,
			165
		],
		[
			-60,
			21
		],
		[
			-36,
			52
		],
		[
			-72,
			52
		],
		[
			-30,
			62
		],
		[
			18,
			52
		],
		[
			-48,
			124
		],
		[
			42,
			52
		],
		[
			-66,
			93
		],
		[
			150,
			166
		]
	],
	[
		[
			32912,
			16519
		],
		[
			-12,
			-20
		]
	],
	[
		[
			32900,
			16499
		],
		[
			12,
			-11
		]
	],
	[
		[
			32912,
			16488
		],
		[
			6,
			-41
		],
		[
			-36,
			-62
		]
	],
	[
		[
			32882,
			16385
		],
		[
			-42,
			0
		],
		[
			-42,
			-42
		],
		[
			-66,
			73
		],
		[
			-30,
			-42
		],
		[
			-36,
			42
		],
		[
			-48,
			-31
		],
		[
			18,
			-94
		],
		[
			-30,
			-51
		],
		[
			60,
			-73
		],
		[
			42,
			-83
		],
		[
			-42,
			-10
		],
		[
			-12,
			-52
		],
		[
			102,
			-114
		],
		[
			-120,
			-72
		],
		[
			-30,
			-114
		],
		[
			-54,
			-52
		],
		[
			-163,
			-114
		],
		[
			-60,
			0
		],
		[
			-126,
			-124
		],
		[
			-102,
			-31
		]
	],
	[
		[
			33610,
			15887
		],
		[
			-211,
			-103
		],
		[
			-72,
			0
		],
		[
			-60,
			-42
		],
		[
			-120,
			-31
		],
		[
			-24,
			-20
		],
		[
			-102,
			31
		],
		[
			-181,
			-11
		],
		[
			-90,
			42
		],
		[
			-66,
			52
		],
		[
			6,
			31
		],
		[
			66,
			31
		],
		[
			24,
			62
		],
		[
			-78,
			62
		],
		[
			-36,
			52
		],
		[
			66,
			41
		],
		[
			-60,
			93
		],
		[
			-36,
			21
		],
		[
			6,
			156
		],
		[
			24,
			51
		],
		[
			42,
			-41
		],
		[
			54,
			0
		],
		[
			60,
			-31
		],
		[
			36,
			62
		],
		[
			24,
			-10
		]
	],
	[
		[
			32882,
			16385
		],
		[
			67,
			72
		],
		[
			-18,
			42
		]
	],
	[
		[
			32967,
			16499
		],
		[
			66,
			72
		],
		[
			48,
			-41
		],
		[
			42,
			72
		]
	],
	[
		[
			33123,
			16602
		],
		[
			6,
			-21
		]
	],
	[
		[
			33129,
			16581
		],
		[
			48,
			31
		]
	],
	[
		[
			33177,
			16612
		],
		[
			-18,
			21
		]
	],
	[
		[
			33171,
			16644
		],
		[
			12,
			-11
		]
	],
	[
		[
			33189,
			16633
		],
		[
			12,
			11
		]
	],
	[
		[
			33183,
			16654
		],
		[
			18,
			10
		]
	],
	[
		[
			33201,
			16664
		],
		[
			18,
			11
		]
	],
	[
		[
			33219,
			16675
		],
		[
			12,
			20
		]
	],
	[
		[
			30646,
			18114
		],
		[
			-145,
			11
		],
		[
			25,
			62
		],
		[
			-25,
			83
		],
		[
			-36,
			-21
		],
		[
			-42,
			72
		],
		[
			-42,
			-10
		],
		[
			-54,
			41
		],
		[
			-60,
			-20
		],
		[
			-36,
			72
		],
		[
			24,
			52
		],
		[
			-84,
			83
		],
		[
			-30,
			-62
		],
		[
			-66,
			-73
		],
		[
			-61,
			-41
		]
	],
	[
		[
			27231,
			25374
		],
		[
			-12,
			94
		],
		[
			42,
			10
		]
	],
	[
		[
			27261,
			25478
		],
		[
			42,
			21
		]
	],
	[
		[
			27303,
			25509
		],
		[
			-6,
			31
		]
	],
	[
		[
			27297,
			25540
		],
		[
			30,
			-10
		]
	],
	[
		[
			27327,
			25530
		],
		[
			24,
			0
		]
	],
	[
		[
			27351,
			25530
		],
		[
			30,
			10
		]
	],
	[
		[
			27381,
			25540
		],
		[
			48,
			-21
		]
	]
];
var transform = {
	scale: [
		0.00017320494362750265,
		0.0001061814267619251
	],
	translate: [
		-8.6427174507393,
		49.866948884277974
	]
};
var objects = {
	lad: {
		type: "GeometryCollection",
		geometries: [
			{
				arcs: [
					[
						0,
						1,
						2,
						3,
						4,
						5,
						6,
						7,
						8,
						9,
						10,
						11,
						12,
						13,
						14,
						15,
						16,
						17,
						18,
						19,
						20
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E06000001",
					LAD13CDO: "00EB",
					LAD13NM: "Hartlepool",
					LAD13NMW: null
				},
				id: "E06000001"
			},
			{
				arcs: [
					[
						[
							21,
							22,
							23
						]
					],
					[
						[
							-23,
							24,
							25,
							26,
							27,
							28,
							29
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "E06000002",
					LAD13CDO: "00EC",
					LAD13NM: "Middlesbrough",
					LAD13NMW: null
				},
				id: "E06000002"
			},
			{
				arcs: [
					[
						31,
						32,
						-26,
						-31,
						-22,
						33
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E06000003",
					LAD13CDO: "00EE",
					LAD13NM: "Redcar and Cleveland",
					LAD13NMW: null
				},
				id: "E06000003"
			},
			{
				arcs: [
					[
						[
							-29,
							-28,
							34,
							35,
							36,
							37,
							38,
							39,
							40,
							41,
							42,
							43,
							44,
							45,
							46,
							47,
							48,
							49,
							50,
							51,
							52,
							53,
							54
						]
					],
					[
						[
							-7,
							55,
							-5
						]
					],
					[
						[
							56,
							57,
							58,
							-16,
							59,
							-14,
							60,
							-12,
							61,
							-10,
							62,
							63,
							-3,
							64,
							65,
							66,
							67,
							68,
							69,
							70,
							71,
							72,
							73,
							-46,
							74,
							75,
							-43,
							76,
							77,
							-40,
							78,
							79,
							-37,
							80,
							81,
							82,
							83,
							84,
							85,
							86,
							87,
							88,
							89,
							90,
							91,
							-20
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "E06000004",
					LAD13CDO: "00EF",
					LAD13NM: "Stockton-on-Tees",
					LAD13NMW: null
				},
				id: "E06000004"
			},
			{
				arcs: [
					[
						-91,
						92,
						93,
						94
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E06000005",
					LAD13CDO: "00EH",
					LAD13NM: "Darlington",
					LAD13NMW: null
				},
				id: "E06000005"
			},
			{
				arcs: [
					[
						[
							95,
							96,
							97
						]
					],
					[
						[
							98,
							99,
							100,
							101,
							102,
							103
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "E06000006",
					LAD13CDO: "00ET",
					LAD13NM: "Halton",
					LAD13NMW: null
				},
				id: "E06000006"
			},
			{
				arcs: [
					[
						104,
						105,
						106,
						-98,
						107,
						-99,
						108,
						109,
						110
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E06000007",
					LAD13CDO: "00EU",
					LAD13NM: "Warrington",
					LAD13NMW: null
				},
				id: "E06000007"
			},
			{
				arcs: [
					[
						111,
						112,
						113,
						114,
						115,
						116,
						117,
						118,
						119,
						120,
						121
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E06000008",
					LAD13CDO: "00EX",
					LAD13NM: "Blackburn with Darwen",
					LAD13NMW: null
				},
				id: "E06000008"
			},
			{
				arcs: [
					[
						122,
						123,
						124,
						125
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E06000009",
					LAD13CDO: "00EY",
					LAD13NM: "Blackpool",
					LAD13NMW: null
				},
				id: "E06000009"
			},
			{
				arcs: [
					[
						[
							126,
							127,
							128,
							129,
							130,
							131,
							132,
							133,
							134,
							135,
							136,
							137,
							138,
							139,
							140,
							141,
							142,
							143
						]
					],
					[
						[
							144,
							145,
							146,
							147,
							-136,
							148,
							149,
							150,
							151,
							-131,
							152,
							-129,
							153,
							-127,
							154,
							155,
							-142,
							156,
							157,
							158,
							159,
							160,
							161,
							162,
							163
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "E06000010",
					LAD13CDO: "00FA",
					LAD13NM: "Kingston upon Hull, City of",
					LAD13NMW: null
				},
				id: "E06000010"
			},
			{
				arcs: [
					[
						[
							164,
							165,
							166,
							167,
							168
						]
					],
					[
						[
							169,
							170,
							171,
							172,
							173,
							174,
							175,
							176,
							177,
							178,
							179,
							180,
							181,
							182,
							183,
							184,
							185,
							186,
							187,
							188,
							189,
							190,
							191,
							192,
							193,
							194,
							195,
							196,
							197,
							198,
							199,
							200,
							201
						]
					],
					[
						[
							203,
							-164,
							204,
							205,
							206,
							207,
							-159,
							208,
							-139,
							209,
							210,
							211,
							212,
							213
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "E06000011",
					LAD13CDO: "00FB",
					LAD13NM: "East Riding of Yorkshire",
					LAD13NMW: null
				},
				id: "E06000011"
			},
			{
				arcs: [
					[
						214,
						215,
						216,
						217,
						218,
						219,
						220,
						221
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E06000012",
					LAD13CDO: "00FC",
					LAD13NM: "North East Lincolnshire",
					LAD13NMW: null
				},
				id: "E06000012"
			},
			{
				arcs: [
					[
						[
							222,
							223,
							224,
							-165,
							225
						]
					],
					[
						[
							226
						]
					],
					[
						[
							-221,
							227,
							228
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "E06000013",
					LAD13CDO: "00FD",
					LAD13NM: "North Lincolnshire",
					LAD13NMW: null
				},
				id: "E06000013"
			},
			{
				arcs: [
					[
						-212,
						229,
						230,
						231,
						232,
						233,
						234,
						235,
						236,
						237,
						238
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E06000014",
					LAD13CDO: "00FF",
					LAD13NM: "York",
					LAD13NMW: null
				},
				id: "E06000014"
			},
			{
				arcs: [
					[
						239,
						240,
						241
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E06000015",
					LAD13CDO: "00FK",
					LAD13NM: "Derby",
					LAD13NMW: null
				},
				id: "E06000015"
			},
			{
				arcs: [
					[
						242,
						243,
						244,
						245,
						246
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E06000016",
					LAD13CDO: "00FN",
					LAD13NM: "Leicester",
					LAD13NMW: null
				},
				id: "E06000016"
			},
			{
				arcs: [
					[
						247,
						248,
						249,
						250,
						251,
						252,
						253,
						254,
						255,
						256,
						257,
						258,
						259,
						260,
						261,
						262,
						263,
						264,
						265,
						266,
						267,
						268,
						269
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E06000017",
					LAD13CDO: "00FP",
					LAD13NM: "Rutland",
					LAD13NMW: null
				},
				id: "E06000017"
			},
			{
				arcs: [
					[
						270,
						271,
						272,
						273
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E06000018",
					LAD13CDO: "00FY",
					LAD13NM: "Nottingham",
					LAD13NMW: null
				},
				id: "E06000018"
			},
			{
				arcs: [
					[
						274,
						275,
						276,
						277,
						278,
						279,
						280,
						281,
						282,
						283,
						284,
						285,
						286,
						287,
						288,
						289
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E06000019",
					LAD13CDO: "00GA",
					LAD13NM: "Herefordshire, County of",
					LAD13NMW: null
				},
				id: "E06000019"
			},
			{
				arcs: [
					[
						290,
						291,
						292,
						293,
						294
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E06000020",
					LAD13CDO: "00GF",
					LAD13NM: "Telford and Wrekin",
					LAD13NMW: null
				},
				id: "E06000020"
			},
			{
				arcs: [
					[
						295,
						296,
						297,
						298,
						299,
						300
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E06000021",
					LAD13CDO: "00GL",
					LAD13NM: "Stoke-on-Trent",
					LAD13NMW: null
				},
				id: "E06000021"
			},
			{
				arcs: [
					[
						301,
						302,
						303,
						304,
						305,
						306,
						307,
						308,
						309,
						310,
						-309,
						311,
						312,
						313,
						314,
						315
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E06000022",
					LAD13CDO: "00HA",
					LAD13NM: "Bath and North East Somerset",
					LAD13NMW: null
				},
				id: "E06000022"
			},
			{
				arcs: [
					[
						-315,
						-314,
						316,
						317,
						318,
						319,
						320
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E06000023",
					LAD13CDO: "00HB",
					LAD13NM: "Bristol, City of",
					LAD13NMW: null
				},
				id: "E06000023"
			},
			{
				arcs: [
					[
						-318,
						-317,
						-313,
						-312,
						308,
						-311,
						-310,
						-309,
						-308,
						-307,
						321,
						322,
						323,
						324
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E06000024",
					LAD13CDO: "00HC",
					LAD13NM: "North Somerset",
					LAD13NMW: null
				},
				id: "E06000024"
			},
			{
				arcs: [
					[
						325,
						326,
						327,
						328,
						329,
						330,
						-316,
						-321,
						331,
						332
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E06000025",
					LAD13CDO: "00HD",
					LAD13NM: "South Gloucestershire",
					LAD13NMW: null
				},
				id: "E06000025"
			},
			{
				arcs: [
					[
						333,
						334,
						335
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E06000026",
					LAD13CDO: "00HG",
					LAD13NM: "Plymouth",
					LAD13NMW: null
				},
				id: "E06000026"
			},
			{
				arcs: [
					[
						336,
						337,
						338
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E06000027",
					LAD13CDO: "00HH",
					LAD13NM: "Torbay",
					LAD13NMW: null
				},
				id: "E06000027"
			},
			{
				arcs: [
					[
						339,
						340,
						341,
						342,
						343,
						344,
						345,
						346,
						347,
						348,
						349,
						350,
						351,
						352,
						353,
						354,
						355,
						356,
						357
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E06000028",
					LAD13CDO: "00HN",
					LAD13NM: "Bournemouth",
					LAD13NMW: null
				},
				id: "E06000028"
			},
			{
				arcs: [
					[
						358,
						-356,
						-355,
						359,
						360,
						361,
						362
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E06000029",
					LAD13CDO: "00HP",
					LAD13NM: "Poole",
					LAD13NMW: null
				},
				id: "E06000029"
			},
			{
				arcs: [
					[
						363,
						364,
						365,
						366,
						367,
						368,
						369,
						370,
						371
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E06000030",
					LAD13CDO: "00HX",
					LAD13NM: "Swindon",
					LAD13NMW: null
				},
				id: "E06000030"
			},
			{
				arcs: [
					[
						372,
						373,
						374,
						375,
						376,
						377,
						378,
						379,
						380,
						381,
						382
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E06000031",
					LAD13CDO: "00JA",
					LAD13NM: "Peterborough",
					LAD13NMW: null
				},
				id: "E06000031"
			},
			{
				arcs: [
					[
						383,
						384
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E06000032",
					LAD13CDO: "00KA",
					LAD13NM: "Luton",
					LAD13NMW: null
				},
				id: "E06000032"
			},
			{
				arcs: [
					[
						[
							385,
							386,
							387
						]
					],
					[
						[
							388,
							389,
							390,
							391
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "E06000033",
					LAD13CDO: "00KF",
					LAD13NM: "Southend-on-Sea",
					LAD13NMW: null
				},
				id: "E06000033"
			},
			{
				arcs: [
					[
						[
							392,
							393,
							394
						]
					],
					[
						[
							395,
							396,
							397,
							398,
							399,
							400,
							401
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "E06000034",
					LAD13CDO: "00KG",
					LAD13NM: "Thurrock",
					LAD13NMW: null
				},
				id: "E06000034"
			},
			{
				arcs: [
					[
						[
							402
						]
					],
					[
						[
							403,
							404,
							405
						]
					],
					[
						[
							411,
							412,
							413,
							414
						]
					],
					[
						[
							415,
							416,
							417
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "E06000035",
					LAD13CDO: "00LC",
					LAD13NM: "Medway",
					LAD13NMW: null
				},
				id: "E06000035"
			},
			{
				arcs: [
					[
						418,
						419,
						420,
						421,
						422
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E06000036",
					LAD13CDO: "00MA",
					LAD13NM: "Bracknell Forest",
					LAD13NMW: null
				},
				id: "E06000036"
			},
			{
				arcs: [
					[
						423,
						424,
						425,
						426,
						427,
						428,
						429,
						430,
						431,
						432,
						433,
						434,
						435,
						436,
						437
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E06000037",
					LAD13CDO: "00MB",
					LAD13NM: "West Berkshire",
					LAD13NMW: null
				},
				id: "E06000037"
			},
			{
				arcs: [
					[
						438,
						439,
						-426,
						440
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E06000038",
					LAD13CDO: "00MC",
					LAD13NM: "Reading",
					LAD13NMW: null
				},
				id: "E06000038"
			},
			{
				arcs: [
					[
						441,
						442,
						443,
						444,
						445
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E06000039",
					LAD13CDO: "00MD",
					LAD13NM: "Slough",
					LAD13NMW: null
				},
				id: "E06000039"
			},
			{
				arcs: [
					[
						446,
						-445,
						447,
						448,
						449,
						-423,
						450,
						451
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E06000040",
					LAD13CDO: "00ME",
					LAD13NM: "Windsor and Maidenhead",
					LAD13NMW: null
				},
				id: "E06000040"
			},
			{
				arcs: [
					[
						-451,
						-422,
						452,
						453,
						-429,
						-428,
						-427,
						-440,
						-439,
						454,
						455
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E06000041",
					LAD13CDO: "00MF",
					LAD13NM: "Wokingham",
					LAD13NMW: null
				},
				id: "E06000041"
			},
			{
				arcs: [
					[
						456,
						457,
						458,
						459,
						460,
						461
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E06000042",
					LAD13CDO: "00MG",
					LAD13NM: "Milton Keynes",
					LAD13NMW: null
				},
				id: "E06000042"
			},
			{
				arcs: [
					[
						462,
						463,
						464,
						465,
						466
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E06000043",
					LAD13CDO: "00ML",
					LAD13NM: "Brighton and Hove",
					LAD13NMW: null
				},
				id: "E06000043"
			},
			{
				arcs: [
					[
						[
							467,
							468
						]
					],
					[
						[
							469,
							470,
							471,
							472,
							473,
							474,
							475,
							476,
							477
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "E06000044",
					LAD13CDO: "00MR",
					LAD13NM: "Portsmouth",
					LAD13NMW: null
				},
				id: "E06000044"
			},
			{
				arcs: [
					[
						478,
						479,
						480,
						481,
						482,
						483
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E06000045",
					LAD13CDO: "00MS",
					LAD13NM: "Southampton",
					LAD13NMW: null
				},
				id: "E06000045"
			},
			{
				arcs: [
					[
						484
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E06000046",
					LAD13CDO: "00MW",
					LAD13NM: "Isle of Wight",
					LAD13NMW: null
				},
				id: "E06000046"
			},
			{
				arcs: [
					[
						485,
						486,
						487,
						-21,
						-92,
						-95,
						488,
						489,
						490,
						491,
						492
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E06000047",
					LAD13CDO: "00EJ",
					LAD13NM: "County Durham",
					LAD13NMW: null
				},
				id: "E06000047"
			},
			{
				arcs: [
					[
						493,
						494,
						495,
						496,
						497,
						498,
						499,
						500,
						501,
						502,
						503,
						504,
						505,
						506,
						507,
						508,
						509,
						510,
						511,
						512,
						513,
						514,
						515,
						516,
						517,
						518,
						-106
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E06000049",
					LAD13CDO: "00EQ",
					LAD13NM: "Cheshire East",
					LAD13NMW: null
				},
				id: "E06000049"
			},
			{
				arcs: [
					[
						-518,
						-517,
						-516,
						-515,
						-514,
						-513,
						-512,
						-511,
						521,
						522,
						523,
						524,
						525,
						526,
						527,
						528,
						529,
						530,
						531,
						532,
						533,
						534,
						535,
						536,
						537,
						538,
						539,
						-96,
						-107,
						-519
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E06000050",
					LAD13CDO: "00EW",
					LAD13NM: "Cheshire West and Chester",
					LAD13NMW: null
				},
				id: "E06000050"
			},
			{
				arcs: [
					[
						540,
						541,
						542,
						543,
						-295,
						-294,
						544,
						545,
						546,
						547,
						548,
						549,
						-276,
						-275,
						-290,
						-289,
						550,
						551,
						552,
						553,
						554,
						555,
						556,
						557,
						-522,
						-510,
						-509,
						-508,
						-507
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E06000051",
					LAD13CDO: "00GG",
					LAD13NM: "Shropshire",
					LAD13NMW: null
				},
				id: "E06000051"
			},
			{
				arcs: [
					[
						560,
						561,
						562,
						563,
						564,
						565,
						566,
						567,
						568,
						569,
						570,
						571,
						572,
						573,
						574,
						575,
						576,
						577,
						578,
						579,
						580,
						581,
						582,
						583,
						584,
						585,
						586,
						587,
						588,
						589,
						590,
						591,
						-559,
						592,
						593
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E06000052",
					LAD13CDO: "00HE",
					LAD13NM: "Cornwall",
					LAD13NMW: null
				},
				id: "E06000052"
			},
			{
				arcs: [
					[
						[
							594
						]
					],
					[
						[
							595
						]
					],
					[
						[
							596
						]
					],
					[
						[
							597
						]
					],
					[
						[
							598
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "E06000053",
					LAD13CDO: "00HF",
					LAD13NM: "Isles of Scilly",
					LAD13NMW: null
				},
				id: "E06000053"
			},
			{
				arcs: [
					[
						-371,
						-370,
						-369,
						-368,
						599,
						-437,
						600,
						601,
						602,
						603,
						604,
						605,
						606,
						-302,
						-331,
						-330,
						-329,
						607,
						608,
						609
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E06000054",
					LAD13CDO: "00HY",
					LAD13NM: "Wiltshire",
					LAD13NMW: null
				},
				id: "E06000054"
			},
			{
				arcs: [
					[
						610,
						-457,
						611,
						612,
						613
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E06000055",
					LAD13CDO: "00KB",
					LAD13NM: "Bedford",
					LAD13NMW: null
				},
				id: "E06000055"
			},
			{
				arcs: [
					[
						614,
						615,
						616,
						617,
						-385,
						618,
						619,
						620,
						621,
						-458,
						-611
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E06000056",
					LAD13CDO: "00KC",
					LAD13NM: "Central Bedfordshire",
					LAD13NMW: null
				},
				id: "E06000056"
			},
			{
				arcs: [
					[
						[
							629
						]
					],
					[
						[
							634,
							635,
							636,
							637,
							638,
							639,
							640,
							641,
							-492,
							642,
							643,
							644,
							645,
							646,
							647,
							648,
							649,
							650
						]
					],
					[
						[
							-634,
							651,
							652,
							653
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "E06000057",
					LAD13CDO: "00EM",
					LAD13NM: "Northumberland",
					LAD13NMW: null
				},
				id: "E06000057"
			},
			{
				arcs: [
					[
						-460,
						-459,
						-622,
						654,
						655,
						656,
						657,
						658,
						659,
						660,
						661,
						662,
						663
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000004",
					LAD13CDO: "11UB",
					LAD13NM: "Aylesbury Vale",
					LAD13NMW: null
				},
				id: "E07000004"
			},
			{
				arcs: [
					[
						664,
						665,
						666,
						667,
						668,
						-656
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000005",
					LAD13CDO: "11UC",
					LAD13NM: "Chiltern",
					LAD13NMW: null
				},
				id: "E07000005"
			},
			{
				arcs: [
					[
						669,
						670,
						671,
						-446,
						-447,
						672,
						-667
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000006",
					LAD13CDO: "11UE",
					LAD13NM: "South Bucks",
					LAD13NMW: null
				},
				id: "E07000006"
			},
			{
				arcs: [
					[
						-669,
						-668,
						-673,
						-452,
						-456,
						673,
						-657
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000007",
					LAD13CDO: "11UF",
					LAD13NM: "Wycombe",
					LAD13NMW: null
				},
				id: "E07000007"
			},
			{
				arcs: [
					[
						674
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000008",
					LAD13CDO: "12UB",
					LAD13NM: "Cambridge",
					LAD13NMW: null
				},
				id: "E07000008"
			},
			{
				arcs: [
					[
						[
							675,
							676,
							677,
							678,
							679,
							680,
							681
						]
					],
					[
						[
							682,
							683,
							684,
							685,
							686,
							687,
							688,
							689,
							690,
							691,
							692,
							-677,
							693,
							694
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "E07000009",
					LAD13CDO: "12UC",
					LAD13NM: "East Cambridgeshire",
					LAD13NMW: null
				},
				id: "E07000009"
			},
			{
				arcs: [
					[
						[
							-681,
							695,
							-377,
							696,
							697,
							-374,
							698,
							699,
							700,
							701,
							702,
							703
						]
					],
					[
						[
							704,
							705,
							-701,
							706,
							707,
							-373,
							708
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "E07000010",
					LAD13CDO: "12UD",
					LAD13NM: "Fenland",
					LAD13NMW: null
				},
				id: "E07000010"
			},
			{
				arcs: [
					[
						-378,
						-696,
						-680,
						709,
						710,
						711,
						712,
						713,
						-615,
						-614,
						714,
						-379
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000011",
					LAD13CDO: "12UE",
					LAD13NM: "Huntingdonshire",
					LAD13NMW: null
				},
				id: "E07000011"
			},
			{
				arcs: [
					[
						-691,
						-690,
						715,
						716,
						717,
						718,
						719,
						-616,
						-714,
						720,
						721,
						722,
						723
					],
					[
						-675
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000012",
					LAD13CDO: "12UG",
					LAD13NM: "South Cambridgeshire",
					LAD13NMW: null
				},
				id: "E07000012"
			},
			{
				arcs: [
					[
						724,
						725,
						726,
						727,
						728,
						729,
						730,
						731,
						732,
						733
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000026",
					LAD13CDO: "16UB",
					LAD13NM: "Allerdale",
					LAD13NMW: null
				},
				id: "E07000026"
			},
			{
				arcs: [
					[
						[
							734
						]
					],
					[
						[
							735,
							736,
							737,
							738,
							739
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "E07000027",
					LAD13CDO: "16UC",
					LAD13NM: "Barrow-in-Furness",
					LAD13NMW: null
				},
				id: "E07000027"
			},
			{
				arcs: [
					[
						-646,
						-645,
						-644,
						741,
						-727,
						742,
						-725,
						743,
						744,
						745,
						746,
						747,
						-647
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000028",
					LAD13CDO: "16UD",
					LAD13NM: "Carlisle",
					LAD13NMW: null
				},
				id: "E07000028"
			},
			{
				arcs: [
					[
						[
							748,
							749,
							750
						]
					],
					[
						[
							751,
							752,
							753
						]
					],
					[
						[
							-732,
							-731,
							754,
							755,
							756,
							757,
							758,
							-753,
							759,
							-750,
							-749,
							760,
							-733
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "E07000029",
					LAD13CDO: "16UE",
					LAD13NM: "Copeland",
					LAD13NMW: null
				},
				id: "E07000029"
			},
			{
				arcs: [
					[
						-491,
						-490,
						761,
						762,
						-729,
						-728,
						-742,
						-643
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000030",
					LAD13CDO: "16UF",
					LAD13NM: "Eden",
					LAD13NMW: null
				},
				id: "E07000030"
			},
			{
				arcs: [
					[
						[
							763,
							764
						]
					],
					[
						[
							-763,
							765,
							766,
							767,
							768,
							769,
							770,
							-740,
							771,
							772,
							-737,
							773,
							774,
							-756,
							-755,
							-730
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "E07000031",
					LAD13CDO: "16UG",
					LAD13NM: "South Lakeland",
					LAD13NMW: null
				},
				id: "E07000031"
			},
			{
				arcs: [
					[
						775,
						776,
						777,
						778,
						779,
						780,
						781,
						782,
						783,
						-242,
						784,
						785
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000032",
					LAD13CDO: "17UB",
					LAD13NM: "Amber Valley",
					LAD13NMW: null
				},
				id: "E07000032"
			},
			{
				arcs: [
					[
						786,
						787,
						788,
						789,
						790,
						-777,
						791,
						792,
						793
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000033",
					LAD13CDO: "17UC",
					LAD13NM: "Bolsover",
					LAD13NMW: null
				},
				id: "E07000033"
			},
			{
				arcs: [
					[
						-793,
						794
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000034",
					LAD13CDO: "17UD",
					LAD13NM: "Chesterfield",
					LAD13NMW: null
				},
				id: "E07000034"
			},
			{
				arcs: [
					[
						795,
						796,
						-786,
						797,
						798,
						799,
						800,
						801,
						802,
						803,
						804,
						805
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000035",
					LAD13CDO: "17UF",
					LAD13NM: "Derbyshire Dales",
					LAD13NMW: null
				},
				id: "E07000035"
			},
			{
				arcs: [
					[
						806,
						807,
						808,
						809,
						810,
						811,
						812,
						813,
						-240,
						-784,
						-783
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000036",
					LAD13CDO: "17UG",
					LAD13NM: "Erewash",
					LAD13NMW: null
				},
				id: "E07000036"
			},
			{
				arcs: [
					[
						814,
						815,
						-805,
						-804,
						-803,
						816,
						-502,
						-501,
						-500,
						817,
						818,
						819,
						820
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000037",
					LAD13CDO: "17UH",
					LAD13NM: "High Peak",
					LAD13NMW: null
				},
				id: "E07000037"
			},
			{
				arcs: [
					[
						821,
						822,
						823,
						-794,
						-795,
						-792,
						-776,
						-797,
						-796,
						824,
						825
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000038",
					LAD13CDO: "17UJ",
					LAD13NM: "North East Derbyshire",
					LAD13NMW: null
				},
				id: "E07000038"
			},
			{
				arcs: [
					[
						-785,
						-241,
						-814,
						826,
						827,
						828,
						829,
						830,
						831,
						832,
						833,
						834,
						835,
						836,
						-798
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000039",
					LAD13CDO: "17UK",
					LAD13NM: "South Derbyshire",
					LAD13NMW: null
				},
				id: "E07000039"
			},
			{
				arcs: [
					[
						837,
						838,
						839,
						840,
						841,
						842,
						843,
						844,
						845,
						846,
						847,
						848,
						849,
						850,
						851,
						852,
						853,
						854,
						855,
						856
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000040",
					LAD13CDO: "18UB",
					LAD13NM: "East Devon",
					LAD13NMW: null
				},
				id: "E07000040"
			},
			{
				arcs: [
					[
						857,
						858,
						-845,
						859,
						-843,
						860,
						861,
						862,
						863,
						864,
						-850
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000041",
					LAD13CDO: "18UC",
					LAD13NM: "Exeter",
					LAD13NMW: null
				},
				id: "E07000041"
			},
			{
				arcs: [
					[
						865,
						866,
						-856,
						-855,
						-854,
						-853,
						-852,
						867,
						868,
						869,
						870,
						871,
						872,
						873,
						874,
						875,
						876,
						877,
						878,
						879
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000042",
					LAD13CDO: "18UD",
					LAD13NM: "Mid Devon",
					LAD13NMW: null
				},
				id: "E07000042"
			},
			{
				arcs: [
					[
						880,
						-879,
						-878,
						881,
						882,
						883,
						884,
						885,
						886,
						887
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000043",
					LAD13CDO: "18UE",
					LAD13NM: "North Devon",
					LAD13NMW: null
				},
				id: "E07000043"
			},
			{
				arcs: [
					[
						888,
						-338,
						889,
						-336,
						890,
						891,
						892,
						893,
						894,
						895
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000044",
					LAD13CDO: "18UG",
					LAD13NM: "South Hams",
					LAD13NMW: null
				},
				id: "E07000044"
			},
			{
				arcs: [
					[
						-851,
						-865,
						-864,
						896,
						-339,
						-889,
						-896,
						897,
						898,
						-870,
						-869,
						-868
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000045",
					LAD13CDO: "18UH",
					LAD13NM: "Teignbridge",
					LAD13NMW: null
				},
				id: "E07000045"
			},
			{
				arcs: [
					[
						[
							-887,
							-886,
							-885,
							-884,
							-883,
							-882,
							-877,
							-876,
							-875,
							899,
							900,
							901,
							-575,
							-574,
							-573,
							-572,
							-571,
							-570,
							-569,
							-568,
							-567,
							-566,
							-565,
							-564,
							-563,
							-562,
							-561,
							-594,
							902
						]
					],
					[
						[
							903
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "E07000046",
					LAD13CDO: "18UK",
					LAD13NM: "Torridge",
					LAD13NMW: null
				},
				id: "E07000046"
			},
			{
				arcs: [
					[
						-874,
						-873,
						-872,
						-871,
						-899,
						-898,
						-895,
						-894,
						904,
						905,
						906,
						907,
						908,
						-587,
						909,
						910,
						-584,
						911,
						912,
						-581,
						913,
						914,
						-578,
						915,
						-576,
						-902,
						-901,
						-900
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000047",
					LAD13CDO: "18UL",
					LAD13NM: "West Devon",
					LAD13NMW: null
				},
				id: "E07000047"
			},
			{
				arcs: [
					[
						[
							917,
							918,
							919,
							920
						]
					],
					[
						[
							922,
							923,
							924,
							925,
							926,
							-919,
							927,
							928,
							929,
							930,
							931,
							932,
							933,
							-345,
							934,
							935,
							-340,
							936
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "E07000048",
					LAD13CDO: "19UC",
					LAD13NM: "Christchurch",
					LAD13NMW: null
				},
				id: "E07000048"
			},
			{
				arcs: [
					[
						937,
						938,
						939,
						-937,
						-358,
						-357,
						-359,
						-363,
						940,
						941,
						942,
						-603
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000049",
					LAD13CDO: "19UD",
					LAD13NM: "East Dorset",
					LAD13NMW: null
				},
				id: "E07000049"
			},
			{
				arcs: [
					[
						-943,
						-942,
						943,
						944,
						945,
						946,
						947,
						948,
						949,
						950,
						951,
						-604
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000050",
					LAD13CDO: "19UE",
					LAD13NM: "North Dorset",
					LAD13NMW: null
				},
				id: "E07000050"
			},
			{
				arcs: [
					[
						[
							961
						]
					],
					[
						[
							-362,
							962,
							963,
							964,
							965,
							966,
							-944,
							-941
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "E07000051",
					LAD13CDO: "19UG",
					LAD13NM: "Purbeck",
					LAD13NMW: null
				},
				id: "E07000051"
			},
			{
				arcs: [
					[
						967,
						-949,
						-948,
						-947,
						-946,
						-945,
						-967,
						968,
						969,
						970,
						971,
						972,
						-840,
						-839,
						973,
						974,
						975,
						976,
						977,
						978,
						979
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000052",
					LAD13CDO: "19UH",
					LAD13NM: "West Dorset",
					LAD13NMW: null
				},
				id: "E07000052"
			},
			{
				arcs: [
					[
						[
							-972,
							980
						]
					],
					[
						[
							981,
							-970
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "E07000053",
					LAD13CDO: "19UJ",
					LAD13NM: "Weymouth and Portland",
					LAD13NMW: null
				},
				id: "E07000053"
			},
			{
				arcs: [
					[
						982,
						983
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000061",
					LAD13CDO: "21UC",
					LAD13NM: "Eastbourne",
					LAD13NMW: null
				},
				id: "E07000061"
			},
			{
				arcs: [
					[
						984,
						985
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000062",
					LAD13CDO: "21UD",
					LAD13NM: "Hastings",
					LAD13NMW: null
				},
				id: "E07000062"
			},
			{
				arcs: [
					[
						[
							992,
							993,
							994,
							995,
							996,
							997
						]
					],
					[
						[
							998,
							999,
							1000,
							1001,
							1002,
							1003,
							1004,
							1005,
							1006,
							1007,
							1008,
							1009,
							1010,
							1011,
							1012,
							1013,
							-995,
							1014,
							-993,
							1015,
							1016,
							-463,
							1017,
							1018
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "E07000063",
					LAD13CDO: "21UF",
					LAD13NM: "Lewes",
					LAD13NMW: null
				},
				id: "E07000063"
			},
			{
				arcs: [
					[
						1019,
						1020,
						1021,
						1022,
						-986,
						1023,
						1024,
						1025,
						1026,
						1027
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000064",
					LAD13CDO: "21UG",
					LAD13NM: "Rother",
					LAD13NMW: null
				},
				id: "E07000064"
			},
			{
				arcs: [
					[
						1028,
						1029,
						1030,
						1031,
						-1027,
						-1026,
						-1025,
						1032,
						-984,
						1033,
						1034,
						1035,
						-988,
						1036,
						-1009,
						1037,
						1038,
						1039,
						-990,
						1040,
						-991,
						-1005,
						1041,
						-1003,
						-1002,
						-1001,
						-1000,
						-999,
						-1019,
						1042,
						1043,
						1044,
						1045,
						1046
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000065",
					LAD13CDO: "21UH",
					LAD13NM: "Wealden",
					LAD13NMW: null
				},
				id: "E07000065"
			},
			{
				arcs: [
					[
						-1049,
						1049,
						1050,
						1051,
						1052,
						1053,
						1054,
						1055,
						1056,
						1057,
						1058,
						1059,
						1060,
						1061,
						-393,
						1062,
						-397,
						1063,
						-402,
						1064,
						1065
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000066",
					LAD13CDO: "22UB",
					LAD13NM: "Basildon",
					LAD13NMW: null
				},
				id: "E07000066"
			},
			{
				arcs: [
					[
						1066,
						1067,
						1068,
						1069,
						1070,
						1071,
						1072,
						1073,
						1074,
						-718,
						1075,
						1076,
						1077,
						1078
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000067",
					LAD13CDO: "22UC",
					LAD13NM: "Braintree",
					LAD13NMW: null
				},
				id: "E07000067"
			},
			{
				arcs: [
					[
						1079,
						-1065,
						-401,
						1080,
						1081,
						1082
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000068",
					LAD13CDO: "22UD",
					LAD13NM: "Brentwood",
					LAD13NMW: null
				},
				id: "E07000068"
			},
			{
				arcs: [
					[
						[
							1084,
							1085,
							1086,
							1087,
							1088
						]
					],
					[
						[
							-386,
							1089,
							1090,
							1091
						]
					],
					[
						[
							-1086,
							1092,
							1093,
							1094,
							1095,
							1093,
							1096,
							1097,
							1098,
							1099,
							1100,
							-1060,
							1101,
							1102,
							-1057,
							1103,
							1104,
							1105
						]
					],
					[
						[
							-391,
							1106,
							1107,
							1108,
							1109,
							-1105,
							1110,
							-1056,
							1111
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "E07000069",
					LAD13CDO: "22UE",
					LAD13NM: "Castle Point",
					LAD13NMW: null
				},
				id: "E07000069"
			},
			{
				arcs: [
					[
						1112,
						-1072,
						-1071,
						1113,
						1114,
						1115,
						1116,
						1117,
						1118,
						1119,
						1120,
						1121,
						1122,
						1123,
						1124,
						1125,
						-1048,
						-1066,
						-1080,
						-1083,
						1126,
						1127
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000070",
					LAD13CDO: "22UF",
					LAD13NM: "Chelmsford",
					LAD13NMW: null
				},
				id: "E07000070"
			},
			{
				arcs: [
					[
						[
							1128
						]
					],
					[
						[
							1129,
							1130,
							1131,
							1132,
							-1068,
							-1067,
							1133
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "E07000071",
					LAD13CDO: "22UG",
					LAD13NM: "Colchester",
					LAD13NMW: null
				},
				id: "E07000071"
			},
			{
				arcs: [
					[
						-1127,
						-1082,
						1134,
						1135,
						1136,
						1137,
						1138,
						1139,
						1140,
						1141,
						1142,
						1143
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000072",
					LAD13CDO: "22UH",
					LAD13NM: "Epping Forest",
					LAD13NMW: null
				},
				id: "E07000072"
			},
			{
				arcs: [
					[
						-1142,
						1144
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000073",
					LAD13CDO: "22UJ",
					LAD13NM: "Harlow",
					LAD13NMW: null
				},
				id: "E07000073"
			},
			{
				arcs: [
					[
						[
							1147,
							1148,
							1149,
							1150
						]
					],
					[
						[
							1154
						]
					],
					[
						[
							1155
						]
					],
					[
						[
							-1133,
							1158,
							-1157,
							1159,
							1160,
							-1153,
							1161,
							1162,
							1163,
							1164,
							-1114,
							-1070,
							-1069
						],
						[
							1151,
							1152,
							1153
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "E07000074",
					LAD13CDO: "22UK",
					LAD13NM: "Maldon",
					LAD13NMW: null
				},
				id: "E07000074"
			},
			{
				arcs: [
					[
						[
							1165
						]
					],
					[
						[
							1166,
							-1052,
							1167
						]
					],
					[
						[
							-1122,
							1168,
							1169
						]
					],
					[
						[
							1170
						]
					],
					[
						[
							1171,
							-392,
							-1112,
							-1055,
							1172,
							1173,
							1174,
							-1123,
							-1170,
							1175,
							1176,
							1177,
							1178,
							-1117,
							1179,
							1180
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "E07000075",
					LAD13CDO: "22UL",
					LAD13NM: "Rochford",
					LAD13NMW: null
				},
				id: "E07000075"
			},
			{
				arcs: [
					[
						[
							1181,
							1182,
							1183,
							1184
						]
					],
					[
						[
							1185
						]
					],
					[
						[
							1186
						]
					],
					[
						[
							1187
						]
					],
					[
						[
							1188,
							1189,
							1190,
							1191,
							1192,
							-1183,
							1193,
							1194,
							1195,
							-1131,
							-1130,
							1196
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "E07000076",
					LAD13CDO: "22UN",
					LAD13NM: "Tendring",
					LAD13NMW: null
				},
				id: "E07000076"
			},
			{
				arcs: [
					[
						-1075,
						-1074,
						-1073,
						-1113,
						-1128,
						-1144,
						1197,
						1198,
						1199,
						-719
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000077",
					LAD13CDO: "22UQ",
					LAD13NM: "Uttlesford",
					LAD13NMW: null
				},
				id: "E07000077"
			},
			{
				arcs: [
					[
						1200,
						1201,
						1202
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000078",
					LAD13CDO: "23UB",
					LAD13NM: "Cheltenham",
					LAD13NMW: null
				},
				id: "E07000078"
			},
			{
				arcs: [
					[
						1203,
						1204,
						1205,
						1206,
						1207,
						1208,
						1209,
						1210,
						1211,
						1212,
						-372,
						-610,
						-609,
						-608,
						-328,
						1213,
						1214,
						1215,
						1216,
						1217,
						1218,
						-1201,
						1219,
						1220,
						1221
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000079",
					LAD13CDO: "23UC",
					LAD13NM: "Cotswold",
					LAD13NMW: null
				},
				id: "E07000079"
			},
			{
				arcs: [
					[
						1222,
						1223,
						1224,
						1225,
						1226,
						1227,
						1228,
						1229,
						1230,
						1231,
						-281
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000080",
					LAD13CDO: "23UD",
					LAD13NM: "Forest of Dean",
					LAD13NMW: null
				},
				id: "E07000080"
			},
			{
				arcs: [
					[
						1232,
						1233,
						1234,
						1235,
						1236
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000081",
					LAD13CDO: "23UE",
					LAD13NM: "Gloucester",
					LAD13NMW: null
				},
				id: "E07000081"
			},
			{
				arcs: [
					[
						1237,
						1238,
						-1218,
						-1217,
						-1216,
						-1215,
						-1214,
						-327,
						-326,
						-333,
						1239,
						1240,
						1241,
						1242,
						-1233
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000082",
					LAD13CDO: "23UF",
					LAD13NM: "Stroud",
					LAD13NMW: null
				},
				id: "E07000082"
			},
			{
				arcs: [
					[
						1243,
						-1220,
						-1203,
						-1202,
						-1219,
						-1239,
						-1238,
						-1237,
						1244,
						1245,
						1246,
						1247,
						-1241,
						1248,
						-1224,
						1249,
						1250
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000083",
					LAD13CDO: "23UG",
					LAD13NM: "Tewkesbury",
					LAD13NMW: null
				},
				id: "E07000083"
			},
			{
				arcs: [
					[
						-430,
						-454,
						1251,
						1252,
						1253,
						1254,
						1255,
						-435,
						-434,
						-433,
						-432,
						-431
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000084",
					LAD13CDO: "24UB",
					LAD13NM: "Basingstoke and Deane",
					LAD13NMW: null
				},
				id: "E07000084"
			},
			{
				arcs: [
					[
						1256,
						1257,
						1258,
						1259,
						1260,
						-1253,
						1261
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000085",
					LAD13CDO: "24UC",
					LAD13NM: "East Hampshire",
					LAD13NMW: null
				},
				id: "E07000085"
			},
			{
				arcs: [
					[
						1262,
						1263,
						1264,
						1265,
						1266,
						1267,
						1268,
						1269,
						1270,
						1271,
						1272,
						1273,
						1274,
						-479,
						1275
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000086",
					LAD13CDO: "24UD",
					LAD13NM: "Eastleigh",
					LAD13NMW: null
				},
				id: "E07000086"
			},
			{
				arcs: [
					[
						1276,
						-477,
						1277,
						1278,
						1279,
						1280
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000087",
					LAD13CDO: "24UE",
					LAD13NM: "Fareham",
					LAD13NMW: null
				},
				id: "E07000087"
			},
			{
				arcs: [
					[
						-1279,
						1281
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000088",
					LAD13CDO: "24UF",
					LAD13NM: "Gosport",
					LAD13NMW: null
				},
				id: "E07000088"
			},
			{
				arcs: [
					[
						-421,
						-420,
						1282,
						1283,
						1284,
						-1262,
						-1252,
						-453
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000089",
					LAD13CDO: "24UG",
					LAD13NM: "Hart",
					LAD13NMW: null
				},
				id: "E07000089"
			},
			{
				arcs: [
					[
						[
							1285
						]
					],
					[
						[
							1287,
							1288,
							1289,
							1290,
							-471,
							-470,
							1291,
							-1259
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "E07000090",
					LAD13CDO: "24UH",
					LAD13NM: "Havant",
					LAD13NMW: null
				},
				id: "E07000090"
			},
			{
				arcs: [
					[
						[
							1292,
							1293,
							-482,
							1294,
							1295,
							1296,
							1297,
							1298
						]
					],
					[
						[
							1299,
							1300,
							1301,
							1302,
							1303,
							1304,
							-1296,
							1305,
							1306,
							-924,
							-923,
							-940,
							-939,
							-938,
							-602
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "E07000091",
					LAD13CDO: "24UJ",
					LAD13NM: "New Forest",
					LAD13NMW: null
				},
				id: "E07000091"
			},
			{
				arcs: [
					[
						1307,
						1308,
						1309,
						-1284
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000092",
					LAD13CDO: "24UL",
					LAD13NM: "Rushmoor",
					LAD13NMW: null
				},
				id: "E07000092"
			},
			{
				arcs: [
					[
						[
							1310,
							1311,
							1312,
							1313,
							1314,
							-1297,
							-1305,
							-1304
						]
					],
					[
						[
							-436,
							-1256,
							-1255,
							1315,
							1316,
							-1276,
							-484,
							1317,
							-1293,
							-1312,
							1318,
							-1302,
							-1301,
							-1300,
							-601
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "E07000093",
					LAD13CDO: "24UN",
					LAD13NM: "Test Valley",
					LAD13NMW: null
				},
				id: "E07000093"
			},
			{
				arcs: [
					[
						-1261,
						-1260,
						-1292,
						-478,
						-1277,
						1319,
						1320,
						1321,
						1270,
						1322,
						-1269,
						1323,
						-1267,
						1324,
						1325,
						1326,
						-1263,
						-1317,
						-1316,
						-1254
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000094",
					LAD13CDO: "24UP",
					LAD13NM: "Winchester",
					LAD13NMW: null
				},
				id: "E07000094"
			},
			{
				arcs: [
					[
						-1140,
						1327,
						1328,
						1329
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000095",
					LAD13CDO: "26UB",
					LAD13NM: "Broxbourne",
					LAD13NMW: null
				},
				id: "E07000095"
			},
			{
				arcs: [
					[
						1330,
						1331,
						-665,
						-655,
						-621
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000096",
					LAD13CDO: "26UC",
					LAD13NM: "Dacorum",
					LAD13NMW: null
				},
				id: "E07000096"
			},
			{
				arcs: [
					[
						1332,
						1333,
						1334,
						1335,
						1336,
						1337,
						1338,
						1339
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000098",
					LAD13CDO: "26UE",
					LAD13NM: "Hertsmere",
					LAD13NMW: null
				},
				id: "E07000098"
			},
			{
				arcs: [
					[
						-1200,
						1340,
						1341,
						1342,
						1343,
						1344,
						-619,
						-384,
						-618,
						-617,
						-720
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000099",
					LAD13CDO: "26UF",
					LAD13NM: "North Hertfordshire",
					LAD13NMW: null
				},
				id: "E07000099"
			},
			{
				arcs: [
					[
						1345,
						-1337,
						1346,
						1347,
						-670,
						-666,
						-1332,
						1348
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000102",
					LAD13CDO: "26UJ",
					LAD13NM: "Three Rivers",
					LAD13NMW: null
				},
				id: "E07000102"
			},
			{
				arcs: [
					[
						-1338,
						-1346
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000103",
					LAD13CDO: "26UK",
					LAD13NM: "Watford",
					LAD13NMW: null
				},
				id: "E07000103"
			},
			{
				arcs: [
					[
						1349,
						1350,
						1351,
						-1020,
						1352,
						1353,
						1354,
						1355,
						1356
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000105",
					LAD13CDO: "29UB",
					LAD13NM: "Ashford",
					LAD13NMW: null
				},
				id: "E07000105"
			},
			{
				arcs: [
					[
						[
							1357,
							1358,
							1359,
							1360
						]
					],
					[
						[
							1363,
							1364,
							1365,
							1366,
							1367,
							1368,
							1369,
							1370,
							1371,
							1372,
							1373,
							1374,
							-1358,
							1375,
							-1360,
							1376,
							1377,
							1378,
							-1350,
							1379,
							1380,
							1381
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "E07000106",
					LAD13CDO: "29UC",
					LAD13NM: "Canterbury",
					LAD13NMW: null
				},
				id: "E07000106"
			},
			{
				arcs: [
					[
						1382,
						1383,
						1384,
						1385,
						1386,
						1387,
						1388,
						1389,
						1390,
						1391,
						1392,
						1393
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000107",
					LAD13CDO: "29UD",
					LAD13NM: "Dartford",
					LAD13NMW: null
				},
				id: "E07000107"
			},
			{
				arcs: [
					[
						[
							1394,
							1395,
							1396,
							1397,
							1398,
							1399,
							1400,
							1401,
							1402,
							1403,
							1404,
							1405,
							1406,
							1407,
							1408,
							1409,
							1410,
							1411,
							1412,
							1413,
							1414,
							1415,
							1416,
							1417,
							1418,
							1419,
							1420,
							1421,
							1422,
							1423
						]
					],
					[
						[
							1424,
							1425
						]
					],
					[
						[
							1426,
							-1365,
							1427,
							1428,
							1429,
							1430,
							1431,
							1432,
							1433,
							1434,
							1435,
							1436,
							1437,
							-1423,
							1438,
							1439,
							1440,
							1441,
							-1418,
							1442,
							-1416,
							1443,
							1444,
							1445,
							-1412,
							1446,
							1447,
							-1409,
							1448,
							1449,
							-1406,
							1450,
							1451,
							1452,
							1453,
							-1401,
							1454,
							1455,
							-1398,
							1456,
							1457,
							-1395,
							1458,
							1459,
							1460,
							1461,
							1462,
							-1378,
							-1374,
							1463,
							-1372,
							1464,
							-1370,
							-1363,
							1465,
							-1368,
							1466
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "E07000108",
					LAD13CDO: "29UE",
					LAD13NM: "Dover",
					LAD13NMW: null
				},
				id: "E07000108"
			},
			{
				arcs: [
					[
						-417,
						1467,
						1468,
						-1384,
						-1383,
						1469
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000109",
					LAD13CDO: "29UG",
					LAD13NM: "Gravesham",
					LAD13NMW: null
				},
				id: "E07000109"
			},
			{
				arcs: [
					[
						1470,
						-1356,
						1471,
						1472,
						1473,
						1474,
						1475,
						1476,
						1477,
						1478,
						-413
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000110",
					LAD13CDO: "29UH",
					LAD13NM: "Maidstone",
					LAD13NMW: null
				},
				id: "E07000110"
			},
			{
				arcs: [
					[
						-1469,
						1479,
						1480,
						-1047,
						-1046,
						1481,
						1482,
						1483,
						1484,
						-1385
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000111",
					LAD13CDO: "29UK",
					LAD13NM: "Sevenoaks",
					LAD13NMW: null
				},
				id: "E07000111"
			},
			{
				arcs: [
					[
						-1463,
						-1462,
						1485,
						-1022,
						-1021,
						-1352,
						-1351,
						-1379
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000112",
					LAD13CDO: "29UL",
					LAD13NM: "Shepway",
					LAD13NMW: null
				},
				id: "E07000112"
			},
			{
				arcs: [
					[
						[
							1486
						]
					],
					[
						[
							1487
						]
					],
					[
						[
							-1380,
							-1357,
							-1471,
							-412,
							1488
						]
					],
					[
						[
							1489
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "E07000113",
					LAD13CDO: "29UM",
					LAD13NM: "Swale",
					LAD13NMW: null
				},
				id: "E07000113"
			},
			{
				arcs: [
					[
						-1425,
						1491,
						1492,
						-1436,
						1493,
						1494,
						-1433,
						1495,
						-1431,
						1496,
						-1429,
						1497,
						-1382,
						1498
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000114",
					LAD13CDO: "29UN",
					LAD13NM: "Thanet",
					LAD13NMW: null
				},
				id: "E07000114"
			},
			{
				arcs: [
					[
						[
							-416,
							1499,
							1500,
							1501,
							1502,
							1503,
							1504,
							1505,
							1506,
							1507,
							1508,
							1509,
							-1477,
							-1476,
							1510,
							1511,
							-1480,
							-1468
						]
					],
					[
						[
							-1479,
							-1478,
							1512,
							-1508,
							1513,
							1514,
							1515,
							1516,
							1517,
							1518,
							1519,
							1520,
							-414
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "E07000115",
					LAD13CDO: "29UP",
					LAD13NM: "Tonbridge and Malling",
					LAD13NMW: null
				},
				id: "E07000115"
			},
			{
				arcs: [
					[
						-1475,
						-1474,
						-1473,
						-1472,
						-1355,
						-1354,
						-1353,
						-1028,
						-1032,
						-1031,
						-1030,
						-1029,
						-1481,
						-1512,
						-1511
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000116",
					LAD13CDO: "29UQ",
					LAD13NM: "Tunbridge Wells",
					LAD13NMW: null
				},
				id: "E07000116"
			},
			{
				arcs: [
					[
						1521,
						1522,
						1523,
						1524,
						1525
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000117",
					LAD13CDO: "30UD",
					LAD13NM: "Burnley",
					LAD13NMW: null
				},
				id: "E07000117"
			},
			{
				arcs: [
					[
						[
							1526,
							1527,
							1528,
							1529
						]
					],
					[
						[
							-119,
							1530,
							1531,
							1532,
							1533,
							1534,
							1535,
							1536,
							1537,
							1538,
							1539,
							1540,
							1541,
							1542,
							1543,
							1544,
							1545,
							1546,
							1547,
							1548,
							1549,
							1550,
							1551,
							1552,
							1553,
							1554,
							-120
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "E07000118",
					LAD13CDO: "30UE",
					LAD13NM: "Chorley",
					LAD13NMW: null
				},
				id: "E07000118"
			},
			{
				arcs: [
					[
						1555,
						1556,
						1557,
						1558,
						1559,
						1560,
						1561,
						1562,
						1563,
						1564,
						-123,
						1565,
						1566,
						1567,
						1568,
						1569,
						1570,
						1571,
						1572
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000119",
					LAD13CDO: "30UF",
					LAD13NM: "Fylde",
					LAD13NMW: null
				},
				id: "E07000119"
			},
			{
				arcs: [
					[
						-1524,
						1573,
						-114,
						-113,
						-112,
						1574
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000120",
					LAD13CDO: "30UG",
					LAD13NM: "Hyndburn",
					LAD13NMW: null
				},
				id: "E07000120"
			},
			{
				arcs: [
					[
						[
							1577,
							1578,
							1579,
							1580,
							1581,
							1582,
							1583
						]
					],
					[
						[
							1584,
							1585,
							1586,
							1587
						]
					],
					[
						[
							1588,
							1589,
							1590,
							1591,
							1592,
							1593,
							1594,
							1595,
							1596,
							-1584,
							-1583,
							1597,
							1598,
							-1586,
							1599,
							-1588,
							1600,
							-768
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "E07000121",
					LAD13CDO: "30UH",
					LAD13NM: "Lancaster",
					LAD13NMW: null
				},
				id: "E07000121"
			},
			{
				arcs: [
					[
						1601,
						1602,
						-1526,
						1603,
						1604,
						1605
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000122",
					LAD13CDO: "30UJ",
					LAD13NM: "Pendle",
					LAD13NMW: null
				},
				id: "E07000122"
			},
			{
				arcs: [
					[
						[
							1606,
							-1564,
							1607
						]
					],
					[
						[
							1612,
							1613,
							1614,
							1615,
							1616,
							1617,
							-1562,
							1618,
							1619,
							-1559,
							1620
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "E07000123",
					LAD13CDO: "30UK",
					LAD13NM: "Preston",
					LAD13NMW: null
				},
				id: "E07000123"
			},
			{
				arcs: [
					[
						-1605,
						-1604,
						-1525,
						-1575,
						-122,
						1621,
						-1613,
						1622,
						-1590,
						1623
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000124",
					LAD13CDO: "30UL",
					LAD13NM: "Ribble Valley",
					LAD13NMW: null
				},
				id: "E07000124"
			},
			{
				arcs: [
					[
						1624,
						1625,
						1626,
						-115,
						-1574,
						-1523
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000125",
					LAD13CDO: "30UM",
					LAD13NM: "Rossendale",
					LAD13NMW: null
				},
				id: "E07000125"
			},
			{
				arcs: [
					[
						-1622,
						-121,
						-1555,
						-1554,
						-1553,
						1627,
						1628,
						1629,
						1630,
						1631,
						1632,
						-1611,
						-1610,
						1633,
						1634,
						-1614
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000126",
					LAD13CDO: "30UN",
					LAD13NM: "South Ribble",
					LAD13NMW: null
				},
				id: "E07000126"
			},
			{
				arcs: [
					[
						1636,
						1637,
						1638,
						-1629,
						1639,
						1640,
						1641,
						-1549,
						1642,
						1643,
						1644,
						-1529,
						1645,
						-1542,
						1646,
						-1540,
						1647,
						-1538,
						-1537,
						1648,
						1649,
						1650,
						1651,
						1652,
						1653,
						1654,
						1655,
						1656
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000127",
					LAD13CDO: "30UP",
					LAD13NM: "West Lancashire",
					LAD13NMW: null
				},
				id: "E07000127"
			},
			{
				arcs: [
					[
						[
							1657,
							-1570,
							1658,
							1659,
							-1567,
							-1566,
							-126,
							-125,
							1660
						]
					],
					[
						[
							-1623,
							-1621,
							-1558,
							1661,
							1662,
							1663,
							1664,
							1665,
							-1576,
							1666,
							-1593,
							-1592,
							-1591
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "E07000128",
					LAD13CDO: "30UQ",
					LAD13NM: "Wyre",
					LAD13NMW: null
				},
				id: "E07000128"
			},
			{
				arcs: [
					[
						1667,
						-245,
						1668,
						1669,
						1670,
						1671,
						1672,
						1673,
						1674,
						1675,
						1676,
						1677,
						1678
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000129",
					LAD13CDO: "31UB",
					LAD13NM: "Blaby",
					LAD13NMW: null
				},
				id: "E07000129"
			},
			{
				arcs: [
					[
						1679,
						1680,
						1681,
						1682,
						1683,
						-247,
						-246,
						-1668,
						1684,
						1685,
						1686,
						1687,
						1688,
						1689,
						1690
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000130",
					LAD13CDO: "31UC",
					LAD13NM: "Charnwood",
					LAD13NMW: null
				},
				id: "E07000130"
			},
			{
				arcs: [
					[
						-263,
						-262,
						-261,
						-260,
						-259,
						-258,
						1691,
						1692,
						1693,
						1694,
						1695,
						1696,
						1697,
						1698,
						1699,
						1700,
						1701,
						1702,
						1703,
						1704,
						1705,
						1706,
						1707,
						1708,
						1709,
						1710,
						1711,
						-1674,
						1712,
						-243,
						-1684,
						1713,
						1714
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000131",
					LAD13CDO: "31UD",
					LAD13NM: "Harborough",
					LAD13NMW: null
				},
				id: "E07000131"
			},
			{
				arcs: [
					[
						-1685,
						-1679,
						-1678,
						-1677,
						-1676,
						1715,
						1716,
						1717,
						1718,
						-1686
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000132",
					LAD13CDO: "31UE",
					LAD13NM: "Hinckley and Bosworth",
					LAD13NMW: null
				},
				id: "E07000132"
			},
			{
				arcs: [
					[
						1719,
						1720,
						-269,
						-268,
						-267,
						-266,
						-265,
						-264,
						-1715,
						-1714,
						-1683,
						-1682,
						1721,
						1722,
						1723,
						1724,
						1725
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000133",
					LAD13CDO: "31UG",
					LAD13NM: "Melton",
					LAD13NMW: null
				},
				id: "E07000133"
			},
			{
				arcs: [
					[
						1726,
						-1688,
						-1687,
						-1719,
						1727,
						1728,
						-830,
						-829,
						-828,
						-827,
						-813
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000134",
					LAD13CDO: "31UH",
					LAD13NM: "North West Leicestershire",
					LAD13NMW: null
				},
				id: "E07000134"
			},
			{
				arcs: [
					[
						-1673,
						-1672,
						-1671,
						-1670,
						-1669,
						-244,
						-1713
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000135",
					LAD13CDO: "31UJ",
					LAD13NM: "Oadby and Wigston",
					LAD13NMW: null
				},
				id: "E07000135"
			},
			{
				arcs: [
					[
						[
							1729,
							1730
						]
					],
					[
						[
							1731,
							1732,
							1733,
							1734,
							1735,
							1736
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "E07000136",
					LAD13CDO: "32UB",
					LAD13NM: "Boston",
					LAD13NMW: null
				},
				id: "E07000136"
			},
			{
				arcs: [
					[
						[
							1737,
							1738,
							1739,
							1740
						]
					],
					[
						[
							1741,
							1742,
							-1741,
							1743,
							-1737,
							1744,
							1745,
							1746,
							-216,
							-215,
							1747
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "E07000137",
					LAD13CDO: "32UC",
					LAD13NM: "East Lindsey",
					LAD13NMW: null
				},
				id: "E07000137"
			},
			{
				arcs: [
					[
						1748,
						1749,
						1750
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000138",
					LAD13CDO: "32UD",
					LAD13NM: "Lincoln",
					LAD13NMW: null
				},
				id: "E07000138"
			},
			{
				arcs: [
					[
						-1750,
						-1749,
						1751,
						-1745,
						-1736,
						1752,
						1753,
						1754,
						1755
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000139",
					LAD13CDO: "32UE",
					LAD13NM: "North Kesteven",
					LAD13NMW: null
				},
				id: "E07000139"
			},
			{
				arcs: [
					[
						[
							1756,
							1757
						]
					],
					[
						[
							-1734,
							-1733,
							1760,
							-1731,
							1761,
							-1759,
							1762,
							-709,
							-383,
							1763,
							-1753,
							-1735
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "E07000140",
					LAD13CDO: "32UF",
					LAD13NM: "South Holland",
					LAD13NMW: null
				},
				id: "E07000140"
			},
			{
				arcs: [
					[
						-1764,
						-382,
						-381,
						-270,
						-1721,
						-1720,
						1764,
						1765,
						-1754
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000141",
					LAD13CDO: "32UG",
					LAD13NM: "South Kesteven",
					LAD13NMW: null
				},
				id: "E07000141"
			},
			{
				arcs: [
					[
						-220,
						-219,
						-218,
						-217,
						-1747,
						-1746,
						-1752,
						-1751,
						-1756,
						1766,
						1767,
						1768,
						1769,
						1770,
						1771,
						1772,
						1773,
						1774,
						1775,
						1776,
						1777,
						1778,
						1779,
						1780,
						-228
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000142",
					LAD13CDO: "32UH",
					LAD13NM: "West Lindsey",
					LAD13NMW: null
				},
				id: "E07000142"
			},
			{
				arcs: [
					[
						1781,
						1782,
						1783,
						1784,
						1785,
						1786,
						1787,
						1788,
						1789,
						1790
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000143",
					LAD13CDO: "33UB",
					LAD13NM: "Breckland",
					LAD13NMW: null
				},
				id: "E07000143"
			},
			{
				arcs: [
					[
						[
							1791,
							1792,
							1793
						]
					],
					[
						[
							1794,
							1795,
							1796,
							1797,
							1798,
							1799,
							1800,
							1801,
							1802,
							1803,
							1804,
							1805,
							1806,
							1807,
							1808,
							1809,
							1810,
							1811,
							1812,
							1813,
							1814,
							1815,
							1816,
							1817,
							1818,
							1819,
							1820,
							1821,
							1822,
							1823,
							1824,
							1825,
							1826,
							1827,
							1828,
							1829,
							1830,
							1831,
							1832,
							1833,
							1834,
							1835,
							1836,
							1837,
							1838,
							1839,
							1840,
							1841,
							1842,
							1843,
							1844,
							1845,
							1846,
							1847,
							1848,
							1849,
							1850,
							1851,
							1852,
							1853,
							1854,
							1855,
							1856,
							1857,
							1858,
							1859,
							1860,
							1861,
							1862,
							1863,
							1864,
							1865,
							1866,
							1867,
							1868,
							1869,
							1870,
							1871,
							1872,
							1873,
							1874,
							1875,
							1876,
							1877,
							1878,
							1879,
							-1784,
							1880,
							1881
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "E07000144",
					LAD13CDO: "33UC",
					LAD13NM: "Broadland",
					LAD13NMW: null
				},
				id: "E07000144"
			},
			{
				arcs: [
					[
						[
							1882,
							1883,
							1884,
							1885,
							1886,
							1887,
							1888,
							1889,
							1890,
							1891
						]
					],
					[
						[
							1892,
							-1840,
							1893,
							1894
						]
					],
					[
						[
							1895,
							1896,
							1897,
							-1842,
							1898,
							1899,
							1900,
							1901,
							1902,
							1903,
							1904,
							1905,
							1906,
							1907,
							1908,
							1909
						]
					],
					[
						[
							1910,
							1911,
							1912,
							1913,
							1914,
							-1907,
							1915,
							1916,
							1917,
							1918,
							1919,
							1920,
							1921,
							1922,
							1923,
							1924,
							1925,
							-1838,
							1926,
							1927,
							-1835,
							1928,
							-1833,
							1929,
							1930,
							-1830,
							1931,
							-1828,
							1932,
							1933,
							1934,
							1935,
							-1823,
							1936,
							1937,
							1938,
							1939,
							1940,
							1941,
							1942,
							1943,
							1944,
							1945,
							1946
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "E07000145",
					LAD13CDO: "33UD",
					LAD13NM: "Great Yarmouth",
					LAD13NMW: null
				},
				id: "E07000145"
			},
			{
				arcs: [
					[
						[
							1947,
							1948,
							-682,
							-704,
							1949,
							-1757,
							1950
						]
					],
					[
						[
							1951,
							1952,
							1953,
							1954,
							1955
						]
					],
					[
						[
							1956,
							1957,
							1958,
							1959,
							1960
						]
					],
					[
						[
							1961,
							-1790,
							1962,
							-695,
							1963,
							1964,
							1965,
							1966,
							-1959,
							1967,
							1968,
							1969,
							1970,
							1971,
							1972,
							1973
						]
					],
					[
						[
							1974
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "E07000146",
					LAD13CDO: "33UE",
					LAD13NM: "King's Lynn and West Norfolk",
					LAD13NMW: null
				},
				id: "E07000146"
			},
			{
				arcs: [
					[
						[
							1975,
							-1812,
							1976,
							1977
						]
					],
					[
						[
							1978,
							1979,
							1980
						]
					],
					[
						[
							1981,
							1982,
							1983
						]
					],
					[
						[
							1984,
							1985,
							1986,
							1987,
							1988,
							1989,
							1990,
							1991
						]
					],
					[
						[
							1992,
							1993,
							1994,
							1995,
							1996,
							1997
						]
					],
					[
						[
							1998,
							1999,
							2000,
							2001,
							2002,
							2003,
							2004,
							2005,
							2006,
							2007
						]
					],
					[
						[
							2008,
							2009,
							2010,
							2011,
							2012,
							2013,
							2014,
							2015,
							2016,
							2017,
							2018,
							2019,
							2020,
							-1997,
							2021
						]
					],
					[
						[
							2022,
							2023,
							2024,
							2025,
							2026,
							2027,
							2028,
							-1985,
							2029,
							2030,
							2031
						]
					],
					[
						[
							2034,
							2035
						]
					],
					[
						[
							2036,
							2037,
							2038,
							2039,
							2040,
							2041,
							2042,
							2043,
							2044,
							2045,
							-1988,
							2046,
							2047,
							2048,
							2049,
							-2024,
							2050,
							2051,
							2052,
							2053
						]
					],
					[
						[
							2054,
							2055,
							2056,
							2057,
							2058,
							2059,
							2060
						]
					],
					[
						[
							-1946,
							2061,
							2062,
							2063,
							2064,
							-1941,
							2065,
							2066,
							-1984,
							2067,
							-1982,
							2068,
							-1819,
							2069,
							2070,
							-1816,
							2071,
							-1810,
							2072,
							2073,
							2074,
							2075,
							2076,
							2077,
							-1981,
							2078,
							2079,
							2080,
							2081,
							2082,
							2083,
							2084,
							2085,
							2086,
							-1797,
							2087,
							-1795,
							-1882,
							-1881,
							-1783,
							-1782,
							-1791,
							-1962,
							2088,
							2089,
							2090,
							2091,
							-2044,
							2092,
							2093,
							2094,
							2095,
							2096,
							2097,
							2098,
							2099,
							-2007,
							2100,
							2101,
							2102,
							-2003,
							2103,
							2104,
							-2000,
							2105,
							2106,
							2107,
							2108,
							-1994,
							2109,
							2110,
							2111,
							-2017,
							2112,
							-2015,
							2113,
							2114,
							2115,
							-2011,
							2116,
							-2009,
							2117,
							-2034,
							2118,
							2119,
							2120
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "E07000147",
					LAD13CDO: "33UF",
					LAD13NM: "North Norfolk",
					LAD13NMW: null
				},
				id: "E07000147"
			},
			{
				arcs: [
					[
						2124,
						2125,
						2126,
						-2122,
						2127,
						2128,
						2129,
						2130,
						2131,
						-1879
					],
					[
						2121,
						2122,
						2123
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000148",
					LAD13CDO: "33UG",
					LAD13NM: "Norwich",
					LAD13NMW: null
				},
				id: "E07000148"
			},
			{
				arcs: [
					[
						[
							-1891,
							2132,
							2133,
							2134,
							2135,
							-1886,
							2136,
							2137,
							2138,
							2139,
							2140,
							-1846,
							2141,
							2142,
							2143
						]
					],
					[
						[
							-2126,
							2144,
							2145
						]
					],
					[
						[
							-2132,
							-2131,
							2146,
							2147,
							-2129,
							2148,
							-2124,
							2149,
							2150,
							-1794,
							2151,
							2152,
							2153,
							2154,
							2155,
							2156,
							2157,
							2158,
							-1868,
							2159,
							2160,
							2161,
							2162,
							2163,
							2164,
							-1861,
							2165,
							2166,
							2167,
							2168,
							2169,
							2170,
							-1854,
							2171,
							2172,
							2173,
							2174,
							2175,
							2176,
							2177,
							2178,
							2179,
							2180,
							2181,
							2182,
							2183,
							2184,
							2185,
							2186,
							2187,
							2188,
							2189,
							2190,
							2191,
							2192,
							2193,
							2194,
							2195,
							2196,
							2197,
							2198,
							2199,
							2200,
							2201,
							2202,
							2203,
							2204,
							2205,
							2206,
							2207,
							2208,
							2209,
							2210,
							2211,
							2212,
							2213,
							2214,
							2215,
							2216,
							2217,
							2218,
							2219,
							2220,
							2221,
							2222,
							2223,
							2224,
							2225,
							2226,
							2227,
							2228,
							2229,
							2230,
							2231,
							-1785,
							-1880
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "E07000149",
					LAD13CDO: "33UH",
					LAD13NM: "South Norfolk",
					LAD13NMW: null
				},
				id: "E07000149"
			},
			{
				arcs: [
					[
						2232,
						-1694,
						-1693,
						-1692,
						-257,
						-256,
						-255,
						-254,
						-253,
						-252,
						2233
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000150",
					LAD13CDO: "34UB",
					LAD13NM: "Corby",
					LAD13NMW: null
				},
				id: "E07000150"
			},
			{
				arcs: [
					[
						-1706,
						2234,
						2235,
						2236,
						2237,
						2238,
						2239,
						2240,
						2241,
						2242,
						2243,
						2244,
						2245,
						-1711,
						-1710,
						-1709,
						-1708,
						-1707
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000151",
					LAD13CDO: "34UC",
					LAD13NM: "Daventry",
					LAD13NMW: null
				},
				id: "E07000151"
			},
			{
				arcs: [
					[
						-380,
						-715,
						-613,
						2246,
						2247,
						2248,
						-2234,
						-251,
						-250,
						-249,
						-248
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000152",
					LAD13CDO: "34UD",
					LAD13NM: "East Northamptonshire",
					LAD13NMW: null
				},
				id: "E07000152"
			},
			{
				arcs: [
					[
						-1702,
						-1701,
						-1700,
						-1699,
						-1698,
						-1697,
						-1696,
						-1695,
						-2233,
						-2249,
						-2248,
						2249,
						-2235,
						-1705,
						-1704,
						-1703
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000153",
					LAD13CDO: "34UE",
					LAD13NM: "Kettering",
					LAD13NMW: null
				},
				id: "E07000153"
			},
			{
				arcs: [
					[
						2250,
						2251,
						2252,
						-2237
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000154",
					LAD13CDO: "34UF",
					LAD13NM: "Northampton",
					LAD13NMW: null
				},
				id: "E07000154"
			},
			{
				arcs: [
					[
						-2253,
						2253,
						-461,
						-664,
						-663,
						-662,
						2254,
						2255,
						-2238
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000155",
					LAD13CDO: "34UG",
					LAD13NM: "South Northamptonshire",
					LAD13NMW: null
				},
				id: "E07000155"
			},
			{
				arcs: [
					[
						-2247,
						-612,
						-462,
						-2254,
						-2252,
						-2251,
						-2236,
						-2250
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000156",
					LAD13CDO: "34UH",
					LAD13NM: "Wellingborough",
					LAD13NMW: null
				},
				id: "E07000156"
			},
			{
				arcs: [
					[
						2256,
						2257,
						2258,
						-1606,
						-1624,
						-1589,
						-767,
						2259
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000163",
					LAD13CDO: "36UB",
					LAD13NM: "Craven",
					LAD13NMW: null
				},
				id: "E07000163"
			},
			{
				arcs: [
					[
						-33,
						2260,
						2261,
						2262,
						2263,
						-238,
						2264,
						2265,
						2266,
						2267,
						-93,
						-90,
						2268,
						-88,
						2269,
						2270,
						-85,
						2271,
						2272,
						-82,
						2273,
						-35,
						-27
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000164",
					LAD13CDO: "36UC",
					LAD13NM: "Hambleton",
					LAD13NMW: null
				},
				id: "E07000164"
			},
			{
				arcs: [
					[
						-237,
						-236,
						2274,
						2275,
						2276,
						2277,
						-2257,
						2278,
						-2265
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000165",
					LAD13CDO: "36UD",
					LAD13NM: "Harrogate",
					LAD13NMW: null
				},
				id: "E07000165"
			},
			{
				arcs: [
					[
						-2268,
						-2267,
						-2266,
						-2279,
						-2260,
						-766,
						-762,
						-489,
						-94
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000166",
					LAD13CDO: "36UE",
					LAD13NM: "Richmondshire",
					LAD13NMW: null
				},
				id: "E07000166"
			},
			{
				arcs: [
					[
						2279,
						2280,
						2281,
						2282,
						-213,
						-239,
						-2264,
						-2263,
						2283
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000167",
					LAD13CDO: "36UF",
					LAD13NM: "Ryedale",
					LAD13NMW: null
				},
				id: "E07000167"
			},
			{
				arcs: [
					[
						2284,
						2285,
						-214,
						-2283,
						-2282,
						-2281,
						-2280,
						-2284,
						-2262,
						-2261,
						-32
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000168",
					LAD13CDO: "36UG",
					LAD13NM: "Scarborough",
					LAD13NMW: null
				},
				id: "E07000168"
			},
			{
				arcs: [
					[
						[
							-211,
							2286,
							2287,
							2288,
							2289,
							2290,
							2291,
							2292,
							2293,
							2294,
							2295,
							2296,
							2297,
							2298,
							2299,
							2300,
							2301,
							2302,
							2303,
							2304,
							2305,
							2306,
							2307,
							-230
						]
					],
					[
						[
							-235,
							2308,
							2309,
							2310,
							2311,
							2312,
							2313,
							2314,
							2315,
							2316,
							2317,
							2318,
							2319,
							2320,
							-2292,
							2321,
							2322,
							2323,
							2324,
							2325,
							-201,
							2326,
							2327,
							2328,
							2329,
							2330,
							2331,
							2332,
							2333,
							2334,
							2335,
							2336,
							-189,
							2337,
							2338,
							-186,
							2339,
							-184,
							2340,
							-182,
							2341,
							-180,
							2342,
							2343,
							-177,
							2344,
							2345,
							2346,
							-173,
							2347,
							2348,
							2349,
							2350,
							-2275
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "E07000169",
					LAD13CDO: "36UH",
					LAD13NM: "Selby",
					LAD13NMW: null
				},
				id: "E07000169"
			},
			{
				arcs: [
					[
						2351,
						2352,
						2353,
						-273,
						2354,
						-781,
						-780,
						-779,
						-778,
						-791,
						-790
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000170",
					LAD13CDO: "37UB",
					LAD13NM: "Ashfield",
					LAD13NMW: null
				},
				id: "E07000170"
			},
			{
				arcs: [
					[
						2356,
						2357,
						2358,
						2359,
						2360,
						2361,
						2362,
						2363,
						2364,
						-1771,
						2365,
						2366,
						2367,
						2368,
						-788,
						2369,
						2370,
						-224
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000171",
					LAD13CDO: "37UC",
					LAD13NM: "Bassetlaw",
					LAD13NMW: null
				},
				id: "E07000171"
			},
			{
				arcs: [
					[
						-272,
						2371,
						-811,
						-810,
						-809,
						-808,
						-807,
						-782,
						-2355
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000172",
					LAD13CDO: "37UD",
					LAD13NM: "Broxtowe",
					LAD13NMW: null
				},
				id: "E07000172"
			},
			{
				arcs: [
					[
						2372,
						2373,
						2374,
						2375,
						-274,
						-2354,
						2376
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000173",
					LAD13CDO: "37UE",
					LAD13NM: "Gedling",
					LAD13NMW: null
				},
				id: "E07000173"
			},
			{
				arcs: [
					[
						-2352,
						-789,
						-2369,
						2377
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000174",
					LAD13CDO: "37UF",
					LAD13NM: "Mansfield",
					LAD13NMW: null
				},
				id: "E07000174"
			},
			{
				arcs: [
					[
						-1755,
						-1766,
						-1765,
						-1726,
						2378,
						-2375,
						-2374,
						-2373,
						-2377,
						-2353,
						-2378,
						-2368,
						2379,
						2380,
						-1767
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000175",
					LAD13CDO: "37UG",
					LAD13NM: "Newark and Sherwood",
					LAD13NMW: null
				},
				id: "E07000175"
			},
			{
				arcs: [
					[
						-1725,
						-1724,
						-1723,
						-1722,
						-1681,
						-1680,
						-1691,
						-1690,
						-1689,
						-1727,
						-812,
						-2372,
						-271,
						-2376,
						-2379
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000176",
					LAD13CDO: "37UJ",
					LAD13NM: "Rushcliffe",
					LAD13NMW: null
				},
				id: "E07000176"
			},
			{
				arcs: [
					[
						-661,
						-660,
						2381,
						2382,
						2383,
						2384,
						2385,
						2386,
						2387,
						2388,
						2389,
						2390,
						-2255
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000177",
					LAD13CDO: "38UB",
					LAD13NM: "Cherwell",
					LAD13NMW: null
				},
				id: "E07000177"
			},
			{
				arcs: [
					[
						2391,
						2392,
						-2383
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000178",
					LAD13CDO: "38UC",
					LAD13NM: "Oxford",
					LAD13NMW: null
				},
				id: "E07000178"
			},
			{
				arcs: [
					[
						-659,
						-658,
						-674,
						-455,
						-441,
						-425,
						-424,
						2393,
						2394,
						-2392,
						-2382
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000179",
					LAD13CDO: "38UD",
					LAD13NM: "South Oxfordshire",
					LAD13NMW: null
				},
				id: "E07000179"
			},
			{
				arcs: [
					[
						-2385,
						-2384,
						-2393,
						-2395,
						-2394,
						-438,
						-600,
						-367,
						-366,
						-365,
						-364,
						-1213,
						2395,
						2396,
						2397,
						2398,
						2399,
						-2386
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000180",
					LAD13CDO: "38UE",
					LAD13NM: "Vale of White Horse",
					LAD13NMW: null
				},
				id: "E07000180"
			},
			{
				arcs: [
					[
						-2387,
						-2400,
						-2399,
						-2398,
						-2397,
						-2396,
						-1212,
						-1211,
						-1210,
						-1209,
						-1208,
						2400,
						2401,
						2402
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000181",
					LAD13CDO: "38UF",
					LAD13NM: "West Oxfordshire",
					LAD13NMW: null
				},
				id: "E07000181"
			},
			{
				arcs: [
					[
						-306,
						-305,
						-304,
						-303,
						-607,
						-606,
						2403,
						2404,
						2405,
						-322
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000187",
					LAD13CDO: "40UB",
					LAD13NM: "Mendip",
					LAD13NMW: null
				},
				id: "E07000187"
			},
			{
				arcs: [
					[
						[
							2406,
							2407,
							2408,
							2409,
							2410,
							2411,
							2412,
							2413,
							2414,
							2415,
							2416,
							2417,
							2418,
							2419,
							2420,
							2421,
							2422,
							2423,
							2424,
							2425,
							2426,
							2427,
							2428,
							2429,
							2430,
							2431
						]
					],
					[
						[
							2432,
							-323,
							-2406,
							2433,
							2434,
							-2423,
							2435,
							-2421,
							2436,
							-2419,
							2437,
							-2417,
							2438,
							2439,
							2440,
							2441,
							-2412,
							2442,
							2443,
							2444,
							-2408,
							2445,
							2446
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "E07000188",
					LAD13CDO: "40UC",
					LAD13NM: "Sedgemoor",
					LAD13NMW: null
				},
				id: "E07000188"
			},
			{
				arcs: [
					[
						-605,
						-952,
						-951,
						-950,
						-968,
						-980,
						-979,
						-978,
						-977,
						-976,
						-975,
						-974,
						-838,
						2447,
						2448,
						2449,
						2450,
						2451,
						2452,
						2453,
						2454,
						-2434,
						-2405,
						-2404
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000189",
					LAD13CDO: "40UD",
					LAD13NM: "South Somerset",
					LAD13NMW: null
				},
				id: "E07000189"
			},
			{
				arcs: [
					[
						[
							2455,
							2456,
							2457,
							2458,
							-2425,
							2459,
							2460
						]
					],
					[
						[
							-2455,
							2461,
							2462,
							2463,
							2464,
							-2461,
							2465,
							-2435
						]
					],
					[
						[
							-2429,
							2466,
							-2427,
							2467,
							-2458,
							2468,
							2469,
							2470,
							-2463,
							2471,
							2472,
							-2452,
							2473,
							2474,
							-2449,
							-2448,
							-857,
							-867,
							-866,
							2475,
							-2430
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "E07000190",
					LAD13CDO: "40UE",
					LAD13NM: "Taunton Deane",
					LAD13NMW: null
				},
				id: "E07000190"
			},
			{
				arcs: [
					[
						-2431,
						-2476,
						-880,
						-881,
						2476
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000191",
					LAD13CDO: "40UF",
					LAD13NM: "West Somerset",
					LAD13NMW: null
				},
				id: "E07000191"
			},
			{
				arcs: [
					[
						2477,
						2478,
						2479,
						2480
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000192",
					LAD13CDO: "41UB",
					LAD13NM: "Cannock Chase",
					LAD13NMW: null
				},
				id: "E07000192"
			},
			{
				arcs: [
					[
						-799,
						-837,
						-836,
						2481,
						2482,
						2483,
						2484,
						2485,
						2486,
						2487,
						2488,
						2489,
						2490,
						2491,
						2492,
						2493,
						2494,
						2495
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000193",
					LAD13CDO: "41UC",
					LAD13NM: "East Staffordshire",
					LAD13NMW: null
				},
				id: "E07000193"
			},
			{
				arcs: [
					[
						-2485,
						-2484,
						-2483,
						-2482,
						-835,
						-834,
						-833,
						-832,
						-831,
						-1729,
						2496,
						2497,
						2498,
						2499,
						2500,
						2501,
						2502,
						-2478,
						2503,
						-2486
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000194",
					LAD13CDO: "41UD",
					LAD13NM: "Lichfield",
					LAD13NMW: null
				},
				id: "E07000194"
			},
			{
				arcs: [
					[
						-301,
						2504,
						-543,
						-542,
						-541,
						-506,
						-505,
						2505
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000195",
					LAD13CDO: "41UE",
					LAD13NM: "Newcastle-under-Lyme",
					LAD13NMW: null
				},
				id: "E07000195"
			},
			{
				arcs: [
					[
						-2480,
						2506,
						2507,
						2508,
						2509,
						2510,
						-546,
						-545,
						-293,
						2511
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000196",
					LAD13CDO: "41UF",
					LAD13NM: "South Staffordshire",
					LAD13NMW: null
				},
				id: "E07000196"
			},
			{
				arcs: [
					[
						-300,
						2512,
						-2491,
						-2490,
						-2489,
						-2488,
						-2487,
						-2504,
						-2481,
						-2512,
						-292,
						-291,
						-544,
						-2505
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000197",
					LAD13CDO: "41UG",
					LAD13NM: "Stafford",
					LAD13NMW: null
				},
				id: "E07000197"
			},
			{
				arcs: [
					[
						-802,
						-801,
						-800,
						-2496,
						-2495,
						-2494,
						-2493,
						-2492,
						-2513,
						-299,
						-298,
						-297,
						-296,
						-2506,
						-504,
						-503,
						-817
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000198",
					LAD13CDO: "41UH",
					LAD13NM: "Staffordshire Moorlands",
					LAD13NMW: null
				},
				id: "E07000198"
			},
			{
				arcs: [
					[
						-2498,
						2513
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000199",
					LAD13CDO: "41UK",
					LAD13NM: "Tamworth",
					LAD13NMW: null
				},
				id: "E07000199"
			},
			{
				arcs: [
					[
						2516,
						2517,
						2518,
						2519,
						-1189,
						-1197,
						-1134,
						-1079,
						2520,
						2521
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000200",
					LAD13CDO: "42UB",
					LAD13NM: "Babergh",
					LAD13NMW: null
				},
				id: "E07000200"
			},
			{
				arcs: [
					[
						2522,
						-688,
						-687,
						-686,
						-685,
						-684,
						-683,
						-1963,
						-1789
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000201",
					LAD13CDO: "42UC",
					LAD13NM: "Forest Heath",
					LAD13NMW: null
				},
				id: "E07000201"
			},
			{
				arcs: [
					[
						2523,
						2524,
						2525,
						-2516,
						2526,
						-2519,
						-2518,
						2527
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000202",
					LAD13CDO: "42UD",
					LAD13NM: "Ipswich",
					LAD13NMW: null
				},
				id: "E07000202"
			},
			{
				arcs: [
					[
						2528,
						2529,
						-2528,
						-2517,
						2530,
						2531,
						-1786,
						-2232
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000203",
					LAD13CDO: "42UE",
					LAD13NM: "Mid Suffolk",
					LAD13NMW: null
				},
				id: "E07000203"
			},
			{
				arcs: [
					[
						-1787,
						-2532,
						-2531,
						-2522,
						-2521,
						-1078,
						-1077,
						-1076,
						-717,
						-716,
						-689,
						-2523,
						-1788
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000204",
					LAD13CDO: "42UF",
					LAD13NM: "St Edmundsbury",
					LAD13NMW: null
				},
				id: "E07000204"
			},
			{
				arcs: [
					[
						[
							2532,
							2533,
							2534
						]
					],
					[
						[
							2537,
							2538,
							2539,
							2540,
							2541,
							2542
						]
					],
					[
						[
							2543,
							2544,
							2545,
							2546,
							2547,
							2548,
							-2544
						]
					],
					[
						[
							2551,
							2552,
							2553,
							2554,
							2555,
							2556
						]
					],
					[
						[
							2557,
							2558,
							2559,
							-2556,
							2560,
							2561,
							2562,
							2563,
							2564,
							2565,
							2566,
							2567,
							2568,
							2569,
							2570,
							-2541,
							2571,
							2572,
							-2538,
							2573,
							2574,
							2575,
							2576,
							-2536,
							2577,
							-2525,
							-2524,
							-2530,
							2578
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "E07000205",
					LAD13CDO: "42UG",
					LAD13NM: "Suffolk Coastal",
					LAD13NMW: null
				},
				id: "E07000205"
			},
			{
				arcs: [
					[
						[
							2579,
							-2569,
							2580,
							2581,
							2582
						]
					],
					[
						[
							2583,
							-2582,
							-2567
						]
					],
					[
						[
							2585,
							2586,
							2587,
							2588,
							2589,
							-2545,
							2590,
							2591,
							-2551,
							2592,
							-2557,
							-2560,
							-2559,
							-2558,
							-2579,
							-2529,
							-2231,
							2593,
							-2229,
							2594,
							-2227,
							2595,
							-2225,
							2596,
							-2223,
							2597,
							2598,
							2599,
							-2219,
							2600,
							2601,
							2602,
							2603,
							2604,
							2605,
							2606,
							2607,
							2608,
							2609,
							-2208,
							2610,
							2611,
							2612,
							2613,
							-2203,
							2614,
							2615,
							2616,
							2617,
							-2198,
							2618,
							2619,
							2620,
							-2194,
							2621,
							2622,
							2623,
							2624,
							2625,
							2626
						]
					],
					[
						[
							2627,
							2628,
							2629,
							-2187,
							2630,
							-2185,
							-2184,
							2631,
							-2182,
							2632,
							-2180,
							-2179,
							2633,
							2634,
							-2176,
							2635,
							-1884,
							-1883
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "E07000206",
					LAD13CDO: "42UH",
					LAD13NM: "Waveney",
					LAD13NMW: null
				},
				id: "E07000206"
			},
			{
				arcs: [
					[
						2636,
						2637,
						2638,
						2639,
						2640,
						2641,
						2642,
						2643,
						2644,
						2645,
						2646
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000207",
					LAD13CDO: "43UB",
					LAD13NM: "Elmbridge",
					LAD13NMW: null
				},
				id: "E07000207"
			},
			{
				arcs: [
					[
						2647,
						2648,
						2649,
						2650
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000208",
					LAD13CDO: "43UC",
					LAD13NM: "Epsom and Ewell",
					LAD13NMW: null
				},
				id: "E07000208"
			},
			{
				arcs: [
					[
						-2640,
						2651,
						2652,
						-1309,
						2653,
						2654,
						2655,
						2656,
						2657,
						2658
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000209",
					LAD13CDO: "43UD",
					LAD13NM: "Guildford",
					LAD13NMW: null
				},
				id: "E07000209"
			},
			{
				arcs: [
					[
						2659,
						2660,
						2661,
						2662,
						2663,
						2664,
						2665,
						2666,
						2667,
						-2652,
						-2639,
						2668,
						-2650
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000210",
					LAD13CDO: "43UE",
					LAD13NM: "Mole Valley",
					LAD13NMW: null
				},
				id: "E07000210"
			},
			{
				arcs: [
					[
						2669,
						2670,
						2671,
						-2663,
						-2662,
						-2661,
						-2660,
						-2649,
						2672
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000211",
					LAD13CDO: "43UF",
					LAD13NM: "Reigate and Banstead",
					LAD13NMW: null
				},
				id: "E07000211"
			},
			{
				arcs: [
					[
						2673,
						2674,
						-2643,
						-2642,
						2675,
						2676,
						-449
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000212",
					LAD13CDO: "43UG",
					LAD13NM: "Runnymede",
					LAD13NMW: null
				},
				id: "E07000212"
			},
			{
				arcs: [
					[
						2677,
						2678,
						2679,
						-2646,
						-2645,
						-2644,
						-2675,
						-2674,
						-448,
						-444
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000213",
					LAD13CDO: "43UH",
					LAD13NM: "Spelthorne",
					LAD13NMW: null
				},
				id: "E07000213"
			},
			{
				arcs: [
					[
						2680,
						-2654,
						-1308,
						-1283,
						-419,
						-450,
						-2677
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000214",
					LAD13CDO: "43UJ",
					LAD13NM: "Surrey Heath",
					LAD13NMW: null
				},
				id: "E07000214"
			},
			{
				arcs: [
					[
						2681,
						-1482,
						-1045,
						2682,
						2683,
						-2671,
						2684
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000215",
					LAD13CDO: "43UK",
					LAD13NM: "Tandridge",
					LAD13NMW: null
				},
				id: "E07000215"
			},
			{
				arcs: [
					[
						-2653,
						-2668,
						-2667,
						2685,
						2686,
						-1257,
						-1285,
						-1310
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000216",
					LAD13CDO: "43UL",
					LAD13NM: "Waverley",
					LAD13NMW: null
				},
				id: "E07000216"
			},
			{
				arcs: [
					[
						-2641,
						-2659,
						-2658,
						-2657,
						-2656,
						-2655,
						-2681,
						-2676
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000217",
					LAD13CDO: "43UM",
					LAD13NM: "Woking",
					LAD13NMW: null
				},
				id: "E07000217"
			},
			{
				arcs: [
					[
						-1718,
						2687,
						2688,
						2689,
						2690,
						-2500,
						-2499,
						-2514,
						-2497,
						-1728
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000218",
					LAD13CDO: "44UB",
					LAD13NM: "North Warwickshire",
					LAD13NMW: null
				},
				id: "E07000218"
			},
			{
				arcs: [
					[
						2691,
						2692,
						-2688,
						-1717
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000219",
					LAD13CDO: "44UC",
					LAD13NM: "Nuneaton and Bedworth",
					LAD13NMW: null
				},
				id: "E07000219"
			},
			{
				arcs: [
					[
						-1675,
						-1712,
						-2246,
						-2245,
						-2244,
						-2243,
						-2242,
						-2241,
						-2240,
						2693,
						2694,
						2695,
						2696,
						-2692,
						-1716
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000220",
					LAD13CDO: "44UD",
					LAD13NM: "Rugby",
					LAD13NMW: null
				},
				id: "E07000220"
			},
			{
				arcs: [
					[
						2697,
						2698,
						2699,
						2700,
						2701,
						2702,
						-2694,
						-2239,
						-2256,
						-2391,
						-2390,
						-2389,
						-2388,
						-2403,
						-2402,
						-2401,
						-1207,
						-1206,
						-1205,
						-1204,
						-1222,
						2703,
						2704,
						2705,
						2706,
						2707,
						2708
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000221",
					LAD13CDO: "44UE",
					LAD13NM: "Stratford-on-Avon",
					LAD13NMW: null
				},
				id: "E07000221"
			},
			{
				arcs: [
					[
						2709,
						-2696,
						-2695,
						-2703,
						-2702,
						-2701,
						-2700,
						-2699,
						2710,
						2711
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000222",
					LAD13CDO: "44UF",
					LAD13NM: "Warwick",
					LAD13NMW: null
				},
				id: "E07000222"
			},
			{
				arcs: [
					[
						[
							2712,
							2713,
							2714,
							2715,
							2716,
							2717,
							-465
						]
					],
					[
						[
							2718,
							2719,
							2720,
							-2715,
							2721,
							2722,
							2723,
							2724
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "E07000223",
					LAD13CDO: "45UB",
					LAD13NM: "Adur",
					LAD13NMW: null
				},
				id: "E07000223"
			},
			{
				arcs: [
					[
						[
							2727,
							2728,
							2729
						]
					],
					[
						[
							-2725,
							2730,
							2731,
							2732,
							2733,
							2734,
							2735,
							2736,
							2737,
							2738,
							2739,
							2740,
							2741,
							2742,
							2743,
							2744,
							2745,
							2746,
							2747,
							2748,
							2749,
							2750,
							2751,
							2752,
							2753,
							2754,
							2755
						]
					],
					[
						[
							2756,
							2757,
							2758,
							-2729,
							2759,
							2760,
							2761,
							2762,
							2763,
							2764,
							2765,
							2766,
							2767,
							-2750,
							2768,
							2769,
							2770,
							2771,
							2772,
							-2744,
							2773,
							2774,
							2775,
							-2740,
							2776,
							-2738,
							2777,
							2778,
							2779,
							2780,
							2781,
							2782,
							2783,
							2784
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "E07000224",
					LAD13CDO: "45UC",
					LAD13NM: "Arun",
					LAD13NMW: null
				},
				id: "E07000224"
			},
			{
				arcs: [
					[
						[
							2785,
							2786,
							2787,
							2788,
							2789
						]
					],
					[
						[
							2793,
							2794,
							2795,
							2796,
							2797,
							2798,
							2799,
							2800,
							2801,
							2802,
							2803,
							2804,
							2805,
							2806,
							2807,
							2808,
							-2791,
							2809,
							2810,
							2811,
							-2785,
							2812,
							2813,
							2814,
							2815,
							-2786,
							2816,
							2817,
							2818,
							-1288,
							-1258,
							-2687,
							2819
						],
						[
							2790,
							2791,
							2792
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "E07000225",
					LAD13CDO: "45UD",
					LAD13NM: "Chichester",
					LAD13NMW: null
				},
				id: "E07000225"
			},
			{
				arcs: [
					[
						-2672,
						-2684,
						2820,
						2821,
						-2664
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000226",
					LAD13CDO: "45UE",
					LAD13NM: "Crawley",
					LAD13NMW: null
				},
				id: "E07000226"
			},
			{
				arcs: [
					[
						[
							2822,
							2823,
							2824,
							2825,
							2826,
							2827,
							2828,
							2829,
							2830,
							2831,
							2832,
							2833,
							2834,
							2835,
							2836,
							2837,
							2838,
							2839,
							-2806,
							2840,
							2841,
							2842,
							2843,
							2844
						]
					],
					[
						[
							2845,
							2846,
							-466,
							-2718,
							2847,
							-2719,
							-2756,
							2848,
							-2762,
							2849,
							-2727,
							2850,
							-2758,
							2851,
							-2812,
							2852,
							2853,
							-2793,
							2854,
							2855,
							2856,
							2857,
							2858,
							2859,
							2860,
							-2834,
							2861,
							2862,
							2863,
							2864,
							2865,
							-2828,
							2866,
							-2826,
							2867,
							2868,
							2869,
							2870,
							2871,
							-2843,
							2872,
							2873,
							-2804,
							2874,
							2875,
							-2801,
							2876,
							-2799,
							2877,
							-2797,
							2878,
							-2795,
							-2794,
							-2820,
							-2686,
							-2666,
							-2665,
							-2822
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "E07000227",
					LAD13CDO: "45UF",
					LAD13NM: "Horsham",
					LAD13NMW: null
				},
				id: "E07000227"
			},
			{
				arcs: [
					[
						-1044,
						-1043,
						-1018,
						-467,
						-2847,
						-2846,
						-2821,
						-2683
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000228",
					LAD13CDO: "45UG",
					LAD13NM: "Mid Sussex",
					LAD13NMW: null
				},
				id: "E07000228"
			},
			{
				arcs: [
					[
						-2724,
						2879,
						-2731
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000229",
					LAD13CDO: "45UH",
					LAD13NM: "Worthing",
					LAD13NMW: null
				},
				id: "E07000229"
			},
			{
				arcs: [
					[
						2880,
						2881,
						2882,
						2883,
						-2708,
						2884,
						2885,
						2886,
						-2510,
						2887,
						2888
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000234",
					LAD13CDO: "47UB",
					LAD13NM: "Bromsgrove",
					LAD13NMW: null
				},
				id: "E07000234"
			},
			{
				arcs: [
					[
						2889,
						2890,
						2891,
						2892,
						2893,
						-1250,
						-1223,
						-280,
						-279,
						-278,
						-277,
						-550,
						-549
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000235",
					LAD13CDO: "47UC",
					LAD13NM: "Malvern Hills",
					LAD13NMW: null
				},
				id: "E07000235"
			},
			{
				arcs: [
					[
						-2707,
						-2706,
						2894,
						-2885
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000236",
					LAD13CDO: "47UD",
					LAD13NM: "Redditch",
					LAD13NMW: null
				},
				id: "E07000236"
			},
			{
				arcs: [
					[
						-2893,
						-2892,
						2895
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000237",
					LAD13CDO: "47UE",
					LAD13NM: "Worcester",
					LAD13NMW: null
				},
				id: "E07000237"
			},
			{
				arcs: [
					[
						-2886,
						-2895,
						-2705,
						-2704,
						-1221,
						-1244,
						-1251,
						-2894,
						-2896,
						-2891,
						2896,
						2897
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000238",
					LAD13CDO: "47UF",
					LAD13NM: "Wychavon",
					LAD13NMW: null
				},
				id: "E07000238"
			},
			{
				arcs: [
					[
						-2887,
						-2898,
						-2897,
						-2890,
						-548,
						-547,
						-2511
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000239",
					LAD13CDO: "47UG",
					LAD13NM: "Wyre Forest",
					LAD13NMW: null
				},
				id: "E07000239"
			},
			{
				arcs: [
					[
						2898,
						-1340,
						-1339,
						-1349,
						-1331,
						-620,
						-1345
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000240",
					LAD13CDO: "26UG",
					LAD13NM: "St Albans",
					LAD13NMW: null
				},
				id: "E07000240"
			},
			{
				arcs: [
					[
						2899,
						2900,
						2901,
						2902,
						2903,
						-1329,
						2904,
						-1333,
						-2899,
						-1344
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000241",
					LAD13CDO: "26UL",
					LAD13NM: "Welwyn Hatfield",
					LAD13NMW: null
				},
				id: "E07000241"
			},
			{
				arcs: [
					[
						-1199,
						-1198,
						-1143,
						-1145,
						-1141,
						-1330,
						-2904,
						-2903,
						-2902,
						-2901,
						-2900,
						-1343,
						2905,
						2906,
						-1341
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000242",
					LAD13CDO: "26UD",
					LAD13NM: "East Hertfordshire",
					LAD13NMW: null
				},
				id: "E07000242"
			},
			{
				arcs: [
					[
						-2907,
						-2906,
						-1342
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E07000243",
					LAD13CDO: "26UH",
					LAD13NM: "Stevenage",
					LAD13NMW: null
				},
				id: "E07000243"
			},
			{
				arcs: [
					[
						2907,
						2908,
						2909,
						2910,
						2911,
						2912,
						2913,
						-1534,
						-1533,
						-1532,
						-1531,
						-118,
						-117
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E08000001",
					LAD13CDO: "00BL",
					LAD13NM: "Bolton",
					LAD13NMW: null
				},
				id: "E08000001"
			},
			{
				arcs: [
					[
						2914,
						2915,
						2916,
						-2908,
						-116,
						-1627
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E08000002",
					LAD13CDO: "00BM",
					LAD13NM: "Bury",
					LAD13NMW: null
				},
				id: "E08000002"
			},
			{
				arcs: [
					[
						2917,
						2918,
						2919,
						2920,
						2921,
						2922,
						-495,
						2923,
						2924,
						2925,
						-2916
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E08000003",
					LAD13CDO: "00BN",
					LAD13NM: "Manchester",
					LAD13NMW: null
				},
				id: "E08000003"
			},
			{
				arcs: [
					[
						2926,
						-820,
						2927,
						-2919,
						2928,
						2929,
						2930,
						2931
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E08000004",
					LAD13CDO: "00BP",
					LAD13NM: "Oldham",
					LAD13NMW: null
				},
				id: "E08000004"
			},
			{
				arcs: [
					[
						-2931,
						-2930,
						-2929,
						-2918,
						-2915,
						-1626,
						2932
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E08000005",
					LAD13CDO: "00BQ",
					LAD13NM: "Rochdale",
					LAD13NMW: null
				},
				id: "E08000005"
			},
			{
				arcs: [
					[
						-2917,
						-2926,
						2933,
						-111,
						2934,
						-2909
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E08000006",
					LAD13CDO: "00BR",
					LAD13NM: "Salford",
					LAD13NMW: null
				},
				id: "E08000006"
			},
			{
				arcs: [
					[
						2935,
						2936,
						2937,
						-818,
						-499,
						-498,
						-497,
						-496,
						-2923,
						-2922,
						-2921
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E08000007",
					LAD13CDO: "00BS",
					LAD13NM: "Stockport",
					LAD13NMW: null
				},
				id: "E08000007"
			},
			{
				arcs: [
					[
						-819,
						-2938,
						-2937,
						-2936,
						-2920,
						-2928
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E08000008",
					LAD13CDO: "00BT",
					LAD13NM: "Tameside",
					LAD13NMW: null
				},
				id: "E08000008"
			},
			{
				arcs: [
					[
						-2925,
						-2924,
						-494,
						-105,
						-2934
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E08000009",
					LAD13CDO: "00BU",
					LAD13NM: "Trafford",
					LAD13NMW: null
				},
				id: "E08000009"
			},
			{
				arcs: [
					[
						-1535,
						-2914,
						-2913,
						-2912,
						-2911,
						-2910,
						-2935,
						-110,
						2938,
						-1649,
						-1536
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E08000010",
					LAD13CDO: "00BW",
					LAD13NM: "Wigan",
					LAD13NMW: null
				},
				id: "E08000010"
			},
			{
				arcs: [
					[
						2939,
						2940,
						2941,
						-103,
						2942,
						2943,
						-1651
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E08000011",
					LAD13CDO: "00BX",
					LAD13NM: "Knowsley",
					LAD13NMW: null
				},
				id: "E08000011"
			},
			{
				arcs: [
					[
						-2943,
						-102,
						-101,
						2944,
						2945
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E08000012",
					LAD13CDO: "00BY",
					LAD13NM: "Liverpool",
					LAD13NMW: null
				},
				id: "E08000012"
			},
			{
				arcs: [
					[
						-2939,
						-109,
						-104,
						-2942,
						-2941,
						-2940,
						-1650
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E08000013",
					LAD13CDO: "00BZ",
					LAD13NM: "St. Helens",
					LAD13NMW: null
				},
				id: "E08000013"
			},
			{
				arcs: [
					[
						[
							-1654,
							2946,
							2947,
							2948,
							2949,
							2950
						]
					],
					[
						[
							-1655,
							-2951,
							2951,
							2952,
							2953
						]
					],
					[
						[
							2956,
							-2949,
							2957,
							2958,
							-1652,
							-2944,
							-2946,
							2959
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "E08000014",
					LAD13CDO: "00CA",
					LAD13NM: "Sefton",
					LAD13NMW: null
				},
				id: "E08000014"
			},
			{
				arcs: [
					[
						[
							2960,
							-537,
							-521,
							2961
						]
					],
					[
						[
							-539,
							2962,
							2963
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "E08000015",
					LAD13CDO: "00CB",
					LAD13NM: "Wirral",
					LAD13NMW: null
				},
				id: "E08000015"
			},
			{
				arcs: [
					[
						2964,
						2965,
						2966,
						-815,
						2967,
						2968,
						2969,
						2970,
						2971
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E08000016",
					LAD13CDO: "00CC",
					LAD13NM: "Barnsley",
					LAD13NMW: null
				},
				id: "E08000016"
			},
			{
				arcs: [
					[
						-166,
						-225,
						-2371,
						2972,
						-2965,
						2973,
						-2348,
						-172,
						2974
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E08000017",
					LAD13CDO: "00CE",
					LAD13NM: "Doncaster",
					LAD13NMW: null
				},
				id: "E08000017"
			},
			{
				arcs: [
					[
						-2973,
						-2370,
						-787,
						-824,
						-823,
						2975,
						-2966
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E08000018",
					LAD13CDO: "00CF",
					LAD13NM: "Rotherham",
					LAD13NMW: null
				},
				id: "E08000018"
			},
			{
				arcs: [
					[
						-2976,
						-822,
						-826,
						-825,
						-806,
						-816,
						-2967
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E08000019",
					LAD13CDO: "00CG",
					LAD13NM: "Sheffield",
					LAD13NMW: null
				},
				id: "E08000019"
			},
			{
				arcs: [
					[
						2976,
						2977,
						2978,
						-639
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E08000021",
					LAD13CDO: "00CJ",
					LAD13NM: "Newcastle upon Tyne",
					LAD13NMW: null
				},
				id: "E08000021"
			},
			{
				arcs: [
					[
						2979,
						-2977,
						-638
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E08000022",
					LAD13CDO: "00CK",
					LAD13NM: "North Tyneside",
					LAD13NMW: null
				},
				id: "E08000022"
			},
			{
				arcs: [
					[
						2980,
						2981,
						2982
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E08000023",
					LAD13CDO: "00CL",
					LAD13NM: "South Tyneside",
					LAD13NMW: null
				},
				id: "E08000023"
			},
			{
				arcs: [
					[
						[
							-487,
							2983,
							2984,
							2985,
							2986,
							2987,
							2988,
							2989,
							2990,
							2991
						]
					],
					[
						[
							2992,
							2993,
							2994,
							-2989,
							2995,
							2996,
							2997,
							2998,
							2999,
							-486,
							3000,
							-2981
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "E08000024",
					LAD13CDO: "00CM",
					LAD13NM: "Sunderland",
					LAD13NMW: null
				},
				id: "E08000024"
			},
			{
				arcs: [
					[
						-2691,
						3001,
						3002,
						3003,
						-2883,
						3004,
						3005,
						3006,
						-2501
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E08000025",
					LAD13CDO: "00CN",
					LAD13NM: "Birmingham",
					LAD13NMW: null
				},
				id: "E08000025"
			},
			{
				arcs: [
					[
						-2697,
						-2710,
						3007,
						3008,
						-2689,
						-2693
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E08000026",
					LAD13CDO: "00CQ",
					LAD13NM: "Coventry",
					LAD13NMW: null
				},
				id: "E08000026"
			},
			{
				arcs: [
					[
						3009,
						3010,
						-3005,
						-2882,
						-2881,
						-2889,
						-2888,
						-2509,
						3011
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E08000027",
					LAD13CDO: "00CR",
					LAD13NM: "Dudley",
					LAD13NMW: null
				},
				id: "E08000027"
			},
			{
				arcs: [
					[
						-3006,
						-3011,
						-3010,
						3012,
						3013
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E08000028",
					LAD13CDO: "00CS",
					LAD13NM: "Sandwell",
					LAD13NMW: null
				},
				id: "E08000028"
			},
			{
				arcs: [
					[
						-3009,
						-3008,
						-2712,
						-2711,
						-2698,
						-2709,
						-2884,
						-3004,
						-3003,
						-3002,
						-2690
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E08000029",
					LAD13CDO: "00CT",
					LAD13NM: "Solihull",
					LAD13NMW: null
				},
				id: "E08000029"
			},
			{
				arcs: [
					[
						-2502,
						-3007,
						-3014,
						3014,
						3015,
						3016,
						-2507,
						-2479,
						-2503
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E08000030",
					LAD13CDO: "00CU",
					LAD13NM: "Walsall",
					LAD13NMW: null
				},
				id: "E08000030"
			},
			{
				arcs: [
					[
						-3017,
						-3016,
						-3015,
						-3013,
						-3012,
						-2508
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E08000031",
					LAD13CDO: "00CW",
					LAD13NM: "Wolverhampton",
					LAD13NMW: null
				},
				id: "E08000031"
			},
			{
				arcs: [
					[
						-2278,
						3017,
						3018,
						3019,
						3020,
						3021,
						-1602,
						-2259,
						-2258
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E08000032",
					LAD13CDO: "00CX",
					LAD13NM: "Bradford",
					LAD13NMW: null
				},
				id: "E08000032"
			},
			{
				arcs: [
					[
						3022,
						3023,
						-2932,
						-2933,
						-1625,
						-1522,
						-1603,
						-3022
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E08000033",
					LAD13CDO: "00CY",
					LAD13NM: "Calderdale",
					LAD13NMW: null
				},
				id: "E08000033"
			},
			{
				arcs: [
					[
						3024,
						3025,
						3026,
						3027,
						3028,
						-2969,
						-2968,
						-821,
						-2927,
						-3024,
						-3023,
						-3021
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E08000034",
					LAD13CDO: "00CZ",
					LAD13NM: "Kirklees",
					LAD13NMW: null
				},
				id: "E08000034"
			},
			{
				arcs: [
					[
						-2276,
						-2351,
						-2350,
						3029,
						3030,
						-3028,
						-3027,
						-3026,
						-3025,
						-3020,
						-3019,
						-3018,
						-2277
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E08000035",
					LAD13CDO: "00DA",
					LAD13NM: "Leeds",
					LAD13NMW: null
				},
				id: "E08000035"
			},
			{
				arcs: [
					[
						-2974,
						-2972,
						-2971,
						-2970,
						-3029,
						-3031,
						-3030,
						-2349
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E08000036",
					LAD13CDO: "00DB",
					LAD13NM: "Wakefield",
					LAD13NMW: null
				},
				id: "E08000036"
			},
			{
				arcs: [
					[
						3031,
						-2982,
						-3001,
						-493,
						-642,
						-641,
						3032
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E08000037",
					LAD13CDO: "00CH",
					LAD13NM: "Gateshead",
					LAD13NMW: null
				},
				id: "E08000037"
			},
			{
				arcs: [
					[
						3033,
						3034,
						3035,
						3036,
						3037,
						3038
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E09000001",
					LAD13CDO: "00AA",
					LAD13NM: "City of London",
					LAD13NMW: null
				},
				id: "E09000001"
			},
			{
				arcs: [
					[
						[
							3039,
							3040,
							3041,
							3042,
							3043,
							3044,
							3045
						]
					],
					[
						[
							3046,
							3047,
							3048,
							3049,
							-3045,
							3050,
							-3043,
							3051,
							3052
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "E09000002",
					LAD13CDO: "00AB",
					LAD13NM: "Barking and Dagenham",
					LAD13NMW: null
				},
				id: "E09000002"
			},
			{
				arcs: [
					[
						3053,
						3054,
						3055,
						3056,
						3057,
						3058,
						3059,
						-1335
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E09000003",
					LAD13CDO: "00AC",
					LAD13NM: "Barnet",
					LAD13NMW: null
				},
				id: "E09000003"
			},
			{
				arcs: [
					[
						3060,
						3061,
						3062,
						3063,
						3064,
						3065,
						3066,
						-1388,
						-1387,
						-1386,
						-1485,
						3067,
						3068,
						3069,
						3070,
						3071
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E09000004",
					LAD13CDO: "00AD",
					LAD13NM: "Bexley",
					LAD13NMW: null
				},
				id: "E09000004"
			},
			{
				arcs: [
					[
						-3059,
						-3058,
						3072,
						3073,
						3074,
						3075,
						3076,
						3077
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E09000005",
					LAD13CDO: "00AE",
					LAD13NM: "Brent",
					LAD13NMW: null
				},
				id: "E09000005"
			},
			{
				arcs: [
					[
						3078,
						-3068,
						-1484,
						-1483,
						-2682,
						3079,
						3080,
						3081,
						3082,
						3083,
						3084,
						3085
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E09000006",
					LAD13CDO: "00AF",
					LAD13NM: "Bromley",
					LAD13NMW: null
				},
				id: "E09000006"
			},
			{
				arcs: [
					[
						3086,
						-3038,
						3087,
						-3073,
						-3057,
						3088
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E09000007",
					LAD13CDO: "00AG",
					LAD13NM: "Camden",
					LAD13NMW: null
				},
				id: "E09000007"
			},
			{
				arcs: [
					[
						-3080,
						-2685,
						-2670,
						3089,
						3090,
						3091
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E09000008",
					LAD13CDO: "00AH",
					LAD13NM: "Croydon",
					LAD13NMW: null
				},
				id: "E09000008"
			},
			{
				arcs: [
					[
						3092,
						3093,
						3094,
						3095,
						-3077
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E09000009",
					LAD13CDO: "00AJ",
					LAD13NM: "Ealing",
					LAD13NMW: null
				},
				id: "E09000009"
			},
			{
				arcs: [
					[
						-1139,
						3096,
						3097,
						-3055,
						-3054,
						-1334,
						-2905,
						-1328
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E09000010",
					LAD13CDO: "00AK",
					LAD13NM: "Enfield",
					LAD13NMW: null
				},
				id: "E09000010"
			},
			{
				arcs: [
					[
						[
							3098,
							3099,
							3100
						]
					],
					[
						[
							-3071,
							-3070,
							-3069,
							-3079,
							-3086,
							3101,
							3102,
							3103,
							3104,
							3105,
							3106,
							3107
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "E09000011",
					LAD13CDO: "00AL",
					LAD13NM: "Greenwich",
					LAD13NMW: null
				},
				id: "E09000011"
			},
			{
				arcs: [
					[
						3108,
						3109,
						3110,
						-3034,
						3111,
						3112
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E09000012",
					LAD13CDO: "00AM",
					LAD13NM: "Hackney",
					LAD13NMW: null
				},
				id: "E09000012"
			},
			{
				arcs: [
					[
						3113,
						3114,
						3115,
						3116,
						3117,
						-3093,
						-3076
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E09000013",
					LAD13CDO: "00AN",
					LAD13NM: "Hammersmith and Fulham",
					LAD13NMW: null
				},
				id: "E09000013"
			},
			{
				arcs: [
					[
						3118,
						-3113,
						3119,
						-3089,
						-3056,
						-3098
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E09000014",
					LAD13CDO: "00AP",
					LAD13NM: "Haringey",
					LAD13NMW: null
				},
				id: "E09000014"
			},
			{
				arcs: [
					[
						-3078,
						-3096,
						3120,
						-1347,
						-1336,
						-3060
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E09000015",
					LAD13CDO: "00AQ",
					LAD13NM: "Harrow",
					LAD13NMW: null
				},
				id: "E09000015"
			},
			{
				arcs: [
					[
						-400,
						3121,
						-3053,
						3122,
						-1135,
						-1081
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E09000016",
					LAD13CDO: "00AR",
					LAD13NM: "Havering",
					LAD13NMW: null
				},
				id: "E09000016"
			},
			{
				arcs: [
					[
						-3121,
						-3095,
						3123,
						3124,
						-2678,
						-443,
						-442,
						-672,
						-671,
						-1348
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E09000017",
					LAD13CDO: "00AS",
					LAD13NM: "Hillingdon",
					LAD13NMW: null
				},
				id: "E09000017"
			},
			{
				arcs: [
					[
						-3118,
						3125,
						3126,
						-2679,
						-3125,
						-3124,
						-3094
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E09000018",
					LAD13CDO: "00AT",
					LAD13NM: "Hounslow",
					LAD13NMW: null
				},
				id: "E09000018"
			},
			{
				arcs: [
					[
						-3112,
						-3039,
						-3087,
						-3120
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E09000019",
					LAD13CDO: "00AU",
					LAD13NM: "Islington",
					LAD13NMW: null
				},
				id: "E09000019"
			},
			{
				arcs: [
					[
						3127,
						3128,
						-3116,
						3129,
						-3114,
						-3075
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E09000020",
					LAD13CDO: "00AW",
					LAD13NM: "Kensington and Chelsea",
					LAD13NMW: null
				},
				id: "E09000020"
			},
			{
				arcs: [
					[
						3130,
						-2651,
						-2669,
						-2638,
						-2637,
						3131,
						3132,
						3133,
						3134
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E09000021",
					LAD13CDO: "00AX",
					LAD13NM: "Kingston upon Thames",
					LAD13NMW: null
				},
				id: "E09000021"
			},
			{
				arcs: [
					[
						3135,
						-3081,
						-3092,
						3136,
						3137,
						3138
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E09000022",
					LAD13CDO: "00AY",
					LAD13NM: "Lambeth",
					LAD13NMW: null
				},
				id: "E09000022"
			},
			{
				arcs: [
					[
						3139,
						-3099,
						3140,
						-3105,
						3141,
						-3103,
						-3102,
						-3085,
						-3084,
						-3083,
						3142,
						3143,
						3144
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E09000023",
					LAD13CDO: "00AZ",
					LAD13NM: "Lewisham",
					LAD13NMW: null
				},
				id: "E09000023"
			},
			{
				arcs: [
					[
						3145,
						-3137,
						-3091,
						3146,
						-3135,
						3147
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E09000024",
					LAD13CDO: "00BA",
					LAD13NM: "Merton",
					LAD13NMW: null
				},
				id: "E09000024"
			},
			{
				arcs: [
					[
						-3041,
						3148,
						3149,
						3150,
						3151,
						3152,
						3153,
						3154,
						3155,
						3156,
						3157,
						3158,
						3159,
						3160,
						3161,
						-3110,
						3162,
						3163,
						3164
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E09000025",
					LAD13CDO: "00BB",
					LAD13NM: "Newham",
					LAD13NMW: null
				},
				id: "E09000025"
			},
			{
				arcs: [
					[
						-3123,
						-3052,
						-3042,
						-3165,
						3165,
						-1137,
						-1136
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E09000026",
					LAD13CDO: "00BC",
					LAD13NM: "Redbridge",
					LAD13NMW: null
				},
				id: "E09000026"
			},
			{
				arcs: [
					[
						3168,
						-3133,
						-3132,
						-2647,
						-2680,
						-3127,
						3169,
						3170
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E09000027",
					LAD13CDO: "00BD",
					LAD13NM: "Richmond upon Thames",
					LAD13NMW: null
				},
				id: "E09000027"
			},
			{
				arcs: [
					[
						-3145,
						-3144,
						-3143,
						-3082,
						-3136,
						3171
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E09000028",
					LAD13CDO: "00BE",
					LAD13NM: "Southwark",
					LAD13NMW: null
				},
				id: "E09000028"
			},
			{
				arcs: [
					[
						-3090,
						-2673,
						-2648,
						-3131,
						-3147
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E09000029",
					LAD13CDO: "00BF",
					LAD13NM: "Sutton",
					LAD13NMW: null
				},
				id: "E09000029"
			},
			{
				arcs: [
					[
						-3162,
						-3161,
						3172,
						3173,
						3174,
						3175,
						3176,
						-3153,
						3177,
						3178,
						-3035,
						-3111
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E09000030",
					LAD13CDO: "00BG",
					LAD13NM: "Tower Hamlets",
					LAD13NMW: null
				},
				id: "E09000030"
			},
			{
				arcs: [
					[
						-3166,
						-3164,
						-3163,
						-3109,
						-3119,
						-3097,
						-1138
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E09000031",
					LAD13CDO: "00BH",
					LAD13NM: "Waltham Forest",
					LAD13NMW: null
				},
				id: "E09000031"
			},
			{
				arcs: [
					[
						-3146,
						-3148,
						-3134,
						-3169,
						3179,
						-3138
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E09000032",
					LAD13CDO: "00BJ",
					LAD13NM: "Wandsworth",
					LAD13NMW: null
				},
				id: "E09000032"
			},
			{
				arcs: [
					[
						-3037,
						3180,
						-3128,
						-3074,
						-3088
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "E09000033",
					LAD13CDO: "00BK",
					LAD13NM: "Westminster",
					LAD13NMW: null
				},
				id: "E09000033"
			},
			{
				arcs: [
					[
						3181,
						3182,
						3183,
						3184,
						3185
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "S12000005",
					LAD13CDO: "00QF",
					LAD13NM: "Clackmannanshire",
					LAD13NMW: null
				},
				id: "S12000005"
			},
			{
				arcs: [
					[
						3186,
						-747,
						3187,
						3188,
						3189,
						3190,
						3191,
						3192,
						3193,
						3194,
						3195,
						3196,
						3197,
						3198,
						3199,
						3200
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "S12000006",
					LAD13CDO: "00QH",
					LAD13NM: "Dumfries and Galloway",
					LAD13NMW: null
				},
				id: "S12000006"
			},
			{
				arcs: [
					[
						3201,
						3202,
						3203,
						3204,
						-3200,
						-3199,
						-3198,
						-3197,
						-3196,
						-3195,
						-3194,
						-3193,
						3205,
						3206,
						3207,
						3208,
						3209,
						3210,
						3211,
						3212
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "S12000008",
					LAD13CDO: "00QK",
					LAD13NM: "East Ayrshire",
					LAD13NMW: null
				},
				id: "S12000008"
			},
			{
				arcs: [
					[
						3213,
						3214,
						3215,
						3216,
						3217,
						3218,
						3219,
						3220,
						3221
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "S12000010",
					LAD13CDO: "00QM",
					LAD13NM: "East Lothian",
					LAD13NMW: null
				},
				id: "S12000010"
			},
			{
				arcs: [
					[
						3222,
						3223,
						3224,
						3225,
						3226,
						-3202,
						-3213,
						3227,
						3228,
						3229
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "S12000011",
					LAD13CDO: "00QN",
					LAD13NM: "East Renfrewshire",
					LAD13NMW: null
				},
				id: "S12000011"
			},
			{
				arcs: [
					[
						[
							3230
						]
					],
					[
						[
							3231,
							3232
						]
					],
					[
						[
							3236,
							3237
						]
					],
					[
						[
							3240,
							3241
						]
					],
					[
						[
							3242,
							3243,
							3244
						]
					],
					[
						[
							3245
						]
					],
					[
						[
							3248,
							-3247,
							3249
						]
					],
					[
						[
							3252,
							3253,
							3254
						]
					],
					[
						[
							3258
						]
					],
					[
						[
							3259,
							3260,
							3261
						]
					],
					[
						[
							3262,
							3263,
							3264
						]
					],
					[
						[
							3272,
							-3267,
							3273
						]
					],
					[
						[
							3276
						]
					],
					[
						[
							3277
						]
					],
					[
						[
							3278,
							3279,
							3280,
							3281,
							3282,
							3283,
							3284,
							3285,
							3286,
							-3251,
							3287,
							3288,
							3289,
							3290,
							3291,
							3292
						]
					],
					[
						[
							3293
						]
					],
					[
						[
							3299,
							3300,
							3301
						]
					],
					[
						[
							3302,
							3303
						]
					],
					[
						[
							3310,
							3311,
							3312
						]
					],
					[
						[
							3313,
							3314,
							3315
						]
					],
					[
						[
							3316,
							3317,
							3318
						]
					],
					[
						[
							3327,
							3328,
							-3326
						]
					],
					[
						[
							3329,
							3330,
							3331
						]
					],
					[
						[
							3339,
							3340,
							3341
						]
					],
					[
						[
							3354,
							3355,
							3356
						]
					],
					[
						[
							3357,
							3358,
							3359
						]
					],
					[
						[
							3362,
							3363,
							3364
						]
					],
					[
						[
							3369,
							-3351,
							3370,
							3371,
							3372
						]
					],
					[
						[
							3375,
							3376,
							3377,
							3378,
							-3344,
							3379,
							3380,
							3381,
							-3340,
							3382,
							3383,
							3384,
							3385,
							3386,
							3387,
							3388,
							3389,
							3390,
							3391,
							3392,
							-3321,
							3393,
							3394,
							3395,
							3396,
							3397,
							3398,
							3399,
							3400,
							-3303,
							3401,
							3402,
							3403
						]
					],
					[
						[
							3404,
							3405,
							3406
						]
					],
					[
						[
							3411,
							3412,
							3413,
							3414,
							3415,
							3416
						]
					],
					[
						[
							3421,
							3422,
							3423
						]
					],
					[
						[
							3440,
							3441,
							3442
						]
					],
					[
						[
							3451,
							3452,
							3453
						]
					],
					[
						[
							3454,
							3455,
							3456,
							-3445,
							3457
						]
					],
					[
						[
							3459,
							3460
						]
					],
					[
						[
							3463
						]
					],
					[
						[
							3466,
							3467
						]
					],
					[
						[
							3468,
							3469,
							3470,
							3471,
							3472,
							3473,
							3474,
							3475,
							3476,
							-3434,
							3477,
							3478,
							3479,
							3480,
							3481,
							3482,
							-3427,
							3483,
							3484,
							-3418,
							3485,
							3486,
							3487,
							3488,
							3489,
							3490,
							3491,
							3492,
							3493,
							3494,
							3495,
							3496,
							3497,
							-3404,
							3498
						]
					],
					[
						[
							3499
						]
					],
					[
						[
							3500,
							-3467,
							3501,
							3502,
							3503,
							3504,
							3505,
							3506
						]
					],
					[
						[
							3515,
							3516
						]
					],
					[
						[
							3519,
							3520,
							3521,
							3522,
							3523,
							3524,
							3525,
							3526,
							3527
						]
					],
					[
						[
							3536
						]
					],
					[
						[
							3537,
							3538,
							3539
						]
					],
					[
						[
							-3540,
							3540,
							3541,
							3542
						]
					],
					[
						[
							3545
						]
					],
					[
						[
							3546,
							3547,
							3548
						]
					],
					[
						[
							-3550,
							3553,
							3554,
							3555
						]
					],
					[
						[
							3558
						]
					],
					[
						[
							3567,
							3568,
							3569
						]
					],
					[
						[
							3576,
							3577,
							3578,
							3579,
							3580,
							3581,
							3582
						]
					],
					[
						[
							3586
						]
					],
					[
						[
							3594,
							3595,
							3596
						]
					],
					[
						[
							3597
						]
					],
					[
						[
							3608,
							3609,
							3610
						]
					],
					[
						[
							3614
						]
					],
					[
						[
							3615,
							3616,
							3617,
							-3584,
							3618,
							3619,
							3620,
							3621,
							3622,
							3623,
							-3578,
							3624,
							3625,
							3626,
							3627,
							3628,
							3629,
							3630,
							-3560,
							3631,
							3632,
							3633,
							3634,
							3635,
							3636,
							3637,
							3638,
							3639,
							3640,
							3641,
							3642,
							3643,
							3644,
							3645,
							3646,
							3647,
							3648,
							-3517,
							3649,
							-3518,
							3650,
							3651,
							3652,
							3653,
							3654,
							3655,
							3656,
							3657,
							3658,
							3574,
							3659,
							3660,
							3661,
							3662,
							3663,
							3664,
							3665,
							3666
						]
					],
					[
						[
							3667,
							3668,
							3669
						]
					],
					[
						[
							3670
						]
					],
					[
						[
							3673
						]
					],
					[
						[
							3676
						]
					],
					[
						[
							3679,
							3680,
							3681
						]
					],
					[
						[
							3682,
							3683,
							3684,
							3685
						]
					],
					[
						[
							3687
						]
					],
					[
						[
							3688,
							3689,
							3690
						]
					],
					[
						[
							3691,
							3692,
							3693,
							3694
						]
					],
					[
						[
							3696
						]
					],
					[
						[
							3697
						]
					],
					[
						[
							3700,
							-3700,
							3701,
							3702
						]
					],
					[
						[
							3704,
							3705
						]
					],
					[
						[
							3708
						]
					],
					[
						[
							3712
						]
					],
					[
						[
							3720,
							-3717,
							3721,
							3722,
							3723,
							3724,
							3725
						]
					],
					[
						[
							3730,
							3731
						]
					],
					[
						[
							3736,
							3737
						]
					],
					[
						[
							3738
						]
					],
					[
						[
							3741,
							-3740,
							3742
						]
					],
					[
						[
							3743,
							3744
						]
					],
					[
						[
							3745,
							3746,
							3747
						]
					],
					[
						[
							3751,
							3752,
							3753
						]
					],
					[
						[
							3767
						]
					],
					[
						[
							3768
						]
					],
					[
						[
							3769,
							3770
						]
					],
					[
						[
							3773,
							3774
						]
					],
					[
						[
							3779,
							3780
						]
					],
					[
						[
							3781,
							3782,
							-3770,
							3783,
							3784,
							3785
						]
					],
					[
						[
							3788,
							3789,
							3790
						]
					],
					[
						[
							3795,
							-3794,
							3796
						]
					],
					[
						[
							3799,
							-3789,
							3800,
							3801
						]
					],
					[
						[
							3809,
							3810,
							3811
						]
					],
					[
						[
							-3813,
							3814,
							3815
						]
					],
					[
						[
							3816,
							3817,
							3818
						]
					],
					[
						[
							3826,
							3827,
							3828
						]
					],
					[
						[
							3832,
							3833,
							3834
						]
					],
					[
						[
							3835,
							3836,
							3837
						]
					],
					[
						[
							3850,
							3851
						]
					],
					[
						[
							3852,
							3853
						]
					],
					[
						[
							3854,
							-3855,
							3855,
							3856,
							3857,
							3858,
							3859,
							3860,
							3861,
							3862,
							3863,
							3864,
							3865,
							3866,
							3777,
							3867,
							3868,
							3869,
							-3758,
							3870,
							3871,
							3872,
							3873,
							3874,
							3875,
							3876,
							3877,
							3878,
							3879,
							3880,
							3881,
							3882,
							3883,
							3884,
							3885,
							3886,
							3887,
							-3672,
							3888,
							3889,
							-3683,
							3890,
							-3715,
							3891,
							-3733,
							3892,
							3893,
							3894,
							3895,
							3896,
							3897,
							3898,
							3899,
							3900,
							3901,
							-3766,
							3902,
							3903,
							3904,
							3905,
							3906,
							3907,
							3908,
							3909,
							3910,
							3911,
							-3788,
							3912,
							3913,
							3914,
							3915,
							3916,
							3917,
							-3827,
							3918,
							3919,
							-3833,
							3920,
							-3836,
							3921,
							3922,
							3923,
							3924,
							3925,
							3926,
							3927,
							3928,
							3929,
							3930,
							3931,
							-3847,
							3932,
							3933,
							3934,
							-3853,
							3935,
							3936,
							3937
						],
						[
							3709,
							3710,
							3711
						]
					],
					[
						[
							3938,
							3939
						]
					],
					[
						[
							3941
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "S12000013",
					LAD13CDO: "00RJ",
					LAD13NM: "Eilean Siar",
					LAD13NMW: null
				},
				id: "S12000013"
			},
			{
				arcs: [
					[
						3942,
						3943,
						3944,
						3945,
						3946,
						3947,
						3948
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "S12000014",
					LAD13CDO: "00QQ",
					LAD13NM: "Falkirk",
					LAD13NMW: null
				},
				id: "S12000014"
			},
			{
				arcs: [
					[
						[
							3949,
							3950
						]
					],
					[
						[
							3953,
							-3183,
							3954,
							3955,
							3956
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "S12000015",
					LAD13CDO: "00QR",
					LAD13NM: "Fife",
					LAD13NMW: null
				},
				id: "S12000015"
			},
			{
				arcs: [
					[
						[
							3961
						]
					],
					[
						[
							3962,
							3963,
							-3960,
							3964
						]
					],
					[
						[
							3965,
							3966,
							3967
						]
					],
					[
						[
							-3971,
							3974,
							-3974,
							3975
						]
					],
					[
						[
							3976
						]
					],
					[
						[
							3981
						]
					],
					[
						[
							-3983,
							3984,
							3985
						]
					],
					[
						[
							3986
						]
					],
					[
						[
							3987,
							3988
						]
					],
					[
						[
							3989,
							3990
						]
					],
					[
						[
							3991
						]
					],
					[
						[
							3992
						]
					],
					[
						[
							3993
						]
					],
					[
						[
							3994
						]
					],
					[
						[
							3995
						]
					],
					[
						[
							3996
						]
					],
					[
						[
							3997
						]
					],
					[
						[
							3998
						]
					],
					[
						[
							3999
						]
					],
					[
						[
							4000
						]
					],
					[
						[
							4002
						]
					],
					[
						[
							4003
						]
					],
					[
						[
							4004,
							4005,
							4006,
							4007
						]
					],
					[
						[
							4010
						]
					],
					[
						[
							4013
						]
					],
					[
						[
							4014
						]
					],
					[
						[
							4022,
							-4018,
							4023
						]
					],
					[
						[
							4024
						]
					],
					[
						[
							4025
						]
					],
					[
						[
							4026,
							4027
						]
					],
					[
						[
							4028
						]
					],
					[
						[
							4034
						]
					],
					[
						[
							4037,
							4038
						]
					],
					[
						[
							4041
						]
					],
					[
						[
							4046,
							4047,
							4048
						]
					],
					[
						[
							4055
						]
					],
					[
						[
							4062,
							4063
						]
					],
					[
						[
							4085
						]
					],
					[
						[
							4090,
							4091,
							4092
						]
					],
					[
						[
							4095
						]
					],
					[
						[
							4098,
							4099
						]
					],
					[
						[
							4112,
							4113,
							-4082,
							4114,
							-4040,
							4115,
							4116,
							4117,
							4118,
							-4008,
							4119,
							4120,
							4121,
							4122,
							4123,
							4124,
							4125,
							4126,
							4127,
							4128,
							4129,
							4130,
							4131,
							4132,
							4133,
							4134,
							4135,
							4136,
							4137,
							4138,
							4139,
							4140,
							4141,
							4142,
							4143,
							4144,
							4145,
							4146,
							-4009,
							4147,
							4148,
							4149,
							4150,
							4151,
							4152,
							4153,
							4154,
							4155,
							-4051,
							4156,
							4157,
							4158,
							4159,
							-4066,
							4160,
							4161,
							4162,
							4163,
							4164,
							4165,
							4166,
							4167,
							4168,
							4169,
							4170,
							4171,
							4172,
							4173,
							4174,
							4175,
							4176,
							4177,
							-4084,
							4178,
							4179,
							4180,
							4181,
							4182,
							4183,
							4184,
							4185,
							4186,
							4187,
							4188,
							4189,
							4190,
							-4097,
							4191,
							4192,
							4193,
							4194,
							4195,
							4196,
							4197,
							4198
						]
					],
					[
						[
							4199,
							4200
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "S12000017",
					LAD13CDO: "00QT",
					LAD13NM: "Highland",
					LAD13NMW: null
				},
				id: "S12000017"
			},
			{
				arcs: [
					[
						4201,
						4202,
						4203,
						4204,
						4205
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "S12000018",
					LAD13CDO: "00QU",
					LAD13NM: "Inverclyde",
					LAD13NMW: null
				},
				id: "S12000018"
			},
			{
				arcs: [
					[
						-3220,
						-3219,
						-3218,
						-3217,
						4206,
						4207,
						4208
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "S12000019",
					LAD13CDO: "00QW",
					LAD13NM: "Midlothian",
					LAD13NMW: null
				},
				id: "S12000019"
			},
			{
				arcs: [
					[
						4209,
						4210,
						4211,
						-4128,
						-4127,
						-4126,
						-4125,
						-4124,
						-4123,
						4212,
						4213
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "S12000020",
					LAD13CDO: "00QX",
					LAD13NM: "Moray",
					LAD13NMW: null
				},
				id: "S12000020"
			},
			{
				arcs: [
					[
						[
							4214
						]
					],
					[
						[
							-4216,
							4217,
							4218
						]
					],
					[
						[
							4219
						]
					],
					[
						[
							4220
						]
					],
					[
						[
							-4203,
							4221,
							-3228,
							-3212,
							-3211,
							4222,
							4223,
							-4205,
							-4204
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "S12000021",
					LAD13CDO: "00QY",
					LAD13NM: "North Ayrshire",
					LAD13NMW: null
				},
				id: "S12000021"
			},
			{
				arcs: [
					[
						[
							4224
						]
					],
					[
						[
							4225,
							4226
						]
					],
					[
						[
							4227
						]
					],
					[
						[
							4228
						]
					],
					[
						[
							4229
						]
					],
					[
						[
							4230
						]
					],
					[
						[
							4231
						]
					],
					[
						[
							4232,
							4233
						]
					],
					[
						[
							4234
						]
					],
					[
						[
							4238,
							4239,
							4240
						]
					],
					[
						[
							4243
						]
					],
					[
						[
							4244
						]
					],
					[
						[
							4247
						]
					],
					[
						[
							4248
						]
					],
					[
						[
							4251,
							4252,
							4253
						]
					],
					[
						[
							4254
						]
					],
					[
						[
							4260
						]
					],
					[
						[
							4261
						]
					],
					[
						[
							4262
						]
					],
					[
						[
							4263,
							4264,
							4265,
							4266,
							4267,
							-4241,
							4268,
							-4243,
							4269,
							4270,
							4271,
							4272,
							-4256,
							4273
						]
					],
					[
						[
							-4260,
							4274,
							-4251,
							4275,
							4276
						]
					],
					[
						[
							4277
						]
					],
					[
						[
							4278,
							4279
						]
					],
					[
						[
							4280
						]
					],
					[
						[
							4282
						]
					],
					[
						[
							4283
						]
					],
					[
						[
							4291
						]
					],
					[
						[
							4292
						]
					],
					[
						[
							4295,
							4296
						]
					],
					[
						[
							4297
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "S12000023",
					LAD13CDO: "00RA",
					LAD13NM: "Orkney Islands",
					LAD13NMW: null
				},
				id: "S12000023"
			},
			{
				arcs: [
					[
						4300,
						4301,
						4302,
						4303,
						4304,
						4305,
						4306,
						4307,
						4308,
						-3956,
						-3955,
						-3182,
						-3186,
						4309,
						4310,
						4311,
						-4130
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "S12000024",
					LAD13CDO: "00RB",
					LAD13NM: "Perth and Kinross",
					LAD13NMW: null
				},
				id: "S12000024"
			},
			{
				arcs: [
					[
						-653,
						4314,
						-632,
						4315,
						4316,
						-649,
						-648,
						-748,
						-3187,
						4317,
						4318,
						4319,
						4320,
						-4208,
						-4207,
						-3216,
						-3215,
						-3214,
						4321
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "S12000026",
					LAD13CDO: "00QE",
					LAD13NM: "Scottish Borders",
					LAD13NMW: null
				},
				id: "S12000026"
			},
			{
				arcs: [
					[
						[
							4322,
							4323,
							4324
						]
					],
					[
						[
							4325,
							-4325,
							4326
						]
					],
					[
						[
							4331,
							4332,
							4333,
							4334,
							-4328,
							4335,
							4336,
							4337,
							4338
						]
					],
					[
						[
							4352,
							4353,
							4354
						]
					],
					[
						[
							4365,
							-4365,
							4366,
							4367,
							4368
						]
					],
					[
						[
							4369,
							-4369,
							4370
						]
					],
					[
						[
							4384
						]
					],
					[
						[
							4385
						]
					],
					[
						[
							4388
						]
					],
					[
						[
							4390,
							4391,
							4392,
							-4388,
							4393
						]
					],
					[
						[
							4396,
							4397
						]
					],
					[
						[
							4398,
							4399
						]
					],
					[
						[
							4405
						]
					],
					[
						[
							4406
						]
					],
					[
						[
							4413,
							4414,
							4415
						]
					],
					[
						[
							4418,
							-4395,
							4419,
							4420,
							4421
						]
					],
					[
						[
							4422
						]
					],
					[
						[
							4423,
							4424,
							4425
						]
					],
					[
						[
							4430,
							4431
						]
					],
					[
						[
							4438
						]
					],
					[
						[
							4452,
							4453
						]
					],
					[
						[
							4458,
							4459
						]
					],
					[
						[
							4460,
							4461
						]
					],
					[
						[
							4463,
							4464
						]
					],
					[
						[
							4465
						]
					],
					[
						[
							4466,
							4467,
							4468
						]
					],
					[
						[
							4471
						]
					],
					[
						[
							4472,
							4473,
							4474,
							-4468,
							4475,
							4476,
							4477,
							4478,
							4479,
							4480,
							4481
						]
					],
					[
						[
							4485
						]
					],
					[
						[
							4486
						]
					],
					[
						[
							4493
						]
					],
					[
						[
							4494,
							4495,
							4496,
							4497,
							4498,
							-4492,
							4499
						]
					],
					[
						[
							4500,
							4501
						]
					],
					[
						[
							4502,
							4503
						]
					],
					[
						[
							4504
						]
					],
					[
						[
							4507,
							4508
						]
					],
					[
						[
							4509,
							4510,
							4511
						]
					],
					[
						[
							4514
						]
					],
					[
						[
							4515
						]
					],
					[
						[
							4529,
							4530
						]
					],
					[
						[
							4531
						]
					],
					[
						[
							4534,
							4535,
							4536,
							4537,
							4538,
							-4522,
							4539,
							4540
						]
					],
					[
						[
							4542,
							4543,
							4544,
							4545,
							4546,
							4547,
							4548,
							4549,
							4550,
							4551,
							-4378,
							4552,
							4553,
							-4345,
							4554,
							4555,
							4556,
							-4341,
							4557,
							4558,
							4559,
							4560,
							-4348,
							4561,
							4562,
							4563,
							4564,
							4565,
							4566,
							4567,
							4568,
							4569,
							4570,
							4571,
							4572,
							-4360,
							4573,
							4574,
							4575,
							4576,
							4577,
							4578,
							4579,
							-4377,
							4580,
							-4380,
							4581,
							4582,
							-4384,
							4583,
							-4413,
							4584,
							4585,
							-4426,
							4586,
							4587,
							-4429,
							4588,
							4589,
							4590,
							-4441,
							4591,
							4592,
							4593,
							4594,
							4595,
							4596,
							4597,
							4598,
							-4455,
							4599,
							-4513,
							4600,
							4601,
							4602,
							-4518,
							4603,
							4604,
							4605,
							4606,
							4607,
							4608,
							4609,
							4610,
							-4526,
							4611,
							-4533,
							4612,
							4613,
							4614
						]
					],
					[
						[
							4616
						]
					],
					[
						[
							4617
						]
					],
					[
						[
							4618,
							4619,
							4620
						]
					],
					[
						[
							4625,
							4626,
							4627,
							4628,
							4629,
							4630,
							4631,
							4632,
							-4622,
							4633,
							4634
						]
					],
					[
						[
							-4627,
							4637
						]
					],
					[
						[
							4654,
							-4646,
							4655,
							-4644,
							4656,
							4657,
							4658,
							-4651,
							4659,
							4660,
							4661,
							4662
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "S12000027",
					LAD13CDO: "00RD",
					LAD13NM: "Shetland Islands",
					LAD13NMW: null
				},
				id: "S12000027"
			},
			{
				arcs: [
					[
						[
							4664
						]
					],
					[
						[
							-3209,
							-3208,
							-3207,
							-3206,
							-3192,
							-3191,
							-3190,
							4665,
							-4223,
							-3210
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "S12000028",
					LAD13CDO: "00RE",
					LAD13NM: "South Ayrshire",
					LAD13NMW: null
				},
				id: "S12000028"
			},
			{
				arcs: [
					[
						4666,
						4667,
						-4319,
						-4318,
						-3201,
						-3205,
						-3204,
						-3203,
						-3227,
						-3226,
						-3225,
						-3224,
						-3223,
						4668,
						4669,
						4670,
						4671,
						4672,
						4673,
						4674
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "S12000029",
					LAD13CDO: "00RF",
					LAD13NM: "South Lanarkshire",
					LAD13NMW: null
				},
				id: "S12000029"
			},
			{
				arcs: [
					[
						-4310,
						-3185,
						4675,
						-3948,
						4676,
						4677,
						4678,
						4679,
						4680,
						4681,
						4682,
						-4311
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "S12000030",
					LAD13CDO: "00RG",
					LAD13NM: "Stirling",
					LAD13NMW: null
				},
				id: "S12000030"
			},
			{
				arcs: [
					[
						4689,
						-4689,
						4690,
						-4686,
						4691,
						4692,
						4693,
						4694,
						4695,
						4696
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "S12000033",
					LAD13CDO: "00QA",
					LAD13NM: "Aberdeen City",
					LAD13NMW: null
				},
				id: "S12000033"
			},
			{
				arcs: [
					[
						[
							4699,
							4700,
							4701
						]
					],
					[
						[
							4706,
							4707,
							4708
						]
					],
					[
						[
							4711,
							4712,
							4713,
							4714
						]
					],
					[
						[
							4715,
							4716
						]
					],
					[
						[
							4719,
							4720,
							4721
						]
					],
					[
						[
							4722,
							4723
						]
					],
					[
						[
							4724,
							4725,
							4726,
							4727,
							-4716,
							4728,
							-4718,
							4729,
							4730,
							4731,
							4732,
							4733,
							4734,
							4735,
							4736,
							-4715,
							-4714,
							4737,
							4738,
							4739,
							-4710,
							4740,
							4741,
							-4708,
							4742,
							-4705,
							4743,
							4744,
							4745,
							4746,
							4747,
							4748,
							4749,
							4750,
							-4701,
							4751,
							-4697,
							4752,
							-4699,
							4753,
							4754,
							4755,
							4756,
							-4301,
							-4129,
							-4212,
							-4211,
							4757
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "S12000034",
					LAD13CDO: "00QB",
					LAD13NM: "Aberdeenshire",
					LAD13NMW: null
				},
				id: "S12000034"
			},
			{
				arcs: [
					[
						[
							4758
						]
					],
					[
						[
							4762
						]
					],
					[
						[
							4778,
							-4778,
							4779,
							4780
						]
					],
					[
						[
							4800,
							4801,
							4802,
							4803,
							4804,
							4805,
							4806,
							4807,
							4808,
							4809,
							4810
						]
					],
					[
						[
							4813
						]
					],
					[
						[
							4824
						]
					],
					[
						[
							4827,
							4828,
							4829,
							4830,
							4831,
							4832,
							4833,
							4834,
							4835,
							-4799,
							4836,
							4837,
							-4813,
							4838,
							4839,
							4840,
							4841,
							4842,
							4843,
							-4821,
							4844
						],
						[
							-4795,
							4795
						]
					],
					[
						[
							-4826,
							4845,
							4846,
							4847
						]
					],
					[
						[
							4850,
							4851,
							4852
						]
					],
					[
						[
							4867
						]
					],
					[
						[
							4874
						]
					],
					[
						[
							4877,
							4878,
							4879,
							4880,
							4881,
							4882,
							4883,
							4884,
							4885,
							-4853,
							4886,
							4887,
							4888,
							4889,
							-4856,
							4890,
							4891
						]
					],
					[
						[
							4895,
							-4893,
							4896
						]
					],
					[
						[
							4897
						]
					],
					[
						[
							4900,
							4901
						]
					],
					[
						[
							4904,
							4905,
							4906
						]
					],
					[
						[
							4907
						]
					],
					[
						[
							4908,
							4909
						]
					],
					[
						[
							4910,
							4911
						]
					],
					[
						[
							4933,
							4934,
							4935
						]
					],
					[
						[
							4936,
							4937
						]
					],
					[
						[
							4938,
							4939,
							4940
						]
					],
					[
						[
							4941,
							4942,
							4943
						]
					],
					[
						[
							4946,
							4947
						]
					],
					[
						[
							4950,
							4951,
							4952
						]
					],
					[
						[
							4955,
							4956,
							4957
						]
					],
					[
						[
							4960,
							4961,
							4962
						]
					],
					[
						[
							4965,
							4966
						]
					],
					[
						[
							4967,
							4968
						]
					],
					[
						[
							4976
						]
					],
					[
						[
							4977
						]
					],
					[
						[
							4978,
							4979
						]
					],
					[
						[
							4988,
							4989,
							4990,
							4991
						]
					],
					[
						[
							4992,
							4993,
							4994,
							4995,
							4996
						]
					],
					[
						[
							4999
						]
					],
					[
						[
							5000
						]
					],
					[
						[
							5009
						]
					],
					[
						[
							-4683,
							-4682,
							-4681,
							5010,
							5011,
							5012,
							5013,
							5014,
							5015,
							5016,
							5017,
							5018,
							-4866,
							5019,
							5020,
							5021,
							5022,
							5023,
							5024,
							5025,
							5026,
							5027,
							5028,
							5029,
							5030,
							-4131,
							-4312
						]
					],
					[
						[
							5031,
							5032,
							5033,
							5034,
							5035
						]
					],
					[
						[
							5036,
							-4133
						]
					],
					[
						[
							-5038,
							5041
						]
					],
					[
						[
							5042,
							5043,
							5044,
							5045,
							5046,
							5047,
							5048,
							5049,
							5050,
							5051,
							5052,
							5053,
							5054,
							5055,
							5056,
							5057,
							5058,
							-4948,
							5059,
							5060,
							5061,
							5062,
							5063,
							5064,
							5065,
							5066,
							5067,
							5068,
							5069,
							-4964,
							5070,
							5071,
							4960,
							5072,
							5073,
							5074,
							5075
						]
					],
					[
						[
							5078,
							5079,
							5080,
							5081
						]
					],
					[
						[
							5082,
							5083,
							5084,
							5085,
							5086,
							5087,
							5088,
							5089,
							5090,
							5091,
							5079,
							5092,
							5093,
							5094,
							5095
						]
					],
					[
						[
							5098
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "S12000035",
					LAD13CDO: "00QD",
					LAD13NM: "Argyll and Bute",
					LAD13NMW: null
				},
				id: "S12000035"
			},
			{
				arcs: [
					[
						-3221,
						-4209,
						-4321,
						5102,
						5103
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "S12000036",
					LAD13CDO: "00QP",
					LAD13NM: "City of Edinburgh",
					LAD13NMW: null
				},
				id: "S12000036"
			},
			{
				arcs: [
					[
						5104,
						-3229,
						-4222,
						-4202,
						5105
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "S12000038",
					LAD13CDO: "00RC",
					LAD13NM: "Renfrewshire",
					LAD13NMW: null
				},
				id: "S12000038"
			},
			{
				arcs: [
					[
						-4679,
						5106,
						5107,
						5108,
						-5011,
						-4680
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "S12000039",
					LAD13CDO: "00QG",
					LAD13NM: "West Dunbartonshire",
					LAD13NMW: null
				},
				id: "S12000039"
			},
			{
				arcs: [
					[
						-5103,
						-4320,
						-4668,
						5109,
						-3946,
						-3945,
						-3944,
						-3943,
						5110
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "S12000040",
					LAD13CDO: "00RH",
					LAD13NM: "West Lothian",
					LAD13NMW: null
				},
				id: "S12000040"
			},
			{
				arcs: [
					[
						5111,
						5112,
						5113,
						5114,
						5115,
						-4305,
						-4304,
						-4303,
						-4302,
						-4757
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "S12000041",
					LAD13CDO: "00QC",
					LAD13NM: "Angus",
					LAD13NMW: null
				},
				id: "S12000041"
			},
			{
				arcs: [
					[
						5116,
						-4306,
						-5116,
						-5115
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "S12000042",
					LAD13CDO: "00QJ",
					LAD13NM: "Dundee City",
					LAD13NMW: null
				},
				id: "S12000042"
			},
			{
				arcs: [
					[
						-3947,
						-5110,
						-4667,
						5117,
						5118,
						-4677
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "S12000044",
					LAD13CDO: "00QZ",
					LAD13NM: "North Lanarkshire",
					LAD13NMW: null
				},
				id: "S12000044"
			},
			{
				arcs: [
					[
						-5119,
						5119,
						-5107,
						-4678
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "S12000045",
					LAD13CDO: "00QL",
					LAD13NM: "East Dunbartonshire",
					LAD13NMW: null
				},
				id: "S12000045"
			},
			{
				arcs: [
					[
						[
							5120,
							-4669,
							-3230,
							-5105,
							5121
						]
					],
					[
						[
							-5118,
							-4675,
							5122,
							-4673,
							5123,
							5124,
							5125,
							5126,
							-5108,
							-5120
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "S12000046",
					LAD13CDO: "00QS",
					LAD13NM: "Glasgow City",
					LAD13NMW: null
				},
				id: "S12000046"
			},
			{
				arcs: [
					[
						[
							5132
						]
					],
					[
						[
							5135,
							5136,
							5137,
							5138,
							-5131,
							5139,
							5140,
							5141
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "W06000001",
					LAD13CDO: "00NA",
					LAD13NM: "Isle of Anglesey",
					LAD13NMW: "Ynys Mon"
				},
				id: "W06000001"
			},
			{
				arcs: [
					[
						[
							5142
						]
					],
					[
						[
							5143,
							5144,
							5145,
							5146,
							5147,
							5148,
							5149,
							5150,
							5151,
							5152,
							5153,
							5154,
							5155,
							5156,
							5157,
							5158
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "W06000002",
					LAD13CDO: "00NC",
					LAD13NM: "Gwynedd",
					LAD13NMW: "Gwynedd"
				},
				id: "W06000002"
			},
			{
				arcs: [
					[
						5159,
						5160,
						5161,
						-5144,
						-5159,
						5162
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "W06000003",
					LAD13CDO: "00NE",
					LAD13NM: "Conwy",
					LAD13NMW: "Conwy"
				},
				id: "W06000003"
			},
			{
				arcs: [
					[
						5165,
						5166,
						-5145,
						-5162,
						-5161,
						-5160,
						5167,
						5168,
						5169,
						5170
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "W06000004",
					LAD13CDO: "00NG",
					LAD13NM: "Denbighshire",
					LAD13NMW: "Sir Ddinbych"
				},
				id: "W06000004"
			},
			{
				arcs: [
					[
						[
							5171,
							5172,
							-530,
							5173
						]
					],
					[
						[
							5174,
							-5174,
							-529,
							5175,
							5176
						]
					],
					[
						[
							-534,
							5179,
							5180
						]
					],
					[
						[
							-5181,
							5181,
							-535
						]
					],
					[
						[
							5182,
							-528,
							-527,
							5183,
							-5171,
							5184
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "W06000005",
					LAD13CDO: "00NJ",
					LAD13NM: "Flintshire",
					LAD13NMW: "Sir y Fflint"
				},
				id: "W06000005"
			},
			{
				arcs: [
					[
						-525,
						-524,
						-523,
						-558,
						-557,
						-556,
						5185,
						-5166,
						-5184,
						-526
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "W06000006",
					LAD13CDO: "00NL",
					LAD13NM: "Wrexham",
					LAD13NMW: "Wrecsam"
				},
				id: "W06000006"
			},
			{
				arcs: [
					[
						[
							5186,
							5187,
							5188,
							5189
						]
					],
					[
						[
							5190,
							5191,
							5192,
							5193,
							5194,
							5195,
							5196,
							5197,
							5198,
							5199,
							5200,
							5201,
							5202,
							5203,
							5204,
							5205
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "W06000008",
					LAD13CDO: "00NQ",
					LAD13NM: "Ceredigion",
					LAD13NMW: "Ceredigion"
				},
				id: "W06000008"
			},
			{
				arcs: [
					[
						[
							5206
						]
					],
					[
						[
							5209,
							-5208,
							5210
						]
					],
					[
						[
							5212
						]
					],
					[
						[
							5213,
							5214,
							5215
						]
					],
					[
						[
							5216,
							-5214,
							5217
						]
					],
					[
						[
							-5219,
							5224,
							5225,
							5226
						]
					],
					[
						[
							-5189,
							-5188,
							5227,
							5228,
							-5203,
							5229,
							5230,
							5231,
							5232,
							-5198,
							5233,
							5234,
							5235,
							5236,
							5237,
							5238,
							5239,
							5240,
							5241,
							-5217,
							5242,
							5243,
							5244
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "W06000009",
					LAD13CDO: "00NS",
					LAD13NM: "Pembrokeshire",
					LAD13NMW: "Sir Benfro"
				},
				id: "W06000009"
			},
			{
				arcs: [
					[
						[
							5245,
							5246,
							5247,
							5248,
							5249,
							5250,
							5251
						]
					],
					[
						[
							5252,
							5253,
							5254,
							5255,
							5256,
							5257,
							5258,
							5259,
							5260,
							5261
						]
					],
					[
						[
							5262,
							5263,
							5264
						]
					],
					[
						[
							5265,
							5266,
							5267,
							5268,
							5269
						]
					],
					[
						[
							5270,
							5271,
							5272,
							5273,
							5274,
							5275,
							5276,
							5277,
							5278,
							5279,
							5280,
							5281,
							-5267,
							5282,
							-5283,
							5283,
							5284,
							5285
						]
					],
					[
						[
							5286,
							5287,
							5288,
							5289
						]
					],
					[
						[
							5290,
							5291,
							5292,
							5293,
							5294,
							5295,
							5296,
							5297,
							5298,
							5299,
							5300,
							5301,
							5302,
							5303,
							5304,
							-5276,
							5305,
							-5274,
							5306,
							5307,
							5308,
							5309,
							5310,
							5311,
							5256,
							5312,
							5313,
							5314,
							5315,
							5316,
							5317,
							5318,
							5319,
							5320,
							-5249,
							-5248,
							-5247,
							5321,
							5322,
							-5237,
							-5236,
							-5235,
							-5234,
							-5197,
							-5196
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "W06000010",
					LAD13CDO: "00NU",
					LAD13NM: "Carmarthenshire",
					LAD13NMW: "Sir Gaerfyrddin"
				},
				id: "W06000010"
			},
			{
				arcs: [
					[
						[
							5323,
							5324,
							5325
						]
					],
					[
						[
							5326,
							5327,
							5328
						]
					],
					[
						[
							5331,
							5332,
							5333,
							5334
						]
					],
					[
						[
							5335,
							5336,
							5337
						]
					],
					[
						[
							5338,
							-5338,
							5339,
							5340
						]
					],
					[
						[
							5341,
							5342,
							5343,
							5344
						]
					],
					[
						[
							5345,
							5346,
							5347,
							5348
						]
					],
					[
						[
							5349,
							5350,
							5351,
							5352,
							5353,
							5354
						]
					],
					[
						[
							5355,
							5356,
							5357,
							5358,
							5359,
							5360,
							5361,
							5362,
							5363,
							5364,
							-5337,
							5365,
							5366,
							5367,
							-5325,
							5368,
							5332,
							5369,
							-5335,
							5370,
							5371,
							5372,
							5373,
							-5350,
							5374,
							-5354,
							5375,
							5351,
							5376,
							5377,
							-5301,
							5378,
							-5299,
							5379,
							-5297,
							-5296,
							-5295,
							-5294
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "W06000011",
					LAD13CDO: "00NX",
					LAD13NM: "Swansea",
					LAD13NMW: "Abertawe"
				},
				id: "W06000011"
			},
			{
				arcs: [
					[
						5382,
						5383,
						5384,
						5385,
						-5357,
						-5356,
						-5293
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "W06000012",
					LAD13CDO: "00NZ",
					LAD13NM: "Neath Port Talbot",
					LAD13NMW: "Castell-nedd Port Talbot"
				},
				id: "W06000012"
			},
			{
				arcs: [
					[
						5386,
						5387,
						5388,
						5389,
						-5381,
						-5385
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "W06000013",
					LAD13CDO: "00PB",
					LAD13NM: "Bridgend",
					LAD13NMW: "Pen-y-bont ar Ogwr"
				},
				id: "W06000013"
			},
			{
				arcs: [
					[
						5390,
						5391,
						5392,
						5393,
						5394,
						5395,
						5396,
						-5389,
						5397
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "W06000014",
					LAD13CDO: "00PD",
					LAD13NM: "Vale of Glamorgan",
					LAD13NMW: "Bro Morgannwg"
				},
				id: "W06000014"
			},
			{
				arcs: [
					[
						5398,
						5399,
						5400,
						5401,
						5402,
						5403,
						5404,
						5405,
						-5391,
						5406,
						5407
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "W06000015",
					LAD13CDO: "00PT",
					LAD13NM: "Cardiff",
					LAD13NMW: "Caerdydd"
				},
				id: "W06000015"
			},
			{
				arcs: [
					[
						5408,
						5409,
						-5407,
						-5398,
						-5388,
						-5387,
						-5384,
						5410
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "W06000016",
					LAD13CDO: "00PF",
					LAD13NM: "Rhondda Cynon Taf",
					LAD13NMW: "Rhondda Cynon Taf"
				},
				id: "W06000016"
			},
			{
				arcs: [
					[
						5411,
						5412,
						-5408,
						-5410,
						5413,
						5414,
						5415,
						5416
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "W06000018",
					LAD13CDO: "00PK",
					LAD13NM: "Caerphilly",
					LAD13NMW: "Caerffili"
				},
				id: "W06000018"
			},
			{
				arcs: [
					[
						5417,
						5418,
						-5417,
						5419
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "W06000019",
					LAD13CDO: "00PL",
					LAD13NM: "Blaenau Gwent",
					LAD13NMW: "Blaenau Gwent"
				},
				id: "W06000019"
			},
			{
				arcs: [
					[
						5420,
						5421,
						5422,
						5423,
						-5412,
						-5419,
						5424
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "W06000020",
					LAD13CDO: "00PM",
					LAD13NM: "Torfaen",
					LAD13NMW: "Torfaen"
				},
				id: "W06000020"
			},
			{
				arcs: [
					[
						-1232,
						5425,
						5426,
						5427,
						5428,
						-1227,
						5429,
						5430,
						5431,
						5432,
						5433,
						5434,
						5435,
						5436,
						5437,
						5438,
						5439,
						5440,
						5441,
						5442,
						5443,
						5444,
						5445,
						5446,
						5447,
						5448,
						-5423,
						-5422,
						-5421,
						-5425,
						-5418,
						5449,
						-282
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "W06000021",
					LAD13CDO: "00PP",
					LAD13NM: "Monmouthshire",
					LAD13NMW: "Sir Fynwy"
				},
				id: "W06000021"
			},
			{
				arcs: [
					[
						[
							-5449,
							5450,
							5451,
							5452,
							5453,
							-5400,
							-5399,
							-5413,
							-5424
						]
					],
					[
						[
							5454,
							5455,
							-5445,
							5456,
							5457,
							5458,
							5459,
							-5440,
							5460,
							-5438,
							5461,
							-5436,
							5462,
							5463,
							5464,
							-5432
						]
					]
				],
				type: "MultiPolygon",
				properties: {
					LAD13CD: "W06000022",
					LAD13CDO: "00PR",
					LAD13NM: "Newport",
					LAD13NMW: "Casnewydd"
				},
				id: "W06000022"
			},
			{
				arcs: [
					[
						-555,
						-554,
						-553,
						-552,
						-551,
						-288,
						-287,
						-286,
						-285,
						-284,
						-283,
						-5450,
						-5420,
						-5416,
						5465,
						-5411,
						-5383,
						-5292,
						-5291,
						-5195,
						-5194,
						-5193,
						-5192,
						-5191,
						-5206,
						5466,
						5467,
						-5154,
						5468,
						5469,
						5470,
						5471,
						5472,
						-5148,
						-5147,
						-5146,
						-5167,
						-5186
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "W06000023",
					LAD13CDO: "00NN",
					LAD13NM: "Powys",
					LAD13NMW: "Powys"
				},
				id: "W06000023"
			},
			{
				arcs: [
					[
						-5415,
						-5414,
						-5409,
						-5466
					]
				],
				type: "Polygon",
				properties: {
					LAD13CD: "W06000024",
					LAD13CDO: "00PH",
					LAD13NM: "Merthyr Tydfil",
					LAD13NMW: "Merthyr Tudful"
				},
				id: "W06000024"
			}
		]
	}
};
var ukRegions = {
	type: type,
	arcs: arcs,
	transform: transform,
	objects: objects
};

function _templateObject6$1() {
  var data = _taggedTemplateLiteralLoose(["\n  border-radius: 4px;\n  display: flex;\n  flex-wrap: wrap;\n  flex-direction: column;\n  text-align: left;\n  width: max-content;\n  max-width: 250px;\n  white-space: pre-line;\n  font-size: 11px;\n  line-height: 18px;\n  color: #ffffff;\n  background-color: rgb(58, 57, 73);\n  box-shadow: rgb(25 25 39 / 25%) 0px 2px 6px 0px;\n  padding: 5px;\n  ", ";\n  ", ";\n  z-index: 1000;\n"]);

  _templateObject6$1 = function _templateObject6() {
    return data;
  };

  return data;
}

function _templateObject5$1() {
  var data = _taggedTemplateLiteralLoose(["\n    &::after {\n      content: '';\n      width: 0;\n      height: 0;\n      border-style: solid;\n      border-width: 6px 4px 0 4px;\n      border-color: rgb(58, 57, 73) transparent transparent transparent;\n      z-index: 1;\n      position: absolute;\n      bottom: -6px;\n      left: 50%;\n      transform: translate(-50%, 0);\n    }\n  "]);

  _templateObject5$1 = function _templateObject5() {
    return data;
  };

  return data;
}

function _templateObject4$3() {
  var data = _taggedTemplateLiteralLoose(["\n  cursor: pointer;\n"]);

  _templateObject4$3 = function _templateObject4() {
    return data;
  };

  return data;
}

function _templateObject3$5() {
  var data = _taggedTemplateLiteralLoose(["\n  width: 100%;\n  height: 100%;\n  position: relative;\n"]);

  _templateObject3$5 = function _templateObject3() {
    return data;
  };

  return data;
}

var StyledUkMapChartWrapper = styled__default.div(_templateObject3$5());
var StyledUkMapChartFeature = styled__default.svg(_templateObject4$3());

var getTriangle$1 = function getTriangle() {
  return styled.css(_templateObject5$1());
};

var getPosition$1 = function getPosition(left, top) {
  return "\n    position: absolute;\n    top: " + top + "px;\n    left: " + left + "px;\n    transform: translate(-50%, calc(-100% - 12px));\n  ";
};

var StyledUkMapChartTooltip = styled__default.div(_templateObject6$1(), function (props) {
  return getTriangle$1();
}, function (props) {
  return getPosition$1(props.left, props.top);
});

var topology = ukRegions;

var _topojson$feature = topojson.feature(topology, topology.objects.lad),
    regions = _topojson$feature.features;

var districts = {
  border: ['Dumfries and Galloway', 'Scottish Borders', 'Carlisle', 'Allerdale', 'Copeland', 'Eden', 'Barrow-in-Furness'],
  east: ['Breckland', 'Broadland', 'North Norfolk', 'Great Yarmouth', 'Waveney', 'South Norfolk', 'Norwich', 'Broadland', 'Suffolk Coastal', 'Ipswich', 'Mid Suffolk', "King's Lynn and West Norfolk", 'St Edmundsbury', 'Forest Heath', 'Tendring', 'Colchester', 'Babergh', 'Maldon', 'Braintree', 'East Cambridgeshire', 'South Cambridgeshire', 'Cambridge', 'Huntingdonshire', 'Fenland', 'Daventry', 'Kettering', 'Corby', 'East Northamptonshire', 'Peterborough', 'South Northamptonshire', 'Northampton', 'Wellingborough', 'Bedford', 'Milton Keynes', 'Central Bedfordshire', 'North Hertfordshire', 'Uttlesford', 'Stevenage', 'Luton'],
  london: ['Wandsworth', 'Redbridge', 'Newham', 'Hillingdon', 'Barnet', 'Lambeth', 'Tower Hamlets', 'Sutton', 'Richmond upon Thames', 'Havering', 'Westminster', 'Haringey', 'Mole Valley', 'Croydon', 'Bromley', 'Hillingdon', 'Enfield', 'Reigate and Banstead', 'Tandridge', 'Sevenoaks', 'Dartford', 'Gravesham', 'Bexley', 'Greenwich', 'Lewisham', 'Southwark', 'Islington', 'Waltham Forest', 'Medway', 'Waverley', 'Guildford', 'East Hertfordshire', 'Rushmoor', 'Surrey Heath', 'Woking', 'Bracknell Forest', 'Windsor and Maidenhead', 'Slough', 'Runnymede', 'Spelthorne', 'Hounslow', 'Epsom and Ewell', 'Merton', 'Kingston upon Thames', 'Elmbridge', 'South Bucks', 'Chiltern', 'Dacorum', 'Three Rivers', 'Watford', 'Hertsmere', 'St Albans', 'Harrow', 'Brent', 'Barking and Dagenham', 'Thurrock', 'Ealing', 'Kensington and Chelsea', 'Camden', 'Hackney', 'Welwyn Hatfield', 'Broxbourne', 'Epping Forest', 'Harlow', 'Brentwood', 'Basildon', 'Chelmsford', 'City of London', 'Hammersmith and Fulham', 'Castle Point', 'Rochford', 'Southend-on-Sea', 'Rochford'],
  midlands: ['Herefordshire, County of', 'Shropshire', 'Telford and Wrekin', 'Tewkesbury', 'Cheltenham', 'Cotswold', 'South Kesteven', 'Malvern Hills', 'Worcester', 'Wychavon', 'Redditch', 'Bromsgrove', 'Wyre Forest', 'Dudley', 'Sandwell', 'Wolverhampton', 'Walsall', 'South Staffordshire', 'Cannock Chase', 'Stafford', 'Newcastle-under-Lyme', 'Stoke-on-Trent', 'Staffordshire Moorlands', 'Derbyshire Dales', 'Stratford-on-Avon', 'Warwick', 'Solihull', 'Birmingham', 'Coventry', 'Nuneaton and Bedworth', 'North Warwickshire', 'Tamworth', 'Lichfield', 'East Staffordshire', 'South Derbyshire', 'Derby', 'Erewash', 'Amber Valley', 'North East Derbyshire', 'Chesterfield', 'Bolsover', 'Mansfield', 'Ashfield', 'Gedling', 'Nottingham', 'Broxtowe', 'Rushcliffe', 'North West Leicestershire', 'Hinckley and Bosworth', 'Leicester', 'Charnwood', 'Melton', 'Oadby and Wigston', 'Blaby', 'Rugby', 'Harborough', 'Rutland'],
  northEast: ['Northumberland', 'Newcastle upon Tyne', 'North Tyneside', 'Gateshead', 'South Tyneside', 'Sunderland', 'County Durham', 'Hartlepool', 'Stockton-on-Tees', 'Darlington', 'Middlesbrough', 'Redcar and Cleveland'],
  northWest: ['South Lakeland', 'Lancaster', 'Wyre', 'Blackpool', 'Fylde', 'Preston', 'Ribble Valley', 'Hyndburn', 'Blackburn with Darwen', 'Chorley', 'West Lancashire', 'Sefton', 'Craven', 'South Ribble', 'Wigan', 'Bolton', 'St. Helens', 'Knowsley', 'Liverpool', 'Wirral', 'Cheshire West and Chester', 'Warrington', 'Knowsley', 'Halton', 'Cheshire East', 'High Peak', 'Trafford', 'Salford', 'Wigan', 'Bury', 'Rossendale', 'Pendle', 'Burnley', 'Pendle', 'Oldham', 'Tameside', 'Rochdale', 'Manchester', 'Stockport'],
  scotland: ['Clackmannanshire', 'Shetland Islands', 'Highland', 'Orkney Islands', 'Eilean Siar', 'Moray', 'Aberdeenshire', 'Aberdeen City', 'Angus', 'Dundee City', 'Perth and Kinross', 'Argyll and Bute', 'Stirling', 'Fife', 'Falkirk', 'Renfrewshire', 'East Dunbartonshire', 'West Dunbartonshire', 'North Ayrshire', 'South Ayrshire', 'East Ayrshire', 'South Lanarkshire', 'Midlothian', 'East Lothian', 'City of Edinburgh', 'West Lothian', 'North Lanarkshire', 'Glasgow City', 'East Renfrewshire', 'Inverclyde'],
  southAndSouthEast: ['Purbeck', 'North Dorset', 'Poole', 'East Dorset', 'Christchurch', 'New Forest', 'Isle of Wight', 'Portsmouth', 'Gosport', 'Fareham', 'Southampton', 'Test Valley', 'Eastleigh', 'Winchester', 'East Hampshire', 'Chichester', 'Havant', 'Arun', 'Worthing', 'Adur', 'Mid Sussex', 'Brighton and Hove', 'Lewes', 'Eastbourne', 'Wealden', 'Rother', 'Hastings', 'Ashford', 'Shepway', 'Bournemouth', 'Horsham', 'Dover', 'Thanet', 'Canterbury', 'Swale', 'Basingstoke and Deane', 'West Berkshire', 'Swindon', 'Vale of White Horse', 'Maidstone', 'Tunbridge Wells', 'Crawley', 'Tonbridge and Malling', 'Hart', 'South Oxfordshire', 'Oxford', 'Cherwell', 'West Oxfordshire', 'Reading', 'Wokingham', 'Wycombe', 'Aylesbury Vale'],
  southWest: ['Cornwall', 'Plymouth', 'South Hams', 'Torbay', 'Torridge', 'North Devon', 'West Devon', 'Mid Devon', 'Teignbridge', 'Exeter', 'East Devon', 'West Dorset', 'Weymouth and Portland'],
  wales: ['Pembrokeshire', 'Carmarthenshire', 'Conwy', 'Denbighshire', 'Powys', 'Ceredigion', 'Gwynedd', 'Isle of Anglesey', 'Swansea', 'Monmouthshire', 'Torfaen', 'Newport', 'Cardiff', 'Vale of Glamorgan', 'Bridgen', 'Neath Port Talbot', 'Rhondda Cynon Taf', 'Merthyr Tydfil', 'Blaenau Gwent', 'Caerphilly', 'Bridgend', 'Flintshire', 'Wrexham'],
  west: ['West Somerset', 'Taunton Deane', 'South Somerset', 'Sedgemoor', 'Mendip', 'North Somerset', 'Bath and North East Somerset', 'Bristol, City of', 'South Gloucestershire', 'Stroud', 'Gloucester', 'Forest of Dean', 'Wiltshire'],
  yorkshire: ['East Riding of Yorkshire', 'Scarborough', 'Ryedale', 'Kingston upon Hull, City of', 'North Lincolnshire', 'North East Lincolnshire', 'East Lindsey', 'Boston', 'South Holland', 'West Lindsey', 'North Kesteven', 'Lincoln', 'Newark and Sherwood', 'Hambleton', 'Richmondshire', 'Calderdale', 'Bradford', 'Harrogate', 'Leeds', 'Kirklees', 'Selby', 'York', 'Wakefield', 'Barnsley', 'Doncaster', 'Bassetlaw', 'Rotherham', 'Sheffield']
};
var colors = {
  border: '#050505',
  east: '#131313',
  london: '#2d2d2d',
  midlands: '#494848',
  northEast: '#5a5a5a',
  northWest: '#6f6f6f',
  scotland: '#868685',
  southAndSouthEast: '#9e9e9e',
  southWest: '#bfbdbd',
  west: '#d1d2d1',
  wales: '#e7e4e4',
  yorkshire: '#eaeaec'
};
var labels = {
  border: 'Border',
  east: 'East',
  london: 'London',
  midlands: 'Midlands',
  northEast: 'North East',
  northWest: 'North West',
  scotland: 'Scotland',
  southAndSouthEast: 'South and South East',
  southWest: 'South West',
  west: 'West',
  wales: 'Wales',
  yorkshire: 'Yorkshire'
};
var tooltipTimeout$6;

var UkMapChart = function UkMapChart(_ref) {
  var data = _ref.data,
      metric = _ref.metric,
      onItemClick = _ref.onItemClick,
      color = _ref.color,
      emptyDataMessage = _ref.emptyDataMessage,
      showMoreDetail = _ref.showMoreDetail,
      _ref$positionLegend = _ref.positionLegend,
      positionLegend = _ref$positionLegend === void 0 ? 'bottom' : _ref$positionLegend;

  var _useTooltip = tooltip.useTooltip(),
      tooltipOpen = _useTooltip.tooltipOpen,
      tooltipLeft = _useTooltip.tooltipLeft,
      tooltipTop = _useTooltip.tooltipTop,
      tooltipData = _useTooltip.tooltipData,
      hideTooltip = _useTooltip.hideTooltip,
      showTooltip = _useTooltip.showTooltip;

  var _useState = React.useState(0),
      width = _useState[0],
      setWidth = _useState[1];

  var _useState2 = React.useState(0),
      height = _useState2[0],
      setHeight = _useState2[1];

  var windowSize = useWindowSize();
  var svgRef = React.useRef(null);
  var isEmpty = !data || data.length === 0;
  var chartId = React.useRef(uniqid());
  var centerX = width / 2;
  var centerY = height / 2;
  var max = data && Math.max.apply(Math, data.map(function (item) {
    return item[metric];
  })) || 0;
  var min = data && Math.min.apply(Math, data.map(function (item) {
    return item[metric];
  })) || 0;
  var chartRef = React.useCallback(function (node) {
    if (node != null) {
      setWidth(node.getBoundingClientRect().width);
      setHeight(node.getBoundingClientRect().height);
    }
  }, [windowSize]);
  var colorsRange = getMapColors(color);
  var colorScale = React.useMemo(function () {
    return scale.scaleLinear({
      domain: [metric === METRICS.AFFINITY ? min : min * 100, metric === METRICS.AFFINITY ? max : max * 100],
      range: colorsRange
    });
  }, [metric, min, max, color]);
  var getArea = React.useCallback(function (item) {
    var color = null;
    var label = null;
    Object.keys(districts).forEach(function (area) {
      if (districts[area].includes(item)) {
        color = colors[area];
        label = labels[area];
      }
    });
    return {
      label: label,
      color: color
    };
  }, [districts, colors, labels]);
  var getFillColor = React.useCallback(function (item) {
    if (!metric) {
      return item.color;
    }

    var value = item[metric] || 0;

    if (metric !== METRICS.AFFINITY) {
      value = value * 100;
    }

    return colorScale(value);
  }, [metric, colorScale]);
  var handleMouseMove = React.useCallback(function (event$1, item) {
    if (tooltipTimeout$6) clearTimeout(tooltipTimeout$6);
    if (!svgRef.current) return;
    var point = event.localPoint(svgRef.current, event$1);
    showTooltip({
      tooltipData: _extends({}, item, {
        color: getFillColor(item)
      }),
      tooltipTop: point === null || point === void 0 ? void 0 : point.y,
      tooltipLeft: point === null || point === void 0 ? void 0 : point.x
    });
  }, [svgRef, showTooltip, getFillColor]);
  var handleMouseLeave = React.useCallback(function (event) {
    tooltipTimeout$6 = window.setTimeout(function () {
      hideTooltip();
    }, 0);
  }, [hideTooltip]);
  var tooltipContent = React.useMemo(function () {
    if (showMoreDetail) {
      return /*#__PURE__*/React__default.createElement(React__default.Fragment, null, tooltipOpen && tooltipData && /*#__PURE__*/React__default.createElement(ChartTooltip, {
        opened: tooltipOpen,
        top: tooltipTop || 0,
        left: tooltipLeft || 0,
        data: tooltipData
      }, isReach(metric) && /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Reach: "), FormatUtils.formattedValue(getPopulationPerc(tooltipData), METRICS.REACH)), metric === METRICS.AFFINITY && /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Affinity: "), FormatUtils.formattedValue(tooltipData.target_audience_affinity, METRICS.AFFINITY)), metric === METRICS.BASE && /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Base: "), FormatUtils.formattedValue(tooltipData.base_population_perc, METRICS.BASE)), metric === METRICS.PENETRATION && /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Penetration: "), FormatUtils.formattedValue(tooltipData.penetration, METRICS.PENETRATION)), metric === METRICS.RELEVANCY && /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Relevance: "), FormatUtils.formattedValue(tooltipData.relevancy, METRICS.RELEVANCY))));
    }

    return /*#__PURE__*/React__default.createElement(React__default.Fragment, null, tooltipOpen && tooltipData && /*#__PURE__*/React__default.createElement(StyledUkMapChartTooltip, {
      top: tooltipTop,
      left: tooltipLeft
    }, /*#__PURE__*/React__default.createElement("div", null, tooltipData && tooltipData.label)));
  }, [showMoreDetail, tooltipLeft, tooltipTop, tooltipData, metric, tooltipOpen]);

  if (isEmpty) {
    return /*#__PURE__*/React__default.createElement(StyledUkMapChartWrapper, null, /*#__PURE__*/React__default.createElement(hxReactComponents.Box, {
      minWidth: "100%"
    }, /*#__PURE__*/React__default.createElement(hxReactComponents.EmptyState, {
      icon: "analytics",
      mainText: emptyDataMessage,
      size: "large"
    })));
  }

  return /*#__PURE__*/React__default.createElement(StyledUkMapChartWrapper, {
    ref: chartRef
  }, /*#__PURE__*/React__default.createElement("svg", {
    width: width,
    height: height,
    ref: svgRef
  }, /*#__PURE__*/React__default.createElement(geo.Albers, {
    data: regions,
    center: [0, 54],
    rotate: [4.4, 0],
    scale: (width + height) * 2,
    translate: [width / 2, height / 2]
  }, function (_ref2) {
    var features = _ref2.features;
    return features.map(function (_ref3, i) {
      var feature = _ref3.feature,
          path = _ref3.path;
      var area = getArea(feature.properties.LAD13NM);
      var item = data && data.find(function (item) {
        return item.label === area.label;
      });

      if (!item) {
        return null;
      }

      var fullItem = _extends({}, item, {
        color: area.color
      });

      return /*#__PURE__*/React__default.createElement(StyledUkMapChartFeature, {
        key: "region-" + chartId.current + "-" + feature.properties.LAD13CD,
        metric: metric
      }, /*#__PURE__*/React__default.createElement("path", {
        d: path,
        stroke: getFillColor(fullItem) || '#ffffff',
        fill: getFillColor(fullItem) || '#c6c3c3',
        className: "region-" + chartId.current + "-" + feature.properties.LAD13CD,
        onMouseMove: function onMouseMove(event) {
          return handleMouseMove(event, fullItem);
        },
        onMouseLeave: function onMouseLeave(event) {
          return handleMouseLeave(event);
        },
        onClick: function onClick() {
          onItemClick && onItemClick(fullItem);
        }
      }));
    });
  }), metric && /*#__PURE__*/React__default.createElement(group.Group, {
    top: positionLegend === 'left' ? centerY - 100 : height - 40,
    left: positionLegend === 'left' ? 100 : centerX - 100
  }, /*#__PURE__*/React__default.createElement(gradient.LinearGradient, {
    from: colorsRange[0],
    to: colorsRange[1],
    id: "legend-gradient-" + color,
    vertical: positionLegend === 'left'
  }), /*#__PURE__*/React__default.createElement(text.Text, {
    fontSize: "10px",
    fontWeight: "bold",
    textAnchor: "middle",
    verticalAnchor: "middle",
    fill: "#000000",
    width: 100,
    height: 20,
    x: positionLegend === 'left' ? 10 : 0,
    y: -10
  }, FormatUtils.formattedValue(min, metric)), /*#__PURE__*/React__default.createElement(text.Text, {
    fontSize: "10px",
    fontWeight: "bold",
    textAnchor: "middle",
    verticalAnchor: "middle",
    fill: "#000000",
    width: 100,
    height: 20,
    x: positionLegend === 'left' ? 10 : 200,
    y: positionLegend === 'left' ? 210 : -10
  }, "" + FormatUtils.formattedValue(max, metric)), /*#__PURE__*/React__default.createElement("rect", {
    width: positionLegend === 'left' ? 20 : 200,
    height: positionLegend === 'left' ? 200 : 20,
    fill: "url(#legend-gradient-" + color + ")"
  }), /*#__PURE__*/React__default.createElement(text.Text, {
    fontSize: "10px",
    fontWeight: "bold",
    textAnchor: "middle",
    verticalAnchor: "middle",
    fill: "#000000",
    width: 100,
    height: 20,
    x: positionLegend === 'left' ? 40 : 100,
    y: positionLegend === 'left' ? 100 : 30
  }, MAP_CHART_FIELDS_LABEL[metric]))), tooltipContent);
};

function _templateObject6$2() {
  var data = _taggedTemplateLiteralLoose(["\n  border-radius: 4px;\n  display: flex;\n  flex-wrap: wrap;\n  flex-direction: column;\n  text-align: left;\n  width: max-content;\n  max-width: 250px;\n  white-space: pre-line;\n  font-size: 11px;\n  line-height: 18px;\n  color: #ffffff;\n  background-color: rgb(58, 57, 73);\n  box-shadow: rgb(25 25 39 / 25%) 0px 2px 6px 0px;\n  padding: 5px;\n  ", ";\n  ", ";\n  z-index: 1000;\n"]);

  _templateObject6$2 = function _templateObject6() {
    return data;
  };

  return data;
}

function _templateObject5$2() {
  var data = _taggedTemplateLiteralLoose(["\n    &::after {\n      content: '';\n      width: 0;\n      height: 0;\n      border-style: solid;\n      border-width: 6px 4px 0 4px;\n      border-color: rgb(58, 57, 73) transparent transparent transparent;\n      z-index: 1;\n      position: absolute;\n      bottom: -6px;\n      left: 50%;\n      transform: translate(-50%, 0);\n    }\n  "]);

  _templateObject5$2 = function _templateObject5() {
    return data;
  };

  return data;
}

function _templateObject4$4() {
  var data = _taggedTemplateLiteralLoose(["\n  cursor: ", ";\n\n  & path:hover {\n    ", ";\n  }\n"]);

  _templateObject4$4 = function _templateObject4() {
    return data;
  };

  return data;
}

function _templateObject3$6() {
  var data = _taggedTemplateLiteralLoose(["\n  width: 100%;\n  height: 100%;\n  position: relative;\n"]);

  _templateObject3$6 = function _templateObject3() {
    return data;
  };

  return data;
}

function _templateObject2$6() {
  var data = _taggedTemplateLiteralLoose(["\n    fill: #9493a6;\n  "]);

  _templateObject2$6 = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$c() {
  var data = _taggedTemplateLiteralLoose(["\n      fill-opacity: 0.8;\n    "]);

  _templateObject$c = function _templateObject() {
    return data;
  };

  return data;
}

var getColorHover = function getColorHover(metric) {
  if (metric) {
    return styled.css(_templateObject$c());
  }

  return styled.css(_templateObject2$6());
};

var StyledUsaMapChartWrapper = styled__default.div(_templateObject3$6());
var StyledMapFeatureSvg = styled__default.svg(_templateObject4$4(), function (props) {
  return props.selectable && 'pointer';
}, function (props) {
  return props.selectable && getColorHover(props.metric);
});

var getTriangle$2 = function getTriangle() {
  return styled.css(_templateObject5$2());
};

var getPosition$2 = function getPosition(left, top) {
  return "\n    position: absolute;\n    top: " + top + "px;\n    left: " + left + "px;\n    transform: translate(-50%, calc(-100% - 12px));\n  ";
};

var StyledUsaMapChartTooltip = styled__default.div(_templateObject6$2(), function (props) {
  return getTriangle$2();
}, function (props) {
  return getPosition$2(props.left, props.top);
});

var statesAbbr = [
	{
		id: "01",
		label: "AL"
	},
	{
		id: "02",
		label: "AK"
	},
	{
		id: "60",
		label: "AS"
	},
	{
		id: "04",
		label: "AZ"
	},
	{
		id: "05",
		label: "AR"
	},
	{
		id: "06",
		label: "CA"
	},
	{
		id: "08",
		label: "CO"
	},
	{
		id: "09",
		label: "CT"
	},
	{
		id: "10",
		label: "DE"
	},
	{
		id: "12",
		label: "FL"
	},
	{
		id: "64",
		label: "FM"
	},
	{
		id: "13",
		label: "GA"
	},
	{
		id: "66",
		label: "GU"
	},
	{
		id: "15",
		label: "HI"
	},
	{
		id: "16",
		label: "ID"
	},
	{
		id: "17",
		label: "IL"
	},
	{
		id: "18",
		label: "IN"
	},
	{
		id: "19",
		label: "IA"
	},
	{
		id: "20",
		label: "KS"
	},
	{
		id: "21",
		label: "KY"
	},
	{
		id: "22",
		label: "LA"
	},
	{
		id: "23",
		label: "ME"
	},
	{
		id: "68",
		label: "MH"
	},
	{
		id: "24",
		label: "MD"
	},
	{
		id: "25",
		label: "MA"
	},
	{
		id: "26",
		label: "MI"
	},
	{
		id: "27",
		label: "MN"
	},
	{
		id: "28",
		label: "MS"
	},
	{
		id: "29",
		label: "MO"
	},
	{
		id: "30",
		label: "MT"
	},
	{
		id: "31",
		label: "NE"
	},
	{
		id: "32",
		label: "NV"
	},
	{
		id: "33",
		label: "NH"
	},
	{
		id: "34",
		label: "NJ"
	},
	{
		id: "35",
		label: "NM"
	},
	{
		id: "36",
		label: "NY"
	},
	{
		id: "37",
		label: "NC"
	},
	{
		id: "38",
		label: "ND"
	},
	{
		id: "69",
		label: "MP"
	},
	{
		id: "39",
		label: "OH"
	},
	{
		id: "40",
		label: "OK"
	},
	{
		id: "41",
		label: "OR"
	},
	{
		id: "70",
		label: "PW"
	},
	{
		id: "42",
		label: "PA"
	},
	{
		id: "72",
		label: "PR"
	},
	{
		id: "44",
		label: "RI"
	},
	{
		id: "45",
		label: "SC"
	},
	{
		id: "46",
		label: "SD"
	},
	{
		id: "47",
		label: "TN"
	},
	{
		id: "48",
		label: "TX"
	},
	{
		id: "74",
		label: "UM"
	},
	{
		id: "49",
		label: "UT"
	},
	{
		id: "50",
		label: "VT"
	},
	{
		id: "51",
		label: "VA"
	},
	{
		id: "78",
		label: "VI"
	},
	{
		id: "53",
		label: "WA"
	},
	{
		id: "54",
		label: "WV"
	},
	{
		id: "55",
		label: "WI"
	},
	{
		id: "56",
		label: "WY"
	}
];

var arcs$1 = [
	[
		[
			25302,
			52136
		],
		[
			56,
			31
		],
		[
			1,
			25
		],
		[
			14,
			-40
		],
		[
			-9,
			-28
		],
		[
			-10,
			16
		],
		[
			-18,
			-2
		],
		[
			-20,
			-17
		],
		[
			-14,
			15
		]
	],
	[
		[
			25338,
			57677
		],
		[
			0,
			15
		],
		[
			150,
			-6
		],
		[
			63,
			0
		],
		[
			160,
			-13
		],
		[
			93,
			-2
		],
		[
			37,
			2
		],
		[
			159,
			-4
		],
		[
			61,
			-5
		]
	],
	[
		[
			26061,
			57664
		],
		[
			15,
			-321
		],
		[
			23,
			-443
		],
		[
			18,
			-379
		],
		[
			13,
			-294
		],
		[
			15,
			-311
		],
		[
			33,
			-713
		],
		[
			9,
			-32
		],
		[
			-4,
			-36
		],
		[
			13,
			-45
		],
		[
			5,
			-149
		],
		[
			10,
			-72
		],
		[
			17,
			-69
		],
		[
			3,
			-82
		],
		[
			9,
			-36
		],
		[
			-10,
			-117
		],
		[
			18,
			-28
		],
		[
			12,
			-40
		],
		[
			-10,
			-52
		],
		[
			-11,
			0
		],
		[
			2,
			-24
		],
		[
			-14,
			-21
		],
		[
			-13,
			-52
		],
		[
			3,
			-56
		],
		[
			-2,
			-86
		],
		[
			-7,
			-86
		],
		[
			-14,
			-72
		],
		[
			-3,
			-45
		],
		[
			6,
			-124
		],
		[
			-2,
			-44
		],
		[
			19,
			-87
		],
		[
			3,
			-120
		],
		[
			-7,
			-57
		],
		[
			2,
			-43
		],
		[
			-8,
			-80
		],
		[
			1,
			-79
		],
		[
			-7,
			-21
		],
		[
			5,
			-51
		],
		[
			-3,
			-54
		],
		[
			20,
			-91
		],
		[
			7,
			-64
		],
		[
			2,
			-61
		]
	],
	[
		[
			26229,
			53027
		],
		[
			-67,
			0
		],
		[
			-71,
			-5
		],
		[
			-110,
			-4
		],
		[
			-174,
			0
		],
		[
			-135,
			7
		],
		[
			-166,
			-2
		],
		[
			3,
			-38
		],
		[
			-13,
			-115
		],
		[
			2,
			-23
		],
		[
			23,
			-79
		],
		[
			3,
			-41
		],
		[
			36,
			-80
		],
		[
			3,
			-69
		],
		[
			-15,
			-102
		],
		[
			3,
			-55
		],
		[
			20,
			-51
		],
		[
			-18,
			-35
		],
		[
			-8,
			-82
		],
		[
			-9,
			-15
		],
		[
			7,
			-24
		],
		[
			-15,
			-26
		]
	],
	[
		[
			25528,
			52188
		],
		[
			-38,
			-35
		],
		[
			-40,
			-24
		],
		[
			-56,
			-4
		],
		[
			18,
			41
		],
		[
			12,
			-26
		],
		[
			35,
			27
		],
		[
			3,
			34
		],
		[
			-15,
			48
		],
		[
			-7,
			43
		],
		[
			-20,
			47
		],
		[
			-7,
			90
		],
		[
			9,
			74
		],
		[
			-3,
			76
		],
		[
			-7,
			48
		],
		[
			-20,
			32
		],
		[
			-15,
			-46
		],
		[
			2,
			-38
		],
		[
			-9,
			-57
		],
		[
			1,
			-41
		],
		[
			-6,
			-32
		],
		[
			-1,
			-144
		],
		[
			-8,
			-66
		],
		[
			-15,
			-4
		],
		[
			1,
			36
		],
		[
			-20,
			40
		],
		[
			-15,
			-16
		],
		[
			-5,
			23
		],
		[
			-18,
			-22
		]
	],
	[
		[
			25284,
			52292
		],
		[
			-3,
			222
		],
		[
			-3,
			357
		],
		[
			-6,
			423
		],
		[
			-10,
			773
		],
		[
			9,
			283
		],
		[
			21,
			710
		],
		[
			5,
			212
		],
		[
			33,
			1120
		],
		[
			6,
			160
		],
		[
			19,
			643
		],
		[
			12,
			362
		],
		[
			-16,
			35
		],
		[
			-13,
			85
		]
	],
	[
		[
			8053,
			88108
		],
		[
			6,
			38
		],
		[
			18,
			-11
		],
		[
			-20,
			-43
		],
		[
			-4,
			16
		]
	],
	[
		[
			7905,
			86007
		],
		[
			29,
			90
		],
		[
			15,
			-17
		],
		[
			-1,
			-46
		],
		[
			-28,
			-74
		],
		[
			-15,
			19
		],
		[
			0,
			28
		]
	],
	[
		[
			7695,
			85792
		],
		[
			26,
			-14
		],
		[
			-3,
			-36
		],
		[
			-23,
			50
		]
	],
	[
		[
			7642,
			85774
		],
		[
			22,
			-17
		],
		[
			-7,
			-33
		],
		[
			-14,
			14
		],
		[
			-1,
			36
		]
	],
	[
		[
			7602,
			85813
		],
		[
			20,
			-2
		],
		[
			-5,
			-34
		],
		[
			-15,
			36
		]
	],
	[
		[
			7594,
			84711
		],
		[
			8,
			45
		],
		[
			20,
			-13
		],
		[
			-8,
			-73
		],
		[
			-15,
			-17
		],
		[
			-5,
			58
		]
	],
	[
		[
			7543,
			85532
		],
		[
			12,
			28
		],
		[
			21,
			-40
		],
		[
			-33,
			-2
		],
		[
			0,
			14
		]
	],
	[
		[
			7540,
			87187
		],
		[
			29,
			79
		],
		[
			8,
			112
		],
		[
			31,
			-29
		],
		[
			-28,
			-64
		],
		[
			-9,
			-49
		],
		[
			5,
			-24
		],
		[
			-36,
			-25
		]
	],
	[
		[
			7464,
			85521
		],
		[
			14,
			55
		],
		[
			18,
			-28
		],
		[
			23,
			-4
		],
		[
			-33,
			-33
		],
		[
			-22,
			10
		]
	],
	[
		[
			7385,
			86976
		],
		[
			17,
			6
		],
		[
			5,
			-88
		],
		[
			-22,
			82
		]
	],
	[
		[
			7168,
			84530
		],
		[
			29,
			89
		],
		[
			15,
			6
		],
		[
			26,
			-66
		],
		[
			5,
			20
		],
		[
			-21,
			65
		],
		[
			6,
			54
		],
		[
			9,
			10
		],
		[
			27,
			-25
		],
		[
			21,
			19
		],
		[
			-29,
			54
		],
		[
			16,
			56
		],
		[
			29,
			-31
		],
		[
			15,
			4
		],
		[
			-14,
			56
		],
		[
			12,
			17
		],
		[
			20,
			-20
		],
		[
			14,
			45
		],
		[
			-18,
			6
		],
		[
			-13,
			33
		],
		[
			20,
			3
		],
		[
			22,
			67
		],
		[
			34,
			18
		],
		[
			-12,
			35
		],
		[
			-3,
			68
		],
		[
			27,
			66
		],
		[
			7,
			-31
		],
		[
			53,
			51
		],
		[
			7,
			-7
		],
		[
			-12,
			-118
		],
		[
			-13,
			-18
		],
		[
			-26,
			-103
		],
		[
			5,
			-84
		],
		[
			36,
			11
		],
		[
			2,
			69
		],
		[
			22,
			-9
		],
		[
			21,
			-71
		],
		[
			20,
			48
		],
		[
			12,
			-33
		],
		[
			-17,
			-117
		],
		[
			9,
			-22
		],
		[
			9,
			72
		],
		[
			27,
			47
		],
		[
			7,
			-25
		],
		[
			-3,
			-115
		],
		[
			-30,
			-89
		],
		[
			-32,
			23
		],
		[
			-11,
			81
		],
		[
			-21,
			-26
		],
		[
			13,
			-99
		],
		[
			-22,
			-20
		],
		[
			-39,
			13
		],
		[
			-16,
			-54
		],
		[
			-8,
			36
		],
		[
			2,
			74
		],
		[
			-10,
			2
		],
		[
			-9,
			-114
		],
		[
			-8,
			-24
		],
		[
			-31,
			-17
		],
		[
			2,
			-37
		],
		[
			-16,
			-22
		],
		[
			-45,
			-13
		],
		[
			-86,
			76
		],
		[
			-21,
			-13
		],
		[
			-15,
			29
		]
	],
	[
		[
			7129,
			86075
		],
		[
			41,
			28
		],
		[
			18,
			-43
		],
		[
			-5,
			-48
		],
		[
			-13,
			-16
		],
		[
			-29,
			-3
		],
		[
			-16,
			59
		],
		[
			4,
			23
		]
	],
	[
		[
			6962,
			82933
		],
		[
			31,
			45
		],
		[
			8,
			-48
		],
		[
			-37,
			-9
		],
		[
			-2,
			12
		]
	],
	[
		[
			6905,
			82759
		],
		[
			20,
			62
		],
		[
			19,
			20
		],
		[
			11,
			-11
		],
		[
			25,
			17
		],
		[
			5,
			-40
		],
		[
			19,
			-37
		],
		[
			36,
			16
		],
		[
			-2,
			-37
		],
		[
			-19,
			-31
		],
		[
			-46,
			-6
		],
		[
			-32,
			-13
		],
		[
			-32,
			25
		],
		[
			-4,
			35
		]
	],
	[
		[
			6789,
			83718
		],
		[
			20,
			17
		],
		[
			4,
			76
		],
		[
			18,
			75
		],
		[
			25,
			34
		],
		[
			5,
			44
		],
		[
			15,
			-8
		],
		[
			34,
			70
		],
		[
			33,
			36
		],
		[
			39,
			-15
		],
		[
			29,
			1
		],
		[
			0,
			-112
		],
		[
			26,
			-57
		],
		[
			4,
			45
		],
		[
			17,
			53
		],
		[
			-18,
			48
		],
		[
			6,
			25
		],
		[
			53,
			-14
		],
		[
			-3,
			35
		],
		[
			-52,
			44
		],
		[
			-19,
			-4
		],
		[
			-1,
			127
		],
		[
			31,
			61
		],
		[
			29,
			29
		],
		[
			20,
			-12
		],
		[
			22,
			-56
		],
		[
			6,
			-133
		],
		[
			15,
			13
		],
		[
			9,
			77
		],
		[
			-5,
			55
		],
		[
			35,
			-38
		],
		[
			7,
			47
		],
		[
			-37,
			36
		],
		[
			-21,
			58
		],
		[
			7,
			44
		],
		[
			17,
			-6
		],
		[
			51,
			-87
		],
		[
			9,
			4
		],
		[
			30,
			-41
		],
		[
			11,
			10
		],
		[
			-31,
			75
		],
		[
			-20,
			34
		],
		[
			-7,
			44
		],
		[
			17,
			0
		],
		[
			30,
			-58
		],
		[
			29,
			12
		],
		[
			41,
			-29
		],
		[
			7,
			49
		],
		[
			36,
			15
		],
		[
			-8,
			-63
		],
		[
			-39,
			-106
		],
		[
			-7,
			-83
		],
		[
			19,
			-36
		],
		[
			0,
			95
		],
		[
			16,
			43
		],
		[
			16,
			-49
		],
		[
			5,
			46
		],
		[
			17,
			32
		],
		[
			5,
			41
		],
		[
			14,
			10
		],
		[
			10,
			-31
		],
		[
			22,
			72
		],
		[
			17,
			8
		],
		[
			-4,
			-45
		],
		[
			28,
			-16
		],
		[
			-11,
			-38
		],
		[
			-11,
			20
		],
		[
			-18,
			-15
		],
		[
			19,
			-36
		],
		[
			-5,
			-49
		],
		[
			19,
			22
		],
		[
			11,
			-51
		],
		[
			27,
			1
		],
		[
			-24,
			-53
		],
		[
			-16,
			33
		],
		[
			-24,
			2
		],
		[
			-15,
			-48
		],
		[
			16,
			-9
		],
		[
			-8,
			-53
		],
		[
			26,
			-8
		],
		[
			-26,
			-89
		],
		[
			23,
			17
		],
		[
			13,
			47
		],
		[
			5,
			-35
		],
		[
			47,
			-4
		],
		[
			-3,
			-41
		],
		[
			-36,
			-78
		],
		[
			-13,
			-110
		],
		[
			-38,
			13
		],
		[
			-2,
			39
		],
		[
			-10,
			-41
		],
		[
			-23,
			42
		],
		[
			-17,
			-6
		],
		[
			-23,
			49
		],
		[
			-15,
			-13
		],
		[
			-24,
			19
		],
		[
			-8,
			-46
		],
		[
			27,
			1
		],
		[
			15,
			-17
		],
		[
			45,
			-87
		],
		[
			-8,
			-70
		],
		[
			-23,
			-52
		],
		[
			-11,
			36
		],
		[
			-19,
			-50
		],
		[
			-19,
			30
		],
		[
			-6,
			38
		],
		[
			-21,
			18
		],
		[
			-20,
			-12
		],
		[
			-17,
			-37
		],
		[
			29,
			2
		],
		[
			20,
			-49
		],
		[
			-38,
			-53
		],
		[
			-34,
			12
		],
		[
			-4,
			-20
		],
		[
			25,
			-34
		],
		[
			14,
			13
		],
		[
			35,
			1
		],
		[
			22,
			-43
		],
		[
			-11,
			-28
		],
		[
			-24,
			-8
		],
		[
			-34,
			-33
		],
		[
			-8,
			11
		],
		[
			-19,
			-29
		],
		[
			3,
			-49
		],
		[
			-27,
			-50
		],
		[
			-13,
			20
		],
		[
			7,
			34
		],
		[
			-23,
			50
		],
		[
			7,
			47
		],
		[
			27,
			62
		],
		[
			-8,
			24
		],
		[
			-15,
			-21
		],
		[
			-34,
			-105
		],
		[
			-3,
			-24
		],
		[
			-22,
			32
		],
		[
			-22,
			-10
		],
		[
			-5,
			-35
		],
		[
			26,
			-6
		],
		[
			10,
			-63
		],
		[
			-16,
			-61
		],
		[
			-25,
			-20
		],
		[
			1,
			-70
		],
		[
			-25,
			-41
		],
		[
			-12,
			13
		],
		[
			-23,
			-82
		],
		[
			-19,
			-30
		],
		[
			-18,
			21
		],
		[
			-31,
			-20
		],
		[
			22,
			116
		],
		[
			11,
			11
		],
		[
			26,
			71
		],
		[
			24,
			31
		],
		[
			-2,
			37
		],
		[
			-33,
			-23
		],
		[
			3,
			52
		],
		[
			22,
			102
		],
		[
			29,
			52
		],
		[
			-7,
			30
		],
		[
			-15,
			-45
		],
		[
			-34,
			-61
		],
		[
			-26,
			-112
		],
		[
			-24,
			-59
		],
		[
			-14,
			-11
		],
		[
			-5,
			-44
		],
		[
			-19,
			-30
		],
		[
			-4,
			84
		],
		[
			-26,
			58
		],
		[
			-33,
			27
		],
		[
			3,
			100
		],
		[
			-4,
			106
		],
		[
			-13,
			83
		],
		[
			-11,
			32
		],
		[
			-23,
			20
		],
		[
			-27,
			5
		],
		[
			14,
			30
		],
		[
			-15,
			37
		],
		[
			5,
			23
		]
	],
	[
		[
			6782,
			82633
		],
		[
			27,
			101
		],
		[
			51,
			97
		],
		[
			21,
			-4
		],
		[
			16,
			-54
		],
		[
			-12,
			-23
		],
		[
			-55,
			-73
		],
		[
			-29,
			-79
		],
		[
			-19,
			35
		]
	],
	[
		[
			6519,
			81925
		],
		[
			26,
			41
		],
		[
			5,
			38
		],
		[
			13,
			22
		],
		[
			8,
			-32
		],
		[
			-6,
			-43
		],
		[
			5,
			-68
		],
		[
			-7,
			-33
		],
		[
			-36,
			13
		],
		[
			-8,
			62
		]
	],
	[
		[
			6240,
			82171
		],
		[
			5,
			47
		],
		[
			14,
			25
		],
		[
			13,
			-59
		],
		[
			-13,
			-63
		],
		[
			-19,
			50
		]
	],
	[
		[
			6225,
			82357
		],
		[
			9,
			35
		],
		[
			3,
			-82
		],
		[
			-10,
			-1
		],
		[
			-2,
			48
		]
	],
	[
		[
			6080,
			82757
		],
		[
			21,
			48
		],
		[
			48,
			-3
		],
		[
			25,
			-54
		],
		[
			-35,
			23
		],
		[
			-16,
			-26
		],
		[
			-43,
			-6
		],
		[
			0,
			18
		]
	],
	[
		[
			5919,
			82533
		],
		[
			19,
			25
		],
		[
			11,
			-57
		],
		[
			-9,
			-11
		],
		[
			-21,
			43
		]
	],
	[
		[
			5642,
			81925
		],
		[
			8,
			64
		],
		[
			19,
			12
		],
		[
			27,
			-58
		],
		[
			-8,
			-18
		],
		[
			-21,
			37
		],
		[
			-25,
			-37
		]
	],
	[
		[
			5573,
			81984
		],
		[
			16,
			-49
		],
		[
			-27,
			12
		],
		[
			11,
			37
		]
	],
	[
		[
			5524,
			80844
		],
		[
			-1,
			36
		],
		[
			13,
			24
		],
		[
			20,
			-25
		],
		[
			-9,
			-59
		],
		[
			-19,
			-15
		],
		[
			-4,
			39
		]
	],
	[
		[
			5506,
			81836
		],
		[
			8,
			67
		],
		[
			10,
			10
		],
		[
			11,
			-62
		],
		[
			-29,
			-15
		]
	],
	[
		[
			5485,
			80904
		],
		[
			12,
			85
		],
		[
			-11,
			46
		],
		[
			31,
			-2
		],
		[
			4,
			-99
		],
		[
			-27,
			-38
		],
		[
			-9,
			8
		]
	],
	[
		[
			5445,
			80747
		],
		[
			10,
			13
		],
		[
			16,
			-42
		],
		[
			-1,
			-34
		],
		[
			-23,
			-4
		],
		[
			-2,
			67
		]
	],
	[
		[
			5429,
			81185
		],
		[
			17,
			-21
		],
		[
			5,
			49
		],
		[
			17,
			46
		],
		[
			5,
			-22
		],
		[
			-8,
			-58
		],
		[
			9,
			-13
		],
		[
			1,
			-44
		],
		[
			-10,
			-61
		],
		[
			13,
			-30
		],
		[
			-7,
			-19
		],
		[
			-17,
			22
		],
		[
			-2,
			-21
		],
		[
			-20,
			8
		],
		[
			-3,
			164
		]
	],
	[
		[
			5385,
			80755
		],
		[
			21,
			25
		],
		[
			11,
			-30
		],
		[
			-20,
			-26
		],
		[
			-12,
			31
		]
	],
	[
		[
			5377,
			81028
		],
		[
			9,
			39
		],
		[
			23,
			41
		],
		[
			5,
			-36
		],
		[
			-23,
			-38
		],
		[
			-9,
			-58
		],
		[
			-5,
			52
		]
	],
	[
		[
			5303,
			81352
		],
		[
			14,
			11
		],
		[
			5,
			-42
		],
		[
			-19,
			31
		]
	],
	[
		[
			5265,
			80882
		],
		[
			33,
			98
		],
		[
			15,
			27
		],
		[
			-5,
			18
		],
		[
			-22,
			0
		],
		[
			-4,
			76
		],
		[
			22,
			50
		],
		[
			27,
			-44
		],
		[
			-1,
			38
		],
		[
			-13,
			52
		],
		[
			30,
			-13
		],
		[
			18,
			114
		],
		[
			12,
			-23
		],
		[
			-2,
			-43
		],
		[
			-9,
			-2
		],
		[
			-5,
			-75
		],
		[
			12,
			-18
		],
		[
			0,
			33
		],
		[
			13,
			1
		],
		[
			-4,
			-60
		],
		[
			-11,
			-37
		],
		[
			-22,
			12
		],
		[
			-1,
			-45
		],
		[
			-28,
			-71
		],
		[
			-18,
			-24
		],
		[
			-31,
			-141
		],
		[
			-6,
			77
		]
	],
	[
		[
			5246,
			85264
		],
		[
			5,
			41
		],
		[
			14,
			-83
		],
		[
			-7,
			-25
		],
		[
			-12,
			67
		]
	],
	[
		[
			5238,
			81460
		],
		[
			22,
			42
		],
		[
			36,
			-14
		],
		[
			-1,
			-78
		],
		[
			-50,
			12
		],
		[
			-7,
			38
		]
	],
	[
		[
			5213,
			85252
		],
		[
			8,
			77
		],
		[
			5,
			-57
		],
		[
			-13,
			-20
		]
	],
	[
		[
			5096,
			81334
		],
		[
			16,
			74
		],
		[
			25,
			25
		],
		[
			18,
			-23
		],
		[
			-2,
			-46
		],
		[
			10,
			5
		],
		[
			12,
			47
		],
		[
			15,
			-32
		],
		[
			26,
			-26
		],
		[
			26,
			25
		],
		[
			7,
			-66
		],
		[
			-9,
			-60
		],
		[
			-14,
			40
		],
		[
			-22,
			3
		],
		[
			-14,
			23
		],
		[
			-3,
			40
		],
		[
			-10,
			-12
		],
		[
			0,
			-69
		],
		[
			11,
			-20
		],
		[
			11,
			-87
		],
		[
			-11,
			-60
		],
		[
			-36,
			35
		],
		[
			-10,
			59
		],
		[
			-18,
			-18
		],
		[
			-18,
			-90
		],
		[
			4,
			58
		],
		[
			-10,
			43
		],
		[
			0,
			104
		],
		[
			-4,
			28
		]
	],
	[
		[
			5033,
			85142
		],
		[
			7,
			131
		],
		[
			39,
			52
		],
		[
			21,
			6
		],
		[
			39,
			76
		],
		[
			5,
			-2
		],
		[
			-55,
			-273
		],
		[
			-22,
			-32
		],
		[
			-32,
			-4
		],
		[
			-2,
			46
		]
	],
	[
		[
			4937,
			81216
		],
		[
			27,
			3
		],
		[
			-4,
			-71
		],
		[
			-26,
			47
		],
		[
			3,
			21
		]
	],
	[
		[
			4863,
			81217
		],
		[
			10,
			31
		],
		[
			36,
			8
		],
		[
			-9,
			-51
		],
		[
			-37,
			-10
		],
		[
			0,
			22
		]
	],
	[
		[
			4804,
			81100
		],
		[
			4,
			51
		],
		[
			17,
			20
		],
		[
			25,
			-19
		],
		[
			12,
			-29
		],
		[
			35,
			-42
		],
		[
			6,
			-41
		],
		[
			-30,
			44
		],
		[
			-23,
			-57
		],
		[
			-28,
			74
		],
		[
			-11,
			-38
		],
		[
			-7,
			37
		]
	],
	[
		[
			4656,
			80881
		],
		[
			30,
			66
		],
		[
			26,
			-27
		],
		[
			0,
			-83
		],
		[
			-11,
			-53
		],
		[
			-13,
			-21
		],
		[
			-27,
			58
		],
		[
			-5,
			60
		]
	],
	[
		[
			4587,
			90956
		],
		[
			19,
			44
		],
		[
			21,
			16
		],
		[
			24,
			-17
		],
		[
			22,
			6
		],
		[
			9,
			-37
		],
		[
			-1,
			-50
		],
		[
			-75,
			-13
		],
		[
			-18,
			19
		],
		[
			-1,
			32
		]
	],
	[
		[
			4545,
			80324
		],
		[
			1,
			51
		],
		[
			68,
			-54
		],
		[
			19,
			-39
		],
		[
			26,
			0
		],
		[
			18,
			-28
		],
		[
			-20,
			-23
		],
		[
			-10,
			-33
		],
		[
			-22,
			40
		],
		[
			-17,
			-9
		],
		[
			-31,
			37
		],
		[
			-18,
			-29
		],
		[
			-22,
			57
		],
		[
			8,
			30
		]
	],
	[
		[
			4451,
			81463
		],
		[
			14,
			-1
		],
		[
			-5,
			-38
		],
		[
			-9,
			39
		]
	],
	[
		[
			3979,
			80040
		],
		[
			12,
			22
		],
		[
			16,
			-18
		],
		[
			-21,
			-37
		],
		[
			-7,
			33
		]
	],
	[
		[
			3880,
			79918
		],
		[
			22,
			34
		],
		[
			33,
			-11
		],
		[
			24,
			18
		],
		[
			5,
			-24
		],
		[
			-9,
			-45
		],
		[
			-26,
			-13
		],
		[
			-47,
			27
		],
		[
			-2,
			14
		]
	],
	[
		[
			3807,
			79887
		],
		[
			60,
			24
		],
		[
			9,
			-35
		],
		[
			-15,
			-32
		],
		[
			-13,
			37
		],
		[
			-34,
			-4
		],
		[
			-7,
			10
		]
	],
	[
		[
			3781,
			79848
		],
		[
			17,
			29
		],
		[
			7,
			-36
		],
		[
			-18,
			-14
		],
		[
			-6,
			21
		]
	],
	[
		[
			3751,
			80090
		],
		[
			13,
			56
		],
		[
			14,
			-15
		],
		[
			18,
			18
		],
		[
			12,
			-21
		],
		[
			-22,
			-33
		],
		[
			13,
			-48
		],
		[
			30,
			0
		],
		[
			1,
			-41
		],
		[
			-23,
			3
		],
		[
			-18,
			-79
		],
		[
			-23,
			24
		],
		[
			-2,
			78
		],
		[
			16,
			35
		],
		[
			-9,
			20
		],
		[
			-16,
			-21
		],
		[
			-4,
			24
		]
	],
	[
		[
			3635,
			79967
		],
		[
			5,
			36
		],
		[
			28,
			54
		],
		[
			30,
			-6
		],
		[
			3,
			-58
		],
		[
			20,
			6
		],
		[
			14,
			-15
		],
		[
			8,
			-44
		],
		[
			13,
			13
		],
		[
			-2,
			-41
		],
		[
			-26,
			-36
		],
		[
			-12,
			11
		],
		[
			-18,
			-45
		],
		[
			-6,
			28
		],
		[
			-25,
			1
		],
		[
			-17,
			-20
		],
		[
			-18,
			91
		],
		[
			3,
			25
		]
	],
	[
		[
			3608,
			79782
		],
		[
			7,
			15
		],
		[
			27,
			-33
		],
		[
			-32,
			-11
		],
		[
			-2,
			29
		]
	],
	[
		[
			3261,
			87028
		],
		[
			35,
			25
		],
		[
			57,
			0
		],
		[
			22,
			-20
		],
		[
			23,
			10
		],
		[
			9,
			-24
		],
		[
			21,
			10
		],
		[
			10,
			30
		],
		[
			-8,
			38
		],
		[
			34,
			68
		],
		[
			37,
			-11
		],
		[
			0,
			37
		],
		[
			25,
			46
		],
		[
			33,
			-40
		],
		[
			24,
			32
		],
		[
			23,
			9
		],
		[
			15,
			54
		],
		[
			19,
			-132
		],
		[
			27,
			-10
		],
		[
			29,
			34
		],
		[
			29,
			-20
		],
		[
			27,
			-40
		],
		[
			-12,
			-65
		],
		[
			11,
			-44
		],
		[
			-11,
			-40
		],
		[
			13,
			-11
		],
		[
			4,
			-65
		],
		[
			-13,
			-38
		],
		[
			21,
			-54
		],
		[
			2,
			-58
		],
		[
			21,
			10
		],
		[
			-11,
			-34
		],
		[
			2,
			-48
		],
		[
			-71,
			-21
		],
		[
			-6,
			-34
		],
		[
			-20,
			19
		],
		[
			-26,
			-18
		],
		[
			-28,
			-58
		],
		[
			8,
			-64
		],
		[
			-26,
			-8
		],
		[
			-23,
			71
		],
		[
			-38,
			47
		],
		[
			-57,
			-4
		],
		[
			-14,
			35
		],
		[
			-28,
			18
		],
		[
			-27,
			58
		],
		[
			-35,
			42
		],
		[
			-40,
			19
		],
		[
			-32,
			72
		],
		[
			-25,
			10
		],
		[
			-2,
			70
		],
		[
			-28,
			97
		]
	],
	[
		[
			3147,
			79003
		],
		[
			17,
			23
		],
		[
			22,
			53
		],
		[
			25,
			5
		],
		[
			37,
			40
		],
		[
			9,
			27
		],
		[
			28,
			-21
		],
		[
			14,
			19
		],
		[
			8,
			44
		],
		[
			22,
			-19
		],
		[
			3,
			72
		],
		[
			24,
			-11
		],
		[
			-17,
			106
		],
		[
			20,
			32
		],
		[
			8,
			-16
		],
		[
			15,
			18
		],
		[
			-18,
			35
		],
		[
			4,
			39
		],
		[
			17,
			23
		],
		[
			29,
			-1
		],
		[
			9,
			-68
		],
		[
			15,
			7
		],
		[
			-7,
			50
		],
		[
			13,
			31
		],
		[
			-53,
			47
		],
		[
			-14,
			-21
		],
		[
			-32,
			81
		],
		[
			0,
			46
		],
		[
			31,
			92
		],
		[
			42,
			50
		],
		[
			36,
			32
		],
		[
			6,
			-15
		],
		[
			23,
			13
		],
		[
			16,
			-63
		],
		[
			-16,
			-42
		],
		[
			7,
			-35
		],
		[
			17,
			-18
		],
		[
			14,
			53
		],
		[
			6,
			-33
		],
		[
			15,
			29
		],
		[
			-1,
			41
		],
		[
			18,
			63
		],
		[
			15,
			-58
		],
		[
			11,
			26
		],
		[
			20,
			-62
		],
		[
			-8,
			-56
		],
		[
			-23,
			-13
		],
		[
			-24,
			-70
		],
		[
			-40,
			-70
		],
		[
			2,
			-39
		],
		[
			34,
			54
		],
		[
			58,
			64
		],
		[
			4,
			22
		],
		[
			22,
			22
		],
		[
			7,
			-19
		],
		[
			-5,
			-72
		],
		[
			-16,
			-51
		],
		[
			-26,
			-34
		],
		[
			-6,
			-23
		],
		[
			-45,
			-51
		],
		[
			-30,
			-20
		],
		[
			12,
			-46
		],
		[
			-16,
			-1
		],
		[
			-4,
			-61
		],
		[
			-16,
			17
		],
		[
			-7,
			-70
		],
		[
			-20,
			25
		],
		[
			-4,
			-76
		],
		[
			-36,
			-13
		],
		[
			-22,
			30
		],
		[
			-10,
			-31
		],
		[
			-12,
			23
		],
		[
			-21,
			-37
		],
		[
			-6,
			11
		],
		[
			-44,
			-73
		],
		[
			-3,
			-31
		],
		[
			-23,
			4
		],
		[
			-16,
			-23
		],
		[
			-13,
			-60
		],
		[
			-28,
			23
		],
		[
			-9,
			-45
		],
		[
			-49,
			40
		],
		[
			-15,
			36
		]
	],
	[
		[
			3070,
			93368
		],
		[
			7,
			34
		],
		[
			34,
			50
		],
		[
			123,
			108
		],
		[
			63,
			74
		],
		[
			48,
			74
		],
		[
			45,
			56
		],
		[
			42,
			64
		],
		[
			84,
			105
		],
		[
			55,
			56
		],
		[
			146,
			167
		],
		[
			172,
			154
		],
		[
			133,
			90
		],
		[
			87,
			45
		],
		[
			135,
			15
		],
		[
			52,
			-11
		],
		[
			34,
			-31
		],
		[
			-41,
			-11
		],
		[
			7,
			-38
		],
		[
			-10,
			-71
		],
		[
			-31,
			-77
		],
		[
			1,
			-70
		],
		[
			12,
			-56
		],
		[
			-21,
			-59
		],
		[
			-49,
			-33
		],
		[
			-4,
			-20
		],
		[
			49,
			7
		],
		[
			42,
			-151
		],
		[
			40,
			-3
		],
		[
			36,
			32
		],
		[
			42,
			-1
		],
		[
			49,
			-30
		],
		[
			47,
			21
		],
		[
			69,
			15
		],
		[
			32,
			-58
		],
		[
			50,
			21
		],
		[
			18,
			-34
		],
		[
			52,
			32
		],
		[
			18,
			26
		],
		[
			84,
			-65
		],
		[
			18,
			59
		],
		[
			26,
			44
		],
		[
			37,
			150
		],
		[
			18,
			26
		],
		[
			40,
			-9
		],
		[
			8,
			-39
		],
		[
			32,
			-12
		],
		[
			31,
			27
		],
		[
			26,
			0
		],
		[
			-32,
			110
		],
		[
			-71,
			55
		],
		[
			-45,
			24
		],
		[
			-48,
			-1
		],
		[
			-60,
			-60
		],
		[
			13,
			112
		],
		[
			-3,
			83
		],
		[
			-62,
			114
		],
		[
			-22,
			91
		],
		[
			-26,
			35
		],
		[
			-59,
			14
		],
		[
			-8,
			56
		],
		[
			-32,
			90
		],
		[
			7,
			50
		],
		[
			27,
			18
		],
		[
			10,
			43
		],
		[
			16,
			-37
		],
		[
			24,
			28
		],
		[
			27,
			-89
		],
		[
			36,
			-91
		],
		[
			24,
			-10
		],
		[
			-19,
			-101
		],
		[
			3,
			-55
		],
		[
			28,
			-50
		],
		[
			57,
			-123
		],
		[
			53,
			-68
		],
		[
			39,
			18
		],
		[
			30,
			28
		],
		[
			9,
			49
		],
		[
			-45,
			2
		],
		[
			-10,
			45
		],
		[
			-56,
			70
		],
		[
			-53,
			112
		],
		[
			10,
			52
		],
		[
			0,
			60
		],
		[
			14,
			23
		],
		[
			1,
			57
		],
		[
			33,
			93
		],
		[
			30,
			-32
		],
		[
			22,
			3
		],
		[
			1,
			28
		],
		[
			-38,
			55
		],
		[
			-25,
			-8
		],
		[
			-28,
			57
		],
		[
			-87,
			-29
		],
		[
			-32,
			-37
		],
		[
			-34,
			0
		],
		[
			-39,
			-19
		],
		[
			-34,
			17
		],
		[
			-20,
			43
		],
		[
			-17,
			-16
		],
		[
			-21,
			23
		],
		[
			-4,
			-51
		],
		[
			-36,
			39
		],
		[
			-91,
			42
		],
		[
			-54,
			31
		],
		[
			-48,
			15
		],
		[
			-22,
			30
		],
		[
			1,
			98
		],
		[
			-22,
			163
		],
		[
			-52,
			216
		],
		[
			-20,
			58
		],
		[
			-36,
			62
		],
		[
			-91,
			101
		],
		[
			-145,
			228
		],
		[
			-21,
			24
		],
		[
			-51,
			87
		],
		[
			-50,
			49
		],
		[
			-54,
			37
		],
		[
			-51,
			23
		],
		[
			-29,
			35
		],
		[
			-19,
			70
		],
		[
			-54,
			84
		],
		[
			-45,
			40
		],
		[
			-81,
			41
		],
		[
			-42,
			-6
		],
		[
			37,
			40
		],
		[
			92,
			59
		],
		[
			20,
			46
		],
		[
			3,
			57
		],
		[
			19,
			76
		],
		[
			11,
			236
		],
		[
			-8,
			117
		],
		[
			179,
			-31
		],
		[
			68,
			6
		],
		[
			144,
			42
		],
		[
			79,
			28
		],
		[
			77,
			15
		],
		[
			77,
			63
		],
		[
			41,
			65
		],
		[
			29,
			30
		],
		[
			53,
			87
		],
		[
			81,
			192
		],
		[
			21,
			92
		],
		[
			7,
			79
		],
		[
			-2,
			186
		],
		[
			39,
			233
		],
		[
			84,
			183
		],
		[
			65,
			179
		],
		[
			37,
			77
		],
		[
			129,
			162
		],
		[
			96,
			-35
		],
		[
			69,
			-3
		],
		[
			68,
			40
		],
		[
			64,
			53
		],
		[
			93,
			104
		],
		[
			74,
			108
		],
		[
			44,
			86
		],
		[
			114,
			188
		],
		[
			33,
			31
		],
		[
			99,
			63
		],
		[
			7,
			-47
		],
		[
			55,
			-44
		],
		[
			82,
			-12
		],
		[
			68,
			15
		],
		[
			13,
			24
		],
		[
			32,
			-3
		],
		[
			61,
			17
		],
		[
			73,
			51
		],
		[
			74,
			85
		],
		[
			71,
			121
		],
		[
			36,
			88
		],
		[
			86,
			185
		],
		[
			68,
			76
		],
		[
			12,
			-68
		],
		[
			47,
			-38
		],
		[
			39,
			-2
		],
		[
			39,
			-20
		],
		[
			16,
			-82
		],
		[
			27,
			41
		],
		[
			99,
			-49
		],
		[
			15,
			-98
		],
		[
			-54,
			-71
		],
		[
			-35,
			-63
		],
		[
			-41,
			-4
		],
		[
			12,
			-146
		],
		[
			81,
			-15
		],
		[
			44,
			59
		],
		[
			-7,
			76
		],
		[
			16,
			8
		],
		[
			31,
			67
		],
		[
			23,
			12
		],
		[
			19,
			-48
		],
		[
			4,
			63
		],
		[
			-27,
			43
		],
		[
			35,
			55
		],
		[
			21,
			-47
		],
		[
			-3,
			65
		],
		[
			15,
			22
		],
		[
			71,
			-74
		],
		[
			45,
			-66
		],
		[
			13,
			-42
		],
		[
			-11,
			-33
		],
		[
			1,
			-109
		],
		[
			9,
			-49
		],
		[
			61,
			10
		],
		[
			35,
			-37
		],
		[
			16,
			-40
		],
		[
			48,
			62
		],
		[
			30,
			75
		],
		[
			112,
			0
		],
		[
			69,
			42
		],
		[
			53,
			-11
		],
		[
			40,
			-34
		],
		[
			84,
			-2
		],
		[
			61,
			-32
		],
		[
			45,
			-35
		],
		[
			9,
			-34
		],
		[
			-26,
			-11
		],
		[
			-26,
			-83
		],
		[
			-26,
			-30
		],
		[
			14,
			-93
		],
		[
			25,
			5
		],
		[
			19,
			-24
		],
		[
			45,
			-6
		],
		[
			10,
			-28
		],
		[
			69,
			-20
		],
		[
			33,
			9
		],
		[
			-17,
			-43
		],
		[
			9,
			-25
		],
		[
			-53,
			-26
		],
		[
			-8,
			-24
		],
		[
			20,
			-25
		],
		[
			89,
			6
		],
		[
			72,
			-41
		],
		[
			14,
			-33
		],
		[
			28,
			5
		],
		[
			44,
			86
		],
		[
			57,
			15
		],
		[
			24,
			-18
		],
		[
			10,
			34
		],
		[
			40,
			7
		],
		[
			29,
			-27
		],
		[
			15,
			-59
		],
		[
			42,
			27
		],
		[
			38,
			8
		],
		[
			58,
			83
		],
		[
			13,
			-22
		],
		[
			45,
			20
		],
		[
			21,
			-15
		],
		[
			34,
			26
		],
		[
			12,
			-30
		],
		[
			66,
			-8
		],
		[
			62,
			-72
		],
		[
			28,
			-1
		],
		[
			19,
			-24
		],
		[
			26,
			31
		],
		[
			24,
			-8
		],
		[
			37,
			-73
		],
		[
			0,
			-45
		],
		[
			35,
			-19
		],
		[
			41,
			51
		],
		[
			1,
			-63
		],
		[
			26,
			57
		],
		[
			81,
			-77
		],
		[
			14,
			-67
		],
		[
			24,
			-23
		],
		[
			49,
			1
		],
		[
			43,
			-15
		],
		[
			29,
			36
		],
		[
			23,
			-73
		],
		[
			48,
			-10
		],
		[
			29,
			45
		],
		[
			43,
			-12
		],
		[
			62,
			12
		],
		[
			66,
			-10
		],
		[
			49,
			-38
		],
		[
			50,
			-3
		],
		[
			17,
			28
		],
		[
			65,
			-95
		],
		[
			28,
			-8
		],
		[
			32,
			-54
		],
		[
			45,
			-16
		],
		[
			20,
			-30
		],
		[
			45,
			-12
		],
		[
			17,
			-26
		],
		[
			27,
			32
		],
		[
			66,
			-20
		],
		[
			45,
			77
		],
		[
			48,
			6
		],
		[
			9,
			20
		],
		[
			84,
			49
		],
		[
			18,
			24
		],
		[
			86,
			30
		],
		[
			42,
			-25
		],
		[
			48,
			32
		],
		[
			9,
			-18
		],
		[
			79,
			-73
		],
		[
			53,
			-37
		],
		[
			70,
			-80
		],
		[
			26,
			-67
		],
		[
			37,
			-11
		],
		[
			87,
			-97
		],
		[
			68,
			-40
		],
		[
			52,
			-62
		],
		[
			27,
			-47
		],
		[
			61,
			-13
		],
		[
			58,
			-45
		],
		[
			0,
			-9012
		],
		[
			2,
			-971
		],
		[
			-1,
			-889
		],
		[
			130,
			-95
		],
		[
			17,
			100
		],
		[
			135,
			-145
		],
		[
			81,
			180
		],
		[
			170,
			20
		],
		[
			1,
			-39
		],
		[
			-33,
			-272
		],
		[
			47,
			-112
		],
		[
			66,
			-76
		],
		[
			26,
			-22
		],
		[
			11,
			-116
		],
		[
			29,
			-80
		],
		[
			266,
			-580
		],
		[
			30,
			-299
		],
		[
			-8,
			-93
		],
		[
			22,
			4
		],
		[
			51,
			108
		],
		[
			111,
			158
		],
		[
			11,
			23
		],
		[
			68,
			8
		],
		[
			32,
			139
		],
		[
			-2,
			209
		],
		[
			30,
			-19
		],
		[
			18,
			19
		],
		[
			19,
			71
		],
		[
			-1,
			39
		],
		[
			-32,
			47
		],
		[
			45,
			48
		],
		[
			68,
			28
		],
		[
			131,
			158
		],
		[
			62,
			-115
		],
		[
			28,
			-88
		],
		[
			11,
			-2
		],
		[
			24,
			-70
		],
		[
			0,
			-104
		],
		[
			-12,
			-24
		],
		[
			1,
			-37
		],
		[
			16,
			-47
		],
		[
			-5,
			-42
		],
		[
			18,
			-76
		],
		[
			73,
			-38
		],
		[
			5,
			-66
		],
		[
			32,
			-73
		],
		[
			24,
			0
		],
		[
			29,
			-108
		],
		[
			-6,
			-69
		],
		[
			26,
			-20
		],
		[
			-6,
			-46
		],
		[
			22,
			-71
		],
		[
			114,
			-152
		],
		[
			32,
			-119
		],
		[
			46,
			-120
		],
		[
			50,
			-110
		],
		[
			-23,
			-49
		],
		[
			33,
			-134
		],
		[
			47,
			-140
		],
		[
			28,
			-176
		],
		[
			57,
			-182
		],
		[
			32,
			-161
		],
		[
			30,
			-111
		],
		[
			25,
			-123
		],
		[
			53,
			-180
		],
		[
			32,
			-155
		],
		[
			-33,
			-140
		],
		[
			89,
			-52
		],
		[
			-21,
			-205
		],
		[
			71,
			-81
		],
		[
			-8,
			-61
		],
		[
			11,
			-57
		],
		[
			7,
			-119
		],
		[
			71,
			14
		],
		[
			33,
			-77
		],
		[
			82,
			-115
		],
		[
			23,
			-48
		],
		[
			85,
			-47
		],
		[
			44,
			-115
		],
		[
			44,
			-33
		],
		[
			11,
			-116
		],
		[
			23,
			-15
		],
		[
			27,
			-36
		],
		[
			40,
			23
		],
		[
			28,
			-143
		],
		[
			-3,
			-90
		],
		[
			-20,
			-107
		],
		[
			-18,
			-67
		],
		[
			1,
			-60
		],
		[
			10,
			-38
		],
		[
			-5,
			-118
		],
		[
			12,
			-104
		],
		[
			11,
			-46
		],
		[
			6,
			-133
		],
		[
			12,
			-63
		],
		[
			-32,
			-100
		],
		[
			-24,
			-122
		],
		[
			-1,
			-33
		],
		[
			-20,
			-90
		],
		[
			-23,
			-77
		],
		[
			-37,
			-97
		],
		[
			-27,
			-55
		],
		[
			-19,
			-14
		],
		[
			3,
			-46
		],
		[
			-19,
			-23
		],
		[
			-12,
			40
		],
		[
			-1,
			56
		],
		[
			-13,
			24
		],
		[
			-1,
			-44
		],
		[
			-12,
			-22
		],
		[
			-18,
			18
		],
		[
			-13,
			52
		],
		[
			-4,
			108
		],
		[
			3,
			57
		],
		[
			-17,
			33
		],
		[
			8,
			103
		],
		[
			-9,
			6
		],
		[
			-16,
			56
		],
		[
			-6,
			64
		],
		[
			30,
			63
		],
		[
			17,
			63
		],
		[
			15,
			-8
		],
		[
			-3,
			75
		],
		[
			-11,
			82
		],
		[
			14,
			122
		],
		[
			-9,
			190
		],
		[
			-10,
			67
		],
		[
			-43,
			164
		],
		[
			-22,
			55
		],
		[
			-12,
			48
		],
		[
			-7,
			-34
		],
		[
			23,
			-62
		],
		[
			25,
			-85
		],
		[
			7,
			-72
		],
		[
			22,
			-90
		],
		[
			10,
			-131
		],
		[
			-16,
			-43
		],
		[
			-2,
			-79
		],
		[
			7,
			-92
		],
		[
			11,
			-62
		],
		[
			-9,
			-28
		],
		[
			-11,
			96
		],
		[
			-8,
			12
		],
		[
			3,
			-70
		],
		[
			-4,
			-74
		],
		[
			-36,
			-102
		],
		[
			-14,
			-5
		],
		[
			-24,
			49
		],
		[
			19,
			73
		],
		[
			11,
			73
		],
		[
			-3,
			38
		],
		[
			-25,
			-10
		],
		[
			10,
			-72
		],
		[
			-8,
			-42
		],
		[
			-33,
			-56
		],
		[
			-7,
			1
		],
		[
			-23,
			108
		],
		[
			-11,
			-45
		],
		[
			-25,
			54
		],
		[
			-17,
			18
		],
		[
			-12,
			50
		],
		[
			-28,
			68
		],
		[
			0,
			76
		],
		[
			31,
			31
		],
		[
			22,
			51
		],
		[
			-20,
			47
		],
		[
			7,
			75
		],
		[
			-9,
			39
		],
		[
			23,
			44
		],
		[
			3,
			24
		],
		[
			-18,
			1
		],
		[
			-3,
			74
		],
		[
			7,
			43
		],
		[
			-41,
			-17
		],
		[
			6,
			-45
		],
		[
			11,
			-16
		],
		[
			-1,
			-37
		],
		[
			-13,
			-85
		],
		[
			-1,
			-60
		],
		[
			-19,
			-73
		],
		[
			-18,
			13
		],
		[
			7,
			-93
		],
		[
			-10,
			-43
		],
		[
			-24,
			52
		],
		[
			-25,
			22
		],
		[
			-9,
			30
		],
		[
			-12,
			132
		],
		[
			-16,
			70
		],
		[
			21,
			-29
		],
		[
			7,
			75
		],
		[
			27,
			37
		],
		[
			12,
			147
		],
		[
			-8,
			102
		],
		[
			10,
			57
		],
		[
			6,
			-21
		],
		[
			12,
			42
		],
		[
			7,
			92
		],
		[
			-21,
			-11
		],
		[
			-4,
			-58
		],
		[
			-19,
			-30
		],
		[
			-21,
			-61
		],
		[
			13,
			-113
		],
		[
			-8,
			-42
		],
		[
			-33,
			3
		],
		[
			-12,
			-43
		],
		[
			3,
			-30
		],
		[
			-17,
			-14
		],
		[
			-7,
			34
		],
		[
			4,
			67
		],
		[
			-19,
			23
		],
		[
			-12,
			128
		],
		[
			-32,
			-17
		],
		[
			0,
			-48
		],
		[
			-28,
			118
		],
		[
			-3,
			123
		],
		[
			8,
			25
		],
		[
			25,
			1
		],
		[
			7,
			66
		],
		[
			13,
			49
		],
		[
			30,
			12
		],
		[
			16,
			-72
		],
		[
			7,
			63
		],
		[
			-15,
			168
		],
		[
			9,
			3
		],
		[
			30,
			-45
		],
		[
			4,
			-59
		],
		[
			11,
			-32
		],
		[
			6,
			23
		],
		[
			-9,
			77
		],
		[
			-22,
			35
		],
		[
			-19,
			48
		],
		[
			-3,
			53
		],
		[
			-11,
			13
		],
		[
			-12,
			-25
		],
		[
			-10,
			49
		],
		[
			-23,
			32
		],
		[
			-5,
			57
		],
		[
			12,
			23
		],
		[
			-4,
			64
		],
		[
			-22,
			28
		],
		[
			-37,
			66
		],
		[
			-13,
			69
		],
		[
			-15,
			33
		],
		[
			-13,
			79
		],
		[
			29,
			43
		],
		[
			-11,
			58
		],
		[
			-18,
			-47
		],
		[
			-19,
			18
		],
		[
			-2,
			-27
		],
		[
			-23,
			58
		],
		[
			-31,
			8
		],
		[
			-11,
			56
		],
		[
			-27,
			-28
		],
		[
			-54,
			76
		],
		[
			-8,
			75
		],
		[
			15,
			73
		],
		[
			18,
			-22
		],
		[
			33,
			4
		],
		[
			9,
			48
		],
		[
			-22,
			3
		],
		[
			-32,
			36
		],
		[
			2,
			35
		],
		[
			-18,
			125
		],
		[
			13,
			81
		],
		[
			-24,
			-10
		],
		[
			-15,
			19
		],
		[
			-16,
			53
		],
		[
			7,
			103
		],
		[
			20,
			2
		],
		[
			16,
			-36
		],
		[
			33,
			-24
		],
		[
			63,
			-89
		],
		[
			5,
			15
		],
		[
			-25,
			58
		],
		[
			-20,
			19
		],
		[
			-66,
			130
		],
		[
			-3,
			95
		],
		[
			-17,
			-15
		],
		[
			-2,
			-65
		],
		[
			-20,
			3
		],
		[
			-39,
			166
		],
		[
			-55,
			147
		],
		[
			-11,
			140
		],
		[
			9,
			65
		],
		[
			-2,
			52
		],
		[
			27,
			41
		],
		[
			-13,
			100
		],
		[
			-8,
			-2
		],
		[
			-9,
			-85
		],
		[
			-20,
			-30
		],
		[
			0,
			-42
		],
		[
			12,
			-22
		],
		[
			-13,
			-57
		],
		[
			-10,
			10
		],
		[
			-22,
			-20
		],
		[
			-25,
			11
		],
		[
			-36,
			34
		],
		[
			-7,
			-15
		],
		[
			-35,
			36
		],
		[
			-40,
			174
		],
		[
			-4,
			110
		],
		[
			-42,
			140
		],
		[
			-13,
			79
		],
		[
			19,
			1
		],
		[
			-11,
			174
		],
		[
			-19,
			-56
		],
		[
			1,
			-58
		],
		[
			-35,
			132
		],
		[
			-8,
			177
		],
		[
			-8,
			92
		],
		[
			-21,
			135
		],
		[
			-32,
			116
		],
		[
			-36,
			37
		],
		[
			-5,
			-16
		],
		[
			28,
			-38
		],
		[
			4,
			-41
		],
		[
			17,
			-39
		],
		[
			20,
			-131
		],
		[
			-15,
			11
		],
		[
			-34,
			140
		],
		[
			-22,
			36
		],
		[
			-22,
			10
		],
		[
			41,
			-92
		],
		[
			13,
			-85
		],
		[
			17,
			-29
		],
		[
			-7,
			-97
		],
		[
			9,
			-88
		],
		[
			13,
			-23
		],
		[
			-5,
			-24
		],
		[
			27,
			-124
		],
		[
			3,
			-55
		],
		[
			25,
			-139
		],
		[
			2,
			-32
		],
		[
			-14,
			11
		],
		[
			27,
			-204
		],
		[
			9,
			-85
		],
		[
			1,
			-69
		],
		[
			-12,
			8
		],
		[
			-1,
			-61
		],
		[
			12,
			-64
		],
		[
			-29,
			23
		],
		[
			-19,
			32
		],
		[
			-14,
			-4
		],
		[
			-18,
			43
		],
		[
			-15,
			66
		],
		[
			-10,
			84
		],
		[
			-22,
			-16
		],
		[
			-33,
			50
		],
		[
			-27,
			-37
		],
		[
			-50,
			-19
		],
		[
			3,
			81
		],
		[
			-25,
			16
		],
		[
			-4,
			19
		],
		[
			30,
			39
		],
		[
			-10,
			69
		],
		[
			5,
			53
		],
		[
			-28,
			109
		],
		[
			0,
			36
		],
		[
			-22,
			84
		],
		[
			13,
			24
		],
		[
			-2,
			90
		],
		[
			-19,
			64
		],
		[
			-12,
			10
		],
		[
			15,
			-131
		],
		[
			-12,
			-125
		],
		[
			-27,
			-5
		],
		[
			-42,
			70
		],
		[
			-26,
			30
		],
		[
			-15,
			150
		],
		[
			-11,
			-68
		],
		[
			-13,
			-22
		],
		[
			-44,
			54
		],
		[
			-14,
			-20
		],
		[
			-10,
			50
		],
		[
			-12,
			-18
		],
		[
			-3,
			-54
		],
		[
			45,
			-35
		],
		[
			7,
			7
		],
		[
			45,
			-44
		],
		[
			33,
			-66
		],
		[
			30,
			-104
		],
		[
			-11,
			-44
		],
		[
			-24,
			-44
		],
		[
			6,
			-11
		],
		[
			33,
			44
		],
		[
			7,
			30
		],
		[
			27,
			1
		],
		[
			7,
			-105
		],
		[
			26,
			-78
		],
		[
			16,
			-157
		],
		[
			-19,
			-44
		],
		[
			-43,
			-32
		],
		[
			-11,
			10
		],
		[
			9,
			47
		],
		[
			-18,
			16
		],
		[
			-12,
			-17
		],
		[
			7,
			-39
		],
		[
			-10,
			-37
		],
		[
			-43,
			22
		],
		[
			-11,
			-23
		],
		[
			5,
			-60
		],
		[
			-8,
			-35
		],
		[
			-29,
			5
		],
		[
			-8,
			78
		],
		[
			-36,
			35
		],
		[
			3,
			15
		],
		[
			-28,
			74
		],
		[
			-17,
			19
		],
		[
			-29,
			-19
		],
		[
			-35,
			70
		],
		[
			-16,
			15
		],
		[
			-56,
			107
		],
		[
			-51,
			75
		],
		[
			-2,
			50
		],
		[
			-30,
			70
		],
		[
			-37,
			64
		],
		[
			-5,
			28
		],
		[
			4,
			75
		],
		[
			-15,
			48
		],
		[
			-55,
			121
		],
		[
			-30,
			47
		],
		[
			-96,
			89
		],
		[
			-36,
			71
		],
		[
			-43,
			66
		],
		[
			-98,
			104
		],
		[
			-42,
			49
		],
		[
			-91,
			144
		],
		[
			-30,
			39
		],
		[
			5,
			29
		],
		[
			31,
			89
		],
		[
			24,
			-14
		],
		[
			-9,
			-27
		],
		[
			24,
			3
		],
		[
			0,
			43
		],
		[
			21,
			70
		],
		[
			-22,
			7
		],
		[
			2,
			77
		],
		[
			-14,
			116
		],
		[
			7,
			35
		],
		[
			22,
			41
		],
		[
			-5,
			34
		],
		[
			16,
			30
		],
		[
			-13,
			56
		],
		[
			-19,
			-51
		],
		[
			-2,
			-59
		],
		[
			-25,
			-21
		],
		[
			-21,
			-72
		],
		[
			-1,
			-49
		],
		[
			-107,
			-100
		],
		[
			-12,
			-28
		],
		[
			-28,
			-28
		],
		[
			-95,
			22
		],
		[
			-67,
			36
		],
		[
			-26,
			32
		],
		[
			-123,
			125
		],
		[
			-17,
			56
		],
		[
			18,
			-10
		],
		[
			34,
			24
		],
		[
			11,
			71
		],
		[
			-33,
			131
		],
		[
			3,
			42
		],
		[
			-20,
			-17
		],
		[
			-31,
			44
		],
		[
			6,
			-50
		],
		[
			45,
			-120
		],
		[
			-10,
			-21
		],
		[
			-54,
			-51
		],
		[
			-39,
			0
		],
		[
			-49,
			55
		],
		[
			-61,
			24
		],
		[
			-32,
			23
		],
		[
			-81,
			40
		],
		[
			-45,
			11
		],
		[
			-59,
			-4
		],
		[
			-63,
			-33
		],
		[
			-77,
			-12
		],
		[
			-80,
			-28
		],
		[
			-54,
			-48
		],
		[
			-39,
			39
		],
		[
			-45,
			-26
		],
		[
			-64,
			-120
		],
		[
			-46,
			-115
		],
		[
			6,
			65
		],
		[
			36,
			103
		],
		[
			62,
			117
		],
		[
			46,
			2
		],
		[
			-16,
			66
		],
		[
			-49,
			48
		],
		[
			-8,
			25
		],
		[
			-10,
			-82
		],
		[
			-26,
			84
		],
		[
			-26,
			30
		],
		[
			-17,
			-9
		],
		[
			-16,
			27
		],
		[
			-71,
			19
		],
		[
			9,
			28
		],
		[
			38,
			23
		],
		[
			-42,
			33
		],
		[
			-19,
			-6
		],
		[
			-2,
			25
		],
		[
			37,
			156
		],
		[
			-15,
			15
		],
		[
			-13,
			-36
		],
		[
			-29,
			-22
		],
		[
			-1,
			-57
		],
		[
			-20,
			-66
		],
		[
			-39,
			12
		],
		[
			-70,
			97
		],
		[
			1,
			31
		],
		[
			-26,
			36
		],
		[
			-39,
			26
		],
		[
			-41,
			-35
		],
		[
			-22,
			27
		],
		[
			13,
			29
		],
		[
			31,
			32
		],
		[
			25,
			74
		],
		[
			-14,
			10
		],
		[
			-18,
			-49
		],
		[
			-79,
			-93
		],
		[
			-29,
			-23
		],
		[
			-38,
			5
		],
		[
			1,
			-54
		],
		[
			60,
			27
		],
		[
			11,
			-24
		],
		[
			2,
			-53
		],
		[
			-17,
			2
		],
		[
			-28,
			-37
		],
		[
			-18,
			6
		],
		[
			-41,
			-38
		],
		[
			-41,
			-77
		],
		[
			-12,
			2
		],
		[
			-12,
			48
		],
		[
			47,
			77
		],
		[
			-37,
			-12
		],
		[
			-17,
			11
		],
		[
			-1,
			54
		],
		[
			23,
			83
		],
		[
			13,
			27
		],
		[
			18,
			2
		],
		[
			20,
			-31
		],
		[
			24,
			17
		],
		[
			22,
			41
		],
		[
			38,
			13
		],
		[
			57,
			58
		],
		[
			42,
			20
		],
		[
			-9,
			25
		],
		[
			-19,
			-2
		],
		[
			1,
			71
		],
		[
			-11,
			-49
		],
		[
			-19,
			-20
		],
		[
			1,
			30
		],
		[
			25,
			65
		],
		[
			1,
			21
		],
		[
			-33,
			-58
		],
		[
			-45,
			-47
		],
		[
			-19,
			-3
		],
		[
			-4,
			30
		],
		[
			63,
			112
		],
		[
			-6,
			38
		],
		[
			-29,
			-60
		],
		[
			-38,
			-14
		],
		[
			-12,
			26
		],
		[
			-15,
			-49
		],
		[
			-20,
			-14
		],
		[
			-54,
			13
		],
		[
			-10,
			58
		],
		[
			27,
			19
		],
		[
			11,
			-9
		],
		[
			18,
			25
		],
		[
			40,
			16
		],
		[
			29,
			28
		],
		[
			23,
			65
		],
		[
			-25,
			2
		],
		[
			-14,
			-46
		],
		[
			-23,
			-19
		],
		[
			-45,
			-2
		],
		[
			-18,
			68
		],
		[
			-12,
			3
		],
		[
			-17,
			-69
		],
		[
			-21,
			-8
		],
		[
			-4,
			59
		],
		[
			16,
			26
		],
		[
			17,
			-6
		],
		[
			-11,
			44
		],
		[
			-3,
			55
		],
		[
			13,
			34
		],
		[
			26,
			114
		],
		[
			96,
			6
		],
		[
			-7,
			38
		],
		[
			-91,
			-5
		],
		[
			-21,
			-63
		],
		[
			-27,
			-26
		],
		[
			-21,
			-77
		],
		[
			-31,
			-48
		],
		[
			-23,
			12
		],
		[
			20,
			36
		],
		[
			-10,
			113
		],
		[
			-12,
			53
		],
		[
			18,
			30
		],
		[
			-22,
			10
		],
		[
			-14,
			-23
		],
		[
			-1,
			-51
		],
		[
			12,
			-63
		],
		[
			-14,
			-63
		],
		[
			1,
			-41
		],
		[
			-13,
			-15
		],
		[
			-26,
			48
		],
		[
			-2,
			-67
		],
		[
			-27,
			-45
		],
		[
			-21,
			22
		],
		[
			0,
			52
		],
		[
			-11,
			19
		],
		[
			-7,
			-73
		],
		[
			-9,
			15
		],
		[
			4,
			129
		],
		[
			9,
			62
		],
		[
			-15,
			11
		],
		[
			-17,
			-130
		],
		[
			9,
			-111
		],
		[
			-4,
			-29
		],
		[
			-19,
			-9
		],
		[
			1,
			49
		],
		[
			-27,
			34
		],
		[
			-7,
			-46
		],
		[
			16,
			-65
		],
		[
			-13,
			-8
		],
		[
			-38,
			16
		],
		[
			-34,
			-48
		],
		[
			-28,
			9
		],
		[
			-5,
			31
		],
		[
			14,
			95
		],
		[
			42,
			151
		],
		[
			1,
			53
		],
		[
			49,
			123
		],
		[
			16,
			81
		],
		[
			-6,
			18
		],
		[
			-73,
			-211
		],
		[
			-1,
			-35
		],
		[
			-18,
			-58
		],
		[
			-8,
			8
		],
		[
			-8,
			69
		],
		[
			-12,
			-1
		],
		[
			-3,
			-81
		],
		[
			-11,
			-54
		],
		[
			-18,
			-42
		],
		[
			-3,
			-64
		],
		[
			-16,
			-68
		],
		[
			-21,
			27
		],
		[
			-7,
			-44
		],
		[
			24,
			-28
		],
		[
			-5,
			-91
		],
		[
			10,
			-8
		],
		[
			19,
			85
		],
		[
			37,
			6
		],
		[
			11,
			-22
		],
		[
			4,
			-91
		],
		[
			-14,
			-45
		],
		[
			-31,
			-32
		],
		[
			-22,
			-76
		],
		[
			1,
			-63
		],
		[
			21,
			20
		],
		[
			17,
			75
		],
		[
			30,
			44
		],
		[
			30,
			-89
		],
		[
			0,
			-44
		],
		[
			10,
			-43
		],
		[
			-23,
			-192
		],
		[
			-26,
			0
		],
		[
			-9,
			52
		],
		[
			-19,
			9
		],
		[
			1,
			-36
		],
		[
			-27,
			-44
		],
		[
			0,
			-17
		],
		[
			28,
			14
		],
		[
			23,
			-27
		],
		[
			61,
			-124
		],
		[
			26,
			-85
		],
		[
			-15,
			-77
		],
		[
			-13,
			-26
		],
		[
			-34,
			-35
		],
		[
			-17,
			16
		],
		[
			-14,
			-18
		],
		[
			-29,
			-6
		],
		[
			9,
			51
		],
		[
			-26,
			67
		],
		[
			9,
			60
		],
		[
			-17,
			63
		],
		[
			-16,
			-126
		],
		[
			0,
			-62
		],
		[
			-12,
			-41
		],
		[
			-19,
			69
		],
		[
			-9,
			-8
		],
		[
			-7,
			-59
		],
		[
			-18,
			-33
		],
		[
			-34,
			50
		],
		[
			-29,
			-40
		],
		[
			-15,
			52
		],
		[
			-27,
			-21
		],
		[
			-22,
			5
		],
		[
			-9,
			28
		],
		[
			24,
			74
		],
		[
			-9,
			14
		],
		[
			-27,
			-38
		],
		[
			-29,
			-175
		],
		[
			-30,
			-42
		],
		[
			-9,
			18
		],
		[
			14,
			55
		],
		[
			13,
			84
		],
		[
			-15,
			172
		],
		[
			-16,
			5
		],
		[
			-5,
			-28
		],
		[
			1,
			-81
		],
		[
			13,
			-53
		],
		[
			-10,
			-4
		],
		[
			-10,
			-72
		],
		[
			-17,
			11
		],
		[
			-8,
			-20
		],
		[
			-5,
			-68
		],
		[
			-11,
			-17
		],
		[
			4,
			-47
		],
		[
			25,
			-31
		],
		[
			-6,
			-74
		],
		[
			-27,
			32
		],
		[
			-12,
			127
		],
		[
			8,
			37
		],
		[
			-11,
			78
		],
		[
			-17,
			6
		],
		[
			6,
			-52
		],
		[
			-8,
			-49
		],
		[
			5,
			-196
		],
		[
			-5,
			-64
		],
		[
			-27,
			74
		],
		[
			-1,
			43
		],
		[
			-16,
			28
		],
		[
			-34,
			31
		],
		[
			3,
			-40
		],
		[
			24,
			-36
		],
		[
			-1,
			-63
		],
		[
			-69,
			-158
		],
		[
			-32,
			-91
		],
		[
			0,
			-36
		],
		[
			-16,
			-10
		],
		[
			-9,
			-86
		],
		[
			-12,
			2
		],
		[
			-3,
			70
		],
		[
			34,
			211
		],
		[
			0,
			29
		],
		[
			-26,
			-65
		],
		[
			-19,
			-111
		],
		[
			-12,
			11
		],
		[
			-9,
			142
		],
		[
			-13,
			-52
		],
		[
			-11,
			2
		],
		[
			16,
			-62
		],
		[
			-5,
			-80
		],
		[
			-39,
			0
		],
		[
			-8,
			-61
		],
		[
			-18,
			-24
		],
		[
			-22,
			-55
		],
		[
			7,
			-43
		],
		[
			-15,
			-41
		],
		[
			-16,
			-10
		],
		[
			0,
			54
		],
		[
			-16,
			36
		],
		[
			-13,
			-45
		],
		[
			-1,
			-53
		],
		[
			-22,
			-17
		],
		[
			-24,
			31
		],
		[
			-9,
			-23
		],
		[
			-21,
			38
		],
		[
			-7,
			43
		],
		[
			-12,
			-36
		],
		[
			-21,
			-27
		],
		[
			6,
			-35
		],
		[
			-20,
			0
		],
		[
			-5,
			-39
		],
		[
			-41,
			-7
		],
		[
			-6,
			76
		],
		[
			-22,
			-14
		],
		[
			-21,
			22
		],
		[
			3,
			22
		],
		[
			-21,
			8
		],
		[
			-3,
			70
		],
		[
			8,
			36
		],
		[
			16,
			18
		],
		[
			5,
			71
		],
		[
			32,
			31
		],
		[
			9,
			-11
		],
		[
			29,
			51
		],
		[
			33,
			3
		],
		[
			0,
			45
		],
		[
			33,
			21
		],
		[
			34,
			62
		],
		[
			31,
			-9
		],
		[
			-11,
			69
		],
		[
			22,
			26
		],
		[
			3,
			32
		],
		[
			37,
			102
		],
		[
			-13,
			15
		],
		[
			-24,
			-22
		],
		[
			-60,
			-109
		],
		[
			-30,
			-20
		],
		[
			-18,
			-39
		],
		[
			-39,
			16
		],
		[
			-43,
			67
		],
		[
			-15,
			40
		],
		[
			-5,
			46
		],
		[
			18,
			117
		],
		[
			13,
			45
		],
		[
			15,
			133
		],
		[
			27,
			79
		],
		[
			17,
			33
		],
		[
			35,
			99
		],
		[
			11,
			98
		],
		[
			0,
			71
		],
		[
			23,
			32
		],
		[
			5,
			156
		],
		[
			4,
			27
		],
		[
			-18,
			44
		],
		[
			-22,
			163
		],
		[
			39,
			35
		],
		[
			5,
			27
		],
		[
			63,
			27
		],
		[
			89,
			164
		],
		[
			92,
			118
		],
		[
			51,
			-161
		],
		[
			41,
			-16
		],
		[
			13,
			-27
		],
		[
			34,
			112
		],
		[
			30,
			8
		],
		[
			36,
			-45
		],
		[
			19,
			10
		],
		[
			63,
			-48
		],
		[
			65,
			-20
		],
		[
			30,
			-55
		],
		[
			-1,
			27
		],
		[
			-22,
			63
		],
		[
			-29,
			36
		],
		[
			-38,
			-14
		],
		[
			-51,
			63
		],
		[
			-24,
			-1
		],
		[
			-40,
			42
		],
		[
			-25,
			68
		],
		[
			-39,
			66
		],
		[
			-29,
			28
		],
		[
			18,
			55
		],
		[
			24,
			9
		],
		[
			31,
			124
		],
		[
			23,
			18
		],
		[
			8,
			60
		],
		[
			46,
			27
		],
		[
			30,
			45
		],
		[
			-32,
			50
		],
		[
			-20,
			4
		],
		[
			-43,
			-64
		],
		[
			-11,
			-49
		],
		[
			-19,
			-14
		],
		[
			-12,
			-70
		],
		[
			0,
			-70
		],
		[
			-18,
			-31
		],
		[
			-25,
			19
		],
		[
			-36,
			7
		],
		[
			-74,
			-17
		],
		[
			-26,
			43
		],
		[
			-28,
			16
		],
		[
			-14,
			-52
		],
		[
			-87,
			-84
		],
		[
			-39,
			-154
		],
		[
			-36,
			-12
		],
		[
			-19,
			-31
		],
		[
			-33,
			2
		],
		[
			-39,
			-63
		],
		[
			-48,
			-109
		],
		[
			-1,
			-29
		],
		[
			26,
			-124
		],
		[
			-2,
			-23
		],
		[
			-38,
			25
		],
		[
			-19,
			-18
		],
		[
			-30,
			-52
		],
		[
			-21,
			-92
		],
		[
			-27,
			-29
		],
		[
			-32,
			-74
		],
		[
			-6,
			-73
		],
		[
			8,
			-34
		],
		[
			19,
			-24
		],
		[
			-40,
			-56
		],
		[
			-9,
			-67
		],
		[
			-13,
			-4
		],
		[
			-28,
			-70
		],
		[
			-19,
			-7
		],
		[
			-9,
			28
		],
		[
			-25,
			-11
		],
		[
			4,
			-68
		],
		[
			16,
			-13
		],
		[
			-3,
			-30
		],
		[
			25,
			-42
		],
		[
			8,
			-35
		],
		[
			-12,
			-73
		],
		[
			-19,
			-47
		],
		[
			-7,
			-62
		],
		[
			-25,
			-21
		],
		[
			-4,
			-22
		],
		[
			-39,
			-2
		],
		[
			-15,
			12
		],
		[
			-40,
			-31
		],
		[
			-18,
			3
		],
		[
			-19,
			-60
		],
		[
			23,
			16
		],
		[
			15,
			-20
		],
		[
			15,
			30
		],
		[
			19,
			1
		],
		[
			7,
			-50
		],
		[
			-16,
			-116
		],
		[
			-19,
			-16
		],
		[
			-26,
			-51
		],
		[
			-28,
			37
		],
		[
			5,
			-34
		],
		[
			-13,
			-18
		],
		[
			-18,
			18
		],
		[
			7,
			35
		],
		[
			2,
			75
		],
		[
			-22,
			71
		],
		[
			3,
			-119
		],
		[
			-9,
			-55
		],
		[
			-18,
			-15
		],
		[
			-13,
			25
		],
		[
			-6,
			-35
		],
		[
			16,
			-28
		],
		[
			-9,
			-53
		],
		[
			-49,
			-10
		],
		[
			17,
			-93
		],
		[
			-8,
			-32
		],
		[
			-27,
			-21
		],
		[
			-10,
			8
		],
		[
			-24,
			-45
		],
		[
			-12,
			13
		],
		[
			-36,
			-37
		],
		[
			5,
			-26
		],
		[
			20,
			-18
		],
		[
			-23,
			-32
		],
		[
			-7,
			-43
		],
		[
			2,
			-61
		],
		[
			-12,
			-44
		],
		[
			-24,
			-35
		],
		[
			24,
			-26
		],
		[
			-6,
			-59
		],
		[
			10,
			-60
		],
		[
			27,
			63
		],
		[
			59,
			-23
		],
		[
			16,
			22
		],
		[
			12,
			-22
		],
		[
			15,
			25
		],
		[
			22,
			-78
		],
		[
			19,
			-27
		],
		[
			19,
			13
		],
		[
			23,
			-34
		],
		[
			18,
			-53
		],
		[
			8,
			-53
		],
		[
			15,
			-22
		],
		[
			-28,
			-14
		],
		[
			-14,
			-118
		],
		[
			-12,
			-39
		],
		[
			-30,
			-25
		],
		[
			-11,
			-55
		],
		[
			-24,
			-33
		],
		[
			-48,
			0
		],
		[
			-15,
			-17
		],
		[
			-4,
			-94
		],
		[
			-12,
			-33
		],
		[
			-27,
			1
		],
		[
			-5,
			-20
		],
		[
			10,
			-79
		],
		[
			11,
			-32
		],
		[
			-27,
			-36
		],
		[
			-20,
			15
		],
		[
			-2,
			-45
		],
		[
			20,
			-46
		],
		[
			-11,
			-81
		],
		[
			-21,
			-30
		],
		[
			-6,
			-33
		],
		[
			9,
			-24
		],
		[
			-23,
			0
		],
		[
			-14,
			-52
		],
		[
			-26,
			66
		],
		[
			-9,
			-7
		],
		[
			5,
			-57
		],
		[
			-4,
			-40
		],
		[
			-21,
			-3
		],
		[
			-12,
			-43
		],
		[
			-17,
			16
		],
		[
			0,
			27
		],
		[
			-20,
			-1
		],
		[
			-4,
			-39
		],
		[
			-22,
			-24
		],
		[
			-23,
			31
		],
		[
			-28,
			-17
		],
		[
			-35,
			-69
		],
		[
			15,
			-52
		],
		[
			-9,
			-51
		],
		[
			-40,
			-44
		],
		[
			-28,
			-2
		],
		[
			1,
			-53
		],
		[
			14,
			-25
		],
		[
			-6,
			-40
		],
		[
			-20,
			-16
		],
		[
			-36,
			59
		],
		[
			-10,
			30
		],
		[
			-20,
			-20
		],
		[
			-5,
			-63
		],
		[
			1,
			-69
		],
		[
			-26,
			-27
		],
		[
			-3,
			-97
		],
		[
			-65,
			-7
		],
		[
			-21,
			24
		],
		[
			-2,
			-74
		],
		[
			8,
			-71
		],
		[
			-20,
			0
		],
		[
			-12,
			37
		],
		[
			-21,
			3
		],
		[
			-4,
			-39
		],
		[
			-32,
			-27
		],
		[
			-39,
			-92
		],
		[
			-15,
			-12
		],
		[
			-5,
			-44
		],
		[
			13,
			-11
		],
		[
			47,
			64
		],
		[
			4,
			-50
		],
		[
			-6,
			-53
		],
		[
			-15,
			-7
		],
		[
			0,
			-31
		],
		[
			18,
			-38
		],
		[
			-10,
			-38
		],
		[
			-18,
			-26
		],
		[
			-2,
			-49
		],
		[
			-26,
			-44
		],
		[
			-8,
			-32
		],
		[
			2,
			-42
		],
		[
			-32,
			14
		],
		[
			-31,
			-28
		],
		[
			-4,
			-70
		],
		[
			-12,
			-12
		],
		[
			-19,
			75
		],
		[
			-8,
			-53
		],
		[
			-27,
			-42
		],
		[
			-11,
			-53
		],
		[
			-24,
			-6
		],
		[
			5,
			-50
		],
		[
			-17,
			-27
		],
		[
			-25,
			43
		],
		[
			-24,
			67
		],
		[
			-22,
			-16
		],
		[
			0,
			-51
		],
		[
			11,
			-5
		],
		[
			1,
			-36
		],
		[
			-29,
			-10
		],
		[
			-13,
			-67
		],
		[
			6,
			-32
		],
		[
			18,
			-6
		],
		[
			5,
			-52
		],
		[
			-36,
			-4
		],
		[
			-24,
			-15
		],
		[
			-17,
			77
		],
		[
			-51,
			-38
		],
		[
			-18,
			-51
		],
		[
			-16,
			-3
		],
		[
			-9,
			-49
		],
		[
			19,
			-1
		],
		[
			27,
			25
		],
		[
			20,
			-17
		],
		[
			6,
			-54
		],
		[
			-16,
			-47
		],
		[
			-43,
			44
		],
		[
			-23,
			11
		],
		[
			-5,
			-70
		],
		[
			-33,
			6
		],
		[
			-23,
			21
		],
		[
			-20,
			-33
		],
		[
			-27,
			-88
		],
		[
			2,
			-44
		],
		[
			47,
			-20
		],
		[
			32,
			-36
		],
		[
			-3,
			-29
		],
		[
			-32,
			-42
		],
		[
			1,
			-23
		],
		[
			18,
			-4
		],
		[
			25,
			31
		],
		[
			16,
			-7
		],
		[
			-55,
			-78
		],
		[
			-23,
			-63
		],
		[
			1,
			-52
		],
		[
			-13,
			50
		],
		[
			-10,
			-17
		],
		[
			16,
			-66
		],
		[
			-6,
			-50
		],
		[
			-7,
			39
		],
		[
			-10,
			-2
		],
		[
			-2,
			-53
		],
		[
			-25,
			80
		],
		[
			0,
			95
		],
		[
			-19,
			-60
		],
		[
			8,
			-73
		],
		[
			-4,
			-67
		],
		[
			-24,
			-6
		],
		[
			3,
			58
		],
		[
			-35,
			1
		],
		[
			-16,
			-80
		],
		[
			-25,
			-9
		],
		[
			-75,
			-43
		],
		[
			-29,
			-22
		],
		[
			-7,
			-22
		],
		[
			-3,
			-74
		],
		[
			-17,
			46
		],
		[
			5,
			80
		],
		[
			-23,
			-19
		],
		[
			10,
			-30
		],
		[
			1,
			-104
		],
		[
			-16,
			-71
		],
		[
			6,
			-46
		],
		[
			-24,
			-81
		],
		[
			-32,
			-30
		],
		[
			2,
			52
		],
		[
			24,
			4
		],
		[
			-1,
			40
		],
		[
			-10,
			4
		],
		[
			2,
			111
		],
		[
			18,
			72
		],
		[
			-29,
			39
		],
		[
			-28,
			12
		],
		[
			-13,
			-18
		],
		[
			3,
			-45
		],
		[
			-12,
			-21
		],
		[
			-13,
			22
		],
		[
			-25,
			-13
		],
		[
			-9,
			-82
		],
		[
			-35,
			-74
		],
		[
			-26,
			-20
		],
		[
			-37,
			28
		],
		[
			-6,
			-29
		],
		[
			11,
			-44
		],
		[
			-20,
			-81
		],
		[
			1,
			-31
		],
		[
			-21,
			-37
		],
		[
			-12,
			105
		],
		[
			-10,
			13
		],
		[
			-14,
			-37
		],
		[
			-11,
			14
		],
		[
			-18,
			-31
		],
		[
			31,
			-13
		],
		[
			-2,
			-68
		],
		[
			-32,
			-10
		],
		[
			-16,
			25
		],
		[
			5,
			39
		],
		[
			-13,
			24
		],
		[
			-22,
			-22
		],
		[
			-19,
			-90
		],
		[
			-61,
			-85
		],
		[
			-26,
			2
		],
		[
			-11,
			29
		],
		[
			-26,
			-29
		],
		[
			-13,
			4
		],
		[
			10,
			156
		],
		[
			29,
			96
		],
		[
			1,
			46
		],
		[
			-15,
			16
		],
		[
			-31,
			-2
		],
		[
			-24,
			-29
		],
		[
			-24,
			-101
		],
		[
			4,
			-129
		],
		[
			-40,
			-140
		],
		[
			-7,
			-12
		],
		[
			-14,
			-85
		],
		[
			-21,
			36
		],
		[
			-19,
			-12
		],
		[
			13,
			-65
		],
		[
			10,
			-17
		],
		[
			1,
			-56
		],
		[
			-25,
			-38
		],
		[
			-19,
			33
		],
		[
			0,
			45
		],
		[
			-16,
			15
		],
		[
			-13,
			-60
		],
		[
			10,
			-49
		],
		[
			-17,
			-47
		],
		[
			-14,
			27
		],
		[
			-32,
			-8
		],
		[
			-16,
			18
		],
		[
			-14,
			74
		],
		[
			32,
			6
		],
		[
			-21,
			47
		],
		[
			-8,
			104
		],
		[
			-21,
			56
		],
		[
			-11,
			7
		],
		[
			-16,
			-33
		],
		[
			-10,
			-65
		],
		[
			7,
			-27
		],
		[
			14,
			0
		],
		[
			18,
			-70
		],
		[
			-11,
			-46
		],
		[
			14,
			-95
		],
		[
			0,
			-52
		],
		[
			-22,
			30
		],
		[
			-20,
			-19
		],
		[
			3,
			-26
		],
		[
			-17,
			-30
		],
		[
			-18,
			-7
		],
		[
			-22,
			28
		],
		[
			-16,
			59
		],
		[
			4,
			36
		],
		[
			-13,
			56
		],
		[
			-21,
			37
		],
		[
			-31,
			-25
		],
		[
			-10,
			-56
		],
		[
			49,
			-85
		],
		[
			4,
			-31
		],
		[
			-50,
			-111
		],
		[
			-24,
			-21
		],
		[
			-20,
			-33
		],
		[
			16,
			-56
		],
		[
			27,
			2
		],
		[
			9,
			24
		],
		[
			22,
			-50
		],
		[
			13,
			-83
		],
		[
			-26,
			6
		],
		[
			8,
			34
		],
		[
			-17,
			6
		],
		[
			-10,
			-28
		],
		[
			-16,
			22
		],
		[
			-17,
			62
		],
		[
			-25,
			-39
		],
		[
			2,
			-69
		],
		[
			-18,
			-1
		],
		[
			-28,
			-50
		],
		[
			-23,
			18
		],
		[
			-37,
			10
		],
		[
			-45,
			-5
		],
		[
			-34,
			-14
		],
		[
			-41,
			-40
		],
		[
			-29,
			-71
		],
		[
			-4,
			-69
		],
		[
			-29,
			-53
		],
		[
			-51,
			-33
		],
		[
			-29,
			3
		],
		[
			-28,
			28
		],
		[
			-9,
			30
		],
		[
			-9,
			74
		],
		[
			-10,
			30
		],
		[
			-1,
			55
		],
		[
			8,
			29
		],
		[
			44,
			41
		],
		[
			14,
			25
		],
		[
			23,
			110
		],
		[
			19,
			110
		],
		[
			-1,
			29
		],
		[
			22,
			54
		],
		[
			14,
			13
		],
		[
			25,
			-46
		],
		[
			38,
			39
		],
		[
			25,
			49
		],
		[
			25,
			0
		],
		[
			37,
			81
		],
		[
			34,
			20
		],
		[
			36,
			-14
		],
		[
			31,
			5
		],
		[
			1,
			-37
		],
		[
			28,
			-72
		],
		[
			9,
			-61
		],
		[
			-5,
			-50
		],
		[
			27,
			24
		],
		[
			-8,
			52
		],
		[
			2,
			37
		],
		[
			30,
			-30
		],
		[
			-15,
			42
		],
		[
			2,
			77
		],
		[
			-10,
			109
		],
		[
			32,
			46
		],
		[
			26,
			21
		],
		[
			42,
			-15
		],
		[
			21,
			14
		],
		[
			10,
			69
		],
		[
			-16,
			4
		],
		[
			4,
			28
		],
		[
			18,
			10
		],
		[
			7,
			38
		],
		[
			18,
			-4
		],
		[
			26,
			99
		],
		[
			3,
			-32
		],
		[
			15,
			-20
		],
		[
			21,
			48
		],
		[
			-5,
			83
		],
		[
			-20,
			-9
		],
		[
			27,
			68
		],
		[
			64,
			206
		],
		[
			33,
			52
		],
		[
			23,
			62
		],
		[
			19,
			13
		],
		[
			27,
			42
		],
		[
			25,
			68
		],
		[
			27,
			14
		],
		[
			35,
			39
		],
		[
			37,
			20
		],
		[
			89,
			70
		],
		[
			30,
			-9
		],
		[
			10,
			18
		],
		[
			45,
			5
		],
		[
			10,
			-10
		],
		[
			-20,
			-27
		],
		[
			-1,
			-47
		],
		[
			14,
			-2
		],
		[
			-3,
			-49
		],
		[
			-29,
			-18
		],
		[
			-3,
			-85
		],
		[
			38,
			-98
		],
		[
			11,
			22
		],
		[
			27,
			-39
		],
		[
			4,
			19
		],
		[
			-29,
			53
		],
		[
			-3,
			85
		],
		[
			-6,
			32
		],
		[
			26,
			-28
		],
		[
			57,
			3
		],
		[
			7,
			-86
		],
		[
			23,
			7
		],
		[
			26,
			-36
		],
		[
			7,
			22
		],
		[
			-14,
			40
		],
		[
			27,
			15
		],
		[
			-56,
			89
		],
		[
			-32,
			36
		],
		[
			1,
			58
		],
		[
			-16,
			-7
		],
		[
			39,
			166
		],
		[
			15,
			123
		],
		[
			11,
			56
		],
		[
			23,
			44
		],
		[
			36,
			96
		],
		[
			18,
			13
		],
		[
			40,
			74
		],
		[
			30,
			81
		],
		[
			82,
			96
		],
		[
			41,
			74
		],
		[
			35,
			39
		],
		[
			68,
			106
		],
		[
			17,
			42
		],
		[
			29,
			-68
		],
		[
			19,
			-14
		],
		[
			31,
			19
		],
		[
			8,
			59
		],
		[
			-13,
			47
		],
		[
			-2,
			46
		],
		[
			15,
			122
		],
		[
			29,
			108
		],
		[
			41,
			130
		],
		[
			24,
			62
		],
		[
			22,
			37
		],
		[
			40,
			41
		],
		[
			21,
			52
		],
		[
			22,
			87
		],
		[
			14,
			15
		],
		[
			26,
			62
		],
		[
			30,
			25
		],
		[
			8,
			-74
		],
		[
			18,
			-15
		],
		[
			4,
			41
		],
		[
			-10,
			105
		],
		[
			-23,
			-2
		],
		[
			-6,
			34
		],
		[
			2,
			95
		],
		[
			9,
			59
		],
		[
			25,
			409
		],
		[
			14,
			42
		],
		[
			38,
			16
		],
		[
			12,
			53
		],
		[
			-20,
			-9
		],
		[
			-34,
			77
		],
		[
			-3,
			62
		],
		[
			9,
			97
		],
		[
			20,
			106
		],
		[
			27,
			33
		],
		[
			29,
			101
		],
		[
			49,
			102
		],
		[
			4,
			57
		],
		[
			19,
			93
		],
		[
			-5,
			45
		],
		[
			13,
			33
		],
		[
			-3,
			43
		],
		[
			13,
			38
		],
		[
			-20,
			0
		],
		[
			-11,
			-32
		],
		[
			0,
			-38
		],
		[
			-21,
			-53
		],
		[
			-28,
			-31
		],
		[
			-38,
			-27
		],
		[
			-21,
			-31
		],
		[
			-29,
			-22
		],
		[
			-5,
			-21
		],
		[
			-41,
			-28
		],
		[
			-44,
			-61
		],
		[
			-79,
			-73
		],
		[
			-26,
			5
		],
		[
			-28,
			53
		],
		[
			-5,
			73
		],
		[
			-20,
			49
		],
		[
			-40,
			38
		],
		[
			2,
			46
		],
		[
			11,
			17
		],
		[
			9,
			167
		],
		[
			-12,
			-3
		],
		[
			-25,
			-101
		],
		[
			-41,
			-54
		],
		[
			-6,
			-58
		],
		[
			5,
			-58
		],
		[
			-8,
			-37
		],
		[
			-14,
			-12
		],
		[
			-3,
			-32
		],
		[
			9,
			-80
		],
		[
			16,
			-91
		],
		[
			19,
			-76
		],
		[
			-26,
			-87
		],
		[
			-28,
			-21
		],
		[
			-42,
			32
		],
		[
			-39,
			161
		],
		[
			-47,
			208
		],
		[
			-26,
			73
		],
		[
			-23,
			42
		],
		[
			-31,
			13
		],
		[
			16,
			65
		],
		[
			-16,
			44
		],
		[
			-25,
			-9
		],
		[
			-6,
			-87
		],
		[
			-15,
			7
		],
		[
			1,
			-65
		],
		[
			-29,
			-30
		],
		[
			-24,
			79
		],
		[
			3,
			26
		],
		[
			-19,
			19
		],
		[
			-11,
			-30
		],
		[
			-16,
			6
		],
		[
			-1,
			59
		],
		[
			-22,
			-18
		],
		[
			-25,
			61
		],
		[
			18,
			47
		],
		[
			-17,
			89
		],
		[
			-44,
			-52
		],
		[
			-46,
			-72
		],
		[
			-31,
			-62
		],
		[
			-20,
			-95
		],
		[
			-13,
			57
		],
		[
			-36,
			-33
		],
		[
			-94,
			-124
		],
		[
			-10,
			-41
		],
		[
			0,
			-49
		],
		[
			-41,
			-38
		],
		[
			-8,
			-26
		],
		[
			-22,
			-10
		],
		[
			-15,
			-44
		],
		[
			-20,
			-15
		],
		[
			-4,
			55
		],
		[
			-29,
			45
		],
		[
			-54,
			-20
		],
		[
			-29,
			33
		],
		[
			49,
			47
		],
		[
			15,
			-39
		],
		[
			18,
			12
		],
		[
			5,
			50
		],
		[
			25,
			77
		],
		[
			3,
			60
		],
		[
			-8,
			85
		],
		[
			1,
			81
		],
		[
			-16,
			74
		],
		[
			5,
			21
		],
		[
			-16,
			20
		],
		[
			-29,
			97
		],
		[
			-20,
			139
		],
		[
			29,
			128
		],
		[
			21,
			23
		],
		[
			24,
			79
		],
		[
			24,
			26
		],
		[
			-15,
			77
		],
		[
			-18,
			44
		],
		[
			-15,
			64
		],
		[
			-10,
			107
		],
		[
			-50,
			162
		],
		[
			-3,
			74
		],
		[
			-25,
			67
		],
		[
			-10,
			63
		],
		[
			-30,
			85
		],
		[
			-10,
			44
		],
		[
			-22,
			9
		],
		[
			-11,
			-37
		],
		[
			-2,
			-74
		],
		[
			6,
			-37
		],
		[
			-8,
			-56
		],
		[
			-12,
			-21
		],
		[
			-27,
			-10
		],
		[
			-18,
			21
		],
		[
			-19,
			-54
		],
		[
			-36,
			-29
		],
		[
			-50,
			-68
		],
		[
			-73,
			-48
		],
		[
			-88,
			-28
		],
		[
			-75,
			10
		],
		[
			-51,
			38
		],
		[
			-13,
			32
		],
		[
			-13,
			99
		],
		[
			23,
			18
		],
		[
			-18,
			69
		],
		[
			-54,
			62
		],
		[
			-32,
			108
		],
		[
			-5,
			34
		],
		[
			-33,
			51
		],
		[
			-18,
			62
		],
		[
			-42,
			8
		],
		[
			-31,
			42
		],
		[
			-47,
			110
		],
		[
			23,
			32
		],
		[
			24,
			55
		],
		[
			-2,
			36
		],
		[
			-24,
			6
		],
		[
			-38,
			-54
		],
		[
			-48,
			10
		],
		[
			-16,
			51
		],
		[
			11,
			32
		],
		[
			32,
			1
		],
		[
			57,
			128
		],
		[
			10,
			-4
		],
		[
			17,
			45
		],
		[
			-16,
			34
		],
		[
			-4,
			41
		],
		[
			32,
			24
		],
		[
			-27,
			7
		],
		[
			5,
			70
		],
		[
			27,
			78
		],
		[
			-17,
			3
		],
		[
			-18,
			-48
		],
		[
			-40,
			42
		],
		[
			-6,
			40
		],
		[
			22,
			49
		],
		[
			27,
			-6
		],
		[
			19,
			23
		],
		[
			0,
			45
		],
		[
			-17,
			-21
		],
		[
			-30,
			32
		],
		[
			-16,
			54
		],
		[
			2,
			23
		],
		[
			-20,
			7
		],
		[
			-13,
			35
		],
		[
			-10,
			-14
		],
		[
			-12,
			-99
		],
		[
			-14,
			-6
		],
		[
			-38,
			16
		],
		[
			-10,
			21
		],
		[
			-10,
			66
		],
		[
			1,
			129
		],
		[
			-11,
			19
		],
		[
			-43,
			10
		],
		[
			-18,
			37
		],
		[
			-10,
			98
		],
		[
			42,
			44
		],
		[
			6,
			38
		],
		[
			-17,
			46
		],
		[
			-30,
			31
		],
		[
			-45,
			-27
		],
		[
			0,
			-46
		],
		[
			-21,
			23
		],
		[
			-9,
			88
		],
		[
			8,
			147
		],
		[
			6,
			11
		],
		[
			-2,
			-107
		],
		[
			92,
			47
		],
		[
			0,
			19
		],
		[
			-35,
			20
		],
		[
			-20,
			28
		],
		[
			-24,
			82
		],
		[
			2,
			18
		],
		[
			36,
			19
		],
		[
			55,
			-8
		],
		[
			33,
			25
		],
		[
			-29,
			134
		],
		[
			-4,
			46
		],
		[
			3,
			84
		],
		[
			21,
			77
		],
		[
			101,
			278
		],
		[
			4,
			29
		],
		[
			27,
			77
		],
		[
			29,
			61
		],
		[
			5,
			70
		],
		[
			18,
			67
		],
		[
			21,
			34
		],
		[
			19,
			-4
		],
		[
			9,
			23
		],
		[
			-11,
			115
		],
		[
			26,
			188
		],
		[
			18,
			70
		],
		[
			38,
			61
		],
		[
			-18,
			24
		],
		[
			4,
			22
		],
		[
			58,
			133
		],
		[
			60,
			46
		],
		[
			48,
			11
		],
		[
			42,
			-45
		],
		[
			43,
			-11
		],
		[
			32,
			-84
		],
		[
			24,
			-6
		],
		[
			6,
			-26
		],
		[
			54,
			-88
		],
		[
			73,
			24
		],
		[
			61,
			124
		],
		[
			4,
			47
		],
		[
			44,
			29
		],
		[
			63,
			172
		],
		[
			23,
			89
		],
		[
			23,
			39
		],
		[
			-9,
			58
		],
		[
			14,
			5
		],
		[
			28,
			-28
		],
		[
			22,
			-5
		],
		[
			13,
			-77
		],
		[
			52,
			0
		],
		[
			45,
			20
		],
		[
			26,
			-20
		],
		[
			77,
			28
		],
		[
			48,
			38
		],
		[
			9,
			51
		],
		[
			56,
			128
		],
		[
			38,
			135
		],
		[
			0,
			71
		],
		[
			-12,
			81
		],
		[
			-23,
			95
		],
		[
			-17,
			121
		],
		[
			-1,
			118
		],
		[
			-5,
			52
		],
		[
			-71,
			157
		],
		[
			-9,
			32
		],
		[
			-41,
			28
		],
		[
			-27,
			1
		],
		[
			10,
			97
		],
		[
			27,
			33
		],
		[
			14,
			-25
		],
		[
			35,
			-20
		],
		[
			51,
			7
		],
		[
			-10,
			45
		],
		[
			31,
			10
		],
		[
			41,
			81
		],
		[
			2,
			114
		],
		[
			-42,
			122
		],
		[
			-47,
			68
		],
		[
			-25,
			48
		],
		[
			-1,
			-32
		],
		[
			-27,
			-48
		],
		[
			-20,
			-86
		],
		[
			-42,
			-30
		],
		[
			-42,
			42
		],
		[
			-59,
			-93
		],
		[
			-81,
			-34
		],
		[
			-18,
			-71
		],
		[
			-85,
			-103
		],
		[
			-21,
			-70
		],
		[
			-5,
			-99
		],
		[
			-44,
			-70
		],
		[
			-4,
			93
		],
		[
			-15,
			110
		],
		[
			-23,
			50
		],
		[
			-28,
			-3
		],
		[
			4,
			34
		],
		[
			-32,
			46
		],
		[
			-9,
			36
		],
		[
			-38,
			-60
		],
		[
			16,
			-45
		],
		[
			21,
			-7
		],
		[
			16,
			-39
		],
		[
			24,
			11
		],
		[
			2,
			-48
		],
		[
			-22,
			-81
		],
		[
			-19,
			-11
		],
		[
			-22,
			82
		],
		[
			-55,
			76
		],
		[
			-41,
			33
		],
		[
			-64,
			13
		],
		[
			-41,
			-27
		],
		[
			-27,
			12
		],
		[
			-52,
			3
		],
		[
			-45,
			-22
		],
		[
			-108,
			-112
		],
		[
			-58,
			-17
		],
		[
			-111,
			74
		],
		[
			-94,
			45
		],
		[
			-47,
			14
		],
		[
			-88,
			40
		],
		[
			-49,
			79
		],
		[
			-20,
			96
		],
		[
			1,
			74
		],
		[
			20,
			36
		],
		[
			-6,
			64
		],
		[
			-28,
			63
		],
		[
			-45,
			56
		],
		[
			-1,
			59
		],
		[
			-46,
			64
		],
		[
			-10,
			56
		],
		[
			39,
			-33
		],
		[
			33,
			3
		],
		[
			9,
			27
		],
		[
			24,
			15
		],
		[
			16,
			32
		],
		[
			-3,
			55
		],
		[
			35,
			61
		],
		[
			-38,
			63
		],
		[
			-19,
			9
		],
		[
			-29,
			-16
		],
		[
			-39,
			15
		],
		[
			-64,
			52
		],
		[
			-104,
			21
		],
		[
			-49,
			52
		],
		[
			-38,
			63
		],
		[
			-55,
			60
		],
		[
			-46,
			30
		],
		[
			-15,
			93
		]
	],
	[
		[
			2812,
			78476
		],
		[
			27,
			27
		],
		[
			-1,
			59
		],
		[
			18,
			0
		],
		[
			10,
			36
		],
		[
			0,
			57
		],
		[
			21,
			33
		],
		[
			5,
			57
		],
		[
			-10,
			16
		],
		[
			11,
			87
		],
		[
			46,
			106
		],
		[
			16,
			-26
		],
		[
			27,
			16
		],
		[
			28,
			-3
		],
		[
			-9,
			65
		],
		[
			-12,
			5
		],
		[
			9,
			77
		],
		[
			-6,
			26
		],
		[
			18,
			76
		],
		[
			40,
			67
		],
		[
			54,
			37
		],
		[
			29,
			-53
		],
		[
			31,
			1
		],
		[
			2,
			-23
		],
		[
			-21,
			-74
		],
		[
			5,
			-60
		],
		[
			-55,
			-95
		],
		[
			-65,
			-72
		],
		[
			-19,
			-66
		],
		[
			-1,
			-36
		],
		[
			-28,
			-81
		],
		[
			-15,
			-58
		],
		[
			-25,
			-10
		],
		[
			-28,
			-71
		],
		[
			-15,
			-17
		],
		[
			-4,
			-51
		],
		[
			-15,
			21
		],
		[
			-27,
			-49
		],
		[
			-54,
			-69
		],
		[
			13,
			45
		]
	],
	[
		[
			2752,
			78371
		],
		[
			29,
			49
		],
		[
			-1,
			-45
		],
		[
			-26,
			-25
		],
		[
			-2,
			21
		]
	],
	[
		[
			2615,
			78610
		],
		[
			4,
			50
		],
		[
			19,
			16
		],
		[
			4,
			-44
		],
		[
			-9,
			-45
		],
		[
			-12,
			-8
		],
		[
			-6,
			31
		]
	],
	[
		[
			2607,
			82847
		],
		[
			50,
			-13
		],
		[
			29,
			5
		],
		[
			10,
			-14
		],
		[
			-27,
			-68
		],
		[
			-23,
			4
		],
		[
			-9,
			46
		],
		[
			-20,
			10
		],
		[
			-10,
			30
		]
	],
	[
		[
			2611,
			78728
		],
		[
			8,
			-39
		],
		[
			-15,
			13
		],
		[
			7,
			26
		]
	],
	[
		[
			2547,
			78457
		],
		[
			17,
			17
		],
		[
			23,
			-3
		],
		[
			-2,
			19
		],
		[
			27,
			23
		],
		[
			19,
			-10
		],
		[
			10,
			-25
		],
		[
			-17,
			-105
		],
		[
			-30,
			50
		],
		[
			-25,
			-29
		],
		[
			-19,
			14
		],
		[
			-3,
			49
		]
	],
	[
		[
			2517,
			78521
		],
		[
			8,
			26
		],
		[
			23,
			-16
		],
		[
			1,
			-31
		],
		[
			-14,
			-31
		],
		[
			-13,
			16
		],
		[
			-5,
			36
		]
	],
	[
		[
			2497,
			78313
		],
		[
			4,
			72
		],
		[
			33,
			-18
		],
		[
			-7,
			-57
		],
		[
			-30,
			3
		]
	],
	[
		[
			2431,
			83489
		],
		[
			9,
			43
		],
		[
			22,
			15
		],
		[
			12,
			-10
		],
		[
			29,
			22
		],
		[
			-2,
			-56
		],
		[
			-32,
			-62
		],
		[
			-5,
			31
		],
		[
			-33,
			17
		]
	],
	[
		[
			2316,
			78170
		],
		[
			5,
			42
		],
		[
			40,
			72
		],
		[
			31,
			-27
		],
		[
			1,
			-27
		],
		[
			-13,
			-58
		],
		[
			-19,
			2
		],
		[
			-17,
			-26
		],
		[
			-15,
			-48
		],
		[
			-15,
			21
		],
		[
			2,
			49
		]
	],
	[
		[
			2228,
			78152
		],
		[
			9,
			-32
		],
		[
			-16,
			2
		],
		[
			7,
			30
		]
	],
	[
		[
			2183,
			78046
		],
		[
			17,
			42
		],
		[
			16,
			-37
		],
		[
			-12,
			-55
		],
		[
			-19,
			-1
		],
		[
			-2,
			51
		]
	],
	[
		[
			2036,
			90914
		],
		[
			2,
			37
		],
		[
			25,
			87
		],
		[
			-3,
			75
		],
		[
			8,
			18
		],
		[
			-5,
			57
		],
		[
			21,
			3
		],
		[
			8,
			-42
		],
		[
			-4,
			-48
		],
		[
			12,
			-34
		],
		[
			64,
			-57
		],
		[
			77,
			-48
		],
		[
			55,
			-20
		],
		[
			58,
			87
		],
		[
			58,
			58
		],
		[
			58,
			-14
		],
		[
			29,
			-69
		],
		[
			23,
			-15
		],
		[
			15,
			-104
		],
		[
			-2,
			-38
		],
		[
			53,
			-56
		],
		[
			56,
			-14
		],
		[
			22,
			-32
		],
		[
			9,
			-35
		],
		[
			36,
			-20
		],
		[
			88,
			-20
		],
		[
			14,
			6
		],
		[
			102,
			-55
		],
		[
			-27,
			-131
		],
		[
			-22,
			-43
		],
		[
			-51,
			35
		],
		[
			-43,
			-1
		],
		[
			-50,
			-29
		],
		[
			-44,
			-89
		],
		[
			-10,
			-61
		],
		[
			1,
			-53
		],
		[
			-20,
			-46
		],
		[
			-30,
			22
		],
		[
			3,
			24
		],
		[
			-26,
			119
		],
		[
			-32,
			62
		],
		[
			-50,
			60
		],
		[
			-39,
			-5
		],
		[
			-11,
			69
		],
		[
			-17,
			55
		],
		[
			-54,
			80
		],
		[
			-86,
			69
		],
		[
			-65,
			11
		],
		[
			-47,
			-44
		],
		[
			-18,
			-58
		],
		[
			-36,
			-34
		],
		[
			-28,
			33
		],
		[
			-49,
			36
		],
		[
			-24,
			83
		],
		[
			-7,
			56
		],
		[
			3,
			73
		]
	],
	[
		[
			1818,
			77819
		],
		[
			15,
			59
		],
		[
			33,
			49
		],
		[
			12,
			-2
		],
		[
			27,
			-39
		],
		[
			-1,
			-41
		],
		[
			-28,
			-51
		],
		[
			-32,
			-27
		],
		[
			-22,
			-1
		],
		[
			-4,
			53
		]
	],
	[
		[
			1695,
			87369
		],
		[
			6,
			69
		],
		[
			25,
			52
		],
		[
			11,
			-3
		],
		[
			-4,
			-58
		],
		[
			12,
			-54
		],
		[
			33,
			-70
		],
		[
			48,
			-63
		],
		[
			22,
			-14
		],
		[
			25,
			13
		],
		[
			57,
			-94
		],
		[
			-21,
			-19
		],
		[
			-9,
			37
		],
		[
			-51,
			8
		],
		[
			-26,
			-17
		],
		[
			-33,
			46
		],
		[
			-58,
			136
		],
		[
			-37,
			31
		]
	],
	[
		[
			1687,
			87598
		],
		[
			8,
			-5
		],
		[
			5,
			-84
		],
		[
			-20,
			42
		],
		[
			7,
			47
		]
	],
	[
		[
			1421,
			77626
		],
		[
			35,
			0
		],
		[
			33,
			-31
		],
		[
			9,
			30
		],
		[
			14,
			-2
		],
		[
			33,
			27
		],
		[
			25,
			-1
		],
		[
			-6,
			-28
		],
		[
			10,
			-29
		],
		[
			8,
			15
		],
		[
			31,
			-24
		],
		[
			23,
			16
		],
		[
			10,
			-11
		],
		[
			32,
			11
		],
		[
			5,
			-12
		],
		[
			41,
			-7
		],
		[
			-25,
			-23
		],
		[
			-16,
			6
		],
		[
			-14,
			-22
		],
		[
			-44,
			-1
		],
		[
			-22,
			-35
		],
		[
			-8,
			16
		],
		[
			-16,
			-19
		],
		[
			-19,
			4
		],
		[
			-18,
			25
		],
		[
			-52,
			3
		],
		[
			-9,
			-15
		],
		[
			-29,
			19
		],
		[
			-10,
			49
		],
		[
			-11,
			-1
		],
		[
			-10,
			40
		]
	],
	[
		[
			1064,
			77503
		],
		[
			55,
			37
		],
		[
			11,
			-28
		],
		[
			25,
			50
		],
		[
			3,
			-22
		],
		[
			19,
			38
		],
		[
			5,
			29
		],
		[
			18,
			-29
		],
		[
			27,
			8
		],
		[
			8,
			34
		],
		[
			6,
			-24
		],
		[
			35,
			37
		],
		[
			1,
			42
		],
		[
			44,
			10
		],
		[
			-13,
			41
		],
		[
			43,
			-5
		],
		[
			13,
			34
		],
		[
			-1,
			36
		],
		[
			-32,
			7
		],
		[
			-23,
			29
		],
		[
			5,
			26
		],
		[
			21,
			-16
		],
		[
			12,
			36
		],
		[
			-2,
			39
		],
		[
			38,
			46
		],
		[
			33,
			-32
		],
		[
			22,
			-76
		],
		[
			1,
			-31
		],
		[
			-21,
			-85
		],
		[
			-34,
			8
		],
		[
			-4,
			-43
		],
		[
			33,
			-79
		],
		[
			-3,
			-24
		],
		[
			-15,
			21
		],
		[
			-17,
			-10
		],
		[
			-4,
			-27
		],
		[
			-16,
			-4
		],
		[
			-20,
			23
		],
		[
			-19,
			-95
		],
		[
			-25,
			31
		],
		[
			-64,
			-55
		],
		[
			-13,
			29
		],
		[
			-29,
			12
		],
		[
			-23,
			-6
		],
		[
			-13,
			-35
		],
		[
			-22,
			-8
		],
		[
			-33,
			6
		],
		[
			-32,
			25
		]
	],
	[
		[
			1013,
			77451
		],
		[
			17,
			17
		],
		[
			7,
			-29
		],
		[
			-22,
			-4
		],
		[
			-2,
			16
		]
	],
	[
		[
			1005,
			77685
		],
		[
			16,
			-19
		],
		[
			-11,
			-12
		],
		[
			-5,
			31
		]
	],
	[
		[
			949,
			77433
		],
		[
			5,
			9
		],
		[
			40,
			-3
		],
		[
			1,
			-26
		],
		[
			-19,
			3
		],
		[
			-22,
			-24
		],
		[
			-5,
			41
		]
	],
	[
		[
			890,
			77452
		],
		[
			11,
			14
		],
		[
			28,
			-1
		],
		[
			15,
			-90
		],
		[
			-16,
			5
		],
		[
			-17,
			49
		],
		[
			-21,
			23
		]
	],
	[
		[
			821,
			77563
		],
		[
			14,
			45
		],
		[
			26,
			-9
		],
		[
			23,
			-80
		],
		[
			-20,
			-38
		],
		[
			15,
			-56
		],
		[
			-13,
			-34
		],
		[
			-18,
			-2
		],
		[
			-18,
			22
		],
		[
			3,
			57
		],
		[
			-7,
			2
		],
		[
			-8,
			77
		],
		[
			3,
			16
		]
	],
	[
		[
			811,
			77269
		],
		[
			5,
			56
		],
		[
			12,
			10
		],
		[
			10,
			-27
		],
		[
			19,
			10
		],
		[
			-12,
			22
		],
		[
			34,
			30
		],
		[
			10,
			-23
		],
		[
			-2,
			-55
		],
		[
			-23,
			0
		],
		[
			13,
			-52
		],
		[
			-29,
			29
		],
		[
			2,
			-40
		],
		[
			-12,
			12
		],
		[
			-5,
			-39
		],
		[
			-7,
			45
		],
		[
			-15,
			22
		]
	],
	[
		[
			601,
			77040
		],
		[
			11,
			67
		],
		[
			15,
			16
		],
		[
			7,
			36
		],
		[
			-13,
			66
		],
		[
			4,
			27
		],
		[
			32,
			7
		],
		[
			7,
			59
		],
		[
			-13,
			69
		],
		[
			10,
			45
		],
		[
			15,
			4
		],
		[
			18,
			-20
		],
		[
			19,
			59
		],
		[
			9,
			-14
		],
		[
			3,
			-74
		],
		[
			-20,
			-29
		],
		[
			-2,
			-50
		],
		[
			13,
			-20
		],
		[
			19,
			4
		],
		[
			31,
			26
		],
		[
			30,
			5
		],
		[
			7,
			-64
		],
		[
			-7,
			-88
		],
		[
			-15,
			-12
		],
		[
			-36,
			18
		],
		[
			-13,
			-52
		],
		[
			-18,
			-12
		],
		[
			-13,
			-41
		],
		[
			-23,
			31
		],
		[
			-6,
			-25
		],
		[
			6,
			-48
		],
		[
			-11,
			17
		],
		[
			-13,
			-26
		],
		[
			-4,
			55
		],
		[
			-14,
			29
		],
		[
			-19,
			-108
		],
		[
			-14,
			11
		],
		[
			-2,
			32
		]
	],
	[
		[
			469,
			77371
		],
		[
			13,
			9
		],
		[
			2,
			-26
		],
		[
			-14,
			-17
		],
		[
			-1,
			34
		]
	],
	[
		[
			402,
			77131
		],
		[
			18,
			33
		],
		[
			24,
			-17
		],
		[
			26,
			34
		],
		[
			50,
			39
		],
		[
			21,
			43
		],
		[
			2,
			128
		],
		[
			12,
			16
		],
		[
			16,
			-10
		],
		[
			15,
			-44
		],
		[
			-26,
			-98
		],
		[
			5,
			-86
		],
		[
			-7,
			-38
		],
		[
			-33,
			-31
		],
		[
			-36,
			61
		],
		[
			-27,
			-33
		],
		[
			-40,
			-10
		],
		[
			-1,
			-43
		],
		[
			-10,
			5
		],
		[
			-9,
			51
		]
	],
	[
		[
			257,
			77332
		],
		[
			8,
			29
		],
		[
			29,
			17
		],
		[
			39,
			-5
		],
		[
			11,
			-42
		],
		[
			-2,
			-30
		],
		[
			19,
			-32
		],
		[
			15,
			17
		],
		[
			18,
			-17
		],
		[
			33,
			34
		],
		[
			-10,
			-40
		],
		[
			-41,
			-32
		],
		[
			-12,
			-71
		],
		[
			4,
			-31
		],
		[
			-12,
			-31
		],
		[
			-8,
			16
		],
		[
			-9,
			-44
		],
		[
			8,
			-57
		],
		[
			-8,
			-5
		],
		[
			-9,
			56
		],
		[
			-14,
			-24
		],
		[
			-16,
			48
		],
		[
			-13,
			8
		],
		[
			4,
			28
		],
		[
			41,
			25
		],
		[
			-3,
			64
		],
		[
			-20,
			1
		],
		[
			-13,
			34
		],
		[
			-39,
			66
		],
		[
			0,
			18
		]
	],
	[
		[
			130,
			77016
		],
		[
			32,
			-12
		],
		[
			-3,
			-18
		],
		[
			-27,
			7
		],
		[
			-2,
			23
		]
	],
	[
		[
			81,
			76979
		],
		[
			27,
			-17
		],
		[
			7,
			-23
		],
		[
			-25,
			5
		],
		[
			-9,
			35
		]
	],
	[
		[
			77,
			77233
		],
		[
			14,
			52
		],
		[
			20,
			-35
		],
		[
			0,
			-61
		],
		[
			-19,
			-10
		],
		[
			-15,
			54
		]
	],
	[
		[
			43,
			76751
		],
		[
			8,
			25
		],
		[
			10,
			-22
		],
		[
			5,
			-50
		],
		[
			-12,
			-2
		],
		[
			-10,
			-32
		],
		[
			-1,
			81
		]
	],
	[
		[
			3,
			76640
		],
		[
			12,
			18
		],
		[
			6,
			-59
		],
		[
			-18,
			-25
		],
		[
			0,
			66
		]
	],
	[
		[
			99917,
			77451
		],
		[
			12,
			-2
		],
		[
			12,
			35
		],
		[
			26,
			14
		],
		[
			31,
			-61
		],
		[
			-9,
			-68
		],
		[
			-24,
			-42
		],
		[
			-12,
			-5
		],
		[
			-25,
			29
		],
		[
			-11,
			29
		],
		[
			0,
			71
		]
	],
	[
		[
			99678,
			77049
		],
		[
			5,
			24
		],
		[
			26,
			-29
		],
		[
			19,
			3
		],
		[
			27,
			-24
		],
		[
			4,
			-31
		],
		[
			24,
			-42
		],
		[
			27,
			-78
		],
		[
			25,
			-26
		],
		[
			11,
			-57
		],
		[
			44,
			-11
		],
		[
			21,
			-33
		],
		[
			-18,
			-19
		],
		[
			-9,
			14
		],
		[
			-29,
			-16
		],
		[
			-15,
			41
		],
		[
			-41,
			72
		],
		[
			-30,
			101
		],
		[
			-30,
			43
		],
		[
			-17,
			-8
		],
		[
			-22,
			25
		],
		[
			-22,
			51
		]
	],
	[
		[
			99628,
			77446
		],
		[
			9,
			11
		],
		[
			20,
			-16
		],
		[
			11,
			-33
		],
		[
			-14,
			-49
		],
		[
			-10,
			-4
		],
		[
			-16,
			91
		]
	],
	[
		[
			99570,
			77271
		],
		[
			19,
			-7
		],
		[
			21,
			-67
		],
		[
			-22,
			15
		],
		[
			-18,
			59
		]
	],
	[
		[
			99530,
			77510
		],
		[
			7,
			22
		],
		[
			17,
			-22
		],
		[
			3,
			-34
		],
		[
			-17,
			-20
		],
		[
			-10,
			54
		]
	],
	[
		[
			99282,
			77351
		],
		[
			24,
			27
		],
		[
			15,
			50
		],
		[
			39,
			26
		],
		[
			6,
			63
		],
		[
			16,
			96
		],
		[
			11,
			18
		],
		[
			20,
			-52
		],
		[
			-12,
			-32
		],
		[
			-8,
			-57
		],
		[
			-20,
			-53
		],
		[
			21,
			-18
		],
		[
			0,
			-35
		],
		[
			-13,
			-10
		],
		[
			-42,
			17
		],
		[
			-17,
			-31
		],
		[
			-4,
			-70
		],
		[
			-11,
			2
		],
		[
			-25,
			40
		],
		[
			0,
			19
		]
	],
	[
		[
			98911,
			77903
		],
		[
			26,
			-13
		],
		[
			-18,
			-27
		],
		[
			-8,
			40
		]
	],
	[
		[
			98408,
			78327
		],
		[
			22,
			-8
		],
		[
			3,
			-26
		],
		[
			-24,
			15
		],
		[
			-1,
			19
		]
	],
	[
		[
			98376,
			78346
		],
		[
			14,
			-8
		],
		[
			0,
			-29
		],
		[
			-14,
			37
		]
	],
	[
		[
			98352,
			78374
		],
		[
			20,
			-27
		],
		[
			-12,
			-2
		],
		[
			-8,
			29
		]
	],
	[
		[
			98210,
			77943
		],
		[
			6,
			31
		],
		[
			19,
			27
		],
		[
			23,
			-6
		],
		[
			26,
			67
		],
		[
			41,
			5
		],
		[
			-17,
			-40
		],
		[
			-5,
			-37
		],
		[
			10,
			-104
		],
		[
			-21,
			0
		],
		[
			-17,
			52
		],
		[
			-35,
			-19
		],
		[
			-30,
			24
		]
	],
	[
		[
			97960,
			78551
		],
		[
			47,
			86
		],
		[
			33,
			11
		],
		[
			100,
			-20
		],
		[
			29,
			-63
		],
		[
			24,
			-15
		],
		[
			35,
			-94
		],
		[
			2,
			-18
		],
		[
			-35,
			-8
		],
		[
			-21,
			38
		],
		[
			-17,
			-71
		],
		[
			-9,
			-13
		],
		[
			-38,
			15
		],
		[
			-26,
			-41
		],
		[
			-27,
			32
		],
		[
			-12,
			40
		],
		[
			-3,
			63
		],
		[
			-32,
			56
		],
		[
			-35,
			-24
		],
		[
			-15,
			26
		]
	],
	[
		[
			13347,
			81071
		],
		[
			9,
			23
		],
		[
			10,
			-28
		],
		[
			-5,
			-52
		],
		[
			-16,
			34
		],
		[
			2,
			23
		]
	],
	[
		[
			13279,
			80906
		],
		[
			61,
			56
		],
		[
			7,
			-80
		],
		[
			13,
			-14
		],
		[
			-20,
			-68
		],
		[
			-24,
			-1
		],
		[
			-33,
			63
		],
		[
			-4,
			44
		]
	],
	[
		[
			13241,
			80901
		],
		[
			26,
			65
		],
		[
			8,
			-25
		],
		[
			-26,
			-58
		],
		[
			-8,
			18
		]
	],
	[
		[
			13234,
			81005
		],
		[
			16,
			62
		],
		[
			-2,
			43
		],
		[
			13,
			20
		],
		[
			-14,
			43
		],
		[
			-2,
			70
		],
		[
			5,
			39
		],
		[
			11,
			9
		],
		[
			19,
			-32
		],
		[
			5,
			-35
		],
		[
			13,
			-7
		],
		[
			17,
			-40
		],
		[
			0,
			-165
		],
		[
			-9,
			-34
		],
		[
			-27,
			-2
		],
		[
			-13,
			32
		],
		[
			-23,
			-36
		],
		[
			-9,
			33
		]
	],
	[
		[
			13172,
			81388
		],
		[
			4,
			66
		],
		[
			6,
			1
		],
		[
			52,
			-135
		],
		[
			-12,
			-28
		],
		[
			-1,
			-68
		],
		[
			-15,
			-111
		],
		[
			-23,
			74
		],
		[
			-9,
			113
		],
		[
			-2,
			88
		]
	],
	[
		[
			12999,
			82714
		],
		[
			4,
			48
		],
		[
			9,
			-30
		],
		[
			-13,
			-18
		]
	],
	[
		[
			12979,
			82569
		],
		[
			2,
			29
		],
		[
			21,
			40
		],
		[
			21,
			-38
		],
		[
			-1,
			-22
		],
		[
			-24,
			-37
		],
		[
			-19,
			28
		]
	],
	[
		[
			12954,
			82690
		],
		[
			20,
			33
		],
		[
			17,
			52
		],
		[
			-5,
			-50
		],
		[
			-18,
			-75
		],
		[
			-14,
			40
		]
	],
	[
		[
			12888,
			80934
		],
		[
			18,
			6
		],
		[
			-4,
			-53
		],
		[
			-14,
			47
		]
	],
	[
		[
			12850,
			82395
		],
		[
			7,
			53
		],
		[
			10,
			-24
		],
		[
			22,
			-97
		],
		[
			10,
			-68
		],
		[
			-13,
			-15
		],
		[
			-21,
			61
		],
		[
			-9,
			4
		],
		[
			-6,
			86
		]
	],
	[
		[
			12838,
			82543
		],
		[
			18,
			86
		],
		[
			21,
			30
		],
		[
			30,
			-20
		],
		[
			24,
			22
		],
		[
			28,
			-42
		],
		[
			4,
			-36
		],
		[
			-18,
			-53
		],
		[
			6,
			-82
		],
		[
			-16,
			-19
		],
		[
			-44,
			-22
		],
		[
			-23,
			65
		],
		[
			-24,
			29
		],
		[
			-6,
			42
		]
	],
	[
		[
			12768,
			81460
		],
		[
			21,
			27
		],
		[
			-2,
			-46
		],
		[
			-16,
			-11
		],
		[
			-3,
			30
		]
	],
	[
		[
			12700,
			80811
		],
		[
			9,
			0
		],
		[
			10,
			-128
		],
		[
			-15,
			29
		],
		[
			-4,
			99
		]
	],
	[
		[
			12674,
			81692
		],
		[
			9,
			23
		],
		[
			1,
			61
		],
		[
			20,
			-30
		],
		[
			1,
			-32
		],
		[
			-22,
			-72
		],
		[
			-9,
			50
		]
	],
	[
		[
			12659,
			81749
		],
		[
			12,
			9
		],
		[
			-1,
			-36
		],
		[
			-11,
			27
		]
	],
	[
		[
			12637,
			81497
		],
		[
			8,
			92
		],
		[
			8,
			25
		],
		[
			32,
			-9
		],
		[
			10,
			-16
		],
		[
			-2,
			-35
		],
		[
			-16,
			-42
		],
		[
			8,
			-16
		],
		[
			20,
			40
		],
		[
			5,
			43
		],
		[
			13,
			-19
		],
		[
			19,
			68
		],
		[
			19,
			-2
		],
		[
			16,
			-39
		],
		[
			-5,
			-60
		],
		[
			-15,
			-35
		],
		[
			-19,
			15
		],
		[
			-13,
			-35
		],
		[
			17,
			-22
		],
		[
			-2,
			-37
		],
		[
			-22,
			-21
		],
		[
			-22,
			-50
		],
		[
			-9,
			-97
		],
		[
			-23,
			78
		],
		[
			17,
			61
		],
		[
			-1,
			78
		],
		[
			-29,
			51
		],
		[
			-14,
			-16
		]
	],
	[
		[
			12629,
			82086
		],
		[
			11,
			22
		],
		[
			24,
			102
		],
		[
			28,
			10
		],
		[
			11,
			20
		],
		[
			-22,
			13
		],
		[
			-1,
			47
		],
		[
			15,
			-22
		],
		[
			9,
			34
		],
		[
			-36,
			62
		],
		[
			14,
			29
		],
		[
			-10,
			86
		],
		[
			23,
			49
		],
		[
			45,
			-24
		],
		[
			71,
			-17
		],
		[
			24,
			-82
		],
		[
			11,
			-73
		],
		[
			-5,
			-69
		],
		[
			14,
			-6
		],
		[
			13,
			-68
		],
		[
			17,
			-48
		],
		[
			17,
			5
		],
		[
			57,
			-119
		],
		[
			12,
			-52
		],
		[
			33,
			-111
		],
		[
			3,
			-126
		],
		[
			29,
			-29
		],
		[
			8,
			-82
		],
		[
			8,
			-32
		],
		[
			31,
			-50
		],
		[
			13,
			-58
		],
		[
			-10,
			-6
		],
		[
			-19,
			46
		],
		[
			-75,
			98
		],
		[
			-3,
			-31
		],
		[
			-23,
			-74
		],
		[
			11,
			-8
		],
		[
			14,
			47
		],
		[
			8,
			-19
		],
		[
			23,
			10
		],
		[
			5,
			-37
		],
		[
			20,
			-13
		],
		[
			10,
			-29
		],
		[
			-38,
			-14
		],
		[
			8,
			-36
		],
		[
			32,
			21
		],
		[
			14,
			-52
		],
		[
			16,
			-14
		],
		[
			11,
			-87
		],
		[
			8,
			-9
		],
		[
			-12,
			-49
		],
		[
			-20,
			9
		],
		[
			2,
			-32
		],
		[
			22,
			-22
		],
		[
			11,
			8
		],
		[
			3,
			46
		],
		[
			14,
			36
		],
		[
			9,
			-21
		],
		[
			5,
			-91
		],
		[
			-15,
			-34
		],
		[
			4,
			-36
		],
		[
			-22,
			-94
		],
		[
			-29,
			-40
		],
		[
			18,
			-23
		],
		[
			27,
			59
		],
		[
			15,
			-10
		],
		[
			0,
			-203
		],
		[
			7,
			-72
		],
		[
			-20,
			-105
		],
		[
			-37,
			-9
		],
		[
			-26,
			48
		],
		[
			-14,
			-19
		],
		[
			-17,
			38
		],
		[
			-1,
			37
		],
		[
			-38,
			-2
		],
		[
			17,
			53
		],
		[
			27,
			-10
		],
		[
			1,
			39
		],
		[
			-19,
			42
		],
		[
			-19,
			13
		],
		[
			-35,
			78
		],
		[
			9,
			38
		],
		[
			10,
			115
		],
		[
			-15,
			9
		],
		[
			-11,
			-58
		],
		[
			7,
			101
		],
		[
			8,
			28
		],
		[
			-11,
			39
		],
		[
			-5,
			-55
		],
		[
			-27,
			-21
		],
		[
			14,
			-103
		],
		[
			-18,
			-58
		],
		[
			-47,
			56
		],
		[
			-4,
			35
		],
		[
			17,
			58
		],
		[
			-18,
			100
		],
		[
			-20,
			-5
		],
		[
			-10,
			50
		],
		[
			-21,
			3
		],
		[
			12,
			-78
		],
		[
			18,
			-65
		],
		[
			6,
			-72
		],
		[
			-7,
			-36
		],
		[
			15,
			-17
		],
		[
			20,
			-145
		],
		[
			24,
			-26
		],
		[
			-4,
			58
		],
		[
			24,
			18
		],
		[
			28,
			-65
		],
		[
			4,
			-124
		],
		[
			-14,
			-16
		],
		[
			-18,
			74
		],
		[
			-7,
			-7
		],
		[
			23,
			-170
		],
		[
			-29,
			0
		],
		[
			-26,
			32
		],
		[
			-2,
			60
		],
		[
			-20,
			40
		],
		[
			-49,
			177
		],
		[
			-10,
			22
		],
		[
			-2,
			84
		],
		[
			-12,
			10
		],
		[
			-8,
			61
		],
		[
			29,
			8
		],
		[
			-27,
			33
		],
		[
			3,
			119
		],
		[
			-33,
			-28
		],
		[
			-10,
			26
		],
		[
			-18,
			-19
		],
		[
			-9,
			42
		],
		[
			6,
			84
		],
		[
			33,
			30
		],
		[
			11,
			-63
		],
		[
			17,
			20
		],
		[
			-13,
			29
		],
		[
			6,
			39
		],
		[
			14,
			20
		],
		[
			14,
			-14
		],
		[
			22,
			44
		],
		[
			-29,
			96
		],
		[
			14,
			12
		],
		[
			-16,
			32
		],
		[
			4,
			66
		],
		[
			-24,
			-21
		],
		[
			-49,
			87
		],
		[
			-4,
			28
		],
		[
			16,
			-1
		],
		[
			-9,
			50
		],
		[
			3,
			35
		],
		[
			-27,
			18
		],
		[
			6,
			-57
		],
		[
			-10,
			-13
		],
		[
			-32,
			39
		],
		[
			-16,
			58
		],
		[
			12,
			52
		],
		[
			28,
			14
		],
		[
			37,
			-54
		],
		[
			28,
			35
		],
		[
			-17,
			67
		],
		[
			-18,
			16
		],
		[
			-12,
			-20
		],
		[
			-9,
			17
		],
		[
			8,
			30
		],
		[
			-2,
			42
		],
		[
			7,
			63
		],
		[
			-5,
			16
		],
		[
			-13,
			-47
		],
		[
			-27,
			-65
		],
		[
			-22,
			-33
		],
		[
			-23,
			38
		],
		[
			-5,
			45
		]
	],
	[
		[
			12611,
			83642
		],
		[
			15,
			25
		],
		[
			14,
			-33
		],
		[
			-27,
			-31
		],
		[
			-2,
			39
		]
	],
	[
		[
			12594,
			82026
		],
		[
			14,
			28
		],
		[
			11,
			-6
		],
		[
			4,
			-52
		],
		[
			-8,
			-48
		],
		[
			-10,
			3
		],
		[
			-11,
			75
		]
	],
	[
		[
			12476,
			82024
		],
		[
			28,
			22
		],
		[
			1,
			-43
		],
		[
			31,
			33
		],
		[
			8,
			75
		],
		[
			7,
			-2
		],
		[
			-9,
			-101
		],
		[
			-22,
			-24
		],
		[
			-20,
			-56
		],
		[
			-18,
			17
		],
		[
			8,
			30
		],
		[
			-14,
			49
		]
	],
	[
		[
			12463,
			83115
		],
		[
			17,
			52
		],
		[
			16,
			17
		],
		[
			7,
			33
		],
		[
			33,
			-1
		],
		[
			1,
			26
		],
		[
			28,
			-40
		],
		[
			11,
			-83
		],
		[
			18,
			-54
		],
		[
			31,
			-2
		],
		[
			9,
			-21
		],
		[
			10,
			26
		],
		[
			-29,
			44
		],
		[
			-13,
			80
		],
		[
			-2,
			55
		],
		[
			-35,
			79
		],
		[
			11,
			53
		],
		[
			34,
			26
		],
		[
			51,
			-37
		],
		[
			25,
			-9
		],
		[
			47,
			-44
		],
		[
			31,
			-20
		],
		[
			7,
			14
		],
		[
			57,
			-11
		],
		[
			30,
			-74
		],
		[
			14,
			-82
		],
		[
			3,
			-56
		],
		[
			9,
			-23
		],
		[
			23,
			-11
		],
		[
			16,
			-48
		],
		[
			5,
			-46
		],
		[
			33,
			-52
		],
		[
			9,
			-64
		],
		[
			15,
			-34
		],
		[
			-31,
			-38
		],
		[
			-20,
			-42
		],
		[
			-26,
			-24
		],
		[
			-16,
			16
		],
		[
			-31,
			4
		],
		[
			-43,
			24
		],
		[
			5,
			-48
		],
		[
			-23,
			-51
		],
		[
			-40,
			25
		],
		[
			-19,
			29
		],
		[
			-12,
			-47
		],
		[
			-15,
			-20
		],
		[
			-25,
			-2
		],
		[
			-17,
			15
		],
		[
			-3,
			87
		],
		[
			-11,
			32
		],
		[
			-30,
			-64
		],
		[
			13,
			-29
		],
		[
			-2,
			-90
		],
		[
			-23,
			-3
		],
		[
			-2,
			-31
		],
		[
			10,
			-51
		],
		[
			-11,
			-51
		],
		[
			-2,
			-62
		],
		[
			-17,
			-50
		],
		[
			4,
			-39
		],
		[
			-9,
			-64
		],
		[
			-10,
			-11
		],
		[
			-25,
			15
		],
		[
			-14,
			-103
		],
		[
			-15,
			19
		],
		[
			-12,
			52
		],
		[
			-7,
			63
		],
		[
			-1,
			109
		],
		[
			-10,
			87
		],
		[
			2,
			75
		],
		[
			14,
			48
		],
		[
			-3,
			57
		],
		[
			15,
			101
		],
		[
			-12,
			28
		],
		[
			-22,
			-1
		],
		[
			5,
			77
		],
		[
			-20,
			56
		],
		[
			-8,
			75
		],
		[
			2,
			43
		],
		[
			-5,
			91
		]
	],
	[
		[
			12311,
			84926
		],
		[
			43,
			-96
		],
		[
			7,
			-47
		],
		[
			14,
			-9
		],
		[
			8,
			-130
		],
		[
			19,
			1
		],
		[
			21,
			38
		],
		[
			11,
			-23
		],
		[
			20,
			-2
		],
		[
			21,
			-29
		],
		[
			54,
			13
		],
		[
			-3,
			-89
		],
		[
			25,
			-75
		],
		[
			2,
			-52
		],
		[
			21,
			-52
		],
		[
			14,
			-87
		],
		[
			17,
			-55
		],
		[
			2,
			-142
		],
		[
			21,
			-60
		],
		[
			4,
			-65
		],
		[
			-9,
			-2
		],
		[
			-5,
			47
		],
		[
			-38,
			120
		],
		[
			-10,
			115
		],
		[
			-19,
			37
		],
		[
			-9,
			53
		],
		[
			-21,
			0
		],
		[
			26,
			-101
		],
		[
			4,
			-34
		],
		[
			-13,
			-23
		],
		[
			35,
			-121
		],
		[
			23,
			-49
		],
		[
			-2,
			-62
		],
		[
			24,
			-113
		],
		[
			-19,
			6
		],
		[
			15,
			-102
		],
		[
			0,
			-27
		],
		[
			-25,
			-62
		],
		[
			-20,
			26
		],
		[
			-17,
			-1
		],
		[
			4,
			-34
		],
		[
			-21,
			-104
		],
		[
			-38,
			-83
		],
		[
			-24,
			-25
		],
		[
			-2,
			-33
		],
		[
			-31,
			-65
		],
		[
			-29,
			3
		],
		[
			-9,
			89
		],
		[
			-4,
			135
		],
		[
			21,
			80
		],
		[
			15,
			23
		],
		[
			-16,
			31
		],
		[
			-1,
			69
		],
		[
			14,
			6
		],
		[
			12,
			-39
		],
		[
			6,
			23
		],
		[
			-40,
			141
		],
		[
			-1,
			58
		],
		[
			-18,
			60
		],
		[
			-5,
			82
		],
		[
			-11,
			43
		],
		[
			8,
			125
		],
		[
			-12,
			81
		],
		[
			-3,
			95
		],
		[
			-11,
			91
		],
		[
			4,
			44
		],
		[
			-20,
			93
		],
		[
			-17,
			45
		],
		[
			-9,
			77
		],
		[
			-6,
			101
		],
		[
			3,
			42
		]
	],
	[
		[
			12292,
			85061
		],
		[
			35,
			-45
		],
		[
			27,
			-125
		],
		[
			-10,
			-5
		],
		[
			-22,
			115
		],
		[
			-23,
			19
		],
		[
			-7,
			41
		]
	],
	[
		[
			12202,
			85643
		],
		[
			15,
			-71
		],
		[
			0,
			-46
		],
		[
			-10,
			29
		],
		[
			-5,
			88
		]
	],
	[
		[
			12106,
			83714
		],
		[
			16,
			11
		],
		[
			1,
			26
		],
		[
			28,
			65
		],
		[
			-4,
			68
		],
		[
			36,
			64
		],
		[
			18,
			-12
		],
		[
			25,
			-85
		],
		[
			15,
			10
		],
		[
			18,
			-58
		],
		[
			23,
			-24
		],
		[
			38,
			4
		],
		[
			22,
			-14
		],
		[
			12,
			-79
		],
		[
			-2,
			-49
		],
		[
			-20,
			35
		],
		[
			-19,
			-2
		],
		[
			-1,
			-22
		],
		[
			21,
			-25
		],
		[
			11,
			-46
		],
		[
			29,
			-278
		],
		[
			-1,
			-71
		],
		[
			12,
			-56
		],
		[
			0,
			-58
		],
		[
			18,
			-142
		],
		[
			5,
			-107
		],
		[
			-5,
			-112
		],
		[
			-11,
			1
		],
		[
			8,
			-81
		],
		[
			3,
			-240
		],
		[
			-9,
			-111
		],
		[
			-11,
			6
		],
		[
			-28,
			70
		],
		[
			-10,
			86
		],
		[
			-21,
			59
		],
		[
			-40,
			212
		],
		[
			4,
			48
		],
		[
			22,
			23
		],
		[
			-18,
			30
		],
		[
			-26,
			-31
		],
		[
			-14,
			88
		],
		[
			-11,
			-15
		],
		[
			-17,
			42
		],
		[
			-12,
			55
		],
		[
			2,
			34
		],
		[
			-14,
			-22
		],
		[
			-10,
			24
		],
		[
			-30,
			2
		],
		[
			-19,
			96
		],
		[
			19,
			3
		],
		[
			10,
			-29
		],
		[
			10,
			13
		],
		[
			-3,
			105
		],
		[
			19,
			53
		],
		[
			6,
			38
		],
		[
			-39,
			86
		],
		[
			24,
			63
		],
		[
			-4,
			22
		],
		[
			14,
			35
		],
		[
			4,
			53
		],
		[
			-33,
			16
		],
		[
			-21,
			-28
		],
		[
			-14,
			79
		],
		[
			-26,
			72
		]
	],
	[
		[
			12097,
			84881
		],
		[
			16,
			18
		],
		[
			19,
			-7
		],
		[
			16,
			-52
		],
		[
			-29,
			-6
		],
		[
			-22,
			47
		]
	],
	[
		[
			12062,
			83572
		],
		[
			4,
			48
		],
		[
			-3,
			66
		],
		[
			25,
			9
		],
		[
			34,
			-62
		],
		[
			15,
			-74
		],
		[
			12,
			-19
		],
		[
			17,
			30
		],
		[
			23,
			-10
		],
		[
			-16,
			-82
		],
		[
			-24,
			-14
		],
		[
			-27,
			-161
		],
		[
			-12,
			6
		],
		[
			-40,
			-30
		],
		[
			-9,
			8
		],
		[
			3,
			102
		],
		[
			25,
			47
		],
		[
			1,
			50
		],
		[
			-22,
			4
		],
		[
			2,
			29
		],
		[
			-13,
			31
		],
		[
			5,
			22
		]
	],
	[
		[
			11978,
			85151
		],
		[
			9,
			14
		],
		[
			7,
			-59
		],
		[
			-16,
			45
		]
	],
	[
		[
			11978,
			84786
		],
		[
			30,
			41
		],
		[
			3,
			-53
		],
		[
			-16,
			-19
		],
		[
			-17,
			31
		]
	],
	[
		[
			11861,
			84371
		],
		[
			5,
			174
		],
		[
			16,
			33
		],
		[
			8,
			-9
		],
		[
			29,
			60
		],
		[
			3,
			51
		],
		[
			-12,
			92
		],
		[
			32,
			-2
		],
		[
			0,
			-54
		],
		[
			12,
			-60
		],
		[
			28,
			61
		],
		[
			29,
			-6
		],
		[
			17,
			-20
		],
		[
			17,
			49
		],
		[
			36,
			50
		],
		[
			14,
			-55
		],
		[
			41,
			-30
		],
		[
			25,
			-53
		],
		[
			-12,
			-78
		],
		[
			-31,
			-76
		],
		[
			4,
			-49
		],
		[
			12,
			-5
		],
		[
			8,
			60
		],
		[
			32,
			108
		],
		[
			15,
			12
		],
		[
			34,
			-55
		],
		[
			46,
			-10
		],
		[
			11,
			-32
		],
		[
			29,
			-16
		],
		[
			15,
			-79
		],
		[
			-4,
			-67
		],
		[
			-22,
			-44
		],
		[
			-37,
			49
		],
		[
			-10,
			-8
		],
		[
			12,
			-40
		],
		[
			18,
			-18
		],
		[
			33,
			-75
		],
		[
			-21,
			-29
		],
		[
			-25,
			-2
		],
		[
			4,
			-28
		],
		[
			21,
			-13
		],
		[
			23,
			24
		],
		[
			7,
			-95
		],
		[
			14,
			-69
		],
		[
			12,
			-143
		],
		[
			-14,
			-42
		],
		[
			-42,
			-11
		],
		[
			-17,
			12
		],
		[
			-44,
			95
		],
		[
			-65,
			99
		],
		[
			-27,
			50
		],
		[
			-22,
			-26
		],
		[
			-9,
			29
		],
		[
			-4,
			-32
		],
		[
			30,
			-55
		],
		[
			22,
			-8
		],
		[
			-21,
			-31
		],
		[
			6,
			-25
		],
		[
			0,
			-72
		],
		[
			-9,
			-50
		],
		[
			-31,
			-87
		],
		[
			-51,
			47
		],
		[
			-1,
			38
		],
		[
			-42,
			85
		],
		[
			-20,
			90
		],
		[
			-12,
			-38
		],
		[
			-19,
			43
		],
		[
			-10,
			79
		],
		[
			4,
			25
		],
		[
			-18,
			86
		],
		[
			2,
			24
		],
		[
			-16,
			57
		],
		[
			-26,
			30
		],
		[
			-7,
			49
		],
		[
			-25,
			36
		]
	],
	[
		[
			9331,
			87212
		],
		[
			28,
			-14
		],
		[
			12,
			-44
		],
		[
			-27,
			-9
		],
		[
			-13,
			67
		]
	],
	[
		[
			9232,
			87245
		],
		[
			16,
			14
		],
		[
			58,
			-26
		],
		[
			-3,
			-31
		],
		[
			-21,
			-10
		],
		[
			-50,
			53
		]
	],
	[
		[
			8867,
			87809
		],
		[
			26,
			35
		],
		[
			27,
			3
		],
		[
			15,
			-16
		],
		[
			-18,
			-53
		],
		[
			-50,
			31
		]
	],
	[
		[
			8817,
			87545
		],
		[
			4,
			86
		],
		[
			28,
			16
		],
		[
			21,
			-89
		],
		[
			-11,
			-44
		],
		[
			-37,
			-10
		],
		[
			-5,
			41
		]
	],
	[
		[
			8816,
			87079
		],
		[
			2,
			14
		],
		[
			43,
			47
		],
		[
			1,
			-36
		],
		[
			-40,
			-59
		],
		[
			-6,
			34
		]
	],
	[
		[
			8698,
			86532
		],
		[
			8,
			21
		],
		[
			3,
			71
		],
		[
			23,
			12
		],
		[
			-3,
			42
		],
		[
			21,
			54
		],
		[
			16,
			7
		],
		[
			-3,
			41
		],
		[
			30,
			34
		],
		[
			9,
			30
		],
		[
			43,
			75
		],
		[
			22,
			118
		],
		[
			27,
			44
		],
		[
			-3,
			40
		],
		[
			10,
			71
		],
		[
			27,
			34
		],
		[
			4,
			-43
		],
		[
			24,
			2
		],
		[
			-17,
			-51
		],
		[
			9,
			-17
		],
		[
			24,
			28
		],
		[
			8,
			-22
		],
		[
			-11,
			-37
		],
		[
			-62,
			-118
		],
		[
			-49,
			-129
		],
		[
			-8,
			-80
		],
		[
			-33,
			-60
		],
		[
			30,
			-57
		],
		[
			-19,
			-42
		],
		[
			-23,
			-8
		],
		[
			-22,
			15
		],
		[
			-17,
			-57
		],
		[
			-9,
			6
		],
		[
			-45,
			-47
		],
		[
			-14,
			23
		]
	],
	[
		[
			8692,
			87068
		],
		[
			44,
			270
		],
		[
			11,
			-41
		],
		[
			12,
			13
		],
		[
			-4,
			66
		],
		[
			44,
			84
		],
		[
			0,
			-54
		],
		[
			-12,
			-32
		],
		[
			-3,
			-82
		],
		[
			-20,
			-37
		],
		[
			20,
			-42
		],
		[
			-24,
			-97
		],
		[
			2,
			-46
		],
		[
			-17,
			-104
		],
		[
			-24,
			45
		],
		[
			-3,
			25
		],
		[
			-25,
			7
		],
		[
			-1,
			25
		]
	],
	[
		[
			8672,
			87628
		],
		[
			15,
			31
		],
		[
			17,
			-19
		],
		[
			17,
			-48
		],
		[
			-24,
			-45
		],
		[
			-25,
			81
		]
	],
	[
		[
			17950,
			55027
		],
		[
			5,
			31
		],
		[
			24,
			-13
		],
		[
			25,
			26
		],
		[
			-2,
			40
		],
		[
			18,
			63
		],
		[
			1,
			79
		],
		[
			-15,
			136
		],
		[
			-16,
			8
		],
		[
			-7,
			-13
		],
		[
			-13,
			25
		],
		[
			-3,
			-17
		],
		[
			-14,
			68
		],
		[
			7,
			67
		],
		[
			2,
			142
		],
		[
			-15,
			41
		],
		[
			9,
			65
		],
		[
			-8,
			51
		],
		[
			19,
			9
		],
		[
			28,
			138
		],
		[
			9,
			24
		],
		[
			-4,
			46
		],
		[
			4,
			110
		],
		[
			8,
			12
		],
		[
			-2,
			74
		],
		[
			-7,
			64
		],
		[
			1,
			51
		],
		[
			6,
			6
		],
		[
			-2,
			55
		],
		[
			-7,
			20
		],
		[
			28,
			116
		],
		[
			0,
			69
		],
		[
			8,
			28
		],
		[
			23,
			29
		],
		[
			10,
			40
		],
		[
			17,
			21
		],
		[
			1,
			19
		],
		[
			25,
			65
		],
		[
			-1,
			49
		],
		[
			-11,
			54
		],
		[
			-14,
			19
		],
		[
			-31,
			100
		],
		[
			-13,
			7
		],
		[
			2,
			58
		],
		[
			-26,
			239
		],
		[
			-23,
			63
		],
		[
			-7,
			69
		],
		[
			-16,
			57
		],
		[
			1,
			147
		]
	],
	[
		[
			17974,
			57684
		],
		[
			6,
			95
		],
		[
			-10,
			22
		],
		[
			21,
			43
		],
		[
			0,
			72
		],
		[
			-9,
			178
		],
		[
			-6,
			65
		],
		[
			-11,
			47
		],
		[
			-4,
			58
		],
		[
			6,
			36
		],
		[
			0,
			103
		],
		[
			-9,
			38
		],
		[
			3,
			39
		],
		[
			-7,
			31
		],
		[
			3,
			51
		],
		[
			-5,
			59
		],
		[
			4,
			56
		],
		[
			9,
			24
		],
		[
			-10,
			31
		],
		[
			-12,
			97
		],
		[
			4,
			43
		],
		[
			-7,
			80
		],
		[
			25,
			31
		],
		[
			9,
			29
		],
		[
			5,
			-14
		],
		[
			12,
			25
		],
		[
			17,
			-1
		],
		[
			2,
			-25
		],
		[
			24,
			19
		],
		[
			13,
			-3
		],
		[
			18,
			-71
		],
		[
			-2,
			-28
		],
		[
			21,
			-51
		],
		[
			24,
			11
		],
		[
			24,
			183
		],
		[
			5,
			15
		],
		[
			1,
			230
		],
		[
			-2,
			272
		],
		[
			0,
			437
		]
	],
	[
		[
			18136,
			60011
		],
		[
			200,
			0
		],
		[
			222,
			0
		],
		[
			313,
			1
		],
		[
			97,
			1
		],
		[
			160,
			2
		],
		[
			6,
			-7
		],
		[
			235,
			0
		],
		[
			162,
			1
		]
	],
	[
		[
			19531,
			60009
		],
		[
			0,
			-1691
		],
		[
			-1,
			-237
		],
		[
			1,
			-30
		],
		[
			0,
			-925
		],
		[
			-1,
			-608
		],
		[
			1,
			-145
		],
		[
			-1,
			-113
		],
		[
			0,
			-2847
		]
	],
	[
		[
			19530,
			53413
		],
		[
			-64,
			2
		],
		[
			-201,
			-1
		],
		[
			-128,
			-1
		],
		[
			-172,
			0
		],
		[
			-359,
			476
		],
		[
			-212,
			269
		],
		[
			-102,
			136
		],
		[
			-368,
			471
		],
		[
			5,
			66
		],
		[
			-5,
			17
		],
		[
			1,
			60
		],
		[
			8,
			16
		],
		[
			17,
			103
		]
	],
	[
		[
			19530,
			64667
		],
		[
			242,
			0
		],
		[
			154,
			2
		],
		[
			327,
			0
		],
		[
			66,
			-5
		],
		[
			137,
			-1
		],
		[
			242,
			1
		],
		[
			7,
			2
		],
		[
			217,
			2
		]
	],
	[
		[
			20922,
			64668
		],
		[
			282,
			1
		],
		[
			135,
			0
		],
		[
			140,
			0
		],
		[
			0,
			-1163
		]
	],
	[
		[
			21479,
			63506
		],
		[
			1,
			-381
		],
		[
			0,
			-434
		],
		[
			1,
			-193
		],
		[
			0,
			-1270
		],
		[
			1,
			-137
		],
		[
			0,
			-1089
		]
	],
	[
		[
			21482,
			60002
		],
		[
			-183,
			3
		],
		[
			-22,
			5
		],
		[
			-62,
			1
		]
	],
	[
		[
			21215,
			60011
		],
		[
			-204,
			-3
		],
		[
			-169,
			-5
		],
		[
			-184,
			0
		],
		[
			-34,
			2
		],
		[
			-301,
			-1
		],
		[
			-186,
			-2
		],
		[
			-2,
			9
		],
		[
			-152,
			-1
		],
		[
			-230,
			-1
		],
		[
			-222,
			0
		]
	],
	[
		[
			19531,
			60009
		],
		[
			0,
			583
		],
		[
			1,
			36
		],
		[
			0,
			738
		],
		[
			-5,
			129
		],
		[
			0,
			517
		],
		[
			2,
			216
		],
		[
			0,
			1857
		],
		[
			1,
			46
		],
		[
			0,
			536
		]
	],
	[
		[
			27414,
			45876
		],
		[
			14,
			60
		],
		[
			5,
			-33
		],
		[
			-14,
			-44
		],
		[
			-5,
			17
		]
	],
	[
		[
			27386,
			45813
		],
		[
			9,
			39
		],
		[
			11,
			4
		],
		[
			-5,
			-33
		],
		[
			-15,
			-10
		]
	],
	[
		[
			27310,
			45701
		],
		[
			52,
			90
		],
		[
			6,
			-30
		],
		[
			-45,
			-80
		],
		[
			-13,
			20
		]
	],
	[
		[
			27118,
			45540
		],
		[
			19,
			106
		],
		[
			20,
			46
		],
		[
			25,
			43
		],
		[
			3,
			23
		],
		[
			36,
			66
		],
		[
			38,
			-67
		],
		[
			4,
			-52
		],
		[
			14,
			-43
		],
		[
			-4,
			-11
		],
		[
			-40,
			-48
		],
		[
			-3,
			27
		],
		[
			-27,
			-5
		],
		[
			-3,
			-24
		],
		[
			-46,
			-73
		],
		[
			-36,
			-15
		],
		[
			0,
			27
		]
	],
	[
		[
			27062,
			45510
		],
		[
			39,
			24
		],
		[
			-10,
			-43
		],
		[
			-17,
			-14
		],
		[
			-13,
			8
		],
		[
			1,
			25
		]
	],
	[
		[
			27020,
			45533
		],
		[
			6,
			35
		],
		[
			12,
			-10
		],
		[
			-5,
			-41
		],
		[
			-13,
			16
		]
	],
	[
		[
			26992,
			48019
		],
		[
			5,
			-18
		],
		[
			19,
			-211
		],
		[
			8,
			-28
		],
		[
			17,
			-26
		],
		[
			7,
			17
		],
		[
			14,
			-21
		],
		[
			-14,
			-31
		],
		[
			-9,
			-1
		],
		[
			-21,
			50
		],
		[
			-7,
			28
		],
		[
			-13,
			115
		],
		[
			-6,
			76
		],
		[
			0,
			50
		]
	],
	[
		[
			26806,
			45614
		],
		[
			15,
			13
		],
		[
			4,
			-23
		],
		[
			-20,
			-10
		],
		[
			1,
			20
		]
	],
	[
		[
			26322,
			51623
		],
		[
			29,
			47
		],
		[
			0,
			-29
		],
		[
			-16,
			-37
		],
		[
			-11,
			-6
		],
		[
			-2,
			25
		]
	],
	[
		[
			26229,
			53027
		],
		[
			6,
			-79
		],
		[
			11,
			-52
		],
		[
			2,
			-83
		],
		[
			6,
			-75
		],
		[
			14,
			-48
		],
		[
			136,
			-25
		],
		[
			261,
			-56
		],
		[
			206,
			-51
		],
		[
			135,
			-34
		],
		[
			-5,
			-14
		],
		[
			2,
			-57
		],
		[
			7,
			-26
		],
		[
			-3,
			-71
		],
		[
			11,
			-76
		],
		[
			37,
			13
		],
		[
			0,
			75
		],
		[
			6,
			47
		],
		[
			3,
			119
		],
		[
			-12,
			91
		],
		[
			4,
			60
		],
		[
			-1,
			49
		],
		[
			8,
			16
		],
		[
			-4,
			24
		],
		[
			12,
			-8
		],
		[
			9,
			59
		],
		[
			15,
			-7
		],
		[
			7,
			-33
		],
		[
			17,
			-3
		],
		[
			18,
			-28
		],
		[
			7,
			-25
		],
		[
			33,
			-19
		],
		[
			17,
			-18
		],
		[
			14,
			15
		],
		[
			13,
			-19
		]
	],
	[
		[
			27221,
			52688
		],
		[
			4,
			-13
		],
		[
			-4,
			-113
		],
		[
			3,
			-92
		],
		[
			-4,
			-22
		],
		[
			10,
			-25
		],
		[
			4,
			-95
		],
		[
			1,
			-113
		],
		[
			23,
			-389
		],
		[
			13,
			-129
		],
		[
			0,
			-51
		],
		[
			28,
			-302
		],
		[
			32,
			-288
		],
		[
			29,
			-229
		],
		[
			65,
			-412
		],
		[
			38,
			-200
		],
		[
			4,
			-63
		],
		[
			10,
			-83
		],
		[
			-18,
			-57
		],
		[
			-4,
			-54
		],
		[
			-1,
			-87
		],
		[
			5,
			-130
		],
		[
			6,
			-96
		],
		[
			16,
			-145
		],
		[
			35,
			-269
		],
		[
			15,
			-166
		],
		[
			5,
			-84
		],
		[
			5,
			-29
		],
		[
			11,
			-140
		],
		[
			17,
			-152
		],
		[
			9,
			-66
		],
		[
			6,
			-94
		],
		[
			13,
			-109
		],
		[
			17,
			-258
		],
		[
			-1,
			-235
		],
		[
			-7,
			-175
		],
		[
			-5,
			-210
		],
		[
			-3,
			-37
		],
		[
			-8,
			-286
		],
		[
			0,
			-169
		],
		[
			-3,
			-80
		],
		[
			-7,
			-81
		],
		[
			0,
			-44
		],
		[
			-6,
			23
		],
		[
			3,
			51
		],
		[
			-5,
			20
		],
		[
			-16,
			-25
		],
		[
			-10,
			-102
		],
		[
			-6,
			-17
		],
		[
			-1,
			-64
		],
		[
			-8,
			-40
		],
		[
			-2,
			-78
		],
		[
			5,
			-33
		],
		[
			-2,
			-46
		],
		[
			6,
			-16
		],
		[
			-8,
			-53
		],
		[
			-8,
			-13
		],
		[
			-1,
			-49
		],
		[
			21,
			39
		],
		[
			25,
			194
		],
		[
			7,
			41
		],
		[
			0,
			-41
		],
		[
			-8,
			-83
		],
		[
			-34,
			-222
		],
		[
			-9,
			-82
		],
		[
			-25,
			-93
		],
		[
			-34,
			-139
		],
		[
			-24,
			-66
		],
		[
			-3,
			12
		],
		[
			34,
			122
		],
		[
			14,
			40
		],
		[
			7,
			53
		],
		[
			3,
			81
		],
		[
			5,
			32
		],
		[
			-6,
			23
		],
		[
			-9,
			-11
		],
		[
			-7,
			26
		],
		[
			-6,
			-18
		],
		[
			-34,
			-22
		],
		[
			-14,
			-41
		],
		[
			-9,
			-6
		],
		[
			-18,
			45
		],
		[
			-18,
			-13
		],
		[
			-7,
			-41
		],
		[
			-27,
			-18
		],
		[
			-23,
			-6
		],
		[
			-17,
			52
		],
		[
			-8,
			68
		],
		[
			2,
			79
		],
		[
			6,
			60
		],
		[
			6,
			-3
		],
		[
			-2,
			49
		],
		[
			-12,
			97
		],
		[
			-11,
			47
		],
		[
			2,
			34
		],
		[
			-8,
			62
		],
		[
			-11,
			32
		],
		[
			-5,
			85
		],
		[
			-6,
			18
		],
		[
			-11,
			-15
		],
		[
			-9,
			101
		],
		[
			-24,
			31
		],
		[
			-1,
			16
		],
		[
			-21,
			38
		],
		[
			-21,
			55
		],
		[
			-11,
			-13
		],
		[
			-8,
			-39
		],
		[
			-16,
			126
		],
		[
			-15,
			148
		],
		[
			-5,
			173
		],
		[
			-7,
			109
		],
		[
			-7,
			57
		],
		[
			-28,
			113
		],
		[
			-11,
			9
		],
		[
			-1,
			52
		],
		[
			-12,
			23
		],
		[
			0,
			-64
		],
		[
			-14,
			-11
		],
		[
			-1,
			66
		],
		[
			-8,
			113
		],
		[
			-12,
			51
		],
		[
			3,
			24
		],
		[
			13,
			-3
		],
		[
			9,
			-39
		],
		[
			11,
			159
		],
		[
			-2,
			86
		],
		[
			-8,
			14
		],
		[
			0,
			40
		],
		[
			8,
			10
		],
		[
			-4,
			31
		],
		[
			-12,
			-4
		],
		[
			-5,
			-33
		],
		[
			-11,
			-11
		],
		[
			8,
			-148
		],
		[
			-9,
			-20
		],
		[
			-20,
			-11
		],
		[
			-5,
			-50
		],
		[
			0,
			75
		],
		[
			-6,
			50
		],
		[
			-17,
			94
		],
		[
			-26,
			177
		],
		[
			-9,
			94
		],
		[
			-19,
			140
		],
		[
			-27,
			149
		],
		[
			-14,
			56
		],
		[
			-4,
			58
		],
		[
			-10,
			61
		],
		[
			10,
			-19
		],
		[
			1,
			-30
		],
		[
			15,
			30
		],
		[
			10,
			72
		],
		[
			12,
			28
		],
		[
			13,
			98
		],
		[
			13,
			34
		],
		[
			-2,
			23
		],
		[
			14,
			26
		],
		[
			11,
			84
		],
		[
			-5,
			75
		],
		[
			-22,
			21
		],
		[
			5,
			-113
		],
		[
			-22,
			30
		],
		[
			6,
			34
		],
		[
			-1,
			65
		],
		[
			-5,
			39
		],
		[
			-38,
			71
		],
		[
			1,
			-65
		],
		[
			-11,
			-28
		],
		[
			11,
			-37
		],
		[
			16,
			-6
		],
		[
			11,
			-110
		],
		[
			-10,
			-42
		],
		[
			0,
			-62
		],
		[
			-4,
			-27
		],
		[
			-21,
			-6
		],
		[
			-3,
			-32
		],
		[
			7,
			-38
		],
		[
			-9,
			-30
		],
		[
			-4,
			40
		],
		[
			2,
			83
		],
		[
			-14,
			85
		],
		[
			-9,
			26
		],
		[
			-8,
			58
		],
		[
			6,
			182
		],
		[
			-5,
			66
		],
		[
			-4,
			164
		],
		[
			9,
			1
		],
		[
			0,
			-93
		],
		[
			4,
			-89
		],
		[
			9,
			-7
		],
		[
			-4,
			153
		],
		[
			9,
			37
		],
		[
			1,
			41
		],
		[
			8,
			44
		],
		[
			0,
			38
		],
		[
			7,
			50
		],
		[
			0,
			39
		],
		[
			9,
			47
		],
		[
			1,
			91
		],
		[
			5,
			83
		],
		[
			-6,
			66
		],
		[
			2,
			56
		],
		[
			-13,
			29
		],
		[
			4,
			42
		],
		[
			-9,
			109
		],
		[
			12,
			64
		],
		[
			-21,
			110
		],
		[
			3,
			31
		],
		[
			-8,
			55
		],
		[
			-10,
			3
		],
		[
			5,
			33
		],
		[
			-1,
			49
		],
		[
			-7,
			13
		],
		[
			-47,
			23
		],
		[
			-9,
			-51
		],
		[
			-7,
			-4
		],
		[
			-9,
			100
		],
		[
			3,
			45
		],
		[
			-14,
			32
		],
		[
			-12,
			9
		],
		[
			-2,
			63
		],
		[
			-7,
			58
		],
		[
			-11,
			45
		],
		[
			-15,
			6
		],
		[
			-5,
			44
		],
		[
			-24,
			48
		],
		[
			0,
			111
		],
		[
			-4,
			67
		],
		[
			-12,
			7
		],
		[
			-10,
			38
		],
		[
			-13,
			17
		],
		[
			-13,
			61
		],
		[
			0,
			42
		],
		[
			-9,
			35
		],
		[
			-5,
			51
		],
		[
			-14,
			44
		],
		[
			-28,
			62
		],
		[
			-40,
			72
		],
		[
			-26,
			75
		],
		[
			-11,
			-2
		],
		[
			-26,
			-33
		],
		[
			-31,
			29
		],
		[
			-1,
			-35
		],
		[
			-26,
			-69
		],
		[
			9,
			-99
		],
		[
			-3,
			-28
		],
		[
			-10,
			-7
		],
		[
			-15,
			15
		],
		[
			-5,
			26
		],
		[
			-24,
			-22
		],
		[
			-31,
			-73
		],
		[
			-65,
			-132
		],
		[
			-6,
			2
		],
		[
			7,
			44
		],
		[
			-10,
			12
		],
		[
			-7,
			-39
		],
		[
			-15,
			-41
		],
		[
			-36,
			1
		],
		[
			13,
			-49
		],
		[
			2,
			-38
		],
		[
			16,
			-22
		],
		[
			30,
			53
		],
		[
			29,
			40
		],
		[
			27,
			84
		],
		[
			3,
			-13
		],
		[
			-24,
			-82
		],
		[
			-28,
			-43
		],
		[
			-35,
			-66
		],
		[
			-12,
			-14
		],
		[
			-10,
			33
		],
		[
			-16,
			22
		],
		[
			-23,
			51
		],
		[
			-19,
			7
		],
		[
			-17,
			-28
		],
		[
			-13,
			94
		],
		[
			-5,
			119
		],
		[
			8,
			42
		],
		[
			0,
			-105
		],
		[
			6,
			-91
		],
		[
			7,
			-22
		],
		[
			10,
			39
		],
		[
			1,
			97
		],
		[
			-17,
			105
		],
		[
			-18,
			60
		],
		[
			-17,
			13
		],
		[
			-15,
			40
		],
		[
			-16,
			71
		],
		[
			-27,
			47
		],
		[
			-22,
			69
		],
		[
			-41,
			95
		],
		[
			-47,
			76
		],
		[
			-58,
			70
		],
		[
			-31,
			20
		],
		[
			-62,
			18
		],
		[
			-33,
			-5
		],
		[
			-47,
			-25
		],
		[
			-65,
			-49
		],
		[
			-32,
			-15
		],
		[
			-7,
			10
		],
		[
			-63,
			-51
		]
	],
	[
		[
			26061,
			57664
		],
		[
			39,
			-2
		],
		[
			136,
			6
		],
		[
			183,
			1
		]
	],
	[
		[
			26419,
			57669
		],
		[
			196,
			-2
		],
		[
			-1,
			6
		],
		[
			143,
			10
		]
	],
	[
		[
			26757,
			57683
		],
		[
			-3,
			-72
		],
		[
			-31,
			-68
		],
		[
			-26,
			-105
		],
		[
			1,
			-36
		],
		[
			-8,
			-26
		],
		[
			3,
			-64
		],
		[
			30,
			-82
		],
		[
			17,
			-7
		],
		[
			23,
			-104
		],
		[
			23,
			-51
		],
		[
			28,
			16
		],
		[
			8,
			-12
		],
		[
			8,
			-64
		],
		[
			3,
			-64
		],
		[
			12,
			-30
		],
		[
			3,
			-50
		],
		[
			11,
			-52
		],
		[
			0,
			-51
		],
		[
			7,
			-68
		],
		[
			12,
			-24
		],
		[
			8,
			-67
		],
		[
			14,
			-48
		],
		[
			11,
			-101
		],
		[
			9,
			-1
		],
		[
			19,
			-72
		],
		[
			29,
			-52
		],
		[
			29,
			-98
		],
		[
			4,
			-61
		],
		[
			9,
			-41
		],
		[
			1,
			-40
		],
		[
			13,
			-38
		],
		[
			12,
			-2
		],
		[
			17,
			-37
		],
		[
			18,
			-93
		],
		[
			15,
			-26
		],
		[
			4,
			-24
		],
		[
			-7,
			-43
		],
		[
			4,
			-39
		],
		[
			-4,
			-32
		],
		[
			28,
			-82
		],
		[
			-4,
			-30
		],
		[
			13,
			-42
		],
		[
			11,
			5
		],
		[
			-2,
			-41
		],
		[
			8,
			-45
		],
		[
			27,
			-55
		],
		[
			9,
			1
		],
		[
			16,
			-58
		],
		[
			19,
			-43
		],
		[
			-5,
			-67
		],
		[
			12,
			-64
		],
		[
			2,
			-49
		],
		[
			9,
			-15
		],
		[
			0,
			-85
		],
		[
			4,
			-32
		],
		[
			-5,
			-45
		],
		[
			6,
			-8
		],
		[
			4,
			-48
		],
		[
			-5,
			-41
		],
		[
			12,
			-48
		],
		[
			25,
			-26
		],
		[
			0,
			-23
		],
		[
			23,
			-81
		],
		[
			-4,
			-34
		],
		[
			15,
			-105
		],
		[
			4,
			4
		],
		[
			6,
			-76
		],
		[
			-10,
			-44
		],
		[
			11,
			-67
		],
		[
			-4,
			-26
		],
		[
			5,
			-62
		],
		[
			21,
			-34
		],
		[
			11,
			17
		],
		[
			22,
			-71
		],
		[
			9,
			-4
		]
	],
	[
		[
			27376,
			54230
		],
		[
			12,
			-12
		],
		[
			-5,
			-64
		],
		[
			-14,
			-29
		],
		[
			-10,
			15
		],
		[
			-6,
			-48
		],
		[
			10,
			-8
		],
		[
			-16,
			-60
		],
		[
			-21,
			23
		],
		[
			-3,
			-56
		],
		[
			11,
			-11
		],
		[
			-9,
			-59
		],
		[
			-17,
			-54
		],
		[
			-17,
			13
		],
		[
			-3,
			-16
		],
		[
			12,
			-33
		],
		[
			8,
			5
		],
		[
			-1,
			-84
		],
		[
			-7,
			-62
		],
		[
			-28,
			-26
		],
		[
			0,
			-22
		],
		[
			17,
			10
		],
		[
			6,
			-24
		],
		[
			-23,
			-131
		],
		[
			-6,
			-91
		],
		[
			7,
			-13
		],
		[
			-5,
			-30
		],
		[
			-5,
			-97
		],
		[
			-13,
			-22
		],
		[
			-8,
			-59
		],
		[
			-9,
			-3
		],
		[
			0,
			-71
		],
		[
			-7,
			-69
		],
		[
			-7,
			2
		],
		[
			-12,
			-44
		],
		[
			13,
			-24
		],
		[
			11,
			24
		],
		[
			1,
			-81
		],
		[
			-16,
			-161
		],
		[
			5,
			-70
		]
	],
	[
		[
			25527,
			65491
		],
		[
			15,
			-41
		],
		[
			12,
			20
		],
		[
			7,
			-15
		],
		[
			-6,
			-40
		],
		[
			27,
			-23
		],
		[
			29,
			1
		],
		[
			28,
			25
		],
		[
			52,
			75
		],
		[
			31,
			59
		]
	],
	[
		[
			25722,
			65552
		],
		[
			90,
			-1
		],
		[
			198,
			-1
		],
		[
			187,
			1
		],
		[
			87,
			1
		],
		[
			0,
			-75
		]
	],
	[
		[
			26284,
			65477
		],
		[
			1,
			-242
		],
		[
			0,
			-1380
		],
		[
			-3,
			-437
		],
		[
			0,
			-441
		],
		[
			-2,
			-278
		],
		[
			0,
			-238
		]
	],
	[
		[
			26280,
			62461
		],
		[
			-19,
			-45
		],
		[
			-2,
			-20
		],
		[
			16,
			-71
		],
		[
			2,
			-31
		],
		[
			-11,
			-38
		],
		[
			3,
			-37
		],
		[
			17,
			-7
		],
		[
			4,
			-25
		],
		[
			-13,
			-46
		],
		[
			6,
			-44
		],
		[
			-22,
			3
		],
		[
			-16,
			-23
		],
		[
			-9,
			5
		],
		[
			-35,
			-63
		],
		[
			-14,
			-39
		],
		[
			-19,
			10
		],
		[
			-10,
			43
		],
		[
			-26,
			-7
		],
		[
			-16,
			7
		],
		[
			-12,
			-33
		],
		[
			4,
			-125
		],
		[
			6,
			-71
		],
		[
			-16,
			-40
		],
		[
			-7,
			-44
		],
		[
			-30,
			-34
		],
		[
			-19,
			-161
		],
		[
			-19,
			-39
		],
		[
			-14,
			24
		],
		[
			-10,
			-13
		],
		[
			-6,
			-63
		],
		[
			-16,
			-72
		],
		[
			1,
			-87
		],
		[
			-5,
			-70
		],
		[
			-8,
			-24
		],
		[
			-23,
			-18
		],
		[
			-4,
			-36
		],
		[
			-13,
			58
		],
		[
			-22,
			1
		],
		[
			-26,
			55
		],
		[
			-1,
			94
		],
		[
			-21,
			67
		],
		[
			-8,
			-2
		],
		[
			1,
			-34
		],
		[
			13,
			-12
		],
		[
			-1,
			-25
		],
		[
			-13,
			-2
		],
		[
			-8,
			-29
		],
		[
			-8,
			23
		],
		[
			-9,
			-29
		],
		[
			9,
			-17
		],
		[
			-6,
			-42
		],
		[
			-18,
			-9
		],
		[
			-2,
			-94
		],
		[
			5,
			-38
		],
		[
			-23,
			-9
		],
		[
			-2,
			-63
		],
		[
			-11,
			-29
		],
		[
			-7,
			24
		],
		[
			5,
			51
		],
		[
			-10,
			10
		],
		[
			-10,
			-25
		],
		[
			-10,
			22
		],
		[
			-12,
			89
		],
		[
			-17,
			-2
		],
		[
			-14,
			-52
		],
		[
			-29,
			-27
		],
		[
			-10,
			-30
		],
		[
			-5,
			-97
		],
		[
			-7,
			-27
		],
		[
			-11,
			-3
		],
		[
			-8,
			62
		],
		[
			-18,
			13
		],
		[
			-22,
			57
		],
		[
			-22,
			44
		],
		[
			-20,
			6
		],
		[
			-14,
			-37
		],
		[
			-14,
			19
		],
		[
			-6,
			49
		],
		[
			-8,
			6
		],
		[
			-7,
			-66
		],
		[
			11,
			-64
		],
		[
			-13,
			-40
		],
		[
			-11,
			3
		],
		[
			3,
			56
		],
		[
			-5,
			30
		],
		[
			-42,
			-31
		],
		[
			-11,
			52
		],
		[
			-9,
			4
		],
		[
			-10,
			-40
		],
		[
			10,
			-91
		],
		[
			-12,
			-47
		],
		[
			-23,
			32
		]
	],
	[
		[
			25386,
			60941
		],
		[
			-11,
			2
		],
		[
			-4,
			34
		],
		[
			12,
			-9
		],
		[
			-16,
			92
		],
		[
			24,
			-8
		],
		[
			-15,
			29
		],
		[
			15,
			67
		],
		[
			1,
			60
		],
		[
			-8,
			26
		],
		[
			19,
			19
		],
		[
			2,
			38
		],
		[
			-12,
			-19
		],
		[
			22,
			73
		],
		[
			-14,
			60
		],
		[
			-4,
			59
		],
		[
			9,
			-10
		],
		[
			9,
			68
		],
		[
			5,
			-35
		],
		[
			7,
			41
		],
		[
			8,
			-33
		],
		[
			13,
			102
		],
		[
			8,
			9
		],
		[
			13,
			84
		],
		[
			-2,
			38
		],
		[
			24,
			42
		],
		[
			0,
			66
		],
		[
			9,
			83
		],
		[
			7,
			32
		],
		[
			14,
			12
		],
		[
			14,
			76
		],
		[
			-1,
			42
		],
		[
			-15,
			94
		],
		[
			11,
			111
		],
		[
			-18,
			40
		],
		[
			1,
			79
		],
		[
			-16,
			55
		],
		[
			-3,
			73
		],
		[
			19,
			60
		],
		[
			-9,
			50
		],
		[
			2,
			60
		],
		[
			6,
			32
		],
		[
			13,
			9
		],
		[
			0,
			347
		],
		[
			-1,
			0
		],
		[
			0,
			397
		],
		[
			1,
			12
		],
		[
			0,
			294
		],
		[
			1,
			247
		],
		[
			0,
			1196
		],
		[
			1,
			254
		]
	],
	[
		[
			21479,
			63506
		],
		[
			257,
			-1
		],
		[
			104,
			0
		],
		[
			263,
			-1
		],
		[
			273,
			1
		],
		[
			163,
			0
		],
		[
			279,
			-1
		],
		[
			263,
			-1
		],
		[
			144,
			0
		],
		[
			133,
			0
		]
	],
	[
		[
			23358,
			63503
		],
		[
			16,
			-60
		],
		[
			13,
			-11
		],
		[
			1,
			-43
		],
		[
			13,
			6
		],
		[
			5,
			-36
		],
		[
			26,
			-14
		],
		[
			8,
			41
		],
		[
			24,
			-13
		],
		[
			-4,
			-28
		],
		[
			7,
			-33
		],
		[
			11,
			-11
		],
		[
			-4,
			-42
		],
		[
			-9,
			-1
		],
		[
			3,
			-36
		],
		[
			12,
			16
		],
		[
			-1,
			-49
		],
		[
			-10,
			-6
		],
		[
			-13,
			24
		],
		[
			-5,
			-75
		],
		[
			-15,
			-19
		],
		[
			-7,
			-41
		],
		[
			2,
			-41
		],
		[
			-17,
			-24
		],
		[
			1,
			-48
		],
		[
			15,
			-41
		],
		[
			1,
			-29
		],
		[
			16,
			-31
		],
		[
			12,
			-61
		],
		[
			14,
			0
		],
		[
			5,
			-21
		],
		[
			-9,
			-25
		],
		[
			6,
			-79
		],
		[
			18,
			-52
		],
		[
			-3,
			-28
		],
		[
			15,
			-13
		],
		[
			5,
			-31
		],
		[
			14,
			-11
		],
		[
			9,
			16
		],
		[
			5,
			-31
		],
		[
			20,
			-3
		],
		[
			-5,
			-41
		],
		[
			0,
			-444
		],
		[
			-1,
			-120
		],
		[
			0,
			-696
		],
		[
			-1,
			-52
		],
		[
			0,
			-779
		],
		[
			-1,
			-97
		],
		[
			0,
			-281
		]
	],
	[
		[
			23550,
			60009
		],
		[
			-249,
			1
		],
		[
			-196,
			-1
		],
		[
			-169,
			0
		],
		[
			-218,
			0
		],
		[
			-208,
			-1
		],
		[
			-258,
			2
		],
		[
			-103,
			0
		],
		[
			-154,
			3
		],
		[
			-149,
			-4
		],
		[
			-209,
			-4
		],
		[
			-155,
			-3
		]
	],
	[
		[
			30863,
			68384
		],
		[
			14,
			7
		],
		[
			-7,
			-35
		],
		[
			-7,
			28
		]
	],
	[
		[
			30827,
			68345
		],
		[
			7,
			83
		],
		[
			6,
			-34
		],
		[
			19,
			-55
		],
		[
			-15,
			-45
		],
		[
			-5,
			34
		],
		[
			-12,
			17
		]
	],
	[
		[
			30819,
			68560
		],
		[
			3,
			42
		],
		[
			11,
			-71
		],
		[
			-14,
			29
		]
	],
	[
		[
			30732,
			68434
		],
		[
			14,
			2
		],
		[
			3,
			-41
		],
		[
			-17,
			39
		]
	],
	[
		[
			30712,
			67988
		],
		[
			8,
			37
		],
		[
			1,
			-75
		],
		[
			-9,
			38
		]
	],
	[
		[
			30703,
			68290
		],
		[
			8,
			41
		],
		[
			25,
			45
		],
		[
			11,
			-50
		],
		[
			-9,
			-8
		],
		[
			14,
			-78
		],
		[
			-11,
			-39
		],
		[
			-18,
			-13
		],
		[
			-12,
			24
		],
		[
			5,
			25
		],
		[
			-3,
			50
		],
		[
			-10,
			3
		]
	],
	[
		[
			30697,
			68452
		],
		[
			13,
			68
		],
		[
			2,
			64
		],
		[
			9,
			25
		],
		[
			6,
			-26
		],
		[
			-9,
			-35
		],
		[
			1,
			-36
		],
		[
			-8,
			-70
		],
		[
			-10,
			-29
		],
		[
			-4,
			39
		]
	],
	[
		[
			30213,
			67064
		],
		[
			-35,
			81
		],
		[
			0,
			69
		],
		[
			6,
			42
		],
		[
			-41,
			128
		],
		[
			-9,
			53
		],
		[
			8,
			101
		],
		[
			-4,
			10
		],
		[
			6,
			88
		],
		[
			-6,
			23
		],
		[
			-5,
			313
		],
		[
			0,
			89
		],
		[
			-11,
			861
		],
		[
			-15,
			757
		]
	],
	[
		[
			30107,
			69679
		],
		[
			21,
			15
		],
		[
			0,
			33
		],
		[
			25,
			-41
		],
		[
			-1,
			-38
		],
		[
			7,
			-43
		],
		[
			11,
			-15
		],
		[
			13,
			85
		],
		[
			2,
			86
		],
		[
			-6,
			28
		],
		[
			12,
			36
		],
		[
			8,
			-3
		],
		[
			12,
			-44
		],
		[
			21,
			-9
		],
		[
			1,
			39
		],
		[
			-24,
			83
		],
		[
			-1,
			32
		],
		[
			22,
			107
		],
		[
			14,
			27
		],
		[
			11,
			43
		],
		[
			8,
			-1
		],
		[
			15,
			41
		],
		[
			24,
			38
		],
		[
			-9,
			71
		],
		[
			21,
			66
		],
		[
			23,
			45
		],
		[
			5,
			56
		],
		[
			-7,
			28
		],
		[
			-14,
			0
		],
		[
			0,
			66
		],
		[
			10,
			38
		],
		[
			-8,
			14
		],
		[
			15,
			51
		],
		[
			5,
			46
		],
		[
			-15,
			44
		],
		[
			16,
			115
		],
		[
			8,
			18
		],
		[
			-1,
			37
		],
		[
			17,
			32
		],
		[
			14,
			59
		],
		[
			11,
			8
		],
		[
			17,
			324
		],
		[
			215,
			890
		],
		[
			13,
			-3
		],
		[
			27,
			-38
		],
		[
			11,
			4
		],
		[
			-3,
			-58
		],
		[
			1,
			-141
		],
		[
			4,
			-18
		],
		[
			37,
			-73
		],
		[
			25,
			43
		],
		[
			26,
			30
		],
		[
			28,
			2
		],
		[
			11,
			52
		],
		[
			30,
			11
		],
		[
			25,
			-12
		],
		[
			0,
			62
		],
		[
			16,
			23
		],
		[
			25,
			-6
		],
		[
			23,
			-36
		],
		[
			4,
			-32
		],
		[
			33,
			-68
		],
		[
			36,
			-132
		],
		[
			0,
			-15
		],
		[
			28,
			-51
		],
		[
			0,
			-545
		],
		[
			3,
			-693
		],
		[
			-1,
			-71
		],
		[
			9,
			-30
		],
		[
			-15,
			-39
		],
		[
			14,
			-70
		],
		[
			-15,
			-34
		],
		[
			1,
			-136
		],
		[
			23,
			-18
		],
		[
			3,
			20
		],
		[
			10,
			-57
		],
		[
			19,
			-28
		],
		[
			30,
			-23
		],
		[
			14,
			19
		],
		[
			8,
			-62
		],
		[
			1,
			-56
		],
		[
			-13,
			8
		],
		[
			-11,
			-22
		],
		[
			7,
			-68
		],
		[
			16,
			-63
		],
		[
			-9,
			-73
		],
		[
			-10,
			-41
		],
		[
			23,
			-116
		],
		[
			0,
			-23
		],
		[
			18,
			-40
		],
		[
			13,
			28
		],
		[
			1,
			46
		],
		[
			18,
			-30
		],
		[
			19,
			-3
		],
		[
			13,
			-56
		],
		[
			6,
			-51
		],
		[
			-8,
			-14
		],
		[
			10,
			-32
		],
		[
			12,
			-98
		],
		[
			15,
			-38
		],
		[
			1,
			-118
		],
		[
			-12,
			-50
		],
		[
			-10,
			2
		],
		[
			-4,
			-32
		],
		[
			-32,
			-113
		],
		[
			-24,
			-25
		],
		[
			4,
			-22
		],
		[
			-15,
			-8
		],
		[
			6,
			42
		],
		[
			-4,
			85
		],
		[
			-27,
			-30
		],
		[
			12,
			-58
		],
		[
			-12,
			-43
		],
		[
			-11,
			13
		],
		[
			-13,
			-58
		],
		[
			-13,
			18
		],
		[
			-10,
			-12
		],
		[
			2,
			-35
		],
		[
			16,
			-40
		],
		[
			-22,
			-57
		],
		[
			-13,
			46
		],
		[
			-6,
			57
		],
		[
			-13,
			-10
		],
		[
			-3,
			-38
		],
		[
			-8,
			3
		],
		[
			-7,
			59
		],
		[
			-7,
			-62
		],
		[
			-9,
			-14
		],
		[
			-8,
			-74
		],
		[
			-7,
			19
		],
		[
			-6,
			-48
		],
		[
			-4,
			42
		],
		[
			-20,
			-51
		],
		[
			-5,
			27
		],
		[
			-12,
			-92
		],
		[
			-16,
			39
		],
		[
			0,
			36
		],
		[
			-10,
			-21
		],
		[
			-11,
			9
		],
		[
			2,
			-66
		],
		[
			-16,
			-71
		],
		[
			11,
			-33
		],
		[
			-35,
			-16
		],
		[
			-23,
			32
		],
		[
			-16,
			107
		],
		[
			6,
			29
		],
		[
			22,
			27
		],
		[
			-9,
			45
		],
		[
			-13,
			-35
		],
		[
			2,
			44
		],
		[
			-10,
			-3
		],
		[
			1,
			-68
		],
		[
			-5,
			0
		],
		[
			0,
			64
		],
		[
			-24,
			-56
		],
		[
			5,
			-35
		],
		[
			-6,
			-43
		],
		[
			14,
			-67
		],
		[
			-3,
			-45
		],
		[
			-23,
			-77
		],
		[
			9,
			-11
		],
		[
			-12,
			-31
		],
		[
			11,
			-56
		],
		[
			-5,
			-69
		],
		[
			-16,
			-10
		],
		[
			-3,
			85
		],
		[
			6,
			4
		],
		[
			-3,
			55
		],
		[
			-17,
			45
		],
		[
			-4,
			64
		],
		[
			15,
			51
		],
		[
			-19,
			40
		],
		[
			6,
			26
		],
		[
			-10,
			10
		],
		[
			-18,
			-21
		],
		[
			1,
			113
		],
		[
			11,
			44
		],
		[
			1,
			50
		],
		[
			-7,
			14
		],
		[
			-7,
			-46
		],
		[
			-14,
			-40
		],
		[
			-11,
			33
		],
		[
			-7,
			-32
		],
		[
			-15,
			-4
		],
		[
			14,
			-81
		],
		[
			-3,
			-48
		],
		[
			-12,
			-23
		],
		[
			-10,
			-71
		],
		[
			-4,
			-72
		],
		[
			-13,
			-78
		],
		[
			19,
			-30
		],
		[
			-13,
			-28
		],
		[
			10,
			-57
		],
		[
			-10,
			-38
		],
		[
			-27,
			4
		],
		[
			-13,
			-72
		],
		[
			-15,
			-1
		],
		[
			-2,
			-58
		],
		[
			-11,
			-9
		],
		[
			0,
			52
		],
		[
			7,
			37
		],
		[
			-9,
			15
		],
		[
			-3,
			-30
		],
		[
			-12,
			-13
		],
		[
			5,
			65
		],
		[
			-18,
			-9
		],
		[
			1,
			-52
		],
		[
			-16,
			-37
		],
		[
			-5,
			-50
		],
		[
			-12,
			51
		],
		[
			-2,
			-47
		],
		[
			-15,
			-32
		],
		[
			-12,
			26
		],
		[
			-3,
			-66
		],
		[
			-13,
			51
		],
		[
			-13,
			-92
		],
		[
			-23,
			-27
		],
		[
			-5,
			-19
		],
		[
			-5,
			83
		],
		[
			-16,
			5
		],
		[
			-15,
			-42
		],
		[
			-5,
			-39
		],
		[
			-20,
			4
		],
		[
			-7,
			-49
		],
		[
			-20,
			4
		],
		[
			-10,
			-49
		],
		[
			-3,
			-50
		],
		[
			5,
			-29
		],
		[
			-8,
			-32
		],
		[
			-13,
			29
		],
		[
			-22,
			-31
		],
		[
			-9,
			-46
		],
		[
			6,
			-67
		],
		[
			-8,
			-43
		],
		[
			-10,
			-15
		],
		[
			3,
			-33
		],
		[
			-14,
			-24
		],
		[
			-14,
			4
		],
		[
			-10,
			-25
		],
		[
			-11,
			-98
		],
		[
			5,
			-19
		],
		[
			-14,
			-80
		],
		[
			1,
			-22
		],
		[
			-14,
			-74
		],
		[
			-9,
			-13
		]
	],
	[
		[
			30332,
			65028
		],
		[
			13,
			-24
		],
		[
			29,
			5
		],
		[
			18,
			17
		],
		[
			12,
			70
		],
		[
			16,
			-105
		],
		[
			-1,
			-30
		],
		[
			-10,
			-16
		],
		[
			-33,
			4
		],
		[
			-41,
			60
		],
		[
			-3,
			19
		]
	],
	[
		[
			30177,
			65078
		],
		[
			18,
			0
		],
		[
			19,
			90
		],
		[
			27,
			60
		],
		[
			11,
			-15
		],
		[
			7,
			-70
		],
		[
			15,
			-27
		],
		[
			10,
			40
		],
		[
			-1,
			-84
		],
		[
			-41,
			1
		],
		[
			-31,
			-9
		],
		[
			-18,
			-47
		],
		[
			-16,
			61
		]
	],
	[
		[
			29500,
			66699
		],
		[
			224,
			-22
		]
	],
	[
		[
			29724,
			66677
		],
		[
			199,
			-23
		],
		[
			126,
			-12
		],
		[
			10,
			46
		],
		[
			21,
			1
		],
		[
			-1,
			62
		],
		[
			15,
			36
		],
		[
			19,
			-18
		],
		[
			9,
			62
		],
		[
			36,
			32
		],
		[
			15,
			-30
		],
		[
			8,
			13
		]
	],
	[
		[
			30181,
			66846
		],
		[
			2,
			-72
		],
		[
			9,
			-136
		],
		[
			25,
			-47
		],
		[
			12,
			42
		],
		[
			14,
			-34
		],
		[
			-16,
			-90
		],
		[
			-23,
			-7
		],
		[
			-38,
			-35
		],
		[
			12,
			-50
		],
		[
			-18,
			-50
		],
		[
			-7,
			9
		],
		[
			-5,
			-59
		],
		[
			-4,
			41
		],
		[
			-11,
			-53
		],
		[
			11,
			-74
		],
		[
			-13,
			10
		],
		[
			-5,
			-28
		],
		[
			8,
			-26
		],
		[
			-5,
			-27
		],
		[
			14,
			-14
		],
		[
			6,
			36
		],
		[
			14,
			8
		],
		[
			9,
			-47
		],
		[
			24,
			-28
		],
		[
			12,
			-42
		],
		[
			2,
			-46
		],
		[
			21,
			-93
		],
		[
			-1,
			-50
		],
		[
			-7,
			-39
		],
		[
			-12,
			-5
		],
		[
			3,
			-24
		],
		[
			21,
			-51
		],
		[
			12,
			8
		],
		[
			8,
			-24
		],
		[
			8,
			-83
		],
		[
			-5,
			-50
		],
		[
			13,
			-48
		],
		[
			23,
			-35
		],
		[
			34,
			-12
		],
		[
			9,
			-23
		],
		[
			19,
			44
		],
		[
			19,
			8
		],
		[
			27,
			33
		],
		[
			6,
			25
		],
		[
			-1,
			79
		],
		[
			-6,
			61
		],
		[
			-13,
			-31
		],
		[
			0,
			97
		],
		[
			-5,
			55
		],
		[
			-15,
			34
		],
		[
			-9,
			-7
		],
		[
			-5,
			-39
		],
		[
			-11,
			59
		],
		[
			13,
			11
		],
		[
			21,
			-18
		],
		[
			23,
			-58
		],
		[
			18,
			-123
		],
		[
			9,
			-119
		],
		[
			2,
			-137
		],
		[
			-15,
			-129
		],
		[
			-2,
			-44
		],
		[
			-7,
			9
		],
		[
			12,
			112
		],
		[
			-7,
			23
		],
		[
			-26,
			-5
		],
		[
			-43,
			-40
		],
		[
			-30,
			8
		],
		[
			-7,
			-28
		],
		[
			-17,
			-7
		],
		[
			-15,
			-62
		],
		[
			-33,
			-10
		],
		[
			-34,
			-66
		],
		[
			-16,
			-47
		],
		[
			-21,
			-28
		],
		[
			-23,
			-15
		],
		[
			6,
			26
		],
		[
			35,
			34
		],
		[
			16,
			47
		],
		[
			24,
			49
		],
		[
			5,
			40
		],
		[
			-2,
			117
		],
		[
			6,
			41
		],
		[
			-26,
			26
		],
		[
			0,
			-59
		],
		[
			-7,
			14
		],
		[
			-4,
			-50
		],
		[
			-14,
			3
		],
		[
			2,
			-32
		],
		[
			-31,
			-11
		],
		[
			-7,
			-49
		],
		[
			2,
			-44
		],
		[
			-6,
			-29
		],
		[
			-25,
			-23
		],
		[
			-12,
			17
		],
		[
			-10,
			-14
		]
	],
	[
		[
			30097,
			65246
		],
		[
			-3,
			189
		],
		[
			-18,
			18
		]
	],
	[
		[
			30076,
			65453
		],
		[
			-8,
			41
		]
	],
	[
		[
			30068,
			65494
		],
		[
			-10,
			48
		],
		[
			-19,
			33
		],
		[
			-5,
			56
		],
		[
			2,
			81
		],
		[
			-12,
			-6
		],
		[
			0,
			147
		],
		[
			-116,
			-13
		]
	],
	[
		[
			29908,
			65840
		],
		[
			-1,
			18
		],
		[
			-202,
			13
		],
		[
			-22,
			-4
		],
		[
			-42,
			6
		],
		[
			-3,
			-39
		],
		[
			-14,
			-6
		],
		[
			1,
			45
		],
		[
			-54,
			3
		],
		[
			-118,
			14
		],
		[
			-15,
			-1
		]
	],
	[
		[
			29438,
			65889
		],
		[
			-6,
			42
		],
		[
			34,
			395
		],
		[
			34,
			373
		]
	],
	[
		[
			22823,
			73980
		],
		[
			83,
			-1
		],
		[
			266,
			0
		],
		[
			229,
			-1
		],
		[
			0,
			449
		],
		[
			27,
			-37
		],
		[
			28,
			20
		],
		[
			29,
			-53
		],
		[
			8,
			-35
		],
		[
			14,
			-202
		],
		[
			7,
			-25
		],
		[
			18,
			-251
		],
		[
			-6,
			-69
		],
		[
			4,
			-54
		],
		[
			14,
			-43
		],
		[
			29,
			-45
		],
		[
			24,
			-12
		],
		[
			8,
			19
		],
		[
			44,
			-11
		],
		[
			11,
			-58
		],
		[
			61,
			-7
		],
		[
			48,
			-21
		],
		[
			8,
			-66
		],
		[
			-3,
			-49
		],
		[
			6,
			-12
		],
		[
			42,
			2
		],
		[
			5,
			15
		],
		[
			22,
			-2
		],
		[
			23,
			20
		],
		[
			-1,
			48
		],
		[
			33,
			46
		],
		[
			39,
			18
		],
		[
			9,
			-22
		],
		[
			53,
			0
		],
		[
			72,
			-98
		],
		[
			26,
			4
		],
		[
			1,
			-49
		],
		[
			-19,
			-7
		],
		[
			-4,
			-37
		],
		[
			16,
			-31
		],
		[
			41,
			13
		],
		[
			15,
			-54
		],
		[
			-6,
			-34
		],
		[
			6,
			-49
		],
		[
			24,
			-127
		],
		[
			25,
			27
		],
		[
			-8,
			84
		],
		[
			13,
			45
		],
		[
			15,
			-11
		],
		[
			42,
			16
		],
		[
			16,
			-44
		],
		[
			-2,
			-65
		],
		[
			17,
			-41
		],
		[
			14,
			9
		],
		[
			9,
			-36
		],
		[
			41,
			-9
		],
		[
			5,
			-67
		],
		[
			-4,
			-31
		],
		[
			20,
			-21
		],
		[
			23,
			13
		],
		[
			-3,
			-75
		],
		[
			22,
			28
		],
		[
			14,
			-22
		],
		[
			19,
			24
		],
		[
			34,
			17
		],
		[
			46,
			113
		],
		[
			17,
			13
		],
		[
			13,
			32
		],
		[
			25,
			30
		],
		[
			14,
			-13
		],
		[
			0,
			-67
		],
		[
			17,
			-17
		],
		[
			-6,
			-26
		],
		[
			10,
			-48
		],
		[
			16,
			-3
		],
		[
			35,
			29
		],
		[
			6,
			-29
		],
		[
			25,
			15
		],
		[
			26,
			-18
		],
		[
			19,
			13
		],
		[
			48,
			8
		],
		[
			29,
			-28
		],
		[
			9,
			-66
		],
		[
			34,
			-53
		],
		[
			15,
			35
		],
		[
			20,
			9
		],
		[
			13,
			-20
		],
		[
			23,
			6
		],
		[
			11,
			-18
		],
		[
			25,
			22
		],
		[
			-27,
			-56
		],
		[
			-10,
			20
		],
		[
			-4,
			-34
		],
		[
			-17,
			-15
		],
		[
			-26,
			-58
		],
		[
			-37,
			-34
		],
		[
			-14,
			-37
		],
		[
			-52,
			-44
		],
		[
			-48,
			-54
		],
		[
			-15,
			-6
		],
		[
			-42,
			-45
		],
		[
			-4,
			-14
		],
		[
			-51,
			-77
		],
		[
			-37,
			-79
		],
		[
			-72,
			-183
		],
		[
			-17,
			-69
		],
		[
			-55,
			-178
		],
		[
			-26,
			-72
		],
		[
			-26,
			-41
		],
		[
			-26,
			-88
		],
		[
			-11,
			-11
		],
		[
			-28,
			-83
		],
		[
			-10,
			-10
		],
		[
			-61,
			-134
		],
		[
			-9,
			-25
		],
		[
			8,
			-50
		],
		[
			14,
			-46
		]
	],
	[
		[
			24276,
			71309
		],
		[
			-21,
			50
		],
		[
			-14,
			-11
		],
		[
			-3,
			-29
		],
		[
			-16,
			-14
		],
		[
			9,
			-19
		],
		[
			-11,
			-43
		],
		[
			-22,
			16
		],
		[
			0,
			-685
		],
		[
			-10,
			-10
		],
		[
			-6,
			-59
		],
		[
			-24,
			7
		],
		[
			-10,
			-56
		],
		[
			-14,
			13
		],
		[
			-8,
			-38
		],
		[
			-25,
			-23
		],
		[
			-20,
			-47
		],
		[
			-20,
			-148
		],
		[
			-22,
			-49
		],
		[
			-7,
			-114
		],
		[
			1,
			-53
		],
		[
			21,
			-21
		],
		[
			10,
			9
		],
		[
			14,
			-32
		],
		[
			-1,
			-31
		],
		[
			23,
			-85
		],
		[
			-1,
			-50
		],
		[
			-15,
			-47
		],
		[
			1,
			-29
		],
		[
			-17,
			-49
		],
		[
			2,
			-91
		],
		[
			-4,
			-32
		],
		[
			6,
			-91
		],
		[
			-16,
			-58
		],
		[
			11,
			-34
		],
		[
			-2,
			-65
		],
		[
			6,
			-41
		],
		[
			-7,
			-42
		],
		[
			3,
			-75
		],
		[
			-12,
			-80
		],
		[
			5,
			-36
		],
		[
			16,
			-27
		],
		[
			31,
			-87
		],
		[
			-1,
			-24
		],
		[
			14,
			-16
		],
		[
			9,
			-44
		],
		[
			50,
			-9
		],
		[
			12,
			-17
		],
		[
			10,
			-78
		],
		[
			14,
			-38
		],
		[
			50,
			-51
		],
		[
			22,
			-39
		],
		[
			14,
			-40
		],
		[
			0,
			-53
		],
		[
			8,
			-15
		],
		[
			5,
			-84
		],
		[
			17,
			-45
		],
		[
			27,
			-41
		],
		[
			3,
			-29
		],
		[
			36,
			-90
		],
		[
			39,
			-29
		],
		[
			15,
			-55
		],
		[
			30,
			-136
		],
		[
			9,
			-75
		],
		[
			-8,
			-113
		],
		[
			2,
			-71
		],
		[
			10,
			-37
		],
		[
			-4,
			-44
		],
		[
			8,
			-53
		]
	],
	[
		[
			24498,
			67577
		],
		[
			-204,
			0
		],
		[
			-224,
			0
		],
		[
			-116,
			-1
		],
		[
			-223,
			0
		],
		[
			-180,
			1
		],
		[
			-313,
			0
		],
		[
			-199,
			0
		]
	],
	[
		[
			23039,
			67577
		],
		[
			0,
			1215
		],
		[
			1,
			101
		],
		[
			-1,
			302
		],
		[
			0,
			479
		],
		[
			-10,
			65
		],
		[
			-36,
			59
		],
		[
			-18,
			4
		],
		[
			-14,
			55
		],
		[
			-9,
			73
		],
		[
			-26,
			98
		],
		[
			5,
			46
		],
		[
			25,
			62
		],
		[
			22,
			39
		],
		[
			12,
			63
		],
		[
			14,
			46
		],
		[
			4,
			128
		]
	],
	[
		[
			23008,
			70412
		],
		[
			-4,
			106
		],
		[
			6,
			37
		],
		[
			-11,
			188
		],
		[
			-1,
			129
		],
		[
			-13,
			27
		],
		[
			-20,
			98
		],
		[
			-5,
			49
		],
		[
			-4,
			119
		],
		[
			-11,
			57
		],
		[
			-2,
			39
		],
		[
			5,
			68
		],
		[
			-6,
			112
		],
		[
			5,
			17
		],
		[
			6,
			117
		],
		[
			-6,
			-11
		],
		[
			-11,
			51
		],
		[
			1,
			171
		],
		[
			-5,
			92
		],
		[
			-2,
			114
		],
		[
			3,
			50
		],
		[
			-7,
			103
		],
		[
			1,
			217
		],
		[
			-5,
			3
		],
		[
			-7,
			89
		],
		[
			-11,
			92
		],
		[
			-8,
			17
		],
		[
			-11,
			101
		],
		[
			-3,
			58
		],
		[
			-11,
			34
		],
		[
			-5,
			121
		],
		[
			-16,
			101
		],
		[
			-3,
			110
		],
		[
			7,
			53
		],
		[
			-8,
			93
		],
		[
			3,
			52
		],
		[
			-1,
			107
		],
		[
			-7,
			59
		],
		[
			7,
			76
		],
		[
			9,
			24
		],
		[
			3,
			62
		],
		[
			-15,
			80
		],
		[
			-8,
			124
		],
		[
			-6,
			24
		],
		[
			-11,
			98
		],
		[
			3,
			40
		]
	],
	[
		[
			28860,
			63072
		],
		[
			14,
			65
		]
	],
	[
		[
			28874,
			63137
		],
		[
			9,
			32
		],
		[
			5,
			61
		],
		[
			12,
			42
		]
	],
	[
		[
			28900,
			63272
		],
		[
			17,
			44
		],
		[
			38,
			25
		],
		[
			25,
			45
		],
		[
			0,
			69
		],
		[
			16,
			25
		],
		[
			7,
			33
		],
		[
			34,
			72
		],
		[
			18,
			15
		],
		[
			12,
			51
		],
		[
			10,
			-8
		],
		[
			17,
			39
		],
		[
			-14,
			71
		],
		[
			-20,
			41
		],
		[
			-7,
			52
		],
		[
			-21,
			54
		],
		[
			-7,
			68
		],
		[
			-25,
			19
		],
		[
			-4,
			45
		],
		[
			2,
			95
		],
		[
			-10,
			37
		],
		[
			-17,
			-5
		],
		[
			-9,
			14
		],
		[
			-2,
			83
		],
		[
			7,
			30
		],
		[
			-8,
			22
		],
		[
			9,
			100
		],
		[
			11,
			-5
		],
		[
			23,
			113
		],
		[
			-24,
			120
		],
		[
			13,
			48
		],
		[
			18,
			29
		],
		[
			16,
			56
		],
		[
			-4,
			24
		],
		[
			17,
			35
		],
		[
			11,
			49
		],
		[
			14,
			124
		],
		[
			22,
			69
		],
		[
			16,
			13
		]
	],
	[
		[
			29101,
			65083
		],
		[
			88,
			-173
		],
		[
			132,
			-246
		],
		[
			3,
			-19
		],
		[
			-20,
			-187
		],
		[
			-12,
			-65
		],
		[
			-4,
			-65
		],
		[
			-6,
			-22
		]
	],
	[
		[
			29282,
			64306
		],
		[
			-7,
			-34
		]
	],
	[
		[
			29275,
			64272
		],
		[
			-37,
			-35
		],
		[
			-4,
			-84
		],
		[
			-9,
			-16
		],
		[
			-3,
			-50
		]
	],
	[
		[
			29222,
			64087
		],
		[
			0,
			-43
		],
		[
			19,
			-28
		],
		[
			16,
			18
		],
		[
			24,
			-44
		],
		[
			14,
			-9
		],
		[
			4,
			44
		],
		[
			4,
			-90
		],
		[
			-3,
			-107
		],
		[
			-14,
			-182
		],
		[
			-13,
			-247
		],
		[
			-5,
			-173
		],
		[
			-40,
			-241
		],
		[
			-11,
			-48
		],
		[
			-9,
			-9
		],
		[
			3,
			-32
		],
		[
			-10,
			-55
		],
		[
			-20,
			-63
		],
		[
			-1,
			-19
		],
		[
			-31,
			-55
		],
		[
			-32,
			-108
		],
		[
			-21,
			-118
		],
		[
			-22,
			-149
		],
		[
			-20,
			-60
		],
		[
			-19,
			-14
		],
		[
			-11,
			14
		],
		[
			6,
			88
		],
		[
			15,
			97
		],
		[
			3,
			69
		],
		[
			-21,
			37
		],
		[
			-18,
			4
		],
		[
			-6,
			25
		],
		[
			-18,
			-3
		],
		[
			-7,
			-36
		],
		[
			-9,
			24
		],
		[
			-2,
			47
		],
		[
			-18,
			37
		],
		[
			-3,
			30
		],
		[
			-10,
			-12
		],
		[
			-15,
			68
		],
		[
			-7,
			-8
		],
		[
			-18,
			58
		],
		[
			-10,
			56
		],
		[
			-19,
			25
		],
		[
			6,
			140
		],
		[
			-12,
			29
		]
	],
	[
		[
			28861,
			63044
		],
		[
			-1,
			28
		]
	],
	[
		[
			28814,
			58772
		],
		[
			18,
			-19
		],
		[
			12,
			-74
		],
		[
			1,
			-47
		],
		[
			-15,
			9
		],
		[
			2,
			45
		],
		[
			-18,
			86
		]
	],
	[
		[
			28734,
			57762
		],
		[
			8,
			60
		],
		[
			8,
			0
		],
		[
			47,
			86
		],
		[
			15,
			12
		],
		[
			14,
			33
		],
		[
			12,
			2
		],
		[
			16,
			35
		],
		[
			13,
			10
		],
		[
			5,
			74
		],
		[
			11,
			252
		],
		[
			0,
			54
		],
		[
			-8,
			95
		],
		[
			-6,
			105
		],
		[
			3,
			-2
		],
		[
			11,
			-106
		],
		[
			5,
			-95
		],
		[
			-3,
			-136
		],
		[
			-15,
			-286
		],
		[
			-24,
			-8
		],
		[
			-50,
			-64
		],
		[
			-43,
			-78
		],
		[
			-19,
			-43
		]
	],
	[
		[
			27156,
			59531
		],
		[
			84,
			-16
		],
		[
			55,
			-3
		],
		[
			95,
			-15
		],
		[
			37,
			4
		],
		[
			114,
			-21
		],
		[
			48,
			-2
		],
		[
			170,
			-2
		],
		[
			279,
			0
		],
		[
			74,
			4
		],
		[
			264,
			0
		],
		[
			106,
			-1
		],
		[
			0,
			10
		],
		[
			31,
			-2
		],
		[
			120,
			0
		],
		[
			142,
			0
		]
	],
	[
		[
			28775,
			59487
		],
		[
			2,
			-58
		],
		[
			17,
			-245
		],
		[
			16,
			-158
		],
		[
			23,
			-156
		],
		[
			35,
			-271
		],
		[
			-9,
			14
		],
		[
			-18,
			146
		],
		[
			-14,
			80
		],
		[
			-13,
			11
		],
		[
			-9,
			174
		],
		[
			-16,
			155
		],
		[
			-8,
			23
		],
		[
			3,
			39
		],
		[
			-5,
			89
		],
		[
			-10,
			30
		],
		[
			-4,
			48
		],
		[
			-25,
			13
		],
		[
			-1,
			40
		],
		[
			-13,
			-20
		],
		[
			6,
			-61
		],
		[
			16,
			-48
		],
		[
			11,
			10
		],
		[
			0,
			-67
		],
		[
			15,
			-135
		],
		[
			9,
			-61
		],
		[
			-1,
			-26
		],
		[
			11,
			-75
		],
		[
			0,
			-47
		],
		[
			-19,
			64
		],
		[
			1,
			37
		],
		[
			-13,
			61
		],
		[
			-3,
			38
		],
		[
			-12,
			12
		],
		[
			6,
			-38
		],
		[
			-3,
			-28
		],
		[
			14,
			-39
		],
		[
			-31,
			25
		],
		[
			-32,
			118
		],
		[
			-15,
			12
		],
		[
			19,
			-97
		],
		[
			10,
			-17
		],
		[
			6,
			-52
		],
		[
			-9,
			-23
		],
		[
			-24,
			-14
		],
		[
			-21,
			71
		],
		[
			7,
			-63
		],
		[
			10,
			-27
		],
		[
			-7,
			-14
		],
		[
			-31,
			45
		],
		[
			-13,
			5
		],
		[
			-5,
			29
		],
		[
			-18,
			24
		],
		[
			23,
			-73
		],
		[
			21,
			-23
		],
		[
			-7,
			-19
		],
		[
			-24,
			-8
		],
		[
			-13,
			-62
		],
		[
			-16,
			-22
		],
		[
			-17,
			1
		],
		[
			-8,
			31
		],
		[
			-20,
			12
		],
		[
			-12,
			121
		],
		[
			0,
			61
		],
		[
			12,
			78
		],
		[
			-5,
			13
		],
		[
			-14,
			-76
		],
		[
			-2,
			-76
		],
		[
			8,
			-94
		],
		[
			11,
			-77
		],
		[
			-5,
			-42
		],
		[
			8,
			-34
		],
		[
			40,
			10
		],
		[
			37,
			47
		],
		[
			9,
			-49
		],
		[
			13,
			6
		],
		[
			13,
			30
		],
		[
			26,
			24
		],
		[
			32,
			-1
		],
		[
			14,
			-41
		],
		[
			0,
			-43
		],
		[
			-14,
			-78
		],
		[
			3,
			-55
		],
		[
			2,
			-164
		],
		[
			9,
			5
		],
		[
			7,
			115
		],
		[
			3,
			150
		],
		[
			14,
			40
		],
		[
			-6,
			33
		],
		[
			14,
			20
		],
		[
			25,
			-21
		],
		[
			16,
			-94
		],
		[
			7,
			-65
		],
		[
			-4,
			-52
		],
		[
			7,
			-98
		],
		[
			-8,
			-25
		],
		[
			4,
			-54
		],
		[
			-13,
			-54
		],
		[
			-17,
			-10
		],
		[
			-6,
			18
		],
		[
			-10,
			-16
		],
		[
			-6,
			-40
		],
		[
			-10,
			-9
		],
		[
			-3,
			-43
		],
		[
			-7,
			-11
		],
		[
			-7,
			-71
		],
		[
			-13,
			-15
		],
		[
			-3,
			-46
		],
		[
			-17,
			-25
		],
		[
			-3,
			-24
		],
		[
			-26,
			25
		],
		[
			-29,
			-4
		],
		[
			-26,
			18
		],
		[
			-5,
			25
		],
		[
			-10,
			-14
		],
		[
			-15,
			45
		],
		[
			-13,
			115
		],
		[
			31,
			3
		],
		[
			5,
			45
		],
		[
			-28,
			-25
		],
		[
			-12,
			11
		],
		[
			-9,
			-33
		],
		[
			9,
			-57
		],
		[
			6,
			-86
		],
		[
			-7,
			0
		],
		[
			-29,
			47
		],
		[
			-14,
			-10
		],
		[
			-20,
			34
		],
		[
			-31,
			30
		],
		[
			-23,
			48
		],
		[
			-1,
			-29
		],
		[
			17,
			-61
		],
		[
			21,
			-5
		],
		[
			63,
			-102
		],
		[
			46,
			-28
		],
		[
			8,
			-31
		],
		[
			1,
			-40
		],
		[
			-7,
			-56
		],
		[
			-13,
			-54
		],
		[
			1,
			-28
		],
		[
			-9,
			-53
		],
		[
			-15,
			-42
		],
		[
			-50,
			-112
		],
		[
			-50,
			112
		],
		[
			1,
			-65
		],
		[
			24,
			-55
		],
		[
			36,
			-43
		],
		[
			36,
			80
		],
		[
			13,
			2
		],
		[
			27,
			30
		],
		[
			4,
			62
		],
		[
			11,
			-14
		],
		[
			3,
			-66
		],
		[
			8,
			-31
		],
		[
			18,
			-5
		],
		[
			-9,
			75
		],
		[
			20,
			-29
		],
		[
			2,
			-85
		],
		[
			-17,
			-75
		],
		[
			-18,
			-13
		],
		[
			0,
			-34
		],
		[
			-11,
			-20
		],
		[
			-14,
			-84
		],
		[
			-7,
			-71
		],
		[
			-17,
			20
		],
		[
			1,
			80
		],
		[
			-10,
			19
		],
		[
			1,
			-82
		],
		[
			-16,
			-7
		],
		[
			42,
			-64
		],
		[
			23,
			123
		],
		[
			33,
			120
		],
		[
			24,
			75
		],
		[
			47,
			176
		],
		[
			8,
			-21
		],
		[
			-28,
			-83
		],
		[
			-26,
			-96
		],
		[
			-22,
			-62
		],
		[
			-21,
			-78
		],
		[
			-18,
			-82
		],
		[
			-21,
			-115
		],
		[
			-3,
			-32
		],
		[
			-4,
			67
		],
		[
			-35,
			55
		],
		[
			-39,
			1
		],
		[
			-60,
			-38
		],
		[
			-29,
			-33
		],
		[
			-20,
			-32
		],
		[
			-32,
			-81
		],
		[
			-39,
			-75
		],
		[
			-26,
			-63
		],
		[
			-37,
			-113
		],
		[
			-14,
			-55
		],
		[
			-25,
			-128
		],
		[
			-14,
			-111
		],
		[
			-10,
			-112
		],
		[
			-9,
			-69
		],
		[
			-4,
			-69
		],
		[
			-13,
			7
		],
		[
			-3,
			34
		],
		[
			-21,
			21
		],
		[
			-23,
			9
		],
		[
			-28,
			-2
		],
		[
			-30,
			-12
		],
		[
			-35,
			-42
		],
		[
			-8,
			-17
		]
	],
	[
		[
			28030,
			56345
		],
		[
			-93,
			330
		],
		[
			-104,
			362
		],
		[
			-31,
			116
		],
		[
			-88,
			302
		],
		[
			-61,
			1
		],
		[
			-74,
			7
		],
		[
			-178,
			10
		],
		[
			4,
			135
		],
		[
			-42,
			199
		],
		[
			-30,
			-73
		],
		[
			-5,
			21
		],
		[
			7,
			48
		],
		[
			-2,
			53
		],
		[
			-55,
			13
		],
		[
			-105,
			16
		],
		[
			-188,
			29
		],
		[
			-23,
			-20
		],
		[
			-5,
			39
		],
		[
			-12,
			-52
		],
		[
			-7,
			9
		],
		[
			-20,
			-27
		],
		[
			-6,
			5
		],
		[
			-29,
			-47
		],
		[
			-28,
			-60
		],
		[
			-7,
			21
		],
		[
			-91,
			-99
		]
	],
	[
		[
			26419,
			57669
		],
		[
			9,
			275
		],
		[
			22,
			48
		],
		[
			3,
			-26
		],
		[
			28,
			4
		],
		[
			22,
			63
		],
		[
			-5,
			57
		],
		[
			9,
			25
		],
		[
			-4,
			44
		],
		[
			17,
			62
		],
		[
			13,
			15
		],
		[
			8,
			48
		],
		[
			16,
			8
		],
		[
			15,
			45
		],
		[
			80,
			7
		],
		[
			11,
			50
		],
		[
			22,
			32
		],
		[
			5,
			26
		],
		[
			10,
			-7
		],
		[
			16,
			48
		],
		[
			4,
			35
		],
		[
			16,
			4
		],
		[
			8,
			40
		],
		[
			21,
			29
		],
		[
			24,
			-18
		],
		[
			26,
			115
		],
		[
			-3,
			63
		],
		[
			10,
			30
		],
		[
			15,
			-36
		],
		[
			20,
			98
		],
		[
			33,
			70
		],
		[
			10,
			-40
		],
		[
			-5,
			-70
		],
		[
			15,
			-20
		],
		[
			28,
			62
		],
		[
			15,
			93
		],
		[
			15,
			35
		],
		[
			17,
			21
		],
		[
			12,
			-5
		],
		[
			9,
			33
		],
		[
			19,
			-12
		],
		[
			4,
			-50
		],
		[
			15,
			0
		],
		[
			14,
			28
		],
		[
			33,
			200
		],
		[
			21,
			53
		],
		[
			11,
			12
		],
		[
			8,
			-23
		],
		[
			17,
			0
		],
		[
			-10,
			74
		],
		[
			7,
			65
		],
		[
			6,
			12
		],
		[
			-4,
			80
		],
		[
			9,
			60
		]
	],
	[
		[
			20923,
			73979
		],
		[
			188,
			-1
		],
		[
			322,
			0
		],
		[
			212,
			0
		],
		[
			92,
			0
		],
		[
			193,
			1
		],
		[
			160,
			-1
		],
		[
			135,
			0
		],
		[
			141,
			1
		],
		[
			256,
			1
		],
		[
			201,
			0
		]
	],
	[
		[
			23008,
			70412
		],
		[
			-210,
			-1
		],
		[
			-186,
			1
		],
		[
			-119,
			1
		],
		[
			-252,
			4
		],
		[
			-192,
			2
		],
		[
			-179,
			2
		],
		[
			-253,
			1
		],
		[
			-123,
			0
		],
		[
			-292,
			1
		],
		[
			-173,
			0
		],
		[
			-105,
			0
		]
	],
	[
		[
			20924,
			70423
		],
		[
			0,
			2828
		],
		[
			-1,
			17
		],
		[
			0,
			711
		]
	],
	[
		[
			23550,
			60009
		],
		[
			0,
			-581
		]
	],
	[
		[
			23550,
			59428
		],
		[
			6,
			-130
		],
		[
			7,
			-206
		],
		[
			6,
			-127
		],
		[
			14,
			-355
		],
		[
			4,
			-82
		],
		[
			15,
			-387
		],
		[
			-2,
			-319
		],
		[
			-3,
			-261
		],
		[
			-1,
			-235
		],
		[
			-2,
			-170
		],
		[
			-2,
			-417
		],
		[
			-5,
			-642
		]
	],
	[
		[
			23587,
			56097
		],
		[
			-9,
			-25
		],
		[
			-19,
			73
		],
		[
			-16,
			-13
		],
		[
			-1,
			23
		],
		[
			-17,
			-1
		],
		[
			-18,
			79
		],
		[
			-15,
			-16
		],
		[
			-12,
			5
		],
		[
			-21,
			78
		],
		[
			-7,
			58
		],
		[
			-22,
			2
		],
		[
			-23,
			85
		],
		[
			-27,
			28
		],
		[
			-7,
			-68
		],
		[
			-11,
			-32
		],
		[
			-13,
			-7
		],
		[
			-34,
			4
		],
		[
			0,
			15
		],
		[
			-21,
			-7
		],
		[
			-7,
			61
		],
		[
			-10,
			3
		],
		[
			-24,
			-52
		],
		[
			-20,
			3
		],
		[
			1,
			-45
		],
		[
			-13,
			9
		],
		[
			-9,
			-31
		],
		[
			-29,
			61
		],
		[
			-1,
			-30
		],
		[
			-30,
			-29
		],
		[
			-15,
			13
		],
		[
			1,
			-20
		],
		[
			-14,
			8
		],
		[
			-8,
			-90
		],
		[
			-14,
			-14
		],
		[
			-19,
			19
		],
		[
			-7,
			-81
		],
		[
			-12,
			-3
		],
		[
			-1,
			22
		],
		[
			-17,
			79
		],
		[
			-21,
			-6
		],
		[
			-8,
			57
		],
		[
			-11,
			-4
		],
		[
			-16,
			30
		],
		[
			12,
			58
		],
		[
			-25,
			16
		],
		[
			-8,
			-86
		],
		[
			-18,
			-9
		],
		[
			-4,
			42
		],
		[
			-13,
			14
		],
		[
			-6,
			-33
		],
		[
			-9,
			25
		],
		[
			-6,
			95
		],
		[
			-5,
			11
		],
		[
			-14,
			-27
		],
		[
			-6,
			15
		],
		[
			3,
			-73
		],
		[
			-16,
			-57
		],
		[
			-13,
			19
		],
		[
			11,
			-42
		],
		[
			-13,
			-22
		],
		[
			3,
			-64
		],
		[
			-11,
			-31
		],
		[
			-11,
			14
		],
		[
			-12,
			94
		],
		[
			10,
			30
		],
		[
			-2,
			66
		],
		[
			-9,
			28
		],
		[
			-10,
			-19
		],
		[
			-2,
			-42
		],
		[
			-13,
			19
		],
		[
			-9,
			-7
		],
		[
			-11,
			-64
		],
		[
			-20,
			5
		],
		[
			-5,
			30
		],
		[
			1,
			63
		],
		[
			-12,
			19
		],
		[
			-16,
			-27
		],
		[
			-11,
			25
		],
		[
			3,
			41
		],
		[
			-19,
			42
		],
		[
			-9,
			-3
		],
		[
			-12,
			-58
		],
		[
			-29,
			-92
		],
		[
			-12,
			-9
		],
		[
			-16,
			34
		],
		[
			-9,
			3
		],
		[
			4,
			65
		],
		[
			-5,
			-1
		],
		[
			7,
			60
		],
		[
			-7,
			20
		],
		[
			-13,
			-14
		],
		[
			-19,
			11
		],
		[
			-10,
			91
		],
		[
			8,
			35
		],
		[
			-4,
			50
		],
		[
			-17,
			-47
		],
		[
			-20,
			22
		],
		[
			-15,
			0
		],
		[
			-19,
			28
		],
		[
			-11,
			-40
		],
		[
			-3,
			-44
		],
		[
			-20,
			-26
		],
		[
			-24,
			96
		],
		[
			-21,
			23
		],
		[
			-12,
			-37
		],
		[
			-21,
			4
		],
		[
			-13,
			26
		],
		[
			-13,
			3
		],
		[
			-17,
			24
		],
		[
			-19,
			46
		],
		[
			-16,
			-27
		],
		[
			-9,
			15
		],
		[
			-12,
			-11
		],
		[
			-2,
			20
		],
		[
			-18,
			-3
		],
		[
			-5,
			140
		],
		[
			-18,
			56
		],
		[
			4,
			22
		],
		[
			-16,
			5
		],
		[
			-18,
			57
		],
		[
			-4,
			-92
		],
		[
			-12,
			-4
		],
		[
			-22,
			47
		],
		[
			-17,
			2
		],
		[
			-6,
			-49
		],
		[
			-30,
			15
		],
		[
			-24,
			78
		],
		[
			-37,
			143
		],
		[
			-20,
			-19
		],
		[
			0,
			2257
		],
		[
			-123,
			0
		],
		[
			-179,
			0
		],
		[
			-150,
			0
		],
		[
			-175,
			1
		],
		[
			-210,
			0
		]
	],
	[
		[
			21214,
			59429
		],
		[
			1,
			119
		],
		[
			0,
			463
		]
	],
	[
		[
			27478,
			65805
		],
		[
			48,
			61
		],
		[
			45,
			74
		],
		[
			9,
			24
		],
		[
			10,
			60
		],
		[
			13,
			3
		],
		[
			3,
			-28
		],
		[
			36,
			72
		],
		[
			47,
			74
		]
	],
	[
		[
			27689,
			66145
		],
		[
			0,
			-314
		],
		[
			1,
			-2
		],
		[
			247,
			-1
		],
		[
			77,
			3
		],
		[
			167,
			-2
		],
		[
			243,
			1
		],
		[
			105,
			3
		],
		[
			111,
			-4
		],
		[
			169,
			-1
		],
		[
			107,
			2
		],
		[
			14,
			-59
		],
		[
			5,
			4
		],
		[
			8,
			-100
		],
		[
			15,
			4
		],
		[
			27,
			-34
		],
		[
			10,
			-49
		],
		[
			-8,
			-32
		],
		[
			14,
			-21
		],
		[
			2,
			-159
		],
		[
			-8,
			-12
		],
		[
			25,
			-113
		],
		[
			1,
			-34
		],
		[
			11,
			5
		],
		[
			15,
			-33
		],
		[
			-2,
			-18
		],
		[
			25,
			3
		],
		[
			3,
			-22
		],
		[
			16,
			8
		],
		[
			-1,
			-30
		],
		[
			13,
			-55
		]
	],
	[
		[
			28900,
			63272
		],
		[
			-23,
			37
		],
		[
			-22,
			6
		],
		[
			-24,
			-20
		],
		[
			-15,
			-34
		],
		[
			-20,
			-82
		]
	],
	[
		[
			28796,
			63179
		],
		[
			-217,
			-1
		],
		[
			-118,
			-1
		],
		[
			-151,
			0
		],
		[
			-236,
			3
		],
		[
			-305,
			-2
		]
	],
	[
		[
			27769,
			63178
		],
		[
			-167,
			0
		],
		[
			-124,
			0
		],
		[
			0,
			1068
		]
	],
	[
		[
			27478,
			64246
		],
		[
			0,
			1559
		]
	],
	[
		[
			20920,
			69320
		],
		[
			5,
			4
		],
		[
			0,
			872
		],
		[
			-1,
			227
		]
	],
	[
		[
			23039,
			67577
		],
		[
			-40,
			0
		],
		[
			5,
			-22
		],
		[
			-7,
			-37
		],
		[
			22,
			-64
		],
		[
			-1,
			-110
		],
		[
			-14,
			-5
		],
		[
			8,
			-52
		],
		[
			-3,
			-31
		],
		[
			24,
			-3
		],
		[
			2,
			-83
		],
		[
			9,
			-35
		],
		[
			-7,
			-66
		],
		[
			-14,
			-16
		],
		[
			5,
			-56
		],
		[
			-8,
			-28
		],
		[
			6,
			-21
		],
		[
			-12,
			-46
		],
		[
			0,
			-80
		],
		[
			-11,
			-16
		],
		[
			-3,
			-52
		],
		[
			-11,
			-26
		],
		[
			1,
			-76
		],
		[
			15,
			-27
		],
		[
			17,
			-60
		],
		[
			10,
			-87
		],
		[
			-4,
			-45
		],
		[
			13,
			-31
		]
	],
	[
		[
			23041,
			66402
		],
		[
			-17,
			-7
		],
		[
			-5,
			30
		],
		[
			-24,
			-5
		],
		[
			-7,
			53
		],
		[
			-21,
			66
		],
		[
			7,
			52
		],
		[
			-11,
			16
		],
		[
			-21,
			3
		],
		[
			-1,
			40
		],
		[
			-28,
			35
		],
		[
			-12,
			-17
		],
		[
			-8,
			48
		],
		[
			-43,
			13
		],
		[
			-5,
			28
		],
		[
			-18,
			20
		],
		[
			-1,
			38
		],
		[
			-25,
			25
		],
		[
			-15,
			-14
		],
		[
			-15,
			13
		],
		[
			-7,
			-23
		],
		[
			-18,
			14
		],
		[
			-16,
			-13
		],
		[
			-16,
			11
		],
		[
			-18,
			-17
		],
		[
			-25,
			9
		],
		[
			-20,
			21
		],
		[
			-8,
			-11
		],
		[
			-9,
			-74
		],
		[
			-12,
			-29
		],
		[
			-19,
			-9
		],
		[
			-31,
			69
		],
		[
			-36,
			62
		],
		[
			-58,
			85
		],
		[
			-9,
			59
		],
		[
			-112,
			0
		],
		[
			-186,
			-1
		],
		[
			-153,
			1
		],
		[
			-214,
			-1
		],
		[
			-206,
			-2
		],
		[
			-62,
			4
		],
		[
			-178,
			0
		],
		[
			-143,
			1
		],
		[
			-293,
			1
		]
	],
	[
		[
			20922,
			66996
		],
		[
			0,
			345
		],
		[
			-1,
			8
		],
		[
			0,
			1828
		],
		[
			-1,
			143
		]
	],
	[
		[
			23587,
			56097
		],
		[
			8,
			8
		],
		[
			0,
			-54
		],
		[
			11,
			-25
		],
		[
			9,
			6
		],
		[
			-2,
			-36
		],
		[
			10,
			-9
		],
		[
			5,
			27
		],
		[
			8,
			-18
		],
		[
			3,
			29
		],
		[
			21,
			-27
		],
		[
			11,
			46
		],
		[
			12,
			-17
		],
		[
			5,
			-30
		],
		[
			6,
			21
		],
		[
			16,
			-22
		]
	],
	[
		[
			23710,
			55996
		],
		[
			0,
			0
		]
	],
	[
		[
			23710,
			55996
		],
		[
			1,
			-11
		],
		[
			0,
			-608
		]
	],
	[
		[
			23711,
			55377
		],
		[
			0,
			-1196
		],
		[
			8,
			-12
		],
		[
			11,
			-72
		],
		[
			18,
			-31
		],
		[
			9,
			-83
		],
		[
			15,
			-55
		],
		[
			-2,
			-34
		],
		[
			8,
			-56
		],
		[
			-7,
			-42
		],
		[
			3,
			-45
		],
		[
			-7,
			-28
		],
		[
			6,
			-51
		],
		[
			9,
			-32
		],
		[
			13,
			-6
		],
		[
			3,
			-35
		],
		[
			-6,
			-27
		],
		[
			14,
			-36
		],
		[
			-1,
			-32
		],
		[
			8,
			-15
		],
		[
			3,
			-49
		],
		[
			-6,
			-53
		],
		[
			12,
			-47
		],
		[
			6,
			2
		],
		[
			6,
			-113
		],
		[
			19,
			12
		],
		[
			-6,
			-102
		],
		[
			8,
			-31
		],
		[
			2,
			-54
		],
		[
			-13,
			-21
		],
		[
			-1,
			-33
		],
		[
			12,
			-55
		],
		[
			-9,
			-22
		],
		[
			-3,
			-38
		],
		[
			4,
			-63
		],
		[
			-9,
			-33
		],
		[
			-9,
			-63
		],
		[
			-3,
			-73
		],
		[
			-12,
			-25
		],
		[
			-2,
			-68
		],
		[
			-14,
			-30
		],
		[
			-3,
			-40
		],
		[
			7,
			-24
		],
		[
			5,
			-91
		],
		[
			-13,
			-51
		],
		[
			-6,
			-74
		],
		[
			16,
			-52
		],
		[
			1,
			-53
		],
		[
			-5,
			-39
		],
		[
			9,
			-79
		],
		[
			-12,
			-70
		],
		[
			9,
			-19
		],
		[
			-11,
			-51
		],
		[
			-14,
			-39
		],
		[
			-7,
			-78
		],
		[
			-13,
			-74
		],
		[
			-17,
			-45
		],
		[
			-2,
			-25
		],
		[
			9,
			-30
		],
		[
			17,
			-94
		]
	],
	[
		[
			23768,
			51502
		],
		[
			0,
			-14
		],
		[
			-46,
			3
		],
		[
			-37,
			-40
		],
		[
			-128,
			-208
		],
		[
			-28,
			-61
		],
		[
			-10,
			-54
		],
		[
			-15,
			7
		],
		[
			22,
			71
		],
		[
			9,
			47
		],
		[
			13,
			-1
		],
		[
			9,
			19
		],
		[
			8,
			46
		],
		[
			9,
			-16
		],
		[
			11,
			8
		],
		[
			-15,
			55
		],
		[
			-54,
			-54
		],
		[
			-8,
			26
		],
		[
			17,
			90
		],
		[
			4,
			80
		],
		[
			0,
			74
		],
		[
			-12,
			5
		],
		[
			-5,
			23
		],
		[
			-17,
			-29
		],
		[
			-10,
			-41
		],
		[
			-4,
			-50
		],
		[
			-15,
			-24
		],
		[
			-6,
			46
		],
		[
			-18,
			-45
		],
		[
			-2,
			-35
		],
		[
			9,
			-32
		],
		[
			-10,
			-50
		],
		[
			10,
			-55
		],
		[
			20,
			-17
		],
		[
			-6,
			-54
		],
		[
			11,
			-20
		],
		[
			2,
			-78
		],
		[
			-2,
			-67
		],
		[
			-8,
			-31
		],
		[
			-9,
			10
		],
		[
			-19,
			-71
		],
		[
			-22,
			-65
		],
		[
			-3,
			26
		],
		[
			-13,
			-8
		],
		[
			-2,
			-88
		],
		[
			6,
			-26
		],
		[
			13,
			44
		],
		[
			26,
			65
		],
		[
			3,
			19
		],
		[
			32,
			99
		],
		[
			15,
			23
		],
		[
			0,
			45
		],
		[
			26,
			-15
		],
		[
			-20,
			-61
		],
		[
			-62,
			-153
		],
		[
			-24,
			-69
		],
		[
			-4,
			-25
		],
		[
			-32,
			-91
		],
		[
			-40,
			-143
		],
		[
			-15,
			-8
		],
		[
			-69,
			-146
		],
		[
			-35,
			-80
		],
		[
			-53,
			-89
		],
		[
			-61,
			-112
		],
		[
			-34,
			-87
		],
		[
			-13,
			-42
		],
		[
			-15,
			-74
		],
		[
			-53,
			-111
		],
		[
			-24,
			-68
		],
		[
			-47,
			-155
		],
		[
			-32,
			-143
		],
		[
			-11,
			-83
		],
		[
			-14,
			-59
		],
		[
			-33,
			-221
		],
		[
			-24,
			-197
		],
		[
			-11,
			-127
		],
		[
			-10,
			-192
		],
		[
			-2,
			-108
		],
		[
			1,
			-103
		],
		[
			8,
			-205
		],
		[
			14,
			-207
		],
		[
			12,
			-134
		],
		[
			16,
			-229
		],
		[
			11,
			-260
		],
		[
			-7,
			47
		],
		[
			-5,
			147
		],
		[
			-12,
			189
		],
		[
			-11,
			152
		],
		[
			-24,
			16
		],
		[
			18,
			27
		],
		[
			-9,
			83
		],
		[
			-6,
			87
		],
		[
			-9,
			88
		],
		[
			-3,
			106
		],
		[
			1,
			138
		],
		[
			-1,
			122
		],
		[
			11,
			276
		],
		[
			16,
			180
		],
		[
			19,
			148
		],
		[
			14,
			70
		],
		[
			10,
			87
		],
		[
			8,
			35
		],
		[
			-2,
			47
		],
		[
			13,
			86
		],
		[
			18,
			38
		],
		[
			9,
			45
		],
		[
			18,
			127
		],
		[
			28,
			58
		],
		[
			8,
			53
		],
		[
			16,
			2
		],
		[
			35,
			105
		],
		[
			23,
			49
		],
		[
			24,
			23
		],
		[
			-4,
			43
		],
		[
			9,
			29
		],
		[
			-9,
			16
		],
		[
			-16,
			-41
		],
		[
			-20,
			-35
		],
		[
			-11,
			-40
		],
		[
			-17,
			-5
		],
		[
			-6,
			40
		],
		[
			0,
			60
		],
		[
			-18,
			12
		],
		[
			-6,
			-31
		],
		[
			0,
			-84
		],
		[
			-5,
			-25
		],
		[
			6,
			-41
		],
		[
			-4,
			-36
		],
		[
			-20,
			-56
		],
		[
			-17,
			-61
		],
		[
			-8,
			-1
		],
		[
			-18,
			30
		],
		[
			-3,
			43
		],
		[
			-32,
			-61
		],
		[
			-17,
			-67
		],
		[
			21,
			-22
		],
		[
			24,
			57
		],
		[
			8,
			-74
		],
		[
			-7,
			-23
		],
		[
			-38,
			-223
		],
		[
			-12,
			-2
		],
		[
			-6,
			55
		],
		[
			-21,
			-10
		],
		[
			-4,
			18
		],
		[
			-32,
			-11
		],
		[
			-11,
			12
		],
		[
			-6,
			-38
		],
		[
			12,
			-32
		],
		[
			15,
			-1
		],
		[
			11,
			17
		],
		[
			-4,
			-64
		],
		[
			7,
			-48
		],
		[
			15,
			-34
		],
		[
			17,
			-18
		],
		[
			-19,
			-146
		],
		[
			-13,
			-185
		],
		[
			-12,
			-106
		],
		[
			-20,
			-27
		],
		[
			-7,
			-27
		],
		[
			-11,
			18
		],
		[
			14,
			21
		],
		[
			3,
			59
		],
		[
			-8,
			3
		],
		[
			-6,
			-31
		],
		[
			-29,
			-75
		],
		[
			4,
			-32
		],
		[
			24,
			-16
		],
		[
			25,
			38
		],
		[
			8,
			2
		],
		[
			-5,
			-116
		],
		[
			3,
			-4
		],
		[
			-4,
			-202
		],
		[
			-6,
			-207
		],
		[
			-4,
			-3
		],
		[
			10,
			-230
		],
		[
			8,
			-65
		],
		[
			1,
			-84
		],
		[
			9,
			-1
		],
		[
			23,
			-215
		],
		[
			5,
			-29
		],
		[
			-9,
			-47
		],
		[
			4,
			-34
		],
		[
			-1,
			-62
		],
		[
			8,
			-72
		],
		[
			20,
			-11
		],
		[
			1,
			-35
		],
		[
			12,
			18
		],
		[
			2,
			-127
		],
		[
			-23,
			7
		],
		[
			-13,
			-8
		],
		[
			0,
			-19
		],
		[
			-21,
			-12
		],
		[
			-6,
			-99
		],
		[
			-20,
			11
		],
		[
			-7,
			40
		],
		[
			-15,
			3
		],
		[
			-6,
			55
		],
		[
			-11,
			4
		],
		[
			-18,
			98
		],
		[
			-31,
			12
		],
		[
			-11,
			33
		],
		[
			-17,
			-9
		],
		[
			-7,
			16
		],
		[
			-23,
			-17
		],
		[
			-4,
			18
		],
		[
			-13,
			-1
		],
		[
			-3,
			-29
		],
		[
			-10,
			31
		],
		[
			-20,
			-14
		],
		[
			-8,
			22
		],
		[
			-6,
			-22
		],
		[
			-14,
			20
		],
		[
			-8,
			30
		],
		[
			3,
			25
		],
		[
			-16,
			1
		],
		[
			-3,
			44
		],
		[
			-15,
			-1
		],
		[
			-21,
			75
		],
		[
			-9,
			-11
		],
		[
			-25,
			48
		],
		[
			-19,
			-22
		],
		[
			-13,
			35
		],
		[
			-15,
			69
		],
		[
			-10,
			8
		],
		[
			-2,
			33
		],
		[
			-8,
			12
		],
		[
			-18,
			-15
		],
		[
			-21,
			47
		],
		[
			-12,
			-3
		],
		[
			-8,
			20
		],
		[
			-12,
			-19
		],
		[
			-9,
			44
		],
		[
			6,
			50
		],
		[
			-10,
			56
		],
		[
			-11,
			13
		],
		[
			-3,
			98
		],
		[
			-6,
			42
		],
		[
			-3,
			79
		],
		[
			-8,
			25
		],
		[
			-1,
			49
		],
		[
			-7,
			64
		],
		[
			-17,
			43
		],
		[
			2,
			31
		],
		[
			-13,
			26
		],
		[
			-7,
			37
		],
		[
			5,
			20
		],
		[
			-11,
			46
		],
		[
			-9,
			7
		],
		[
			-1,
			52
		],
		[
			6,
			31
		],
		[
			-3,
			66
		],
		[
			4,
			29
		],
		[
			-4,
			86
		],
		[
			-16,
			25
		],
		[
			1,
			37
		],
		[
			-12,
			11
		],
		[
			9,
			30
		],
		[
			5,
			86
		],
		[
			-3,
			31
		],
		[
			4,
			60
		],
		[
			-13,
			10
		],
		[
			5,
			76
		],
		[
			-12,
			58
		],
		[
			-7,
			-14
		],
		[
			-7,
			46
		],
		[
			-9,
			-18
		],
		[
			-9,
			39
		],
		[
			-10,
			-6
		],
		[
			-18,
			90
		],
		[
			-9,
			11
		],
		[
			-3,
			38
		],
		[
			-8,
			-9
		],
		[
			-10,
			38
		],
		[
			0,
			50
		],
		[
			-7,
			26
		],
		[
			3,
			41
		],
		[
			-13,
			48
		],
		[
			2,
			47
		],
		[
			-17,
			16
		],
		[
			-7,
			81
		],
		[
			-10,
			23
		],
		[
			-8,
			70
		],
		[
			-35,
			53
		],
		[
			-4,
			53
		],
		[
			-7,
			-2
		],
		[
			-13,
			59
		],
		[
			2,
			38
		],
		[
			-17,
			100
		],
		[
			3,
			47
		],
		[
			-9,
			39
		],
		[
			9,
			29
		],
		[
			-12,
			11
		],
		[
			-9,
			47
		],
		[
			4,
			39
		],
		[
			-14,
			28
		],
		[
			1,
			33
		],
		[
			-15,
			28
		],
		[
			-4,
			51
		],
		[
			2,
			41
		],
		[
			-8,
			26
		],
		[
			-4,
			73
		],
		[
			-6,
			1
		],
		[
			-9,
			88
		],
		[
			-8,
			1
		],
		[
			-6,
			47
		],
		[
			1,
			76
		],
		[
			-7,
			106
		],
		[
			-18,
			46
		],
		[
			-10,
			40
		],
		[
			3,
			14
		],
		[
			-9,
			71
		],
		[
			-23,
			41
		],
		[
			-2,
			30
		],
		[
			-17,
			46
		],
		[
			-18,
			25
		],
		[
			-13,
			84
		],
		[
			0,
			21
		],
		[
			-26,
			21
		],
		[
			-6,
			44
		],
		[
			-23,
			7
		],
		[
			3,
			57
		],
		[
			-2,
			65
		],
		[
			-5,
			5
		],
		[
			-6,
			-67
		],
		[
			-6,
			27
		],
		[
			2,
			53
		],
		[
			-17,
			27
		],
		[
			-13,
			108
		],
		[
			-8,
			-4
		],
		[
			-9,
			32
		],
		[
			-13,
			-25
		],
		[
			-7,
			44
		],
		[
			-8,
			-27
		],
		[
			-37,
			-13
		],
		[
			-19,
			31
		],
		[
			-6,
			-8
		],
		[
			-15,
			22
		],
		[
			-22,
			-14
		],
		[
			-12,
			24
		],
		[
			-17,
			-7
		],
		[
			-4,
			-22
		],
		[
			-26,
			21
		],
		[
			-11,
			50
		],
		[
			-13,
			-3
		],
		[
			-20,
			40
		],
		[
			-14,
			-18
		],
		[
			-10,
			-111
		],
		[
			-34,
			19
		],
		[
			-9,
			-37
		],
		[
			-7,
			11
		],
		[
			-22,
			-32
		],
		[
			-7,
			10
		],
		[
			-8,
			-54
		],
		[
			2,
			-23
		],
		[
			-13,
			-40
		],
		[
			0,
			-50
		],
		[
			-7,
			0
		],
		[
			-2,
			-59
		],
		[
			-11,
			-30
		],
		[
			1,
			-33
		],
		[
			-7,
			-58
		],
		[
			2,
			-52
		],
		[
			-5,
			-48
		],
		[
			-10,
			-5
		],
		[
			-3,
			-72
		],
		[
			-5,
			-37
		],
		[
			10,
			-22
		],
		[
			-5,
			-38
		],
		[
			-18,
			-38
		],
		[
			-10,
			8
		],
		[
			-7,
			-67
		],
		[
			-17,
			-43
		],
		[
			-7,
			-36
		],
		[
			-4,
			-84
		],
		[
			-14,
			-8
		],
		[
			-17,
			15
		],
		[
			-15,
			-11
		],
		[
			-14,
			46
		],
		[
			-27,
			24
		],
		[
			-27,
			111
		],
		[
			-24,
			33
		],
		[
			-10,
			-8
		],
		[
			-22,
			38
		],
		[
			-18,
			77
		],
		[
			-13,
			24
		],
		[
			-39,
			21
		],
		[
			-17,
			28
		],
		[
			-19,
			61
		],
		[
			-11,
			12
		],
		[
			-19,
			81
		],
		[
			0,
			24
		],
		[
			-14,
			47
		],
		[
			-21,
			7
		],
		[
			-12,
			27
		],
		[
			-5,
			34
		],
		[
			-30,
			78
		],
		[
			-9,
			43
		],
		[
			-7,
			110
		],
		[
			-12,
			56
		],
		[
			-7,
			60
		],
		[
			-13,
			63
		],
		[
			0,
			59
		],
		[
			-7,
			57
		],
		[
			6,
			72
		],
		[
			-3,
			54
		],
		[
			2,
			55
		],
		[
			-7,
			68
		],
		[
			-11,
			30
		],
		[
			-3,
			44
		],
		[
			-13,
			39
		],
		[
			-1,
			30
		],
		[
			-13,
			34
		],
		[
			2,
			33
		],
		[
			-13,
			177
		],
		[
			-7,
			40
		],
		[
			-12,
			4
		],
		[
			-11,
			91
		],
		[
			-15,
			0
		],
		[
			-14,
			66
		],
		[
			-12,
			10
		],
		[
			-3,
			24
		],
		[
			-15,
			34
		],
		[
			-12,
			-4
		],
		[
			-7,
			28
		],
		[
			-31,
			39
		],
		[
			0,
			39
		],
		[
			-44,
			118
		],
		[
			-13,
			107
		],
		[
			-12,
			37
		],
		[
			-18,
			26
		],
		[
			-9,
			33
		],
		[
			-9,
			2
		],
		[
			-2,
			36
		],
		[
			-24,
			106
		],
		[
			-20,
			35
		],
		[
			-4,
			54
		],
		[
			-14,
			32
		],
		[
			-21,
			7
		],
		[
			-35,
			78
		],
		[
			-11,
			88
		],
		[
			-10,
			24
		],
		[
			-6,
			68
		],
		[
			-13,
			89
		],
		[
			-9,
			41
		],
		[
			-19,
			38
		],
		[
			-11,
			-19
		],
		[
			-11,
			41
		]
	],
	[
		[
			20232,
			53938
		],
		[
			-5,
			28
		],
		[
			-16,
			20
		],
		[
			1,
			23
		],
		[
			-10,
			25
		],
		[
			-3,
			38
		],
		[
			7,
			18
		],
		[
			1,
			101
		],
		[
			331,
			0
		],
		[
			250,
			-1
		],
		[
			226,
			0
		],
		[
			183,
			1
		],
		[
			0,
			1212
		],
		[
			2,
			254
		],
		[
			0,
			149
		],
		[
			2,
			417
		],
		[
			2,
			232
		],
		[
			0,
			1518
		],
		[
			1,
			434
		],
		[
			0,
			809
		],
		[
			-1,
			213
		],
		[
			11,
			0
		]
	],
	[
		[
			20922,
			66996
		],
		[
			0,
			-2328
		]
	],
	[
		[
			19530,
			64667
		],
		[
			-136,
			-2
		],
		[
			-143,
			-1
		],
		[
			-52,
			-3
		],
		[
			-133,
			1
		],
		[
			-93,
			2
		],
		[
			0,
			442
		],
		[
			1,
			219
		],
		[
			-1,
			508
		]
	],
	[
		[
			18973,
			65833
		],
		[
			0,
			676
		],
		[
			1,
			163
		],
		[
			0,
			1090
		],
		[
			-1,
			26
		],
		[
			0,
			516
		],
		[
			-1,
			267
		],
		[
			1,
			140
		]
	],
	[
		[
			18973,
			68711
		],
		[
			-2,
			175
		],
		[
			-1,
			282
		],
		[
			1,
			156
		],
		[
			75,
			2
		],
		[
			22,
			-12
		],
		[
			85,
			2
		],
		[
			11,
			8
		],
		[
			45,
			-5
		],
		[
			25,
			8
		],
		[
			87,
			-2
		],
		[
			194,
			5
		],
		[
			11,
			-7
		],
		[
			221,
			0
		],
		[
			316,
			0
		],
		[
			14,
			-4
		],
		[
			144,
			-2
		],
		[
			178,
			-1
		],
		[
			23,
			7
		],
		[
			132,
			0
		],
		[
			251,
			-2
		],
		[
			115,
			-1
		]
	],
	[
		[
			29908,
			65840
		],
		[
			0,
			-107
		],
		[
			3,
			-222
		],
		[
			0,
			-150
		],
		[
			-3,
			-209
		],
		[
			-12,
			-8
		],
		[
			3,
			-76
		],
		[
			-8,
			-29
		]
	],
	[
		[
			29891,
			65039
		],
		[
			-7,
			19
		],
		[
			-17,
			2
		],
		[
			-21,
			-24
		],
		[
			-18,
			3
		],
		[
			-13,
			-24
		],
		[
			-16,
			28
		],
		[
			-6,
			-37
		],
		[
			-49,
			-35
		],
		[
			-3,
			20
		],
		[
			-15,
			0
		],
		[
			-27,
			-33
		],
		[
			-6,
			21
		],
		[
			-26,
			1
		],
		[
			-7,
			-26
		],
		[
			-18,
			23
		],
		[
			-40,
			-27
		],
		[
			-3,
			60
		],
		[
			-9,
			-17
		],
		[
			-19,
			-82
		],
		[
			-12,
			0
		],
		[
			-22,
			-73
		],
		[
			-13,
			23
		],
		[
			-24,
			-58
		],
		[
			-7,
			13
		],
		[
			-23,
			-28
		],
		[
			5,
			-22
		],
		[
			-10,
			-32
		],
		[
			-29,
			-11
		],
		[
			-22,
			-54
		],
		[
			-9,
			15
		],
		[
			-15,
			-35
		]
	],
	[
		[
			29390,
			64649
		],
		[
			1,
			33
		],
		[
			-20,
			102
		],
		[
			68,
			130
		],
		[
			-19,
			97
		],
		[
			4,
			161
		],
		[
			5,
			295
		],
		[
			9,
			422
		]
	],
	[
		[
			23231,
			64184
		],
		[
			167,
			-9
		],
		[
			159,
			-8
		],
		[
			156,
			3
		],
		[
			130,
			8
		],
		[
			62,
			0
		],
		[
			197,
			12
		],
		[
			152,
			13
		],
		[
			101,
			14
		],
		[
			12,
			-38
		],
		[
			1,
			-33
		],
		[
			18,
			-14
		],
		[
			-1,
			-36
		],
		[
			16,
			-57
		],
		[
			10,
			-2
		],
		[
			1,
			-56
		],
		[
			11,
			-31
		],
		[
			19,
			-7
		]
	],
	[
		[
			24442,
			63943
		],
		[
			-8,
			-18
		],
		[
			-17,
			-144
		],
		[
			-2,
			-71
		],
		[
			6,
			-165
		],
		[
			14,
			-99
		],
		[
			7,
			-28
		],
		[
			-8,
			-66
		],
		[
			5,
			-38
		],
		[
			15,
			-34
		],
		[
			4,
			-28
		],
		[
			-3,
			-61
		],
		[
			26,
			-77
		],
		[
			15,
			-57
		],
		[
			11,
			-14
		],
		[
			10,
			-69
		],
		[
			13,
			-8
		],
		[
			11,
			-76
		],
		[
			16,
			-54
		],
		[
			59,
			-137
		],
		[
			20,
			-90
		],
		[
			3,
			-90
		],
		[
			8,
			-78
		],
		[
			-9,
			-36
		],
		[
			11,
			-85
		],
		[
			3,
			-65
		],
		[
			22,
			-69
		],
		[
			11,
			7
		],
		[
			11,
			32
		],
		[
			9,
			66
		],
		[
			19,
			4
		],
		[
			27,
			-45
		],
		[
			16,
			-5
		],
		[
			38,
			-82
		],
		[
			-2,
			-60
		],
		[
			-12,
			-29
		],
		[
			-13,
			-59
		],
		[
			10,
			-92
		],
		[
			-2,
			-37
		],
		[
			-22,
			-96
		],
		[
			-6,
			-99
		],
		[
			-17,
			-68
		],
		[
			-7,
			-52
		],
		[
			-1,
			-78
		],
		[
			5,
			-70
		],
		[
			18,
			-50
		],
		[
			20,
			-89
		],
		[
			25,
			-37
		],
		[
			11,
			-54
		],
		[
			8,
			0
		],
		[
			17,
			-60
		],
		[
			16,
			7
		],
		[
			3,
			-27
		],
		[
			-12,
			-24
		],
		[
			6,
			-50
		],
		[
			20,
			-5
		],
		[
			10,
			31
		],
		[
			13,
			-28
		],
		[
			1,
			-29
		],
		[
			15,
			-12
		],
		[
			23,
			-70
		],
		[
			-2,
			-40
		],
		[
			14,
			-3
		],
		[
			9,
			-42
		],
		[
			19,
			-24
		],
		[
			0,
			-57
		],
		[
			11,
			-68
		],
		[
			-13,
			-8
		],
		[
			2,
			-50
		],
		[
			26,
			-161
		],
		[
			-4,
			-62
		],
		[
			-15,
			-12
		],
		[
			-8,
			-56
		],
		[
			17,
			-53
		],
		[
			-1,
			-47
		],
		[
			13,
			-87
		],
		[
			11,
			-46
		],
		[
			-1,
			-53
		],
		[
			24,
			-56
		],
		[
			10,
			27
		],
		[
			-15,
			45
		],
		[
			14,
			12
		],
		[
			17,
			-56
		],
		[
			8,
			-53
		],
		[
			11,
			14
		]
	],
	[
		[
			25079,
			59990
		],
		[
			9,
			-21
		],
		[
			-5,
			-90
		],
		[
			-6,
			-46
		],
		[
			-10,
			-9
		],
		[
			-1,
			-38
		],
		[
			17,
			-37
		],
		[
			-3,
			-28
		],
		[
			-16,
			3
		],
		[
			-4,
			-44
		],
		[
			11,
			-58
		],
		[
			-8,
			-29
		],
		[
			-7,
			-71
		],
		[
			-13,
			-18
		],
		[
			-18,
			78
		],
		[
			-13,
			-13
		],
		[
			-13,
			-142
		]
	],
	[
		[
			24999,
			59427
		],
		[
			-8,
			-40
		],
		[
			-13,
			7
		],
		[
			2,
			31
		]
	],
	[
		[
			24980,
			59425
		],
		[
			6,
			38
		],
		[
			-5,
			49
		],
		[
			-21,
			2
		],
		[
			-4,
			-30
		],
		[
			9,
			-58
		]
	],
	[
		[
			24965,
			59426
		],
		[
			6,
			-22
		],
		[
			-7,
			-64
		],
		[
			10,
			-59
		],
		[
			-5,
			-37
		],
		[
			-24,
			-1
		],
		[
			0,
			-37
		],
		[
			21,
			-39
		],
		[
			1,
			-27
		],
		[
			-15,
			-15
		],
		[
			-30,
			16
		],
		[
			-3,
			-21
		],
		[
			28,
			-74
		],
		[
			1,
			-61
		],
		[
			-22,
			-40
		],
		[
			-3,
			-75
		],
		[
			-12,
			-23
		]
	],
	[
		[
			24911,
			58847
		],
		[
			-179,
			-6
		],
		[
			16,
			110
		],
		[
			23,
			58
		],
		[
			0,
			23
		],
		[
			15,
			53
		],
		[
			16,
			28
		],
		[
			3,
			43
		],
		[
			9,
			7
		],
		[
			5,
			133
		],
		[
			-22,
			44
		],
		[
			3,
			15
		],
		[
			-5,
			71
		],
		[
			-349,
			-1
		],
		[
			-323,
			1
		],
		[
			-141,
			0
		],
		[
			-222,
			1
		],
		[
			-210,
			1
		]
	],
	[
		[
			23358,
			63503
		],
		[
			-31,
			56
		],
		[
			8,
			79
		],
		[
			-24,
			76
		],
		[
			-2,
			77
		],
		[
			-20,
			19
		],
		[
			1,
			32
		],
		[
			-18,
			26
		],
		[
			-12,
			110
		],
		[
			1,
			39
		],
		[
			-11,
			34
		],
		[
			-1,
			40
		],
		[
			13,
			42
		],
		[
			-11,
			18
		],
		[
			-1,
			-33
		],
		[
			-20,
			3
		],
		[
			1,
			63
		]
	],
	[
		[
			26900,
			61666
		],
		[
			18,
			-20
		],
		[
			35,
			40
		],
		[
			23,
			11
		],
		[
			5,
			49
		],
		[
			3,
			98
		],
		[
			12,
			28
		],
		[
			16,
			-7
		],
		[
			6,
			30
		],
		[
			-3,
			101
		],
		[
			-10,
			105
		],
		[
			21,
			52
		],
		[
			0,
			67
		],
		[
			14,
			88
		],
		[
			12,
			27
		],
		[
			6,
			37
		],
		[
			13,
			-40
		],
		[
			11,
			-1
		],
		[
			12,
			-79
		],
		[
			-8,
			-40
		],
		[
			11,
			-20
		],
		[
			9,
			22
		],
		[
			3,
			42
		],
		[
			9,
			20
		],
		[
			9,
			-25
		],
		[
			4,
			111
		],
		[
			-10,
			29
		],
		[
			-3,
			43
		],
		[
			19,
			19
		],
		[
			-3,
			96
		],
		[
			8,
			41
		],
		[
			10,
			12
		],
		[
			3,
			55
		],
		[
			31,
			-7
		],
		[
			3,
			83
		],
		[
			25,
			76
		],
		[
			17,
			-19
		],
		[
			6,
			-52
		],
		[
			11,
			3
		],
		[
			21,
			47
		],
		[
			17,
			8
		],
		[
			11,
			54
		],
		[
			11,
			8
		],
		[
			8,
			48
		],
		[
			16,
			57
		],
		[
			30,
			89
		],
		[
			16,
			9
		],
		[
			4,
			83
		],
		[
			10,
			26
		],
		[
			-11,
			50
		],
		[
			12,
			48
		],
		[
			0,
			57
		],
		[
			10,
			23
		],
		[
			-4,
			60
		],
		[
			13,
			-11
		],
		[
			-2,
			52
		],
		[
			7,
			20
		],
		[
			0,
			122
		],
		[
			9,
			30
		],
		[
			0,
			58
		],
		[
			10,
			48
		],
		[
			5,
			61
		],
		[
			10,
			23
		],
		[
			5,
			65
		],
		[
			-3,
			95
		],
		[
			4,
			71
		],
		[
			-9,
			84
		],
		[
			-11,
			44
		],
		[
			9,
			50
		],
		[
			14,
			-1
		],
		[
			18,
			27
		]
	],
	[
		[
			27769,
			63178
		],
		[
			-3,
			-600
		],
		[
			10,
			7
		],
		[
			33,
			103
		],
		[
			12,
			-1
		],
		[
			10,
			67
		],
		[
			31,
			60
		],
		[
			13,
			75
		],
		[
			11,
			-2
		],
		[
			28,
			-36
		],
		[
			11,
			54
		],
		[
			38,
			158
		],
		[
			13,
			-10
		],
		[
			-13,
			-14
		],
		[
			13,
			-18
		],
		[
			2,
			-26
		],
		[
			20,
			-34
		],
		[
			17,
			1
		],
		[
			7,
			-18
		],
		[
			28,
			-4
		],
		[
			14,
			38
		],
		[
			-7,
			49
		],
		[
			13,
			-1
		],
		[
			-11,
			32
		],
		[
			14,
			-11
		],
		[
			9,
			37
		],
		[
			19,
			-23
		],
		[
			28,
			87
		],
		[
			24,
			-20
		],
		[
			17,
			-49
		],
		[
			8,
			-40
		],
		[
			18,
			20
		],
		[
			17,
			-23
		],
		[
			14,
			4
		],
		[
			0,
			-37
		],
		[
			-16,
			-15
		],
		[
			12,
			-69
		],
		[
			19,
			-41
		],
		[
			-2,
			-33
		],
		[
			9,
			-12
		],
		[
			5,
			-43
		],
		[
			-6,
			-63
		],
		[
			10,
			-14
		]
	],
	[
		[
			28258,
			62713
		],
		[
			-9,
			-45
		],
		[
			-21,
			-175
		],
		[
			-78,
			209
		],
		[
			-66,
			179
		],
		[
			-4,
			-62
		],
		[
			5,
			-28
		],
		[
			-6,
			-36
		],
		[
			7,
			-11
		],
		[
			-23,
			-106
		],
		[
			6,
			-15
		],
		[
			-11,
			-54
		],
		[
			10,
			-36
		],
		[
			-16,
			-62
		],
		[
			-7,
			-7
		],
		[
			-24,
			-88
		],
		[
			6,
			-16
		],
		[
			-14,
			-63
		],
		[
			-7,
			21
		],
		[
			-15,
			-66
		],
		[
			-10,
			-24
		],
		[
			0,
			36
		],
		[
			-23,
			-71
		],
		[
			-20,
			-130
		],
		[
			-35,
			101
		],
		[
			-9,
			-69
		],
		[
			-17,
			-82
		],
		[
			-1,
			-71
		],
		[
			-8,
			1
		],
		[
			-10,
			-57
		],
		[
			-15,
			-138
		],
		[
			-28,
			-94
		],
		[
			-46,
			53
		],
		[
			-17,
			109
		],
		[
			-31,
			47
		],
		[
			-14,
			-121
		],
		[
			3,
			-65
		],
		[
			-12,
			-60
		],
		[
			-22,
			-87
		],
		[
			6,
			-44
		],
		[
			-12,
			-21
		],
		[
			-25,
			-81
		],
		[
			-7,
			-56
		],
		[
			6,
			-29
		],
		[
			-8,
			-30
		],
		[
			-6,
			-60
		],
		[
			-10,
			-51
		],
		[
			-18,
			-51
		],
		[
			-30,
			-104
		],
		[
			-21,
			-112
		],
		[
			2,
			-36
		],
		[
			-12,
			-39
		],
		[
			4,
			-41
		],
		[
			17,
			-34
		],
		[
			-12,
			-40
		],
		[
			-18,
			-34
		],
		[
			-1,
			-32
		],
		[
			13,
			-4
		],
		[
			-4,
			-29
		],
		[
			-49,
			-99
		],
		[
			-10,
			68
		],
		[
			-12,
			-9
		],
		[
			-19,
			-47
		],
		[
			-41,
			-71
		],
		[
			-4,
			26
		],
		[
			-21,
			38
		],
		[
			-7,
			-51
		],
		[
			9,
			-43
		],
		[
			-19,
			-47
		],
		[
			-17,
			-5
		],
		[
			-37,
			-27
		],
		[
			-31,
			-51
		],
		[
			-27,
			75
		],
		[
			-11,
			45
		],
		[
			-8,
			-21
		],
		[
			-8,
			-55
		],
		[
			-23,
			-17
		],
		[
			-2,
			-30
		],
		[
			-13,
			-29
		],
		[
			-34,
			-7
		],
		[
			-19,
			48
		],
		[
			0,
			24
		],
		[
			-12,
			25
		],
		[
			-18,
			3
		],
		[
			-7,
			52
		],
		[
			-14,
			31
		],
		[
			-2,
			90
		],
		[
			-15,
			22
		],
		[
			-1,
			33
		],
		[
			18,
			34
		],
		[
			-11,
			29
		]
	],
	[
		[
			27075,
			60636
		],
		[
			-14,
			-4
		],
		[
			-28,
			30
		],
		[
			-3,
			37
		],
		[
			-8,
			1
		],
		[
			-7,
			40
		],
		[
			-9,
			-2
		],
		[
			-7,
			42
		],
		[
			-15,
			11
		],
		[
			-13,
			134
		],
		[
			-10,
			19
		],
		[
			-13,
			61
		],
		[
			1,
			34
		],
		[
			-15,
			19
		],
		[
			-8,
			39
		],
		[
			11,
			55
		],
		[
			-15,
			22
		],
		[
			-9,
			80
		],
		[
			-10,
			45
		],
		[
			-15,
			37
		],
		[
			0,
			38
		],
		[
			8,
			0
		],
		[
			3,
			55
		],
		[
			-4,
			20
		],
		[
			11,
			33
		],
		[
			1,
			58
		],
		[
			-8,
			36
		],
		[
			1,
			90
		]
	],
	[
		[
			24442,
			63943
		],
		[
			12,
			16
		],
		[
			-2,
			50
		],
		[
			4,
			90
		],
		[
			-11,
			35
		],
		[
			13,
			69
		],
		[
			31,
			43
		],
		[
			18,
			-1
		],
		[
			18,
			41
		],
		[
			1,
			61
		],
		[
			6,
			49
		],
		[
			1,
			67
		],
		[
			10,
			27
		],
		[
			14,
			66
		],
		[
			11,
			19
		],
		[
			6,
			106
		],
		[
			-1,
			98
		],
		[
			-13,
			75
		],
		[
			-13,
			6
		],
		[
			-20,
			85
		],
		[
			11,
			77
		],
		[
			2,
			74
		],
		[
			6,
			55
		],
		[
			19,
			21
		],
		[
			13,
			-15
		],
		[
			23,
			40
		],
		[
			31,
			-6
		],
		[
			24,
			17
		],
		[
			16,
			56
		],
		[
			10,
			13
		],
		[
			26,
			-1
		],
		[
			18,
			57
		],
		[
			16,
			21
		],
		[
			-1,
			66
		],
		[
			9,
			59
		],
		[
			0,
			52
		],
		[
			9,
			29
		],
		[
			28,
			49
		],
		[
			-1,
			41
		],
		[
			8,
			72
		],
		[
			-3,
			58
		],
		[
			7,
			61
		],
		[
			-7,
			37
		],
		[
			1,
			89
		],
		[
			-13,
			41
		],
		[
			-47,
			73
		],
		[
			-15,
			74
		],
		[
			3,
			60
		],
		[
			-16,
			63
		],
		[
			-22,
			37
		],
		[
			-2,
			26
		],
		[
			-22,
			35
		],
		[
			0,
			47
		]
	],
	[
		[
			24658,
			66423
		],
		[
			45,
			-2
		],
		[
			227,
			-2
		],
		[
			51,
			-5
		],
		[
			194,
			-11
		],
		[
			41,
			4
		],
		[
			152,
			1
		],
		[
			82,
			-5
		]
	],
	[
		[
			25450,
			66403
		],
		[
			-2,
			-124
		],
		[
			-8,
			-97
		],
		[
			10,
			-109
		],
		[
			21,
			-117
		],
		[
			12,
			-37
		],
		[
			3,
			-54
		],
		[
			13,
			-139
		],
		[
			4,
			-75
		],
		[
			14,
			-93
		],
		[
			8,
			-20
		],
		[
			2,
			-47
		]
	],
	[
		[
			25386,
			60941
		],
		[
			-8,
			-66
		],
		[
			-17,
			-35
		],
		[
			-11,
			-56
		],
		[
			7,
			-105
		],
		[
			20,
			-68
		],
		[
			-6,
			-50
		],
		[
			-48,
			-19
		],
		[
			-12,
			-11
		],
		[
			-18,
			-52
		],
		[
			-14,
			26
		],
		[
			-18,
			-44
		],
		[
			-2,
			-55
		],
		[
			-9,
			-65
		],
		[
			2,
			-25
		],
		[
			17,
			-65
		],
		[
			7,
			-66
		],
		[
			-10,
			-89
		],
		[
			-15,
			-10
		],
		[
			-13,
			13
		],
		[
			-19,
			52
		],
		[
			-35,
			40
		],
		[
			-14,
			39
		],
		[
			-31,
			42
		],
		[
			-19,
			5
		],
		[
			-13,
			-21
		],
		[
			-13,
			-42
		],
		[
			-9,
			-65
		],
		[
			-16,
			-52
		],
		[
			-4,
			-55
		],
		[
			14,
			-52
		]
	],
	[
		[
			20232,
			53938
		],
		[
			-214,
			0
		],
		[
			-254,
			0
		],
		[
			0,
			-524
		],
		[
			-234,
			-1
		]
	],
	[
		[
			24911,
			58847
		],
		[
			4,
			-38
		],
		[
			18,
			-49
		],
		[
			0,
			-45
		],
		[
			-24,
			23
		],
		[
			-9,
			-49
		],
		[
			20,
			-36
		],
		[
			-11,
			-33
		],
		[
			-11,
			-1
		],
		[
			-9,
			-52
		],
		[
			-17,
			-22
		],
		[
			-9,
			21
		],
		[
			-15,
			-41
		],
		[
			6,
			-68
		],
		[
			9,
			-17
		],
		[
			12,
			23
		],
		[
			3,
			-38
		],
		[
			-26,
			-42
		],
		[
			1,
			-53
		],
		[
			9,
			-10
		],
		[
			-3,
			-40
		],
		[
			-22,
			56
		],
		[
			-9,
			-9
		],
		[
			-5,
			-58
		],
		[
			9,
			-42
		],
		[
			-11,
			-75
		],
		[
			-8,
			88
		],
		[
			-23,
			-67
		],
		[
			-3,
			-46
		],
		[
			12,
			-6
		],
		[
			2,
			43
		],
		[
			15,
			-35
		],
		[
			-9,
			-47
		],
		[
			0,
			-45
		],
		[
			-16,
			-10
		],
		[
			4,
			-47
		],
		[
			15,
			-7
		],
		[
			6,
			-29
		],
		[
			-12,
			-43
		],
		[
			15,
			-58
		],
		[
			-10,
			-25
		],
		[
			-12,
			21
		],
		[
			-9,
			-26
		],
		[
			-9,
			-100
		],
		[
			-25,
			13
		],
		[
			-3,
			-49
		]
	],
	[
		[
			24751,
			57677
		],
		[
			17,
			-55
		],
		[
			0,
			-45
		],
		[
			-18,
			-44
		],
		[
			-31,
			-44
		],
		[
			-4,
			59
		],
		[
			-11,
			2
		],
		[
			-2,
			-29
		],
		[
			8,
			-44
		],
		[
			-5,
			-25
		],
		[
			6,
			-72
		],
		[
			-14,
			-19
		],
		[
			-5,
			34
		],
		[
			2,
			57
		],
		[
			-10,
			-27
		],
		[
			2,
			-35
		],
		[
			-7,
			-14
		],
		[
			6,
			-40
		],
		[
			20,
			-2
		],
		[
			2,
			-31
		],
		[
			-14,
			-50
		],
		[
			-11,
			18
		],
		[
			1,
			49
		],
		[
			-10,
			-21
		],
		[
			0,
			-64
		],
		[
			12,
			-61
		],
		[
			1,
			-27
		],
		[
			-13,
			-51
		],
		[
			6,
			-83
		],
		[
			-25,
			-57
		],
		[
			0,
			-63
		],
		[
			-10,
			1
		],
		[
			3,
			54
		],
		[
			-19,
			-1
		],
		[
			-5,
			-27
		],
		[
			8,
			-45
		],
		[
			-7,
			-30
		],
		[
			-19,
			-15
		],
		[
			-4,
			-71
		],
		[
			-16,
			43
		],
		[
			-9,
			-29
		],
		[
			14,
			-43
		],
		[
			20,
			1
		],
		[
			2,
			-25
		],
		[
			-13,
			-28
		],
		[
			-16,
			33
		],
		[
			-12,
			-32
		],
		[
			9,
			-51
		],
		[
			11,
			3
		],
		[
			3,
			-24
		],
		[
			-8,
			-61
		],
		[
			-24,
			-6
		],
		[
			7,
			-45
		],
		[
			-11,
			-16
		],
		[
			-5,
			43
		],
		[
			-16,
			-23
		],
		[
			-3,
			-29
		],
		[
			22,
			-34
		],
		[
			-18,
			-78
		],
		[
			7,
			-55
		],
		[
			16,
			-26
		],
		[
			-10,
			-34
		],
		[
			-8,
			18
		],
		[
			-24,
			-2
		],
		[
			-1,
			-59
		],
		[
			10,
			-26
		],
		[
			13,
			14
		],
		[
			8,
			-50
		],
		[
			-12,
			-18
		],
		[
			-16,
			22
		],
		[
			-7,
			35
		],
		[
			-17,
			-16
		],
		[
			-2,
			-28
		],
		[
			25,
			-51
		],
		[
			2,
			-33
		],
		[
			-28,
			-41
		],
		[
			13,
			-63
		],
		[
			-14,
			-80
		],
		[
			18,
			16
		],
		[
			-1,
			51
		],
		[
			14,
			-27
		],
		[
			-4,
			-54
		],
		[
			-17,
			-10
		],
		[
			-3,
			-19
		],
		[
			10,
			-24
		],
		[
			17,
			14
		],
		[
			10,
			73
		],
		[
			5,
			-32
		],
		[
			-23,
			-90
		],
		[
			0,
			-64
		],
		[
			12,
			-68
		],
		[
			3,
			42
		],
		[
			10,
			13
		],
		[
			2,
			-23
		],
		[
			-13,
			-52
		],
		[
			2,
			-75
		],
		[
			-3,
			-23
		],
		[
			-14,
			-8
		],
		[
			-11,
			14
		],
		[
			-5,
			-39
		],
		[
			23,
			-62
		],
		[
			-13,
			-59
		]
	],
	[
		[
			24512,
			55359
		],
		[
			-219,
			4
		],
		[
			-154,
			5
		],
		[
			-157,
			7
		],
		[
			-86,
			0
		],
		[
			-185,
			2
		]
	],
	[
		[
			16868,
			55911
		],
		[
			16,
			-5
		],
		[
			28,
			-53
		],
		[
			21,
			-22
		],
		[
			1,
			-25
		],
		[
			16,
			-61
		],
		[
			-5,
			-43
		],
		[
			-13,
			25
		],
		[
			-26,
			7
		],
		[
			-6,
			35
		],
		[
			0,
			74
		],
		[
			-20,
			16
		],
		[
			-12,
			52
		]
	],
	[
		[
			16867,
			55390
		],
		[
			9,
			4
		],
		[
			22,
			-117
		],
		[
			40,
			-130
		],
		[
			-10,
			4
		],
		[
			-11,
			-22
		],
		[
			-17,
			44
		],
		[
			-13,
			72
		],
		[
			-14,
			119
		],
		[
			-6,
			26
		]
	],
	[
		[
			16741,
			55926
		],
		[
			8,
			7
		],
		[
			1,
			-41
		],
		[
			-11,
			7
		],
		[
			2,
			27
		]
	],
	[
		[
			16637,
			56552
		],
		[
			8,
			-17
		],
		[
			11,
			14
		],
		[
			0,
			-30
		],
		[
			-17,
			-4
		],
		[
			-9,
			21
		],
		[
			7,
			16
		]
	],
	[
		[
			16596,
			55679
		],
		[
			14,
			7
		],
		[
			20,
			-35
		],
		[
			8,
			-31
		],
		[
			-13,
			-15
		],
		[
			-20,
			21
		],
		[
			-9,
			53
		]
	],
	[
		[
			16501,
			56608
		],
		[
			18,
			-7
		],
		[
			13,
			-22
		],
		[
			15,
			5
		],
		[
			19,
			-43
		],
		[
			19,
			-4
		],
		[
			7,
			39
		],
		[
			20,
			-20
		],
		[
			-11,
			-43
		],
		[
			-28,
			-11
		],
		[
			-17,
			-31
		],
		[
			-42,
			24
		],
		[
			-1,
			61
		],
		[
			-12,
			52
		]
	],
	[
		[
			16410,
			56520
		],
		[
			22,
			8
		],
		[
			9,
			21
		],
		[
			13,
			-8
		],
		[
			13,
			19
		],
		[
			0,
			-48
		],
		[
			18,
			-13
		],
		[
			1,
			-48
		],
		[
			-41,
			-54
		],
		[
			-16,
			37
		],
		[
			-19,
			86
		]
	],
	[
		[
			16354,
			56562
		],
		[
			16,
			17
		],
		[
			6,
			28
		],
		[
			6,
			-35
		],
		[
			13,
			-26
		],
		[
			-21,
			-6
		],
		[
			-20,
			22
		]
	],
	[
		[
			15305,
			65829
		],
		[
			155,
			-4
		],
		[
			9,
			6
		],
		[
			77,
			-1
		],
		[
			56,
			12
		],
		[
			28,
			-8
		],
		[
			115,
			2
		],
		[
			37,
			5
		],
		[
			95,
			-1
		],
		[
			45,
			-5
		],
		[
			154,
			-8
		],
		[
			114,
			-4
		],
		[
			197,
			0
		],
		[
			92,
			2
		]
	],
	[
		[
			16479,
			65825
		],
		[
			0,
			-1
		]
	],
	[
		[
			16479,
			65824
		],
		[
			0,
			-1448
		],
		[
			1,
			-34
		],
		[
			0,
			-756
		],
		[
			-1,
			-393
		],
		[
			-1,
			-13
		],
		[
			0,
			-457
		],
		[
			-1,
			-122
		],
		[
			2,
			-263
		],
		[
			26,
			-77
		],
		[
			115,
			-330
		],
		[
			114,
			-336
		],
		[
			63,
			-182
		],
		[
			99,
			-298
		],
		[
			125,
			-377
		],
		[
			62,
			-186
		],
		[
			127,
			-394
		],
		[
			313,
			-989
		],
		[
			234,
			-759
		],
		[
			70,
			-234
		],
		[
			147,
			-492
		]
	],
	[
		[
			17950,
			55027
		],
		[
			-416,
			-126
		],
		[
			-254,
			-89
		],
		[
			-3,
			98
		],
		[
			-9,
			62
		],
		[
			-8,
			20
		],
		[
			-14,
			-23
		],
		[
			-3,
			66
		],
		[
			1,
			71
		],
		[
			-8,
			41
		],
		[
			9,
			61
		],
		[
			-9,
			161
		],
		[
			-13,
			127
		],
		[
			-9,
			54
		],
		[
			-40,
			193
		],
		[
			-25,
			61
		],
		[
			-10,
			51
		],
		[
			-15,
			37
		],
		[
			-9,
			-2
		],
		[
			-19,
			95
		],
		[
			-26,
			59
		],
		[
			-14,
			15
		],
		[
			-20,
			57
		],
		[
			-25,
			88
		],
		[
			-24,
			39
		],
		[
			-2,
			-47
		],
		[
			-21,
			-23
		],
		[
			-18,
			14
		],
		[
			-10,
			25
		],
		[
			-15,
			6
		],
		[
			-4,
			38
		],
		[
			9,
			34
		],
		[
			1,
			43
		],
		[
			-14,
			116
		],
		[
			-11,
			64
		],
		[
			-17,
			50
		],
		[
			-35,
			1
		],
		[
			-22,
			-8
		],
		[
			-16,
			-36
		],
		[
			-14,
			38
		],
		[
			-28,
			16
		],
		[
			-37,
			59
		],
		[
			-12,
			2
		],
		[
			-24,
			53
		],
		[
			-17,
			141
		],
		[
			-10,
			10
		],
		[
			-17,
			53
		],
		[
			-4,
			-3
		],
		[
			-20,
			65
		],
		[
			-21,
			25
		],
		[
			-6,
			20
		],
		[
			-32,
			4
		],
		[
			-16,
			-24
		],
		[
			-18,
			25
		],
		[
			-22,
			-10
		],
		[
			-37,
			60
		],
		[
			-23,
			0
		],
		[
			-15,
			15
		],
		[
			-44,
			-7
		],
		[
			-48,
			-22
		],
		[
			-1,
			31
		],
		[
			-13,
			66
		],
		[
			-16,
			30
		],
		[
			-12,
			-4
		],
		[
			-6,
			32
		],
		[
			13,
			143
		],
		[
			-11,
			60
		],
		[
			8,
			119
		],
		[
			-17,
			54
		],
		[
			9,
			115
		],
		[
			1,
			140
		],
		[
			-18,
			56
		],
		[
			-14,
			7
		],
		[
			-3,
			-21
		],
		[
			-27,
			55
		],
		[
			-11,
			48
		],
		[
			10,
			131
		],
		[
			-2,
			50
		],
		[
			-11,
			53
		],
		[
			-27,
			14
		],
		[
			-27,
			102
		],
		[
			-18,
			101
		],
		[
			-24,
			25
		],
		[
			-17,
			66
		],
		[
			-5,
			81
		],
		[
			-16,
			47
		],
		[
			-7,
			37
		],
		[
			-14,
			35
		],
		[
			-6,
			99
		],
		[
			-5,
			35
		],
		[
			-20,
			29
		],
		[
			-15,
			104
		],
		[
			-25,
			94
		],
		[
			-33,
			64
		],
		[
			-11,
			45
		],
		[
			-8,
			80
		],
		[
			1,
			42
		],
		[
			-11,
			101
		],
		[
			2,
			92
		],
		[
			-11,
			16
		],
		[
			10,
			74
		],
		[
			18,
			-38
		],
		[
			9,
			30
		],
		[
			7,
			61
		],
		[
			8,
			141
		],
		[
			-21,
			149
		],
		[
			-12,
			43
		],
		[
			-10,
			11
		],
		[
			-9,
			-28
		],
		[
			-37,
			2
		],
		[
			-28,
			68
		],
		[
			-22,
			102
		],
		[
			-14,
			18
		],
		[
			-2,
			31
		],
		[
			-17,
			60
		],
		[
			-4,
			62
		],
		[
			5,
			129
		],
		[
			-12,
			89
		],
		[
			-2,
			52
		],
		[
			-12,
			14
		],
		[
			-6,
			33
		],
		[
			-1,
			64
		],
		[
			5,
			27
		],
		[
			2,
			77
		],
		[
			-6,
			134
		],
		[
			14,
			28
		],
		[
			16,
			8
		],
		[
			6,
			-24
		],
		[
			7,
			-88
		],
		[
			-9,
			-9
		],
		[
			11,
			-107
		],
		[
			-2,
			-27
		],
		[
			27,
			-23
		],
		[
			27,
			-80
		],
		[
			8,
			5
		],
		[
			14,
			-63
		],
		[
			12,
			3
		],
		[
			-6,
			40
		],
		[
			-12,
			19
		],
		[
			-10,
			87
		],
		[
			-7,
			109
		],
		[
			-21,
			54
		],
		[
			-2,
			46
		],
		[
			-22,
			26
		],
		[
			9,
			74
		],
		[
			-7,
			68
		],
		[
			-15,
			-1
		],
		[
			-14,
			68
		],
		[
			8,
			-9
		],
		[
			9,
			26
		],
		[
			0,
			40
		],
		[
			19,
			-2
		],
		[
			10,
			39
		],
		[
			-10,
			71
		],
		[
			-26,
			44
		],
		[
			-13,
			-30
		],
		[
			-14,
			-6
		],
		[
			2,
			-47
		],
		[
			-5,
			-46
		],
		[
			15,
			-51
		],
		[
			-12,
			-25
		],
		[
			-4,
			-44
		],
		[
			19,
			-56
		],
		[
			-7,
			-14
		],
		[
			-11,
			29
		],
		[
			7,
			-71
		],
		[
			-15,
			-16
		],
		[
			-9,
			38
		],
		[
			-26,
			61
		],
		[
			-13,
			-12
		],
		[
			-23,
			67
		],
		[
			-10,
			53
		],
		[
			-17,
			33
		],
		[
			-16,
			8
		],
		[
			-20,
			-33
		],
		[
			14,
			127
		],
		[
			3,
			48
		],
		[
			-12,
			92
		],
		[
			7,
			20
		],
		[
			-16,
			70
		],
		[
			-11,
			-10
		],
		[
			-1,
			67
		],
		[
			-17,
			106
		],
		[
			-20,
			51
		],
		[
			-14,
			19
		],
		[
			-22,
			64
		],
		[
			-37,
			176
		],
		[
			-14,
			29
		],
		[
			-8,
			41
		],
		[
			-31,
			90
		],
		[
			-24,
			116
		],
		[
			14,
			78
		],
		[
			-1,
			42
		],
		[
			-14,
			126
		],
		[
			-16,
			123
		],
		[
			-7,
			105
		],
		[
			3,
			99
		],
		[
			13,
			132
		],
		[
			-5,
			52
		],
		[
			0,
			65
		],
		[
			-14,
			92
		],
		[
			-4,
			108
		],
		[
			-16,
			36
		],
		[
			-6,
			55
		],
		[
			-35,
			133
		],
		[
			-7,
			6
		],
		[
			0,
			43
		],
		[
			-8,
			43
		],
		[
			-22,
			32
		],
		[
			-49,
			151
		],
		[
			4,
			63
		],
		[
			-4,
			70
		],
		[
			-13,
			74
		],
		[
			9,
			98
		],
		[
			14,
			109
		],
		[
			42,
			265
		],
		[
			11,
			95
		],
		[
			7,
			119
		],
		[
			-12,
			37
		],
		[
			-1,
			97
		],
		[
			4,
			2
		],
		[
			11,
			99
		],
		[
			12,
			244
		],
		[
			-5,
			126
		],
		[
			-15,
			128
		],
		[
			-8,
			96
		],
		[
			-9,
			-4
		],
		[
			-17,
			54
		],
		[
			10,
			74
		],
		[
			5,
			110
		],
		[
			-3,
			67
		]
	],
	[
		[
			28861,
			63044
		],
		[
			-1,
			28
		]
	],
	[
		[
			28874,
			63137
		],
		[
			-6,
			7
		],
		[
			-22,
			-81
		],
		[
			2,
			-39
		],
		[
			11,
			-31
		],
		[
			1,
			-49
		],
		[
			-8,
			-28
		],
		[
			0,
			-41
		],
		[
			14,
			-52
		],
		[
			7,
			-58
		],
		[
			21,
			-62
		],
		[
			10,
			-68
		],
		[
			3,
			-58
		],
		[
			-5,
			-35
		],
		[
			2,
			-126
		],
		[
			16,
			-48
		],
		[
			7,
			-43
		],
		[
			2,
			-74
		],
		[
			34,
			-137
		],
		[
			16,
			-29
		],
		[
			10,
			24
		],
		[
			4,
			-36
		],
		[
			5,
			-129
		],
		[
			4,
			-244
		]
	],
	[
		[
			29002,
			61700
		],
		[
			-105,
			1
		],
		[
			-74,
			9
		],
		[
			-2,
			72
		],
		[
			-25,
			1311
		],
		[
			0,
			86
		]
	],
	[
		[
			28426,
			62262
		],
		[
			21,
			70
		],
		[
			37,
			-118
		],
		[
			-36,
			-118
		]
	],
	[
		[
			28448,
			62096
		],
		[
			0,
			93
		],
		[
			-22,
			73
		]
	],
	[
		[
			6433,
			39922
		],
		[
			2,
			44
		],
		[
			19,
			76
		],
		[
			12,
			7
		],
		[
			13,
			93
		],
		[
			16,
			52
		],
		[
			3,
			58
		],
		[
			-17,
			94
		],
		[
			-4,
			45
		],
		[
			-1,
			105
		],
		[
			8,
			37
		],
		[
			18,
			-9
		],
		[
			18,
			-32
		],
		[
			3,
			-32
		],
		[
			22,
			-44
		],
		[
			15,
			-47
		],
		[
			12,
			6
		],
		[
			25,
			-32
		],
		[
			39,
			-77
		],
		[
			13,
			-19
		],
		[
			22,
			-61
		],
		[
			16,
			-57
		],
		[
			17,
			-76
		],
		[
			-3,
			-47
		],
		[
			1,
			-90
		],
		[
			8,
			-10
		],
		[
			16,
			12
		],
		[
			7,
			-57
		],
		[
			-1,
			-57
		],
		[
			22,
			-82
		],
		[
			22,
			-39
		],
		[
			5,
			-21
		],
		[
			-4,
			-44
		],
		[
			-13,
			-51
		],
		[
			-17,
			-47
		],
		[
			-14,
			-56
		],
		[
			-23,
			-38
		],
		[
			-20,
			-47
		],
		[
			-20,
			-18
		],
		[
			-16,
			15
		],
		[
			-9,
			-9
		],
		[
			-18,
			-66
		],
		[
			-16,
			-25
		],
		[
			-13,
			-48
		],
		[
			-14,
			-16
		],
		[
			-12,
			-59
		],
		[
			1,
			-33
		],
		[
			-8,
			-37
		],
		[
			-5,
			-59
		],
		[
			-20,
			-63
		],
		[
			-15,
			61
		],
		[
			-22,
			52
		],
		[
			-22,
			29
		],
		[
			-10,
			95
		],
		[
			5,
			113
		],
		[
			4,
			151
		],
		[
			-10,
			106
		],
		[
			1,
			46
		],
		[
			-9,
			12
		],
		[
			-5,
			114
		],
		[
			-7,
			66
		],
		[
			-9,
			8
		],
		[
			-8,
			108
		]
	],
	[
		[
			6254,
			41293
		],
		[
			5,
			69
		],
		[
			11,
			56
		],
		[
			14,
			6
		],
		[
			13,
			-33
		],
		[
			10,
			-78
		],
		[
			10,
			-50
		],
		[
			24,
			29
		],
		[
			18,
			35
		],
		[
			26,
			-21
		],
		[
			0,
			-16
		],
		[
			17,
			-51
		],
		[
			10,
			-15
		],
		[
			5,
			-40
		],
		[
			31,
			-37
		],
		[
			5,
			-32
		],
		[
			0,
			-52
		],
		[
			-8,
			-43
		],
		[
			-13,
			-40
		],
		[
			-6,
			3
		],
		[
			-17,
			-36
		],
		[
			-14,
			10
		],
		[
			-30,
			-53
		],
		[
			-21,
			-9
		],
		[
			-17,
			26
		],
		[
			-7,
			210
		],
		[
			-7,
			20
		],
		[
			-14,
			-24
		],
		[
			-26,
			50
		],
		[
			-13,
			58
		],
		[
			-6,
			58
		]
	],
	[
		[
			6253,
			40841
		],
		[
			7,
			29
		],
		[
			28,
			57
		],
		[
			10,
			-30
		],
		[
			-4,
			-44
		],
		[
			5,
			-17
		],
		[
			-13,
			-19
		],
		[
			-5,
			15
		],
		[
			-18,
			-23
		],
		[
			-10,
			32
		]
	],
	[
		[
			6153,
			41274
		],
		[
			7,
			27
		],
		[
			13,
			5
		],
		[
			26,
			-19
		],
		[
			17,
			-60
		],
		[
			8,
			-51
		],
		[
			-9,
			-65
		],
		[
			-19,
			-29
		],
		[
			-17,
			-5
		],
		[
			-7,
			60
		],
		[
			-3,
			73
		],
		[
			-14,
			32
		],
		[
			-2,
			32
		]
	],
	[
		[
			6084,
			41504
		],
		[
			6,
			52
		],
		[
			9,
			29
		],
		[
			-2,
			58
		],
		[
			17,
			-2
		],
		[
			3,
			-14
		],
		[
			54,
			-29
		],
		[
			10,
			34
		],
		[
			4,
			-42
		],
		[
			22,
			-13
		],
		[
			27,
			18
		],
		[
			17,
			-25
		],
		[
			-8,
			-55
		],
		[
			-18,
			-51
		],
		[
			-20,
			-21
		],
		[
			-35,
			32
		],
		[
			-26,
			31
		],
		[
			-15,
			-14
		],
		[
			-29,
			-5
		],
		[
			-16,
			17
		]
	],
	[
		[
			5814,
			42059
		],
		[
			43,
			9
		],
		[
			13,
			49
		],
		[
			4,
			35
		],
		[
			13,
			48
		],
		[
			14,
			15
		],
		[
			6,
			-27
		],
		[
			6,
			-70
		],
		[
			20,
			-84
		],
		[
			4,
			-52
		],
		[
			-4,
			-15
		],
		[
			3,
			-47
		],
		[
			18,
			-55
		],
		[
			3,
			57
		],
		[
			12,
			-2
		],
		[
			-4,
			-64
		],
		[
			8,
			-24
		],
		[
			-1,
			-29
		],
		[
			17,
			-70
		],
		[
			-12,
			-37
		],
		[
			-11,
			18
		],
		[
			-21,
			-29
		],
		[
			-6,
			26
		],
		[
			-17,
			31
		],
		[
			-25,
			11
		],
		[
			-30,
			-20
		],
		[
			-7,
			4
		],
		[
			-7,
			84
		],
		[
			-11,
			34
		],
		[
			-1,
			31
		],
		[
			-14,
			67
		],
		[
			0,
			61
		],
		[
			-13,
			45
		]
	],
	[
		[
			5394,
			42585
		],
		[
			1,
			40
		],
		[
			11,
			38
		],
		[
			4,
			49
		],
		[
			33,
			72
		],
		[
			8,
			26
		],
		[
			23,
			-18
		],
		[
			3,
			25
		],
		[
			16,
			-11
		],
		[
			8,
			14
		],
		[
			15,
			-20
		],
		[
			10,
			-37
		],
		[
			5,
			-45
		],
		[
			0,
			-46
		],
		[
			-11,
			-63
		],
		[
			1,
			-106
		],
		[
			-4,
			-28
		],
		[
			-28,
			-78
		],
		[
			-8,
			15
		],
		[
			-36,
			12
		],
		[
			-18,
			71
		],
		[
			-24,
			29
		],
		[
			-9,
			61
		]
	],
	[
		[
			5266,
			42374
		],
		[
			4,
			43
		],
		[
			12,
			44
		],
		[
			19,
			45
		],
		[
			2,
			38
		],
		[
			11,
			9
		],
		[
			2,
			-31
		],
		[
			-5,
			-57
		],
		[
			2,
			-36
		],
		[
			-20,
			-28
		],
		[
			-16,
			-97
		],
		[
			-12,
			30
		],
		[
			1,
			40
		]
	],
	[
		[
			24498,
			67577
		],
		[
			-5,
			-52
		],
		[
			10,
			-50
		],
		[
			-1,
			-74
		],
		[
			27,
			-41
		],
		[
			13,
			-76
		],
		[
			-18,
			-60
		],
		[
			-6,
			-52
		],
		[
			-9,
			-24
		],
		[
			1,
			-108
		],
		[
			8,
			-88
		],
		[
			0,
			-68
		],
		[
			12,
			-25
		],
		[
			13,
			-169
		],
		[
			33,
			-64
		],
		[
			47,
			-37
		],
		[
			17,
			-20
		],
		[
			18,
			-109
		],
		[
			0,
			-37
		]
	],
	[
		[
			23231,
			64184
		],
		[
			4,
			28
		],
		[
			-10,
			56
		],
		[
			-13,
			16
		],
		[
			-15,
			58
		],
		[
			2,
			37
		],
		[
			13,
			35
		],
		[
			-4,
			83
		],
		[
			10,
			51
		],
		[
			-7,
			27
		],
		[
			2,
			66
		],
		[
			-9,
			20
		],
		[
			1,
			42
		],
		[
			-7,
			30
		],
		[
			5,
			27
		],
		[
			-5,
			93
		],
		[
			12,
			17
		],
		[
			-24,
			24
		],
		[
			4,
			37
		],
		[
			-5,
			63
		],
		[
			13,
			41
		],
		[
			-20,
			27
		],
		[
			7,
			29
		],
		[
			-1,
			116
		],
		[
			-20,
			10
		],
		[
			2,
			77
		],
		[
			-9,
			1
		],
		[
			-2,
			-37
		],
		[
			-15,
			28
		],
		[
			3,
			56
		],
		[
			-11,
			39
		],
		[
			7,
			39
		],
		[
			-8,
			41
		],
		[
			11,
			18
		],
		[
			-6,
			54
		],
		[
			8,
			20
		],
		[
			3,
			46
		],
		[
			-12,
			23
		],
		[
			-1,
			38
		],
		[
			-14,
			61
		],
		[
			6,
			11
		],
		[
			3,
			66
		],
		[
			-16,
			6
		],
		[
			1,
			30
		],
		[
			-15,
			11
		],
		[
			5,
			16
		],
		[
			-15,
			25
		],
		[
			1,
			83
		],
		[
			-22,
			56
		],
		[
			-3,
			48
		],
		[
			10,
			25
		],
		[
			-14,
			103
		],
		[
			-11,
			29
		],
		[
			0,
			76
		],
		[
			9,
			44
		],
		[
			-4,
			44
		],
		[
			-14,
			8
		]
	],
	[
		[
			26280,
			62461
		],
		[
			18,
			48
		],
		[
			7,
			-2
		],
		[
			15,
			-54
		],
		[
			21,
			-28
		],
		[
			14,
			29
		],
		[
			14,
			-3
		],
		[
			8,
			29
		],
		[
			8,
			-8
		],
		[
			4,
			-69
		],
		[
			29,
			-32
		],
		[
			10,
			-84
		],
		[
			16,
			-83
		],
		[
			0,
			-66
		],
		[
			5,
			-26
		],
		[
			40,
			-41
		],
		[
			33,
			19
		],
		[
			29,
			-46
		],
		[
			3,
			-34
		],
		[
			15,
			-26
		],
		[
			5,
			-50
		],
		[
			28,
			-29
		],
		[
			14,
			66
		],
		[
			26,
			22
		],
		[
			15,
			-32
		],
		[
			28,
			-20
		],
		[
			11,
			-24
		],
		[
			5,
			-43
		],
		[
			13,
			24
		],
		[
			30,
			-1
		],
		[
			10,
			53
		],
		[
			18,
			34
		],
		[
			9,
			39
		],
		[
			15,
			0
		],
		[
			21,
			32
		],
		[
			7,
			-33
		],
		[
			-3,
			-44
		],
		[
			9,
			-111
		],
		[
			13,
			-37
		],
		[
			21,
			-6
		],
		[
			21,
			-79
		],
		[
			13,
			-35
		],
		[
			2,
			-44
		]
	],
	[
		[
			27075,
			60636
		],
		[
			-108,
			-317
		],
		[
			-37,
			-39
		],
		[
			-22,
			-41
		],
		[
			-19,
			-49
		],
		[
			-25,
			-45
		],
		[
			0,
			-86
		],
		[
			-16,
			-39
		],
		[
			-12,
			-2
		],
		[
			-12,
			-33
		],
		[
			3,
			-59
		],
		[
			-6,
			-45
		],
		[
			-25,
			-36
		],
		[
			-29,
			-4
		],
		[
			-16,
			-80
		],
		[
			-2,
			-50
		],
		[
			-16,
			-4
		],
		[
			-33,
			-35
		],
		[
			-39,
			-52
		],
		[
			-21,
			2
		],
		[
			-33,
			-49
		],
		[
			-8,
			-27
		]
	],
	[
		[
			26599,
			59546
		],
		[
			-4,
			-21
		],
		[
			-83,
			8
		],
		[
			-79,
			2
		],
		[
			-76,
			5
		],
		[
			-83,
			11
		],
		[
			-51,
			16
		],
		[
			-74,
			9
		],
		[
			-55,
			-14
		],
		[
			-96,
			8
		],
		[
			-56,
			10
		],
		[
			-83,
			22
		],
		[
			-49,
			4
		],
		[
			-16,
			-22
		],
		[
			-7,
			22
		],
		[
			-146,
			-12
		],
		[
			-92,
			-2
		],
		[
			-114,
			-8
		],
		[
			1,
			35
		],
		[
			-61,
			17
		],
		[
			10,
			-147
		],
		[
			-6,
			-64
		],
		[
			-137,
			6
		],
		[
			-126,
			0
		],
		[
			-84,
			6
		],
		[
			-33,
			-10
		]
	],
	[
		[
			24980,
			59425
		],
		[
			-15,
			1
		]
	],
	[
		[
			28739,
			61120
		],
		[
			-14,
			0
		]
	],
	[
		[
			28725,
			61120
		],
		[
			-1,
			72
		],
		[
			8,
			28
		],
		[
			11,
			-40
		],
		[
			-4,
			-60
		]
	],
	[
		[
			28711,
			61320
		],
		[
			2,
			79
		],
		[
			11,
			13
		],
		[
			7,
			-30
		],
		[
			5,
			-118
		],
		[
			-15,
			21
		],
		[
			4,
			27
		],
		[
			-14,
			8
		]
	],
	[
		[
			28627,
			62072
		],
		[
			5,
			20
		],
		[
			5,
			-46
		],
		[
			-10,
			26
		]
	],
	[
		[
			29002,
			61700
		],
		[
			-1,
			-43
		],
		[
			-9,
			-105
		],
		[
			-5,
			-15
		],
		[
			-20,
			-211
		],
		[
			-18,
			-120
		]
	],
	[
		[
			28949,
			61206
		],
		[
			-107,
			-38
		],
		[
			-6,
			-55
		],
		[
			-6,
			4
		]
	],
	[
		[
			28830,
			61117
		],
		[
			-13,
			30
		],
		[
			-19,
			-4
		],
		[
			-22,
			-64
		],
		[
			-9,
			-1
		],
		[
			-1,
			67
		],
		[
			7,
			70
		],
		[
			17,
			28
		],
		[
			-17,
			2
		],
		[
			2,
			45
		],
		[
			11,
			40
		],
		[
			-21,
			9
		],
		[
			-12,
			-33
		],
		[
			-4,
			28
		],
		[
			5,
			58
		],
		[
			26,
			27
		],
		[
			-6,
			39
		],
		[
			-9,
			-13
		],
		[
			-4,
			36
		],
		[
			15,
			112
		],
		[
			-15,
			-24
		],
		[
			-7,
			-47
		],
		[
			0,
			-60
		],
		[
			-8,
			-1
		],
		[
			-11,
			77
		],
		[
			11,
			9
		],
		[
			-1,
			53
		],
		[
			-8,
			10
		],
		[
			-4,
			-49
		],
		[
			-9,
			-33
		],
		[
			6,
			-27
		],
		[
			-9,
			-62
		],
		[
			-4,
			29
		],
		[
			-17,
			-23
		],
		[
			-9,
			12
		],
		[
			-16,
			83
		],
		[
			-9,
			13
		],
		[
			2,
			43
		],
		[
			-24,
			151
		],
		[
			20,
			14
		],
		[
			5,
			39
		],
		[
			-8,
			-7
		],
		[
			-9,
			51
		],
		[
			8,
			40
		],
		[
			12,
			22
		],
		[
			6,
			-25
		],
		[
			12,
			26
		],
		[
			1,
			-36
		],
		[
			22,
			-9
		],
		[
			13,
			-39
		],
		[
			4,
			10
		],
		[
			-16,
			69
		],
		[
			-17,
			14
		],
		[
			-8,
			42
		],
		[
			-7,
			-3
		],
		[
			-16,
			77
		],
		[
			-5,
			-28
		],
		[
			-12,
			20
		],
		[
			-1,
			-59
		],
		[
			-7,
			8
		],
		[
			3,
			101
		],
		[
			18,
			92
		],
		[
			14,
			-45
		],
		[
			8,
			10
		],
		[
			-3,
			124
		],
		[
			-8,
			17
		],
		[
			-17,
			-47
		],
		[
			-12,
			4
		],
		[
			1,
			-48
		],
		[
			-12,
			-17
		],
		[
			4,
			104
		],
		[
			16,
			101
		],
		[
			7,
			-51
		],
		[
			21,
			-11
		],
		[
			11,
			31
		],
		[
			-6,
			54
		],
		[
			11,
			55
		],
		[
			-16,
			-9
		],
		[
			-3,
			-52
		],
		[
			4,
			-31
		],
		[
			-12,
			17
		],
		[
			3,
			63
		],
		[
			-6,
			59
		],
		[
			-7,
			14
		],
		[
			16,
			136
		],
		[
			12,
			42
		],
		[
			-2,
			24
		],
		[
			14,
			25
		],
		[
			7,
			37
		],
		[
			30,
			-6
		],
		[
			-11,
			24
		],
		[
			18,
			70
		],
		[
			-10,
			6
		],
		[
			12,
			122
		],
		[
			-35,
			-24
		],
		[
			-6,
			-48
		],
		[
			12,
			-24
		],
		[
			4,
			-32
		],
		[
			-12,
			-14
		],
		[
			-34,
			-97
		],
		[
			-7,
			31
		],
		[
			7,
			54
		],
		[
			-8,
			28
		],
		[
			0,
			-44
		],
		[
			-9,
			-51
		],
		[
			8,
			-34
		],
		[
			-7,
			-46
		],
		[
			-6,
			96
		],
		[
			-15,
			14
		],
		[
			6,
			-103
		],
		[
			-8,
			8
		],
		[
			-6,
			-42
		],
		[
			12,
			-22
		],
		[
			-21,
			-44
		],
		[
			-7,
			-28
		],
		[
			-13,
			8
		],
		[
			-2,
			26
		],
		[
			-22,
			46
		],
		[
			3,
			-46
		],
		[
			9,
			-13
		],
		[
			2,
			-41
		],
		[
			27,
			-54
		],
		[
			2,
			-67
		],
		[
			-5,
			-25
		],
		[
			13,
			-48
		],
		[
			-23,
			-45
		],
		[
			7,
			-37
		],
		[
			-3,
			-40
		],
		[
			-9,
			4
		],
		[
			-7,
			-55
		],
		[
			6,
			-53
		],
		[
			-17,
			-58
		],
		[
			9,
			-50
		],
		[
			-2,
			-54
		],
		[
			6,
			-73
		],
		[
			-2,
			-89
		],
		[
			7,
			-65
		],
		[
			22,
			-80
		],
		[
			8,
			-62
		],
		[
			-9,
			-45
		],
		[
			-14,
			7
		],
		[
			9,
			-42
		],
		[
			9,
			22
		],
		[
			8,
			-14
		],
		[
			-7,
			-47
		],
		[
			4,
			-48
		],
		[
			18,
			-92
		],
		[
			-5,
			-22
		],
		[
			5,
			-97
		],
		[
			-9,
			19
		],
		[
			-11,
			58
		],
		[
			-8,
			4
		],
		[
			-5,
			64
		],
		[
			-8,
			-9
		],
		[
			-2,
			-57
		],
		[
			-7,
			38
		],
		[
			-8,
			-3
		],
		[
			-5,
			48
		],
		[
			-12,
			45
		],
		[
			-23,
			23
		],
		[
			-35,
			3
		],
		[
			-8,
			129
		],
		[
			-8,
			13
		],
		[
			-4,
			-31
		],
		[
			10,
			-68
		],
		[
			-2,
			-22
		],
		[
			-22,
			43
		],
		[
			-2,
			34
		],
		[
			-13,
			31
		],
		[
			-12,
			114
		],
		[
			-20,
			-44
		],
		[
			-33,
			-56
		],
		[
			-12,
			27
		],
		[
			-7,
			115
		],
		[
			11,
			82
		],
		[
			15,
			57
		],
		[
			20,
			30
		],
		[
			-5,
			10
		]
	],
	[
		[
			28423,
			61914
		],
		[
			-1,
			45
		],
		[
			7,
			27
		],
		[
			18,
			25
		],
		[
			1,
			85
		]
	],
	[
		[
			28426,
			62262
		],
		[
			-9,
			37
		],
		[
			-20,
			6
		],
		[
			-8,
			17
		],
		[
			1,
			48
		],
		[
			-26,
			42
		],
		[
			-34,
			15
		],
		[
			-6,
			39
		],
		[
			-10,
			13
		],
		[
			1,
			58
		],
		[
			9,
			18
		],
		[
			7,
			49
		],
		[
			-23,
			43
		],
		[
			-6,
			45
		],
		[
			-15,
			-1
		],
		[
			-16,
			25
		],
		[
			-13,
			-3
		]
	],
	[
		[
			26327,
			70327
		],
		[
			8,
			17
		],
		[
			9,
			-60
		],
		[
			65,
			-63
		],
		[
			-17,
			-58
		],
		[
			-23,
			18
		],
		[
			-14,
			61
		],
		[
			-28,
			85
		]
	],
	[
		[
			26120,
			70229
		],
		[
			5,
			40
		],
		[
			7,
			-20
		],
		[
			-12,
			-20
		]
	],
	[
		[
			26084,
			70289
		],
		[
			21,
			-39
		],
		[
			-4,
			-36
		],
		[
			-19,
			38
		],
		[
			2,
			37
		]
	],
	[
		[
			26055,
			70019
		],
		[
			7,
			48
		],
		[
			3,
			69
		],
		[
			6,
			15
		],
		[
			1,
			57
		],
		[
			18,
			-7
		],
		[
			-1,
			-85
		],
		[
			4,
			-83
		],
		[
			-19,
			-44
		],
		[
			-19,
			30
		]
	],
	[
		[
			26035,
			70180
		],
		[
			13,
			8
		],
		[
			-5,
			-54
		],
		[
			-7,
			1
		],
		[
			-1,
			45
		]
	],
	[
		[
			25984,
			69839
		],
		[
			13,
			-17
		],
		[
			1,
			-59
		],
		[
			-14,
			76
		]
	],
	[
		[
			25933,
			69486
		],
		[
			6,
			23
		],
		[
			19,
			-25
		],
		[
			-6,
			-96
		],
		[
			-17,
			52
		],
		[
			-2,
			46
		]
	],
	[
		[
			25908,
			69335
		],
		[
			11,
			44
		],
		[
			6,
			-47
		],
		[
			-17,
			3
		]
	],
	[
		[
			25759,
			70041
		],
		[
			20,
			-64
		],
		[
			-8,
			-22
		],
		[
			-4,
			36
		],
		[
			-14,
			43
		],
		[
			6,
			7
		]
	],
	[
		[
			25722,
			65552
		],
		[
			30,
			68
		],
		[
			27,
			87
		],
		[
			37,
			261
		],
		[
			34,
			146
		],
		[
			19,
			134
		],
		[
			10,
			99
		],
		[
			10,
			176
		],
		[
			-1,
			58
		],
		[
			6,
			87
		],
		[
			-1,
			163
		],
		[
			-6,
			182
		],
		[
			-11,
			120
		],
		[
			-35,
			230
		],
		[
			-11,
			94
		],
		[
			-12,
			138
		],
		[
			-17,
			119
		],
		[
			0,
			48
		],
		[
			22,
			102
		],
		[
			7,
			50
		],
		[
			1,
			77
		],
		[
			-9,
			134
		],
		[
			-14,
			90
		],
		[
			4,
			32
		],
		[
			20,
			51
		],
		[
			24,
			151
		],
		[
			21,
			112
		],
		[
			4,
			124
		],
		[
			9,
			134
		],
		[
			-11,
			112
		],
		[
			1,
			33
		],
		[
			27,
			43
		],
		[
			20,
			15
		],
		[
			6,
			93
		],
		[
			-2,
			74
		],
		[
			10,
			36
		],
		[
			13,
			-18
		],
		[
			16,
			80
		],
		[
			18,
			-35
		],
		[
			17,
			13
		],
		[
			8,
			32
		],
		[
			9,
			86
		],
		[
			10,
			16
		],
		[
			15,
			94
		],
		[
			11,
			47
		],
		[
			9,
			-7
		],
		[
			12,
			35
		],
		[
			3,
			-39
		],
		[
			-19,
			-32
		],
		[
			-3,
			-42
		],
		[
			12,
			-81
		],
		[
			-23,
			-81
		],
		[
			13,
			19
		],
		[
			0,
			-74
		],
		[
			-6,
			-7
		],
		[
			-8,
			-84
		],
		[
			7,
			-95
		],
		[
			8,
			-2
		],
		[
			19,
			145
		],
		[
			3,
			98
		],
		[
			13,
			20
		],
		[
			-8,
			-158
		],
		[
			-15,
			-44
		],
		[
			-6,
			-67
		],
		[
			14,
			-14
		],
		[
			8,
			65
		],
		[
			7,
			13
		],
		[
			22,
			135
		],
		[
			5,
			78
		],
		[
			-1,
			56
		],
		[
			4,
			82
		],
		[
			-6,
			85
		],
		[
			5,
			94
		],
		[
			17,
			49
		],
		[
			10,
			3
		],
		[
			18,
			48
		],
		[
			18,
			16
		],
		[
			25,
			-7
		],
		[
			26,
			14
		],
		[
			12,
			20
		],
		[
			-1,
			33
		],
		[
			-33,
			17
		],
		[
			-14,
			47
		],
		[
			-8,
			114
		],
		[
			16,
			75
		],
		[
			13,
			14
		],
		[
			20,
			69
		],
		[
			-2,
			31
		],
		[
			-18,
			27
		],
		[
			60,
			-15
		],
		[
			7,
			49
		],
		[
			61,
			-102
		],
		[
			26,
			-58
		],
		[
			13,
			20
		],
		[
			11,
			-16
		],
		[
			13,
			10
		],
		[
			32,
			-34
		],
		[
			24,
			-85
		],
		[
			3,
			-57
		],
		[
			17,
			-27
		],
		[
			33,
			4
		],
		[
			8,
			-9
		],
		[
			29,
			-77
		],
		[
			23,
			-7
		],
		[
			34,
			-71
		],
		[
			29,
			6
		],
		[
			21,
			-78
		],
		[
			11,
			-25
		],
		[
			-9,
			-27
		],
		[
			15,
			-96
		],
		[
			11,
			-30
		],
		[
			14,
			-133
		],
		[
			-20,
			21
		],
		[
			-16,
			34
		],
		[
			-15,
			-41
		],
		[
			4,
			-110
		],
		[
			12,
			-44
		],
		[
			21,
			-26
		],
		[
			5,
			-59
		],
		[
			1,
			-98
		],
		[
			7,
			-37
		],
		[
			-4,
			-71
		],
		[
			-8,
			-67
		],
		[
			2,
			-65
		],
		[
			-5,
			-111
		],
		[
			-1,
			-121
		],
		[
			-12,
			-15
		],
		[
			-14,
			-64
		],
		[
			-24,
			2
		],
		[
			-8,
			-30
		],
		[
			-8,
			-108
		],
		[
			-4,
			-115
		],
		[
			-19,
			-5
		],
		[
			-8,
			-19
		],
		[
			0,
			-49
		],
		[
			-42,
			-6
		],
		[
			-13,
			-35
		],
		[
			-9,
			-76
		],
		[
			-5,
			-124
		],
		[
			-8,
			-42
		],
		[
			13,
			-91
		],
		[
			16,
			-32
		],
		[
			9,
			33
		],
		[
			5,
			-38
		],
		[
			20,
			-21
		],
		[
			13,
			-38
		],
		[
			10,
			16
		],
		[
			28,
			120
		],
		[
			14,
			0
		],
		[
			7,
			25
		],
		[
			-7,
			51
		],
		[
			9,
			44
		],
		[
			9,
			87
		],
		[
			4,
			-50
		],
		[
			19,
			31
		],
		[
			5,
			29
		],
		[
			-21,
			31
		],
		[
			24,
			-3
		],
		[
			11,
			24
		],
		[
			5,
			41
		],
		[
			23,
			10
		],
		[
			34,
			28
		],
		[
			9,
			45
		],
		[
			31,
			30
		],
		[
			11,
			-30
		],
		[
			23,
			-25
		],
		[
			15,
			-39
		],
		[
			17,
			-123
		],
		[
			10,
			-37
		],
		[
			7,
			-97
		],
		[
			5,
			-208
		],
		[
			17,
			-178
		],
		[
			4,
			-247
		],
		[
			10,
			-143
		],
		[
			18,
			-110
		],
		[
			2,
			-48
		],
		[
			-11,
			-46
		],
		[
			-7,
			-145
		],
		[
			4,
			-47
		],
		[
			-12,
			-113
		],
		[
			-4,
			-67
		],
		[
			-18,
			-66
		],
		[
			-15,
			4
		],
		[
			-12,
			-42
		],
		[
			1,
			66
		],
		[
			-9,
			27
		],
		[
			10,
			16
		],
		[
			15,
			62
		],
		[
			-14,
			26
		],
		[
			-15,
			-5
		],
		[
			-19,
			-34
		],
		[
			-7,
			-32
		],
		[
			9,
			-27
		],
		[
			2,
			-45
		],
		[
			-15,
			4
		],
		[
			-11,
			-52
		],
		[
			1,
			-84
		],
		[
			-7,
			-77
		],
		[
			-17,
			-53
		],
		[
			-30,
			-25
		],
		[
			-18,
			-97
		],
		[
			2,
			-127
		],
		[
			-3,
			-44
		],
		[
			-15,
			-25
		],
		[
			-1,
			-70
		],
		[
			-16,
			-39
		],
		[
			-6,
			-39
		],
		[
			-13,
			-4
		],
		[
			-7,
			-65
		],
		[
			-11,
			-11
		],
		[
			-17,
			-72
		],
		[
			5,
			-79
		],
		[
			-8,
			-9
		]
	],
	[
		[
			26661,
			65520
		],
		[
			-86,
			-11
		],
		[
			-167,
			-20
		],
		[
			-124,
			-12
		]
	],
	[
		[
			25045,
			72671
		],
		[
			21,
			69
		],
		[
			95,
			141
		],
		[
			7,
			-2
		],
		[
			43,
			98
		],
		[
			31,
			42
		],
		[
			6,
			-11
		],
		[
			28,
			29
		],
		[
			-1,
			-28
		],
		[
			-12,
			-16
		],
		[
			-30,
			-80
		],
		[
			0,
			-30
		],
		[
			-25,
			-55
		],
		[
			-51,
			-53
		],
		[
			-42,
			-66
		],
		[
			2,
			-20
		],
		[
			23,
			0
		],
		[
			-59,
			-73
		],
		[
			-18,
			3
		],
		[
			-18,
			52
		]
	],
	[
		[
			24721,
			71146
		],
		[
			19,
			40
		],
		[
			12,
			3
		],
		[
			39,
			49
		],
		[
			38,
			34
		],
		[
			31,
			77
		],
		[
			19,
			64
		],
		[
			16,
			27
		],
		[
			33,
			17
		],
		[
			15,
			-17
		],
		[
			29,
			27
		],
		[
			22,
			-3
		],
		[
			52,
			75
		],
		[
			30,
			94
		],
		[
			22,
			5
		],
		[
			29,
			23
		],
		[
			10,
			39
		],
		[
			5,
			51
		],
		[
			25,
			65
		],
		[
			14,
			16
		],
		[
			30,
			82
		],
		[
			23,
			23
		],
		[
			21,
			56
		],
		[
			11,
			54
		],
		[
			20,
			52
		],
		[
			58,
			85
		],
		[
			56,
			25
		],
		[
			50,
			-7
		],
		[
			23,
			-39
		],
		[
			1,
			-45
		],
		[
			-11,
			5
		],
		[
			-17,
			-24
		],
		[
			-19,
			13
		],
		[
			-21,
			-10
		],
		[
			5,
			-47
		],
		[
			-32,
			-57
		],
		[
			-30,
			-95
		],
		[
			-19,
			-20
		],
		[
			-5,
			-74
		],
		[
			-7,
			9
		],
		[
			-7,
			-52
		],
		[
			-14,
			-26
		],
		[
			-5,
			-67
		],
		[
			-12,
			-48
		],
		[
			-9,
			-6
		],
		[
			-12,
			-164
		],
		[
			6,
			-52
		],
		[
			-9,
			-35
		],
		[
			11,
			3
		],
		[
			20,
			87
		],
		[
			3,
			44
		],
		[
			7,
			-13
		],
		[
			29,
			80
		],
		[
			28,
			43
		],
		[
			-12,
			-55
		],
		[
			-12,
			-24
		],
		[
			-15,
			-77
		],
		[
			30,
			84
		],
		[
			26,
			18
		],
		[
			14,
			-13
		],
		[
			37,
			1
		],
		[
			15,
			-30
		],
		[
			8,
			8
		],
		[
			17,
			-35
		],
		[
			8,
			-39
		],
		[
			15,
			11
		],
		[
			22,
			-63
		],
		[
			3,
			-61
		],
		[
			17,
			-49
		],
		[
			6,
			-47
		],
		[
			14,
			-49
		],
		[
			19,
			-15
		],
		[
			-2,
			-79
		],
		[
			11,
			-28
		],
		[
			26,
			-15
		],
		[
			42,
			10
		],
		[
			25,
			43
		],
		[
			11,
			-8
		],
		[
			14,
			-72
		],
		[
			12,
			-27
		],
		[
			19,
			-4
		],
		[
			8,
			46
		],
		[
			16,
			-7
		],
		[
			9,
			-38
		],
		[
			4,
			69
		],
		[
			-7,
			53
		],
		[
			16,
			20
		],
		[
			7,
			-32
		],
		[
			-6,
			-56
		],
		[
			17,
			-26
		],
		[
			26,
			72
		],
		[
			40,
			62
		],
		[
			59,
			110
		],
		[
			11,
			-21
		],
		[
			61,
			42
		],
		[
			46,
			-16
		],
		[
			35,
			-3
		],
		[
			30,
			7
		],
		[
			62,
			85
		],
		[
			24,
			12
		],
		[
			30,
			-7
		],
		[
			32,
			14
		],
		[
			-22,
			-84
		],
		[
			-2,
			-135
		],
		[
			2,
			-45
		],
		[
			-8,
			-19
		],
		[
			9,
			-51
		],
		[
			16,
			-8
		],
		[
			9,
			16
		],
		[
			6,
			-26
		],
		[
			15,
			3
		],
		[
			17,
			-28
		],
		[
			34,
			49
		],
		[
			13,
			-4
		],
		[
			11,
			-46
		],
		[
			-1,
			-35
		],
		[
			25,
			28
		],
		[
			7,
			-7
		],
		[
			10,
			65
		],
		[
			19,
			24
		],
		[
			23,
			-19
		],
		[
			11,
			9
		],
		[
			8,
			39
		],
		[
			27,
			-5
		],
		[
			5,
			-30
		],
		[
			-10,
			-100
		],
		[
			7,
			-120
		],
		[
			1,
			-95
		],
		[
			-29,
			-2
		],
		[
			-8,
			-65
		],
		[
			15,
			-12
		],
		[
			5,
			21
		],
		[
			15,
			-4
		],
		[
			8,
			-38
		],
		[
			19,
			-19
		],
		[
			-13,
			-40
		],
		[
			24,
			-75
		],
		[
			12,
			-1
		],
		[
			20,
			-45
		],
		[
			8,
			38
		],
		[
			14,
			-35
		],
		[
			8,
			26
		],
		[
			-16,
			100
		],
		[
			14,
			-15
		],
		[
			41,
			13
		],
		[
			12,
			-15
		],
		[
			14,
			-91
		],
		[
			16,
			-31
		],
		[
			-10,
			-64
		],
		[
			-14,
			-20
		],
		[
			-27,
			39
		],
		[
			-31,
			-16
		],
		[
			-31,
			42
		],
		[
			-11,
			-12
		],
		[
			-27,
			1
		],
		[
			-27,
			23
		],
		[
			-60,
			-26
		],
		[
			-13,
			-28
		],
		[
			-37,
			69
		],
		[
			-15,
			48
		],
		[
			-13,
			-7
		],
		[
			-13,
			30
		],
		[
			-10,
			-41
		],
		[
			2,
			-51
		],
		[
			-15,
			-32
		],
		[
			1,
			-45
		],
		[
			9,
			-63
		],
		[
			-12,
			-20
		],
		[
			-24,
			42
		],
		[
			-3,
			31
		],
		[
			-21,
			37
		],
		[
			-5,
			30
		],
		[
			-22,
			64
		],
		[
			-38,
			46
		],
		[
			-13,
			-7
		],
		[
			-33,
			49
		],
		[
			-18,
			-5
		],
		[
			-13,
			23
		],
		[
			-5,
			-20
		],
		[
			-19,
			11
		],
		[
			-25,
			-75
		],
		[
			-17,
			-73
		],
		[
			-9,
			-8
		],
		[
			-32,
			23
		],
		[
			-23,
			-15
		],
		[
			-8,
			-22
		],
		[
			2,
			-34
		],
		[
			-23,
			37
		],
		[
			-21,
			17
		],
		[
			-24,
			-14
		],
		[
			-10,
			11
		],
		[
			-23,
			-24
		],
		[
			-13,
			-42
		],
		[
			-2,
			-63
		],
		[
			-9,
			-72
		],
		[
			-14,
			4
		],
		[
			-7,
			-39
		],
		[
			-22,
			-15
		],
		[
			-6,
			-46
		],
		[
			-13,
			-3
		],
		[
			0,
			-45
		],
		[
			-12,
			-9
		],
		[
			4,
			-61
		],
		[
			-20,
			32
		],
		[
			-9,
			40
		],
		[
			12,
			27
		],
		[
			1,
			34
		],
		[
			11,
			31
		],
		[
			1,
			40
		],
		[
			13,
			-4
		],
		[
			15,
			87
		],
		[
			-3,
			43
		],
		[
			-12,
			10
		],
		[
			-18,
			-75
		],
		[
			-38,
			24
		],
		[
			3,
			-51
		],
		[
			-13,
			-47
		],
		[
			-5,
			-56
		],
		[
			-30,
			-31
		],
		[
			-5,
			-27
		],
		[
			-6,
			39
		],
		[
			3,
			55
		],
		[
			-4,
			67
		],
		[
			-8,
			32
		],
		[
			-10,
			-19
		],
		[
			-5,
			-120
		],
		[
			3,
			-12
		],
		[
			-31,
			-55
		],
		[
			-26,
			-129
		],
		[
			-17,
			-146
		],
		[
			-19,
			-65
		],
		[
			-20,
			-112
		],
		[
			-41,
			-174
		],
		[
			6,
			-33
		]
	],
	[
		[
			25508,
			69434
		],
		[
			-19,
			14
		],
		[
			-8,
			47
		],
		[
			-13,
			28
		],
		[
			-2,
			29
		],
		[
			15,
			118
		],
		[
			11,
			48
		],
		[
			-2,
			34
		],
		[
			-11,
			25
		],
		[
			-16,
			-47
		],
		[
			-27,
			-10
		]
	],
	[
		[
			25436,
			69720
		],
		[
			0,
			0
		]
	],
	[
		[
			25436,
			69720
		],
		[
			-7,
			47
		],
		[
			7,
			24
		],
		[
			-3,
			38
		],
		[
			13,
			34
		],
		[
			6,
			40
		],
		[
			-3,
			47
		],
		[
			8,
			69
		],
		[
			-14,
			75
		],
		[
			12,
			13
		],
		[
			-8,
			44
		],
		[
			-13,
			18
		],
		[
			-6,
			33
		],
		[
			-24,
			4
		],
		[
			-9,
			43
		],
		[
			-21,
			-18
		],
		[
			-18,
			45
		],
		[
			17,
			52
		],
		[
			-7,
			21
		],
		[
			0,
			47
		],
		[
			-40,
			48
		],
		[
			-14,
			-14
		],
		[
			-24,
			47
		],
		[
			-12,
			-15
		],
		[
			-21,
			21
		],
		[
			-2,
			25
		],
		[
			-27,
			-2
		],
		[
			-3,
			-32
		],
		[
			-14,
			0
		],
		[
			-4,
			29
		],
		[
			-17,
			16
		],
		[
			-12,
			-13
		],
		[
			-86,
			142
		],
		[
			-287,
			231
		],
		[
			1,
			27
		],
		[
			-28,
			167
		],
		[
			-27,
			16
		],
		[
			-10,
			24
		]
	],
	[
		[
			24739,
			71113
		],
		[
			0,
			0
		]
	],
	[
		[
			24739,
			71113
		],
		[
			-12,
			-6
		],
		[
			-6,
			39
		]
	],
	[
		[
			25252,
			52115
		],
		[
			30,
			-13
		],
		[
			-14,
			-20
		],
		[
			-12,
			9
		],
		[
			-4,
			24
		]
	],
	[
		[
			25179,
			52148
		],
		[
			16,
			13
		],
		[
			30,
			-29
		],
		[
			6,
			-15
		],
		[
			-24,
			5
		],
		[
			-28,
			26
		]
	],
	[
		[
			25119,
			52114
		],
		[
			15,
			7
		],
		[
			15,
			31
		],
		[
			-4,
			-29
		],
		[
			-21,
			-27
		],
		[
			-5,
			18
		]
	],
	[
		[
			25071,
			52140
		],
		[
			21,
			-1
		],
		[
			8,
			13
		],
		[
			-5,
			-43
		],
		[
			-10,
			-7
		],
		[
			-17,
			26
		],
		[
			3,
			12
		]
	],
	[
		[
			24751,
			57677
		],
		[
			229,
			-2
		],
		[
			156,
			1
		],
		[
			202,
			1
		]
	],
	[
		[
			25284,
			52292
		],
		[
			-4,
			-32
		],
		[
			-7,
			15
		],
		[
			-10,
			-40
		],
		[
			-18,
			27
		],
		[
			-13,
			-15
		],
		[
			-5,
			30
		],
		[
			-18,
			7
		],
		[
			-18,
			-23
		],
		[
			-23,
			49
		],
		[
			-2,
			-28
		],
		[
			-21,
			38
		],
		[
			-22,
			-3
		],
		[
			-31,
			-27
		],
		[
			-28,
			-42
		],
		[
			-30,
			-33
		],
		[
			4,
			54
		],
		[
			-10,
			30
		],
		[
			-14,
			-27
		],
		[
			9,
			-17
		],
		[
			1,
			-40
		],
		[
			-25,
			-57
		],
		[
			-8,
			-80
		],
		[
			-9,
			10
		],
		[
			-13,
			-16
		]
	],
	[
		[
			24969,
			52072
		],
		[
			-12,
			0
		],
		[
			-13,
			50
		],
		[
			-4,
			66
		],
		[
			0,
			69
		],
		[
			-15,
			77
		],
		[
			0,
			54
		],
		[
			-10,
			43
		],
		[
			-11,
			19
		],
		[
			-4,
			39
		],
		[
			-10,
			34
		],
		[
			-4,
			95
		],
		[
			-8,
			14
		],
		[
			10,
			88
		],
		[
			-4,
			36
		],
		[
			7,
			25
		],
		[
			9,
			125
		],
		[
			7,
			19
		],
		[
			-1,
			45
		],
		[
			7,
			22
		],
		[
			-7,
			36
		],
		[
			-165,
			-2
		],
		[
			-134,
			-1
		],
		[
			-226,
			0
		],
		[
			13,
			21
		],
		[
			7,
			58
		],
		[
			-16,
			50
		],
		[
			-1,
			28
		],
		[
			10,
			46
		],
		[
			-3,
			41
		],
		[
			-12,
			30
		],
		[
			1,
			38
		],
		[
			18,
			-7
		],
		[
			17,
			20
		],
		[
			2,
			43
		],
		[
			-12,
			37
		],
		[
			-1,
			45
		],
		[
			-7,
			16
		],
		[
			9,
			39
		],
		[
			4,
			-50
		],
		[
			8,
			-29
		],
		[
			9,
			7
		],
		[
			0,
			29
		],
		[
			-13,
			75
		],
		[
			-1,
			74
		],
		[
			20,
			18
		],
		[
			12,
			35
		],
		[
			-4,
			32
		],
		[
			-18,
			-13
		],
		[
			-9,
			30
		],
		[
			5,
			38
		],
		[
			10,
			-28
		],
		[
			18,
			0
		],
		[
			1,
			106
		],
		[
			11,
			35
		],
		[
			23,
			5
		],
		[
			4,
			18
		],
		[
			-29,
			11
		],
		[
			7,
			94
		],
		[
			12,
			11
		],
		[
			2,
			-43
		],
		[
			7,
			-17
		],
		[
			5,
			28
		],
		[
			-6,
			21
		],
		[
			24,
			78
		],
		[
			-2,
			50
		],
		[
			7,
			25
		],
		[
			19,
			14
		],
		[
			0,
			50
		],
		[
			-19,
			26
		],
		[
			5,
			25
		],
		[
			13,
			-39
		],
		[
			5,
			36
		],
		[
			12,
			22
		],
		[
			9,
			69
		],
		[
			-15,
			24
		],
		[
			2,
			-62
		],
		[
			-32,
			11
		],
		[
			2,
			79
		],
		[
			27,
			20
		],
		[
			7,
			27
		],
		[
			14,
			-31
		],
		[
			5,
			42
		],
		[
			-2,
			53
		],
		[
			12,
			-8
		],
		[
			16,
			79
		],
		[
			-4,
			18
		],
		[
			-6,
			-40
		],
		[
			-23,
			17
		],
		[
			0,
			58
		],
		[
			8,
			20
		],
		[
			-8,
			35
		],
		[
			-10,
			-20
		],
		[
			-23,
			49
		],
		[
			3,
			58
		],
		[
			5,
			1
		],
		[
			17,
			-48
		],
		[
			10,
			7
		],
		[
			-5,
			26
		],
		[
			-21,
			50
		],
		[
			14,
			31
		],
		[
			8,
			37
		],
		[
			-7,
			37
		],
		[
			-6,
			-46
		],
		[
			-20,
			-26
		],
		[
			-6,
			14
		],
		[
			-3,
			52
		],
		[
			9,
			38
		],
		[
			16,
			33
		],
		[
			2,
			27
		],
		[
			-31,
			30
		],
		[
			1,
			71
		],
		[
			5,
			37
		],
		[
			21,
			52
		],
		[
			2,
			39
		],
		[
			-9,
			72
		],
		[
			-11,
			-4
		],
		[
			1,
			-67
		],
		[
			-14,
			-26
		],
		[
			-9,
			22
		],
		[
			3,
			48
		],
		[
			10,
			50
		]
	],
	[
		[
			17580,
			73980
		],
		[
			234,
			-2
		],
		[
			232,
			3
		],
		[
			190,
			-5
		],
		[
			190,
			2
		],
		[
			348,
			-2
		],
		[
			211,
			0
		],
		[
			232,
			2
		],
		[
			328,
			0
		],
		[
			141,
			0
		],
		[
			292,
			0
		],
		[
			227,
			1
		],
		[
			143,
			-1
		],
		[
			294,
			0
		],
		[
			114,
			0
		],
		[
			167,
			1
		]
	],
	[
		[
			18973,
			68711
		],
		[
			-21,
			23
		],
		[
			-6,
			49
		],
		[
			-24,
			59
		],
		[
			2,
			43
		],
		[
			-28,
			117
		],
		[
			-17,
			36
		],
		[
			-8,
			-52
		],
		[
			-20,
			-3
		],
		[
			5,
			-33
		],
		[
			-16,
			-98
		],
		[
			15,
			-64
		],
		[
			-32,
			26
		],
		[
			-9,
			-16
		],
		[
			-24,
			13
		],
		[
			-3,
			-19
		],
		[
			-30,
			-40
		],
		[
			-13,
			63
		],
		[
			-22,
			-8
		],
		[
			-13,
			-25
		],
		[
			-10,
			13
		],
		[
			-21,
			-30
		],
		[
			-8,
			22
		],
		[
			-14,
			-8
		],
		[
			-12,
			35
		],
		[
			-16,
			7
		],
		[
			-9,
			-35
		],
		[
			-9,
			0
		],
		[
			-2,
			-61
		],
		[
			-8,
			-45
		],
		[
			-24,
			38
		],
		[
			-8,
			-20
		],
		[
			-11,
			24
		],
		[
			-33,
			2
		],
		[
			-17,
			22
		],
		[
			-17,
			-23
		],
		[
			-15,
			-72
		],
		[
			6,
			-53
		],
		[
			-9,
			-22
		],
		[
			-11,
			44
		],
		[
			-18,
			24
		],
		[
			-15,
			40
		],
		[
			-6,
			53
		],
		[
			5,
			34
		],
		[
			-21,
			81
		],
		[
			9,
			48
		],
		[
			-5,
			50
		],
		[
			-18,
			109
		],
		[
			-32,
			58
		],
		[
			-26,
			-44
		],
		[
			-4,
			40
		],
		[
			-28,
			53
		],
		[
			-11,
			97
		],
		[
			14,
			13
		],
		[
			2,
			55
		],
		[
			-4,
			61
		],
		[
			-19,
			39
		],
		[
			2,
			26
		],
		[
			-17,
			15
		],
		[
			-7,
			73
		],
		[
			-24,
			73
		],
		[
			-1,
			35
		],
		[
			-14,
			54
		],
		[
			2,
			70
		],
		[
			-8,
			19
		],
		[
			-6,
			57
		],
		[
			6,
			30
		],
		[
			-1,
			46
		],
		[
			-19,
			0
		],
		[
			7,
			95
		],
		[
			-15,
			25
		],
		[
			-12,
			-2
		],
		[
			2,
			26
		],
		[
			-10,
			44
		],
		[
			-15,
			26
		],
		[
			-9,
			-13
		],
		[
			2,
			-41
		],
		[
			-15,
			-35
		],
		[
			-19,
			-82
		],
		[
			-19,
			-26
		],
		[
			-13,
			12
		],
		[
			-3,
			-58
		],
		[
			-24,
			-42
		],
		[
			-5,
			36
		],
		[
			-14,
			22
		],
		[
			-13,
			60
		],
		[
			-25,
			0
		],
		[
			4,
			53
		],
		[
			-8,
			36
		],
		[
			18,
			37
		],
		[
			1,
			48
		],
		[
			-19,
			74
		],
		[
			18,
			89
		],
		[
			25,
			1
		],
		[
			7,
			44
		],
		[
			-13,
			54
		],
		[
			6,
			49
		],
		[
			-19,
			27
		],
		[
			-4,
			54
		],
		[
			9,
			58
		],
		[
			-17,
			33
		],
		[
			2,
			49
		],
		[
			19,
			7
		],
		[
			-1,
			79
		],
		[
			-6,
			30
		],
		[
			13,
			24
		],
		[
			1,
			116
		],
		[
			13,
			65
		],
		[
			-7,
			69
		],
		[
			12,
			3
		],
		[
			10,
			123
		],
		[
			-3,
			58
		],
		[
			-8,
			10
		],
		[
			-26,
			-23
		],
		[
			-4,
			-21
		],
		[
			-22,
			15
		],
		[
			-19,
			-5
		],
		[
			-8,
			39
		],
		[
			6,
			39
		],
		[
			-7,
			30
		],
		[
			-14,
			9
		],
		[
			-4,
			-30
		],
		[
			-15,
			-21
		],
		[
			-6,
			17
		],
		[
			6,
			55
		],
		[
			-34,
			58
		],
		[
			-16,
			59
		],
		[
			4,
			71
		],
		[
			-20,
			60
		],
		[
			-13,
			-1
		],
		[
			-6,
			60
		],
		[
			-19,
			82
		],
		[
			-17,
			54
		],
		[
			-12,
			13
		],
		[
			-5,
			37
		],
		[
			-11,
			7
		],
		[
			2,
			38
		],
		[
			-9,
			41
		],
		[
			-24,
			10
		],
		[
			-32,
			45
		],
		[
			-7,
			54
		],
		[
			-47,
			87
		],
		[
			-11,
			-2
		],
		[
			12,
			36
		],
		[
			22,
			8
		],
		[
			3,
			22
		],
		[
			-16,
			7
		],
		[
			-5,
			57
		],
		[
			-11,
			5
		],
		[
			2,
			34
		],
		[
			13,
			32
		],
		[
			-12,
			55
		],
		[
			2,
			63
		],
		[
			-13,
			24
		],
		[
			-7,
			47
		],
		[
			-8,
			-6
		],
		[
			-8,
			88
		],
		[
			-15,
			21
		],
		[
			-39,
			152
		],
		[
			-1,
			279
		],
		[
			1,
			109
		],
		[
			0,
			804
		]
	],
	[
		[
			29991,
			69339
		],
		[
			3,
			68
		],
		[
			18,
			64
		],
		[
			-3,
			15
		],
		[
			11,
			74
		],
		[
			-13,
			36
		],
		[
			18,
			11
		],
		[
			4,
			26
		],
		[
			22,
			42
		],
		[
			15,
			-61
		],
		[
			28,
			-5
		],
		[
			13,
			70
		]
	],
	[
		[
			30213,
			67064
		],
		[
			-30,
			-174
		],
		[
			-2,
			-44
		]
	],
	[
		[
			29724,
			66677
		],
		[
			-9,
			53
		],
		[
			-6,
			-10
		],
		[
			-12,
			102
		],
		[
			9,
			73
		],
		[
			1,
			57
		],
		[
			13,
			10
		],
		[
			8,
			45
		],
		[
			-6,
			52
		],
		[
			9,
			33
		],
		[
			-5,
			65
		],
		[
			4,
			138
		],
		[
			12,
			64
		],
		[
			-6,
			60
		],
		[
			10,
			135
		],
		[
			-5,
			35
		],
		[
			5,
			74
		],
		[
			15,
			33
		],
		[
			6,
			109
		],
		[
			9,
			44
		],
		[
			19,
			43
		],
		[
			6,
			44
		],
		[
			-1,
			64
		],
		[
			19,
			67
		],
		[
			0,
			85
		],
		[
			12,
			44
		],
		[
			12,
			69
		],
		[
			0,
			47
		],
		[
			-10,
			68
		],
		[
			6,
			57
		],
		[
			-6,
			34
		],
		[
			10,
			61
		],
		[
			35,
			32
		],
		[
			10,
			-13
		],
		[
			16,
			21
		],
		[
			5,
			52
		],
		[
			24,
			14
		],
		[
			14,
			39
		],
		[
			7,
			45
		],
		[
			16,
			22
		],
		[
			-6,
			59
		],
		[
			11,
			13
		],
		[
			2,
			73
		],
		[
			-10,
			38
		],
		[
			-11,
			102
		],
		[
			15,
			52
		],
		[
			4,
			64
		],
		[
			18,
			75
		],
		[
			-13,
			89
		],
		[
			11,
			30
		]
	],
	[
		[
			29842,
			64964
		],
		[
			3,
			18
		],
		[
			27,
			22
		],
		[
			-21,
			-43
		],
		[
			-9,
			3
		]
	],
	[
		[
			29812,
			64781
		],
		[
			5,
			20
		],
		[
			11,
			-16
		],
		[
			0,
			-50
		],
		[
			-6,
			35
		],
		[
			-10,
			11
		]
	],
	[
		[
			29792,
			64880
		],
		[
			16,
			16
		],
		[
			-12,
			-43
		],
		[
			-4,
			27
		]
	],
	[
		[
			29275,
			64272
		],
		[
			5,
			-67
		],
		[
			-9,
			-39
		],
		[
			-38,
			-78
		],
		[
			-11,
			-1
		]
	],
	[
		[
			28633,
			68013
		],
		[
			16,
			50
		],
		[
			-5,
			-45
		],
		[
			-11,
			-5
		]
	],
	[
		[
			28611,
			68032
		],
		[
			12,
			40
		],
		[
			9,
			-5
		],
		[
			-21,
			-35
		]
	],
	[
		[
			27689,
			66145
		],
		[
			33,
			53
		],
		[
			53,
			111
		],
		[
			29,
			91
		],
		[
			30,
			50
		],
		[
			26,
			25
		],
		[
			11,
			70
		],
		[
			13,
			36
		],
		[
			4,
			52
		],
		[
			36,
			56
		],
		[
			19,
			54
		],
		[
			-4,
			80
		],
		[
			-13,
			40
		],
		[
			2,
			43
		],
		[
			-7,
			37
		],
		[
			-23,
			35
		],
		[
			1,
			92
		],
		[
			-18,
			15
		],
		[
			9,
			77
		],
		[
			-5,
			125
		],
		[
			-3,
			13
		],
		[
			28,
			22
		],
		[
			38,
			42
		],
		[
			56,
			47
		],
		[
			40,
			20
		],
		[
			33,
			2
		],
		[
			38,
			-9
		],
		[
			36,
			8
		],
		[
			86,
			-42
		],
		[
			23,
			-19
		],
		[
			15,
			-47
		],
		[
			23,
			-46
		],
		[
			12,
			-10
		],
		[
			40,
			49
		],
		[
			35,
			1
		],
		[
			43,
			12
		],
		[
			21,
			-19
		],
		[
			23,
			-1
		],
		[
			14,
			25
		],
		[
			30,
			20
		],
		[
			18,
			40
		],
		[
			9,
			1
		],
		[
			19,
			80
		],
		[
			30,
			64
		],
		[
			10,
			8
		],
		[
			19,
			54
		],
		[
			14,
			5
		],
		[
			20,
			-15
		],
		[
			17,
			19
		],
		[
			9,
			53
		],
		[
			2,
			87
		],
		[
			-9,
			180
		],
		[
			-20,
			40
		],
		[
			11,
			50
		],
		[
			14,
			11
		],
		[
			2,
			-33
		],
		[
			21,
			41
		],
		[
			-3,
			43
		],
		[
			-19,
			47
		],
		[
			-22,
			-15
		],
		[
			5,
			29
		],
		[
			-15,
			51
		],
		[
			-15,
			1
		],
		[
			1,
			80
		],
		[
			16,
			115
		],
		[
			19,
			5
		],
		[
			23,
			42
		],
		[
			0,
			48
		],
		[
			18,
			22
		],
		[
			27,
			55
		],
		[
			9,
			-5
		],
		[
			16,
			29
		],
		[
			25,
			75
		],
		[
			4,
			46
		],
		[
			12,
			51
		],
		[
			41,
			121
		],
		[
			31,
			100
		],
		[
			56,
			141
		],
		[
			-1,
			12
		],
		[
			68,
			109
		],
		[
			26,
			62
		],
		[
			18,
			0
		],
		[
			22,
			37
		],
		[
			27,
			-29
		],
		[
			19,
			10
		],
		[
			91,
			-8
		],
		[
			53,
			-1
		],
		[
			107,
			14
		],
		[
			24,
			-1
		],
		[
			93,
			10
		]
	],
	[
		[
			29478,
			69336
		],
		[
			1,
			-109
		],
		[
			-7,
			-30
		],
		[
			-4,
			-63
		],
		[
			13,
			-57
		],
		[
			-10,
			-55
		],
		[
			-2,
			-92
		],
		[
			-4,
			-31
		],
		[
			4,
			-70
		],
		[
			19,
			-88
		],
		[
			4,
			-69
		],
		[
			-12,
			-80
		],
		[
			7,
			-114
		],
		[
			-4,
			-36
		],
		[
			-19,
			-63
		],
		[
			-5,
			-89
		],
		[
			-8,
			-79
		],
		[
			9,
			-27
		],
		[
			-1,
			-103
		],
		[
			10,
			-67
		],
		[
			-5,
			-64
		],
		[
			12,
			-57
		],
		[
			-16,
			-97
		],
		[
			-7,
			-114
		],
		[
			10,
			-26
		],
		[
			7,
			66
		],
		[
			19,
			0
		],
		[
			2,
			-53
		],
		[
			13,
			-29
		],
		[
			-2,
			-343
		],
		[
			-6,
			-422
		],
		[
			0,
			-74
		],
		[
			-4,
			-37
		],
		[
			8,
			-65
		]
	],
	[
		[
			29390,
			64649
		],
		[
			-7,
			-42
		],
		[
			-21,
			-42
		],
		[
			-2,
			-79
		],
		[
			-13,
			2
		],
		[
			9,
			-60
		],
		[
			18,
			87
		],
		[
			11,
			-15
		],
		[
			10,
			42
		],
		[
			21,
			27
		],
		[
			18,
			2
		],
		[
			4,
			33
		],
		[
			22,
			-30
		],
		[
			2,
			41
		],
		[
			9,
			-28
		],
		[
			20,
			-8
		],
		[
			18,
			-23
		],
		[
			23,
			28
		],
		[
			2,
			43
		],
		[
			17,
			8
		],
		[
			10,
			-12
		],
		[
			75,
			3
		],
		[
			39,
			20
		],
		[
			14,
			18
		],
		[
			30,
			63
		],
		[
			9,
			40
		],
		[
			12,
			13
		],
		[
			13,
			50
		],
		[
			21,
			21
		],
		[
			12,
			-2
		],
		[
			-18,
			-52
		],
		[
			-9,
			-6
		],
		[
			15,
			-31
		],
		[
			5,
			-44
		],
		[
			17,
			-12
		],
		[
			11,
			25
		],
		[
			16,
			-72
		],
		[
			15,
			17
		],
		[
			23,
			48
		],
		[
			2,
			28
		],
		[
			17,
			11
		],
		[
			12,
			-12
		],
		[
			-5,
			-21
		],
		[
			-67,
			-94
		],
		[
			-78,
			-123
		],
		[
			-50,
			-62
		],
		[
			-81,
			-93
		],
		[
			-53,
			-78
		],
		[
			-43,
			-41
		],
		[
			-27,
			-12
		],
		[
			-6,
			15
		],
		[
			-64,
			-60
		],
		[
			-61,
			10
		],
		[
			-46,
			-55
		],
		[
			3,
			38
		],
		[
			-23,
			-2
		],
		[
			3,
			25
		],
		[
			-11,
			39
		],
		[
			7,
			35
		],
		[
			-8,
			36
		]
	],
	[
		[
			26861,
			65369
		],
		[
			16,
			17
		],
		[
			-2,
			-36
		],
		[
			-14,
			19
		]
	],
	[
		[
			26831,
			65420
		],
		[
			6,
			90
		],
		[
			11,
			-35
		],
		[
			-3,
			-35
		],
		[
			-14,
			-42
		],
		[
			0,
			22
		]
	],
	[
		[
			26661,
			65520
		],
		[
			1,
			-26
		],
		[
			21,
			-28
		],
		[
			13,
			17
		],
		[
			37,
			-82
		],
		[
			25,
			-20
		],
		[
			11,
			-21
		],
		[
			18,
			-66
		],
		[
			19,
			-29
		],
		[
			18,
			23
		],
		[
			2,
			50
		],
		[
			7,
			13
		],
		[
			14,
			-55
		],
		[
			19,
			2
		],
		[
			-1,
			-37
		],
		[
			29,
			-96
		],
		[
			16,
			-33
		],
		[
			22,
			-21
		],
		[
			41,
			57
		],
		[
			22,
			4
		],
		[
			17,
			35
		],
		[
			51,
			60
		],
		[
			37,
			-38
		],
		[
			19,
			15
		],
		[
			20,
			-9
		],
		[
			29,
			61
		],
		[
			29,
			86
		],
		[
			8,
			10
		],
		[
			16,
			58
		],
		[
			44,
			102
		],
		[
			10,
			1
		],
		[
			67,
			108
		],
		[
			30,
			17
		],
		[
			24,
			34
		],
		[
			65,
			69
		],
		[
			17,
			24
		]
	],
	[
		[
			15490,
			70789
		],
		[
			21,
			10
		],
		[
			13,
			-45
		],
		[
			-1,
			-55
		],
		[
			17,
			-42
		],
		[
			25,
			-1
		],
		[
			32,
			51
		],
		[
			14,
			-4
		],
		[
			59,
			-119
		],
		[
			7,
			-61
		],
		[
			18,
			-81
		],
		[
			1,
			-57
		],
		[
			7,
			-52
		],
		[
			-3,
			-67
		],
		[
			10,
			-88
		],
		[
			-4,
			-41
		],
		[
			3,
			-50
		],
		[
			33,
			-54
		],
		[
			46,
			-35
		],
		[
			11,
			-19
		],
		[
			17,
			14
		],
		[
			13,
			-32
		],
		[
			18,
			-5
		],
		[
			23,
			39
		],
		[
			23,
			7
		],
		[
			54,
			83
		],
		[
			12,
			45
		],
		[
			15,
			16
		],
		[
			21,
			-15
		],
		[
			29,
			12
		],
		[
			28,
			26
		],
		[
			19,
			-30
		],
		[
			17,
			-9
		],
		[
			18,
			14
		],
		[
			34,
			-40
		],
		[
			9,
			-75
		],
		[
			14,
			4
		],
		[
			19,
			50
		],
		[
			34,
			4
		],
		[
			13,
			-16
		],
		[
			11,
			34
		],
		[
			47,
			51
		],
		[
			15,
			35
		],
		[
			21,
			-9
		],
		[
			21,
			-51
		],
		[
			22,
			6
		],
		[
			34,
			26
		],
		[
			20,
			5
		],
		[
			11,
			42
		],
		[
			28,
			27
		],
		[
			29,
			46
		],
		[
			46,
			27
		],
		[
			37,
			10
		],
		[
			13,
			57
		],
		[
			14,
			23
		],
		[
			24,
			-22
		],
		[
			64,
			39
		],
		[
			17,
			-14
		],
		[
			19,
			6
		],
		[
			28,
			42
		],
		[
			11,
			36
		],
		[
			163,
			1
		],
		[
			250,
			-3
		],
		[
			164,
			-3
		]
	],
	[
		[
			17338,
			70482
		],
		[
			16,
			-107
		],
		[
			11,
			-27
		],
		[
			16,
			-75
		],
		[
			18,
			5
		],
		[
			10,
			-47
		],
		[
			19,
			-2
		],
		[
			16,
			-48
		],
		[
			0,
			-53
		],
		[
			13,
			-49
		],
		[
			7,
			-54
		],
		[
			-24,
			-108
		],
		[
			-1,
			-55
		],
		[
			-10,
			-23
		],
		[
			-24,
			-150
		],
		[
			1,
			-36
		],
		[
			-9,
			-51
		],
		[
			-7,
			-116
		],
		[
			-13,
			-40
		],
		[
			-6,
			-53
		],
		[
			-14,
			-44
		],
		[
			-3,
			-51
		],
		[
			7,
			-58
		],
		[
			-9,
			-68
		],
		[
			-18,
			-76
		],
		[
			0,
			-21
		],
		[
			-32,
			-49
		],
		[
			-14,
			-93
		],
		[
			-8,
			-97
		],
		[
			-10,
			-66
		],
		[
			-18,
			-48
		],
		[
			3,
			-66
		],
		[
			-8,
			-36
		],
		[
			15,
			-69
		],
		[
			-8,
			-56
		],
		[
			13,
			-35
		],
		[
			19,
			25
		],
		[
			16,
			-59
		],
		[
			20,
			12
		],
		[
			2,
			-53
		],
		[
			18,
			-17
		],
		[
			1,
			-31
		],
		[
			-10,
			-62
		],
		[
			-12,
			-17
		],
		[
			1,
			-42
		],
		[
			11,
			-32
		],
		[
			-1,
			-43
		],
		[
			-12,
			-81
		],
		[
			0,
			-54
		],
		[
			-11,
			-11
		],
		[
			-2,
			-59
		],
		[
			0,
			-2105
		]
	],
	[
		[
			17307,
			65831
		],
		[
			-166,
			-2
		],
		[
			-273,
			-5
		],
		[
			-26,
			-3
		],
		[
			-143,
			2
		],
		[
			-220,
			2
		]
	],
	[
		[
			15305,
			65829
		],
		[
			-21,
			55
		],
		[
			-15,
			55
		],
		[
			-7,
			69
		],
		[
			2,
			33
		],
		[
			-14,
			81
		],
		[
			2,
			32
		],
		[
			-7,
			63
		],
		[
			-2,
			126
		],
		[
			13,
			147
		],
		[
			-7,
			107
		],
		[
			-17,
			87
		],
		[
			-11,
			2
		],
		[
			-11,
			123
		],
		[
			15,
			90
		],
		[
			12,
			96
		],
		[
			6,
			83
		],
		[
			0,
			52
		],
		[
			9,
			80
		],
		[
			6,
			99
		],
		[
			-6,
			42
		],
		[
			17,
			53
		],
		[
			8,
			43
		],
		[
			16,
			132
		],
		[
			15,
			193
		],
		[
			15,
			283
		],
		[
			7,
			225
		],
		[
			4,
			188
		],
		[
			-2,
			8
		],
		[
			10,
			197
		],
		[
			-1,
			69
		],
		[
			7,
			184
		],
		[
			0,
			92
		],
		[
			-5,
			39
		],
		[
			8,
			91
		],
		[
			12,
			227
		],
		[
			8,
			117
		],
		[
			4,
			157
		],
		[
			-3,
			66
		],
		[
			3,
			109
		],
		[
			-4,
			69
		],
		[
			5,
			24
		],
		[
			5,
			176
		],
		[
			-1,
			76
		],
		[
			-11,
			41
		],
		[
			6,
			87
		],
		[
			-2,
			83
		],
		[
			-7,
			45
		],
		[
			16,
			36
		],
		[
			1,
			109
		],
		[
			-19,
			193
		],
		[
			27,
			-79
		],
		[
			14,
			-14
		],
		[
			-3,
			38
		],
		[
			23,
			10
		],
		[
			7,
			17
		],
		[
			11,
			-28
		],
		[
			12,
			31
		],
		[
			15,
			0
		],
		[
			20,
			51
		]
	],
	[
		[
			26599,
			59546
		],
		[
			33,
			-4
		],
		[
			78,
			1
		],
		[
			5,
			-5
		],
		[
			157,
			-1
		],
		[
			61,
			3
		],
		[
			151,
			-2
		],
		[
			3,
			26
		],
		[
			77,
			-5
		],
		[
			-8,
			-28
		]
	],
	[
		[
			18139,
			65823
		],
		[
			61,
			-6
		],
		[
			262,
			13
		],
		[
			192,
			2
		],
		[
			5,
			-5
		],
		[
			196,
			3
		],
		[
			118,
			3
		]
	],
	[
		[
			18136,
			60011
		],
		[
			0,
			880
		],
		[
			1,
			11
		],
		[
			-1,
			272
		],
		[
			1,
			173
		],
		[
			-1,
			298
		],
		[
			1,
			318
		],
		[
			0,
			1661
		],
		[
			1,
			149
		],
		[
			0,
			628
		],
		[
			1,
			266
		],
		[
			0,
			1156
		]
	],
	[
		[
			28738,
			60998
		],
		[
			7,
			-15
		],
		[
			-7,
			-27
		],
		[
			0,
			42
		]
	],
	[
		[
			28949,
			61206
		],
		[
			-16,
			-79
		],
		[
			-15,
			-98
		],
		[
			-8,
			-27
		],
		[
			-5,
			21
		],
		[
			-15,
			-7
		],
		[
			-19,
			-78
		],
		[
			-12,
			-70
		],
		[
			-11,
			-126
		],
		[
			1,
			-64
		],
		[
			-23,
			-128
		],
		[
			7,
			-14
		],
		[
			-18,
			-91
		],
		[
			-12,
			-79
		],
		[
			-9,
			-11
		],
		[
			1,
			-57
		],
		[
			-11,
			-86
		],
		[
			-18,
			-64
		],
		[
			-16,
			2
		],
		[
			4,
			-35
		],
		[
			-9,
			-5
		],
		[
			-1,
			84
		],
		[
			-10,
			55
		],
		[
			-4,
			61
		],
		[
			2,
			70
		],
		[
			9,
			59
		],
		[
			3,
			89
		],
		[
			10,
			105
		],
		[
			4,
			76
		],
		[
			16,
			79
		],
		[
			18,
			110
		],
		[
			-4,
			34
		],
		[
			21,
			17
		],
		[
			15,
			65
		],
		[
			1,
			28
		],
		[
			-20,
			21
		],
		[
			25,
			54
		]
	],
	[
		[
			28739,
			61120
		],
		[
			-11,
			-44
		],
		[
			-3,
			44
		]
	],
	[
		[
			28423,
			61914
		],
		[
			-20,
			-21
		],
		[
			-13,
			21
		],
		[
			0,
			-52
		],
		[
			-18,
			-113
		],
		[
			-4,
			-52
		],
		[
			2,
			-76
		],
		[
			15,
			-59
		],
		[
			29,
			15
		],
		[
			6,
			26
		],
		[
			15,
			0
		],
		[
			12,
			38
		],
		[
			9,
			-30
		],
		[
			-6,
			-74
		],
		[
			19,
			-64
		],
		[
			0,
			-49
		],
		[
			35,
			-59
		],
		[
			25,
			-2
		],
		[
			7,
			-28
		],
		[
			6,
			21
		],
		[
			24,
			-9
		],
		[
			4,
			-44
		],
		[
			16,
			-39
		],
		[
			8,
			-59
		],
		[
			13,
			-15
		],
		[
			15,
			-54
		],
		[
			20,
			-23
		],
		[
			30,
			-68
		],
		[
			-5,
			-65
		],
		[
			-15,
			-24
		],
		[
			-2,
			-107
		],
		[
			4,
			-29
		],
		[
			-11,
			-46
		],
		[
			13,
			-23
		],
		[
			-19,
			-30
		],
		[
			-31,
			64
		],
		[
			-11,
			-27
		],
		[
			-7,
			25
		],
		[
			0,
			41
		],
		[
			-13,
			81
		],
		[
			-19,
			32
		],
		[
			-8,
			35
		],
		[
			-12,
			12
		],
		[
			-21,
			103
		],
		[
			-11,
			11
		],
		[
			-4,
			45
		],
		[
			-13,
			30
		],
		[
			-2,
			-30
		],
		[
			28,
			-89
		],
		[
			20,
			-114
		],
		[
			15,
			-24
		],
		[
			1,
			-25
		],
		[
			16,
			-14
		],
		[
			10,
			-96
		],
		[
			11,
			-53
		],
		[
			30,
			-4
		],
		[
			7,
			-36
		],
		[
			31,
			-24
		],
		[
			-14,
			-29
		],
		[
			-1,
			-37
		],
		[
			13,
			-8
		],
		[
			4,
			22
		],
		[
			8,
			-41
		],
		[
			5,
			-110
		],
		[
			-8,
			-90
		],
		[
			-18,
			63
		],
		[
			-21,
			45
		],
		[
			-9,
			-42
		],
		[
			11,
			-39
		],
		[
			7,
			-55
		],
		[
			9,
			-14
		],
		[
			-22,
			-24
		],
		[
			-18,
			-4
		],
		[
			6,
			-39
		],
		[
			22,
			11
		],
		[
			-2,
			-76
		],
		[
			14,
			12
		],
		[
			4,
			-31
		],
		[
			12,
			-20
		],
		[
			6,
			-49
		],
		[
			-9,
			-97
		],
		[
			-4,
			15
		],
		[
			-16,
			-18
		],
		[
			-15,
			-34
		],
		[
			-10,
			68
		],
		[
			-29,
			61
		],
		[
			-14,
			45
		],
		[
			4,
			48
		],
		[
			-13,
			71
		],
		[
			-22,
			-9
		],
		[
			-8,
			-25
		],
		[
			-10,
			46
		],
		[
			-18,
			11
		],
		[
			-4,
			23
		],
		[
			-21,
			-35
		],
		[
			11,
			-33
		],
		[
			12,
			8
		],
		[
			18,
			-13
		],
		[
			15,
			-55
		],
		[
			9,
			-2
		],
		[
			8,
			58
		],
		[
			8,
			-119
		],
		[
			1,
			-67
		],
		[
			22,
			-19
		],
		[
			25,
			-82
		],
		[
			1,
			-65
		],
		[
			27,
			4
		],
		[
			9,
			27
		],
		[
			1,
			-33
		],
		[
			9,
			-11
		],
		[
			-3,
			86
		],
		[
			17,
			6
		],
		[
			13,
			-29
		],
		[
			35,
			-36
		],
		[
			17,
			27
		],
		[
			11,
			-11
		],
		[
			8,
			-128
		],
		[
			12,
			-140
		],
		[
			9,
			-71
		],
		[
			7,
			-94
		]
	],
	[
		[
			15775,
			72069
		],
		[
			4,
			105
		],
		[
			10,
			72
		],
		[
			12,
			-52
		],
		[
			-2,
			-58
		],
		[
			19,
			-32
		],
		[
			-18,
			-27
		],
		[
			-5,
			-26
		],
		[
			-18,
			-12
		],
		[
			-2,
			30
		]
	],
	[
		[
			15740,
			73454
		],
		[
			0,
			40
		],
		[
			20,
			-41
		],
		[
			-17,
			-26
		],
		[
			-3,
			27
		]
	],
	[
		[
			15720,
			73667
		],
		[
			6,
			14
		],
		[
			26,
			-115
		],
		[
			-18,
			42
		],
		[
			-14,
			59
		]
	],
	[
		[
			15715,
			73495
		],
		[
			8,
			29
		],
		[
			12,
			-47
		],
		[
			-15,
			-33
		],
		[
			-5,
			51
		]
	],
	[
		[
			15707,
			73080
		],
		[
			13,
			89
		],
		[
			14,
			59
		],
		[
			2,
			55
		],
		[
			16,
			11
		],
		[
			7,
			-19
		],
		[
			0,
			-49
		],
		[
			19,
			-38
		],
		[
			3,
			-26
		],
		[
			-15,
			-19
		],
		[
			-17,
			15
		],
		[
			-1,
			-29
		],
		[
			-13,
			-34
		],
		[
			-14,
			-7
		],
		[
			3,
			-24
		],
		[
			23,
			10
		],
		[
			11,
			-42
		],
		[
			8,
			-84
		],
		[
			-4,
			-14
		],
		[
			10,
			-100
		],
		[
			8,
			27
		],
		[
			-5,
			67
		],
		[
			10,
			-3
		],
		[
			16,
			-57
		],
		[
			16,
			-13
		],
		[
			7,
			-94
		],
		[
			-8,
			-58
		],
		[
			-14,
			13
		],
		[
			-12,
			86
		],
		[
			-21,
			-25
		],
		[
			2,
			30
		],
		[
			-19,
			44
		],
		[
			3,
			93
		],
		[
			-5,
			56
		],
		[
			-18,
			-4
		],
		[
			-3,
			30
		],
		[
			-22,
			54
		]
	],
	[
		[
			15649,
			73739
		],
		[
			11,
			-4
		],
		[
			34,
			-53
		],
		[
			-8,
			-8
		],
		[
			-22,
			20
		],
		[
			-15,
			45
		]
	],
	[
		[
			15623,
			73630
		],
		[
			17,
			26
		],
		[
			2,
			-33
		],
		[
			-19,
			7
		]
	],
	[
		[
			15618,
			73982
		],
		[
			15,
			0
		],
		[
			4,
			-29
		],
		[
			-17,
			-2
		],
		[
			-2,
			31
		]
	],
	[
		[
			15586,
			73509
		],
		[
			7,
			30
		],
		[
			20,
			1
		],
		[
			2,
			-29
		],
		[
			15,
			-33
		],
		[
			17,
			-9
		],
		[
			-18,
			69
		],
		[
			37,
			108
		],
		[
			12,
			-2
		],
		[
			37,
			-58
		],
		[
			-19,
			-50
		],
		[
			11,
			-66
		],
		[
			-2,
			-62
		],
		[
			-11,
			-25
		],
		[
			4,
			-69
		],
		[
			-20,
			-12
		],
		[
			-15,
			50
		],
		[
			-9,
			-12
		],
		[
			-22,
			11
		],
		[
			-31,
			62
		],
		[
			-6,
			76
		],
		[
			-9,
			20
		]
	],
	[
		[
			15577,
			73617
		],
		[
			18,
			-10
		],
		[
			18,
			-54
		],
		[
			-30,
			41
		],
		[
			-6,
			23
		]
	],
	[
		[
			17306,
			73978
		],
		[
			-1,
			-290
		],
		[
			0,
			-441
		],
		[
			-2,
			-286
		],
		[
			0,
			-702
		],
		[
			1,
			-52
		],
		[
			0,
			-1247
		],
		[
			-7,
			-48
		],
		[
			20,
			-76
		],
		[
			8,
			-54
		],
		[
			0,
			-63
		],
		[
			12,
			-40
		],
		[
			-17,
			-93
		],
		[
			7,
			-11
		],
		[
			11,
			-93
		]
	],
	[
		[
			15490,
			70789
		],
		[
			-34,
			9
		],
		[
			-3,
			34
		],
		[
			-12,
			6
		],
		[
			-10,
			-31
		],
		[
			-13,
			10
		],
		[
			-19,
			-51
		],
		[
			-9,
			7
		],
		[
			-21,
			74
		],
		[
			-10,
			8
		],
		[
			-7,
			-47
		],
		[
			-10,
			-10
		],
		[
			6,
			139
		],
		[
			1,
			124
		],
		[
			-4,
			165
		],
		[
			13,
			-61
		],
		[
			-2,
			-100
		],
		[
			4,
			-137
		],
		[
			17,
			0
		],
		[
			1,
			37
		],
		[
			-10,
			40
		],
		[
			0,
			61
		],
		[
			12,
			-37
		],
		[
			14,
			83
		],
		[
			-19,
			116
		],
		[
			11,
			42
		],
		[
			25,
			53
		],
		[
			-17,
			37
		],
		[
			-6,
			-27
		],
		[
			-18,
			-2
		],
		[
			4,
			-23
		],
		[
			-16,
			4
		],
		[
			-20,
			44
		],
		[
			-1,
			55
		],
		[
			-11,
			130
		],
		[
			8,
			8
		],
		[
			6,
			-52
		],
		[
			11,
			31
		],
		[
			52,
			63
		],
		[
			-10,
			27
		],
		[
			-34,
			23
		],
		[
			-2,
			45
		],
		[
			-27,
			14
		],
		[
			-8,
			-24
		],
		[
			8,
			-90
		],
		[
			-16,
			-21
		],
		[
			3,
			38
		],
		[
			-4,
			206
		],
		[
			-14,
			176
		],
		[
			-24,
			80
		],
		[
			-9,
			207
		],
		[
			-5,
			77
		],
		[
			-15,
			162
		],
		[
			-14,
			36
		],
		[
			-4,
			55
		],
		[
			-14,
			23
		],
		[
			-5,
			31
		],
		[
			-19,
			29
		],
		[
			-12,
			110
		],
		[
			-8,
			101
		],
		[
			1,
			53
		],
		[
			-11,
			56
		],
		[
			12,
			58
		],
		[
			9,
			138
		],
		[
			-19,
			46
		],
		[
			3,
			22
		],
		[
			17,
			1
		],
		[
			40,
			-55
		],
		[
			32,
			-64
		],
		[
			10,
			-1
		],
		[
			25,
			-39
		],
		[
			6,
			12
		],
		[
			41,
			-55
		],
		[
			-1,
			-20
		],
		[
			35,
			-41
		],
		[
			56,
			-11
		],
		[
			21,
			13
		],
		[
			31,
			-37
		],
		[
			9,
			19
		],
		[
			10,
			-18
		],
		[
			24,
			7
		],
		[
			12,
			-32
		],
		[
			41,
			2
		],
		[
			32,
			71
		],
		[
			-3,
			-24
		],
		[
			22,
			-42
		],
		[
			7,
			-45
		],
		[
			17,
			17
		],
		[
			17,
			-5
		],
		[
			-3,
			-32
		],
		[
			14,
			-20
		],
		[
			1,
			-59
		],
		[
			10,
			6
		],
		[
			3,
			53
		],
		[
			-14,
			34
		],
		[
			0,
			40
		],
		[
			12,
			28
		],
		[
			21,
			10
		],
		[
			3,
			-31
		],
		[
			-15,
			-34
		],
		[
			10,
			-50
		],
		[
			7,
			6
		],
		[
			2,
			48
		],
		[
			10,
			14
		],
		[
			8,
			-100
		],
		[
			-15,
			-10
		],
		[
			11,
			-42
		],
		[
			8,
			-78
		],
		[
			13,
			-21
		],
		[
			-8,
			-25
		],
		[
			-16,
			2
		],
		[
			2,
			-42
		],
		[
			-17,
			-36
		],
		[
			-9,
			-113
		],
		[
			-14,
			-9
		],
		[
			11,
			113
		],
		[
			-6,
			17
		],
		[
			-19,
			-101
		],
		[
			-4,
			-53
		],
		[
			-21,
			-70
		],
		[
			-38,
			-183
		],
		[
			-13,
			-119
		],
		[
			12,
			8
		],
		[
			23,
			-13
		],
		[
			12,
			27
		],
		[
			21,
			17
		],
		[
			3,
			38
		],
		[
			-44,
			-62
		],
		[
			-17,
			27
		],
		[
			42,
			226
		],
		[
			31,
			74
		],
		[
			29,
			28
		],
		[
			3,
			73
		],
		[
			16,
			73
		],
		[
			31,
			68
		],
		[
			-9,
			97
		],
		[
			22,
			-40
		],
		[
			14,
			-187
		],
		[
			-22,
			0
		],
		[
			3,
			-40
		],
		[
			11,
			-14
		],
		[
			-4,
			-56
		],
		[
			7,
			-19
		],
		[
			0,
			-53
		],
		[
			-14,
			-38
		],
		[
			-1,
			-38
		],
		[
			15,
			-16
		],
		[
			-10,
			-48
		],
		[
			-6,
			-87
		],
		[
			4,
			-21
		],
		[
			-10,
			-57
		],
		[
			7,
			-49
		],
		[
			-15,
			-79
		],
		[
			-27,
			78
		],
		[
			8,
			96
		],
		[
			-16,
			-42
		],
		[
			-6,
			-63
		],
		[
			30,
			-83
		],
		[
			-10,
			-16
		],
		[
			1,
			-48
		],
		[
			-11,
			-26
		],
		[
			-16,
			46
		],
		[
			-20,
			105
		],
		[
			12,
			37
		],
		[
			1,
			61
		],
		[
			-7,
			25
		],
		[
			0,
			-51
		],
		[
			-12,
			-57
		],
		[
			7,
			-72
		],
		[
			-6,
			-48
		],
		[
			13,
			14
		],
		[
			11,
			-66
		],
		[
			27,
			-22
		],
		[
			11,
			37
		],
		[
			0,
			33
		],
		[
			13,
			16
		],
		[
			8,
			79
		],
		[
			10,
			53
		],
		[
			-2,
			30
		],
		[
			25,
			-58
		],
		[
			10,
			25
		],
		[
			-4,
			36
		],
		[
			27,
			34
		],
		[
			0,
			50
		],
		[
			-8,
			58
		],
		[
			-8,
			11
		],
		[
			6,
			35
		],
		[
			-10,
			40
		],
		[
			-7,
			71
		],
		[
			22,
			38
		],
		[
			-24,
			58
		],
		[
			16,
			82
		],
		[
			-6,
			91
		],
		[
			15,
			46
		],
		[
			9,
			119
		],
		[
			22,
			25
		],
		[
			-1,
			69
		],
		[
			-14,
			23
		],
		[
			-23,
			86
		],
		[
			1,
			74
		],
		[
			-10,
			49
		],
		[
			-15,
			4
		],
		[
			3,
			-24
		],
		[
			-11,
			-28
		],
		[
			10,
			-67
		],
		[
			18,
			-50
		],
		[
			1,
			-35
		],
		[
			-26,
			85
		],
		[
			-12,
			4
		],
		[
			-7,
			58
		],
		[
			2,
			77
		],
		[
			18,
			24
		],
		[
			16,
			-22
		],
		[
			10,
			42
		],
		[
			-10,
			45
		],
		[
			-28,
			45
		],
		[
			-13,
			48
		],
		[
			1,
			39
		],
		[
			-29,
			-33
		],
		[
			-7,
			33
		],
		[
			4,
			45
		],
		[
			-13,
			-17
		],
		[
			3,
			39
		],
		[
			24,
			28
		],
		[
			13,
			-15
		],
		[
			9,
			-49
		],
		[
			19,
			7
		],
		[
			-10,
			108
		],
		[
			17,
			6
		],
		[
			5,
			34
		],
		[
			-21,
			66
		],
		[
			-5,
			66
		],
		[
			8,
			44
		],
		[
			-13,
			30
		],
		[
			-17,
			-6
		],
		[
			-11,
			-41
		],
		[
			9,
			-44
		],
		[
			-19,
			40
		],
		[
			8,
			57
		],
		[
			-10,
			25
		],
		[
			-9,
			-14
		],
		[
			-1,
			65
		],
		[
			-21,
			54
		],
		[
			11,
			21
		],
		[
			-5,
			36
		],
		[
			-13,
			16
		],
		[
			16,
			54
		],
		[
			184,
			0
		],
		[
			97,
			-6
		],
		[
			145,
			5
		],
		[
			143,
			-2
		],
		[
			190,
			0
		],
		[
			169,
			0
		],
		[
			165,
			1
		],
		[
			178,
			0
		],
		[
			325,
			-2
		]
	],
	[
		[
			25685,
			69733
		],
		[
			6,
			80
		],
		[
			31,
			-17
		],
		[
			-23,
			-128
		],
		[
			-14,
			65
		]
	],
	[
		[
			25568,
			69555
		],
		[
			12,
			14
		],
		[
			2,
			-63
		],
		[
			-14,
			23
		],
		[
			0,
			26
		]
	],
	[
		[
			24707,
			71654
		],
		[
			8,
			83
		],
		[
			12,
			4
		],
		[
			-5,
			-75
		],
		[
			-15,
			-12
		]
	],
	[
		[
			24691,
			71507
		],
		[
			21,
			33
		],
		[
			-14,
			-47
		],
		[
			-7,
			14
		]
	],
	[
		[
			24655,
			71564
		],
		[
			5,
			21
		],
		[
			30,
			29
		],
		[
			5,
			-13
		],
		[
			-11,
			-48
		],
		[
			-24,
			-11
		],
		[
			-5,
			22
		]
	],
	[
		[
			24625,
			71464
		],
		[
			3,
			27
		],
		[
			20,
			41
		],
		[
			1,
			-19
		],
		[
			-24,
			-49
		]
	],
	[
		[
			24631,
			71609
		],
		[
			14,
			-54
		],
		[
			-13,
			-3
		],
		[
			-8,
			37
		],
		[
			7,
			20
		]
	],
	[
		[
			24621,
			71679
		],
		[
			35,
			36
		],
		[
			11,
			-55
		],
		[
			14,
			34
		],
		[
			2,
			-44
		],
		[
			-16,
			-9
		],
		[
			-17,
			-49
		],
		[
			-11,
			42
		],
		[
			-16,
			20
		],
		[
			-2,
			25
		]
	],
	[
		[
			24616,
			71401
		],
		[
			17,
			18
		],
		[
			32,
			86
		],
		[
			14,
			-32
		],
		[
			-30,
			-33
		],
		[
			5,
			-35
		],
		[
			-17,
			-4
		],
		[
			-20,
			-37
		],
		[
			-1,
			37
		]
	],
	[
		[
			24563,
			71635
		],
		[
			15,
			17
		],
		[
			-1,
			-44
		],
		[
			-14,
			27
		]
	],
	[
		[
			24276,
			71309
		],
		[
			20,
			-30
		],
		[
			34,
			11
		],
		[
			49,
			52
		],
		[
			19,
			27
		],
		[
			18,
			0
		],
		[
			48,
			70
		],
		[
			25,
			27
		],
		[
			6,
			26
		],
		[
			17,
			-22
		],
		[
			7,
			33
		],
		[
			25,
			10
		],
		[
			22,
			70
		],
		[
			14,
			-12
		],
		[
			14,
			35
		],
		[
			10,
			-4
		],
		[
			24,
			-81
		],
		[
			-14,
			-76
		],
		[
			-24,
			-78
		],
		[
			9,
			-73
		],
		[
			-16,
			-35
		],
		[
			-11,
			-77
		],
		[
			13,
			-16
		],
		[
			42,
			73
		],
		[
			5,
			54
		],
		[
			42,
			-108
		],
		[
			13,
			-22
		],
		[
			9,
			10
		],
		[
			25,
			-27
		]
	],
	[
		[
			25508,
			69434
		],
		[
			-10,
			-58
		],
		[
			-1,
			-80
		],
		[
			-37,
			-13
		],
		[
			-21,
			-40
		],
		[
			3,
			-47
		],
		[
			-11,
			-59
		],
		[
			-9,
			-15
		],
		[
			-11,
			-83
		],
		[
			-12,
			-42
		],
		[
			-7,
			-104
		],
		[
			3,
			-25
		],
		[
			-13,
			-50
		],
		[
			20,
			-42
		],
		[
			12,
			7
		],
		[
			7,
			53
		],
		[
			26,
			64
		],
		[
			10,
			3
		],
		[
			15,
			63
		],
		[
			0,
			36
		],
		[
			31,
			133
		],
		[
			26,
			36
		],
		[
			11,
			-7
		],
		[
			11,
			34
		],
		[
			15,
			-32
		],
		[
			-6,
			46
		],
		[
			12,
			97
		],
		[
			27,
			109
		],
		[
			7,
			100
		],
		[
			12,
			-5
		],
		[
			21,
			32
		],
		[
			1,
			59
		],
		[
			17,
			60
		],
		[
			22,
			-3
		],
		[
			-2,
			-87
		],
		[
			-16,
			-5
		],
		[
			-2,
			-142
		],
		[
			-12,
			-40
		],
		[
			-8,
			4
		],
		[
			-5,
			-53
		],
		[
			-14,
			-52
		],
		[
			5,
			-43
		],
		[
			-13,
			-39
		],
		[
			4,
			-26
		],
		[
			-18,
			-33
		],
		[
			-13,
			-62
		],
		[
			-8,
			-87
		],
		[
			-17,
			-107
		],
		[
			-9,
			-26
		],
		[
			-9,
			-62
		],
		[
			-21,
			-268
		],
		[
			9,
			-94
		],
		[
			-2,
			-71
		],
		[
			-12,
			-41
		],
		[
			-23,
			-46
		],
		[
			-3,
			-62
		],
		[
			-8,
			-37
		],
		[
			-14,
			-162
		],
		[
			2,
			-82
		],
		[
			8,
			-50
		],
		[
			-2,
			-102
		],
		[
			-21,
			-118
		],
		[
			-7,
			-136
		],
		[
			-20,
			-107
		],
		[
			-9,
			-156
		],
		[
			8,
			-76
		],
		[
			-5,
			-38
		],
		[
			8,
			-85
		],
		[
			-7,
			-57
		],
		[
			14,
			-62
		],
		[
			0,
			-85
		],
		[
			6,
			-63
		],
		[
			16,
			-59
		],
		[
			-4,
			-89
		],
		[
			-11,
			-107
		],
		[
			6,
			-145
		]
	],
	[
		[
			2682,
			386
		],
		[
			26,
			11
		],
		[
			1,
			-51
		],
		[
			-9,
			8
		],
		[
			-8,
			-28
		],
		[
			-10,
			60
		]
	],
	[
		[
			2636,
			452
		],
		[
			21,
			8
		],
		[
			-4,
			-21
		],
		[
			-13,
			-12
		],
		[
			-4,
			25
		]
	],
	[
		[
			2313,
			271
		],
		[
			13,
			35
		],
		[
			16,
			2
		],
		[
			19,
			68
		],
		[
			4,
			-20
		],
		[
			27,
			2
		],
		[
			4,
			-44
		],
		[
			-7,
			13
		],
		[
			-29,
			-30
		],
		[
			-23,
			-89
		],
		[
			-11,
			47
		],
		[
			-13,
			16
		]
	],
	[
		[
			90204,
			32599
		],
		[
			5,
			15
		],
		[
			34,
			16
		],
		[
			21,
			137
		],
		[
			6,
			65
		],
		[
			7,
			-11
		],
		[
			7,
			-43
		],
		[
			14,
			-11
		],
		[
			-10,
			-88
		],
		[
			-32,
			-109
		],
		[
			-9,
			-44
		],
		[
			-2,
			-111
		],
		[
			-12,
			-56
		],
		[
			-18,
			30
		],
		[
			-7,
			101
		],
		[
			8,
			50
		],
		[
			-12,
			59
		]
	],
	[
		[
			90597,
			35570
		],
		[
			10,
			43
		],
		[
			4,
			-16
		],
		[
			-8,
			-45
		],
		[
			-6,
			18
		]
	],
	[
		[
			90537,
			37432
		],
		[
			5,
			20
		],
		[
			1,
			-49
		],
		[
			-6,
			29
		]
	],
	[
		[
			90507,
			37973
		],
		[
			14,
			53
		],
		[
			0,
			59
		],
		[
			11,
			0
		],
		[
			0,
			-66
		],
		[
			-9,
			-13
		],
		[
			-10,
			-55
		],
		[
			-6,
			22
		]
	],
	[
		[
			90501,
			34555
		],
		[
			4,
			28
		],
		[
			2,
			101
		],
		[
			9,
			-12
		],
		[
			20,
			67
		],
		[
			5,
			-22
		],
		[
			-14,
			-80
		],
		[
			4,
			-63
		],
		[
			-13,
			7
		],
		[
			0,
			-73
		],
		[
			-12,
			18
		],
		[
			-5,
			29
		]
	],
	[
		[
			90487,
			38800
		],
		[
			6,
			39
		],
		[
			11,
			-28
		],
		[
			-1,
			-51
		],
		[
			-8,
			-23
		],
		[
			-7,
			25
		],
		[
			-1,
			38
		]
	],
	[
		[
			90486,
			35993
		],
		[
			20,
			2
		],
		[
			3,
			-36
		],
		[
			-19,
			-8
		],
		[
			-4,
			42
		]
	],
	[
		[
			90472,
			34420
		],
		[
			4,
			45
		],
		[
			13,
			54
		],
		[
			5,
			-54
		],
		[
			-4,
			-24
		],
		[
			7,
			-40
		],
		[
			-2,
			-61
		],
		[
			-9,
			-29
		],
		[
			-14,
			109
		]
	],
	[
		[
			90343,
			33382
		],
		[
			11,
			51
		],
		[
			21,
			35
		],
		[
			15,
			-9
		],
		[
			-2,
			-35
		],
		[
			-12,
			-13
		],
		[
			-8,
			-39
		],
		[
			-11,
			-6
		],
		[
			-5,
			23
		],
		[
			-9,
			-7
		]
	],
	[
		[
			28030,
			56345
		],
		[
			-13,
			-8
		],
		[
			-36,
			-51
		],
		[
			-27,
			-66
		],
		[
			-35,
			-121
		],
		[
			-18,
			-79
		],
		[
			-7,
			-45
		],
		[
			-16,
			-58
		],
		[
			-14,
			-93
		],
		[
			-13,
			-174
		],
		[
			3,
			-55
		],
		[
			-7,
			-48
		],
		[
			-14,
			-47
		],
		[
			-23,
			-41
		],
		[
			-9,
			-97
		],
		[
			-17,
			10
		],
		[
			-17,
			-16
		],
		[
			-11,
			39
		],
		[
			-16,
			-33
		],
		[
			-10,
			-63
		],
		[
			3,
			-31
		],
		[
			8,
			10
		],
		[
			0,
			-33
		],
		[
			-15,
			-20
		],
		[
			-18,
			-45
		],
		[
			-9,
			-52
		],
		[
			-34,
			-59
		],
		[
			-10,
			38
		],
		[
			-11,
			-7
		],
		[
			-1,
			-32
		],
		[
			17,
			-22
		],
		[
			-5,
			-59
		],
		[
			-25,
			-52
		],
		[
			-7,
			-40
		],
		[
			-10,
			5
		],
		[
			-24,
			-22
		],
		[
			-17,
			-59
		],
		[
			-6,
			18
		],
		[
			-36,
			-90
		],
		[
			-8,
			21
		],
		[
			-15,
			-28
		],
		[
			-2,
			30
		],
		[
			-13,
			-1
		],
		[
			-4,
			-42
		],
		[
			15,
			-83
		],
		[
			-7,
			-74
		],
		[
			-32,
			-62
		],
		[
			-19,
			-20
		],
		[
			-2,
			41
		],
		[
			-19,
			40
		],
		[
			-11,
			-22
		],
		[
			-2,
			-31
		],
		[
			12,
			-15
		],
		[
			14,
			-59
		],
		[
			-15,
			-65
		],
		[
			-25,
			-59
		],
		[
			-9,
			0
		],
		[
			-17,
			-67
		],
		[
			5,
			-21
		]
	],
	[
		[
			31708,
			38299
		],
		[
			11,
			-21
		],
		[
			12,
			13
		],
		[
			9,
			-36
		],
		[
			-17,
			-36
		],
		[
			-12,
			19
		],
		[
			-3,
			61
		]
	],
	[
		[
			31642,
			38028
		],
		[
			49,
			54
		],
		[
			35,
			-32
		],
		[
			-18,
			-26
		],
		[
			-21,
			-7
		],
		[
			-11,
			-24
		],
		[
			-8,
			12
		],
		[
			-17,
			-17
		],
		[
			-9,
			40
		]
	],
	[
		[
			31637,
			38350
		],
		[
			7,
			-14
		],
		[
			0,
			-44
		],
		[
			-7,
			58
		]
	],
	[
		[
			31170,
			38320
		],
		[
			15,
			18
		],
		[
			17,
			49
		],
		[
			-4,
			63
		],
		[
			7,
			32
		],
		[
			14,
			12
		],
		[
			20,
			-6
		],
		[
			17,
			-25
		],
		[
			50,
			2
		],
		[
			20,
			-22
		],
		[
			24,
			26
		],
		[
			18,
			-5
		],
		[
			25,
			-25
		],
		[
			8,
			20
		],
		[
			28,
			0
		],
		[
			27,
			-20
		],
		[
			16,
			1
		],
		[
			7,
			-19
		],
		[
			6,
			24
		],
		[
			37,
			-35
		],
		[
			4,
			19
		],
		[
			18,
			-18
		],
		[
			6,
			7
		],
		[
			31,
			-33
		],
		[
			14,
			-49
		],
		[
			7,
			13
		],
		[
			5,
			-27
		],
		[
			10,
			-6
		],
		[
			14,
			22
		],
		[
			-5,
			-40
		],
		[
			3,
			-84
		],
		[
			13,
			-30
		],
		[
			-7,
			-43
		],
		[
			-11,
			19
		],
		[
			3,
			-28
		],
		[
			-10,
			2
		],
		[
			-7,
			-32
		],
		[
			-13,
			1
		],
		[
			-11,
			-59
		],
		[
			-7,
			-83
		],
		[
			-8,
			-6
		],
		[
			-1,
			-44
		],
		[
			-25,
			-46
		],
		[
			-15,
			-9
		],
		[
			-12,
			12
		],
		[
			-7,
			-27
		],
		[
			-10,
			13
		],
		[
			-21,
			-43
		],
		[
			-10,
			9
		],
		[
			-9,
			-29
		],
		[
			-8,
			9
		],
		[
			-18,
			66
		],
		[
			-12,
			-10
		],
		[
			-7,
			-34
		],
		[
			-21,
			60
		],
		[
			-8,
			0
		],
		[
			-25,
			-33
		],
		[
			-14,
			24
		],
		[
			-12,
			-19
		],
		[
			-25,
			47
		],
		[
			-7,
			-39
		],
		[
			-14,
			-27
		],
		[
			-21,
			-3
		],
		[
			-12,
			-18
		],
		[
			-8,
			41
		],
		[
			-21,
			8
		],
		[
			-11,
			-32
		],
		[
			-19,
			19
		],
		[
			-12,
			-12
		],
		[
			1,
			53
		],
		[
			10,
			31
		],
		[
			-11,
			12
		],
		[
			3,
			65
		],
		[
			5,
			15
		],
		[
			1,
			75
		],
		[
			7,
			31
		],
		[
			-10,
			101
		],
		[
			-13,
			21
		],
		[
			-9,
			78
		]
	],
	[
		[
			30985,
			38023
		],
		[
			20,
			12
		],
		[
			5,
			-43
		],
		[
			-15,
			-38
		],
		[
			-12,
			32
		],
		[
			2,
			37
		]
	],
	[
		[
			31858,
			38286
		],
		[
			13,
			39
		],
		[
			11,
			-4
		],
		[
			15,
			-28
		],
		[
			-13,
			-4
		],
		[
			1,
			-49
		],
		[
			-9,
			20
		],
		[
			-13,
			-5
		],
		[
			-5,
			31
		]
	],
	[
		[
			31828,
			37522
		],
		[
			7,
			36
		],
		[
			-4,
			40
		],
		[
			7,
			30
		],
		[
			10,
			-13
		],
		[
			8,
			22
		],
		[
			17,
			3
		],
		[
			6,
			-29
		],
		[
			39,
			5
		],
		[
			2,
			-18
		],
		[
			-32,
			-48
		],
		[
			-41,
			-30
		],
		[
			-19,
			2
		]
	],
	[
		[
			31779,
			38288
		],
		[
			6,
			50
		],
		[
			10,
			-23
		],
		[
			12,
			26
		],
		[
			19,
			-21
		],
		[
			33,
			6
		],
		[
			-2,
			-23
		],
		[
			-14,
			-4
		],
		[
			9,
			-42
		],
		[
			-16,
			-11
		],
		[
			-15,
			23
		],
		[
			-7,
			-20
		],
		[
			-12,
			49
		],
		[
			-23,
			-10
		]
	],
	[
		[
			17306,
			73978
		],
		[
			171,
			1
		],
		[
			103,
			1
		]
	],
	[
		[
			18139,
			65823
		],
		[
			-119,
			3
		],
		[
			-36,
			-2
		],
		[
			-58,
			9
		],
		[
			-63,
			-7
		],
		[
			-79,
			0
		],
		[
			-293,
			0
		],
		[
			-184,
			5
		]
	],
	[
		[
			29478,
			69336
		],
		[
			71,
			5
		],
		[
			115,
			0
		],
		[
			40,
			-9
		],
		[
			62,
			-5
		],
		[
			57,
			2
		],
		[
			168,
			10
		]
	],
	[
		[
			25149,
			51924
		],
		[
			13,
			-63
		],
		[
			5,
			-76
		],
		[
			-3,
			-101
		],
		[
			-10,
			-105
		],
		[
			-4,
			3
		],
		[
			8,
			90
		],
		[
			4,
			100
		],
		[
			-1,
			46
		],
		[
			-12,
			106
		]
	],
	[
		[
			25020,
			51931
		],
		[
			11,
			38
		],
		[
			32,
			81
		],
		[
			2,
			-14
		],
		[
			-13,
			-63
		],
		[
			2,
			-28
		],
		[
			13,
			-33
		],
		[
			-15,
			-50
		],
		[
			-3,
			47
		],
		[
			-10,
			-10
		],
		[
			-17,
			10
		],
		[
			-2,
			22
		]
	],
	[
		[
			24941,
			51321
		],
		[
			17,
			10
		],
		[
			-9,
			-42
		],
		[
			-8,
			32
		]
	],
	[
		[
			24732,
			50824
		],
		[
			7,
			27
		],
		[
			13,
			-65
		],
		[
			-8,
			-14
		],
		[
			-12,
			52
		]
	],
	[
		[
			24681,
			50807
		],
		[
			39,
			-33
		],
		[
			-19,
			-8
		],
		[
			-20,
			41
		]
	],
	[
		[
			24628,
			50763
		],
		[
			25,
			19
		],
		[
			2,
			-17
		],
		[
			-26,
			-20
		],
		[
			-1,
			18
		]
	],
	[
		[
			24275,
			51386
		],
		[
			10,
			27
		],
		[
			12,
			-5
		],
		[
			3,
			26
		],
		[
			22,
			-6
		],
		[
			23,
			-61
		],
		[
			9,
			7
		],
		[
			6,
			-29
		],
		[
			-15,
			-36
		],
		[
			-1,
			-40
		],
		[
			-14,
			-19
		],
		[
			-59,
			115
		],
		[
			4,
			21
		]
	],
	[
		[
			24969,
			52072
		],
		[
			-17,
			-35
		],
		[
			-8,
			7
		],
		[
			-17,
			-56
		],
		[
			-2,
			-38
		],
		[
			-12,
			-15
		],
		[
			3,
			-40
		],
		[
			-28,
			17
		],
		[
			-11,
			-45
		],
		[
			5,
			-68
		],
		[
			18,
			-10
		],
		[
			13,
			25
		],
		[
			-4,
			-59
		],
		[
			8,
			-34
		],
		[
			15,
			-19
		],
		[
			13,
			11
		],
		[
			6,
			29
		],
		[
			5,
			101
		],
		[
			-2,
			13
		],
		[
			24,
			54
		],
		[
			3,
			44
		],
		[
			18,
			-34
		],
		[
			13,
			6
		],
		[
			0,
			-21
		],
		[
			-17,
			-34
		],
		[
			0,
			-34
		],
		[
			15,
			-17
		],
		[
			3,
			-61
		],
		[
			15,
			14
		],
		[
			11,
			82
		],
		[
			16,
			-25
		],
		[
			-4,
			-55
		],
		[
			-13,
			0
		],
		[
			-12,
			-44
		],
		[
			22,
			2
		],
		[
			-3,
			-29
		],
		[
			-31,
			-22
		],
		[
			13,
			-66
		],
		[
			11,
			22
		],
		[
			-7,
			-59
		],
		[
			-9,
			26
		],
		[
			-14,
			11
		],
		[
			-12,
			-55
		],
		[
			-1,
			-99
		],
		[
			-9,
			-5
		],
		[
			-6,
			86
		],
		[
			-11,
			1
		],
		[
			-2,
			-66
		],
		[
			13,
			-58
		],
		[
			-13,
			33
		],
		[
			-14,
			5
		],
		[
			-8,
			-17
		],
		[
			-15,
			6
		],
		[
			18,
			-39
		],
		[
			0,
			-32
		],
		[
			-23,
			49
		],
		[
			0,
			-25
		],
		[
			12,
			-32
		],
		[
			-12,
			-14
		],
		[
			1,
			-34
		],
		[
			11,
			-36
		],
		[
			20,
			-11
		],
		[
			-1,
			-22
		],
		[
			12,
			-24
		],
		[
			-1,
			-34
		],
		[
			7,
			-46
		],
		[
			9,
			30
		],
		[
			5,
			-21
		],
		[
			22,
			-2
		],
		[
			16,
			-34
		],
		[
			3,
			30
		],
		[
			20,
			-91
		],
		[
			11,
			44
		],
		[
			24,
			-111
		],
		[
			0,
			-59
		],
		[
			6,
			-13
		],
		[
			18,
			28
		],
		[
			7,
			-41
		],
		[
			-24,
			-15
		],
		[
			-2,
			-33
		],
		[
			16,
			-3
		],
		[
			-8,
			-52
		],
		[
			-11,
			24
		],
		[
			-12,
			-96
		],
		[
			2,
			-44
		],
		[
			-21,
			36
		],
		[
			-2,
			55
		],
		[
			-8,
			16
		],
		[
			-31,
			-138
		],
		[
			-15,
			-41
		],
		[
			7,
			67
		],
		[
			9,
			29
		],
		[
			5,
			48
		],
		[
			9,
			21
		],
		[
			0,
			54
		],
		[
			9,
			23
		],
		[
			-1,
			51
		],
		[
			-10,
			24
		],
		[
			-4,
			-62
		],
		[
			-16,
			-29
		],
		[
			-12,
			29
		],
		[
			-14,
			77
		],
		[
			-34,
			43
		],
		[
			-10,
			45
		],
		[
			-56,
			33
		],
		[
			-12,
			-14
		],
		[
			-48,
			-143
		],
		[
			-46,
			-115
		],
		[
			-7,
			10
		],
		[
			4,
			41
		],
		[
			-12,
			16
		],
		[
			-2,
			41
		],
		[
			6,
			3
		],
		[
			-12,
			100
		],
		[
			-11,
			27
		],
		[
			-9,
			-1
		],
		[
			1,
			-28
		],
		[
			-8,
			-36
		],
		[
			2,
			76
		],
		[
			-10,
			56
		],
		[
			-13,
			-64
		],
		[
			-14,
			14
		],
		[
			-7,
			-22
		],
		[
			-7,
			31
		],
		[
			-6,
			-27
		],
		[
			10,
			-63
		],
		[
			-12,
			4
		],
		[
			-7,
			-27
		],
		[
			-4,
			-54
		],
		[
			-8,
			7
		],
		[
			-5,
			-57
		],
		[
			-8,
			12
		],
		[
			-19,
			-33
		],
		[
			-6,
			-76
		],
		[
			-16,
			16
		],
		[
			5,
			21
		],
		[
			-13,
			67
		],
		[
			-18,
			57
		],
		[
			-11,
			-13
		],
		[
			-26,
			21
		],
		[
			-10,
			33
		],
		[
			-25,
			12
		],
		[
			-16,
			25
		],
		[
			-16,
			60
		],
		[
			12,
			14
		],
		[
			7,
			58
		],
		[
			8,
			-12
		],
		[
			12,
			-52
		],
		[
			7,
			22
		],
		[
			-1,
			-68
		],
		[
			15,
			-17
		],
		[
			-4,
			104
		],
		[
			-23,
			64
		],
		[
			0,
			42
		],
		[
			-11,
			7
		],
		[
			-9,
			-41
		],
		[
			-13,
			-13
		],
		[
			2,
			41
		],
		[
			-10,
			-7
		],
		[
			3,
			39
		],
		[
			9,
			28
		],
		[
			-10,
			40
		],
		[
			-29,
			-50
		],
		[
			-10,
			80
		],
		[
			-10,
			-8
		],
		[
			-6,
			118
		],
		[
			-26,
			1
		],
		[
			6,
			33
		],
		[
			1,
			85
		],
		[
			-32,
			16
		],
		[
			-13,
			-10
		],
		[
			-20,
			-38
		],
		[
			-7,
			57
		],
		[
			8,
			41
		],
		[
			8,
			-3
		],
		[
			-2,
			46
		],
		[
			-16,
			8
		],
		[
			-14,
			-22
		],
		[
			-9,
			20
		],
		[
			-2,
			-40
		],
		[
			-24,
			-36
		],
		[
			-14,
			-34
		],
		[
			-6,
			32
		],
		[
			-18,
			-16
		],
		[
			0,
			-32
		],
		[
			9,
			-30
		],
		[
			18,
			-8
		],
		[
			-9,
			-30
		],
		[
			8,
			-63
		],
		[
			20,
			21
		],
		[
			5,
			-18
		],
		[
			-13,
			-14
		],
		[
			6,
			-20
		],
		[
			-32,
			-6
		],
		[
			-26,
			-49
		],
		[
			-20,
			-9
		],
		[
			-82,
			63
		],
		[
			-35,
			42
		],
		[
			-57,
			101
		],
		[
			-23,
			32
		],
		[
			-41,
			40
		],
		[
			-33,
			5
		],
		[
			-14,
			-14
		],
		[
			-36,
			7
		],
		[
			-58,
			-25
		],
		[
			-17,
			-13
		],
		[
			-26,
			-53
		]
	],
	[
		[
			30097,
			65246
		],
		[
			-20,
			-46
		],
		[
			-6,
			102
		],
		[
			2,
			64
		],
		[
			-10,
			22
		],
		[
			2,
			-159
		],
		[
			-17,
			2
		],
		[
			-2,
			-35
		],
		[
			-10,
			-7
		],
		[
			-1,
			55
		],
		[
			16,
			95
		],
		[
			8,
			68
		],
		[
			17,
			46
		]
	],
	[
		[
			30029,
			65436
		],
		[
			5,
			7
		],
		[
			11,
			-52
		],
		[
			-5,
			-7
		],
		[
			-11,
			52
		]
	],
	[
		[
			30019,
			65203
		],
		[
			6,
			51
		],
		[
			-4,
			23
		],
		[
			5,
			57
		],
		[
			4,
			-20
		],
		[
			0,
			-85
		],
		[
			-11,
			-26
		]
	],
	[
		[
			29960,
			64853
		],
		[
			11,
			80
		],
		[
			5,
			-14
		],
		[
			1,
			-76
		],
		[
			-17,
			10
		]
	],
	[
		[
			30068,
			65494
		],
		[
			-3,
			-45
		],
		[
			-14,
			-41
		],
		[
			-6,
			42
		],
		[
			4,
			35
		],
		[
			-19,
			54
		],
		[
			-8,
			40
		],
		[
			5,
			-129
		],
		[
			-22,
			17
		],
		[
			12,
			-39
		],
		[
			1,
			-75
		],
		[
			-12,
			-11
		],
		[
			8,
			-53
		],
		[
			0,
			-72
		],
		[
			-10,
			-45
		],
		[
			-8,
			-73
		],
		[
			-12,
			6
		],
		[
			-27,
			-18
		],
		[
			-27,
			-34
		],
		[
			-38,
			-30
		],
		[
			-1,
			16
		]
	]
];
var bbox = [
	-179.14733999999999,
	-14.552548999999999,
	179.77847,
	71.352561
];
var objects$1 = {
	nation: {
		geometries: [
			{
				arcs: [
					[
						[
							0
						]
					],
					[
						[
							164,
							4,
							328,
							413,
							236,
							261,
							147,
							276,
							350,
							369,
							403,
							330,
							215,
							196,
							380,
							317,
							381,
							259,
							169,
							314,
							346,
							222,
							341,
							405,
							332,
							185,
							333,
							190,
							414,
							192,
							418,
							243,
							343,
							205,
							338,
							207,
							277,
							201,
							278,
							300,
							355,
							302,
							357,
							212,
							394,
							168
						]
					],
					[
						[
							6
						]
					],
					[
						[
							7
						]
					],
					[
						[
							8
						]
					],
					[
						[
							9
						]
					],
					[
						[
							10
						]
					],
					[
						[
							11
						]
					],
					[
						[
							12
						]
					],
					[
						[
							13
						]
					],
					[
						[
							14
						]
					],
					[
						[
							15
						]
					],
					[
						[
							16
						]
					],
					[
						[
							17
						]
					],
					[
						[
							18
						]
					],
					[
						[
							19
						]
					],
					[
						[
							20
						]
					],
					[
						[
							21
						]
					],
					[
						[
							22
						]
					],
					[
						[
							23
						]
					],
					[
						[
							24
						]
					],
					[
						[
							25
						]
					],
					[
						[
							26
						]
					],
					[
						[
							27
						]
					],
					[
						[
							28
						]
					],
					[
						[
							29
						]
					],
					[
						[
							30
						]
					],
					[
						[
							31
						]
					],
					[
						[
							32
						]
					],
					[
						[
							33
						]
					],
					[
						[
							34
						]
					],
					[
						[
							35
						]
					],
					[
						[
							36
						]
					],
					[
						[
							37
						]
					],
					[
						[
							38
						]
					],
					[
						[
							39
						]
					],
					[
						[
							40
						]
					],
					[
						[
							41
						]
					],
					[
						[
							42
						]
					],
					[
						[
							43
						]
					],
					[
						[
							44
						]
					],
					[
						[
							45
						]
					],
					[
						[
							46
						]
					],
					[
						[
							47
						]
					],
					[
						[
							48
						]
					],
					[
						[
							49
						]
					],
					[
						[
							50
						]
					],
					[
						[
							51
						]
					],
					[
						[
							52
						]
					],
					[
						[
							53
						]
					],
					[
						[
							54
						]
					],
					[
						[
							55
						]
					],
					[
						[
							56
						]
					],
					[
						[
							57
						]
					],
					[
						[
							58
						]
					],
					[
						[
							59
						]
					],
					[
						[
							60
						]
					],
					[
						[
							61
						]
					],
					[
						[
							62
						]
					],
					[
						[
							63
						]
					],
					[
						[
							64
						]
					],
					[
						[
							65
						]
					],
					[
						[
							66
						]
					],
					[
						[
							67
						]
					],
					[
						[
							68
						]
					],
					[
						[
							69
						]
					],
					[
						[
							70
						]
					],
					[
						[
							71
						]
					],
					[
						[
							72
						]
					],
					[
						[
							73
						]
					],
					[
						[
							74
						]
					],
					[
						[
							75
						]
					],
					[
						[
							76
						]
					],
					[
						[
							77
						]
					],
					[
						[
							78
						]
					],
					[
						[
							79
						]
					],
					[
						[
							80
						]
					],
					[
						[
							81
						]
					],
					[
						[
							82
						]
					],
					[
						[
							83
						]
					],
					[
						[
							84
						]
					],
					[
						[
							85
						]
					],
					[
						[
							86
						]
					],
					[
						[
							87
						]
					],
					[
						[
							88
						]
					],
					[
						[
							89
						]
					],
					[
						[
							90
						]
					],
					[
						[
							91
						]
					],
					[
						[
							92
						]
					],
					[
						[
							93
						]
					],
					[
						[
							94
						]
					],
					[
						[
							95
						]
					],
					[
						[
							96
						]
					],
					[
						[
							97
						]
					],
					[
						[
							98
						]
					],
					[
						[
							99
						]
					],
					[
						[
							100
						]
					],
					[
						[
							101
						]
					],
					[
						[
							102
						]
					],
					[
						[
							103
						]
					],
					[
						[
							104
						]
					],
					[
						[
							105
						]
					],
					[
						[
							106
						]
					],
					[
						[
							107
						]
					],
					[
						[
							108
						]
					],
					[
						[
							109
						]
					],
					[
						[
							110
						]
					],
					[
						[
							111
						]
					],
					[
						[
							112
						]
					],
					[
						[
							113
						]
					],
					[
						[
							114
						]
					],
					[
						[
							115
						]
					],
					[
						[
							116
						]
					],
					[
						[
							117
						]
					],
					[
						[
							118
						]
					],
					[
						[
							119
						]
					],
					[
						[
							120
						]
					],
					[
						[
							121
						]
					],
					[
						[
							122
						]
					],
					[
						[
							123
						]
					],
					[
						[
							124
						]
					],
					[
						[
							125
						]
					],
					[
						[
							126
						]
					],
					[
						[
							127
						]
					],
					[
						[
							128
						]
					],
					[
						[
							129
						]
					],
					[
						[
							130
						]
					],
					[
						[
							131
						]
					],
					[
						[
							132
						]
					],
					[
						[
							133
						]
					],
					[
						[
							134
						]
					],
					[
						[
							135
						]
					],
					[
						[
							136
						]
					],
					[
						[
							137
						]
					],
					[
						[
							138
						]
					],
					[
						[
							139
						]
					],
					[
						[
							140
						]
					],
					[
						[
							141
						]
					],
					[
						[
							142
						]
					],
					[
						[
							154
						]
					],
					[
						[
							155
						]
					],
					[
						[
							156
						]
					],
					[
						[
							157
						]
					],
					[
						[
							158
						]
					],
					[
						[
							159
						]
					],
					[
						[
							160
						]
					],
					[
						[
							161
						]
					],
					[
						[
							162
						]
					],
					[
						[
							177
						]
					],
					[
						[
							178
						]
					],
					[
						[
							179
						]
					],
					[
						[
							180
						]
					],
					[
						[
							181
						]
					],
					[
						[
							182
						]
					],
					[
						[
							183
						]
					],
					[
						[
							186
						]
					],
					[
						[
							187
						]
					],
					[
						[
							209
						]
					],
					[
						[
							210
						]
					],
					[
						[
							265
						]
					],
					[
						[
							266
						]
					],
					[
						[
							267
						]
					],
					[
						[
							268
						]
					],
					[
						[
							269
						]
					],
					[
						[
							270
						]
					],
					[
						[
							271
						]
					],
					[
						[
							272
						]
					],
					[
						[
							282
						]
					],
					[
						[
							283
						]
					],
					[
						[
							284
						]
					],
					[
						[
							285
						]
					],
					[
						[
							286
						]
					],
					[
						[
							287
						]
					],
					[
						[
							288
						]
					],
					[
						[
							289
						]
					],
					[
						[
							297,
							356
						]
					],
					[
						[
							298
						]
					],
					[
						[
							299
						]
					],
					[
						[
							305
						]
					],
					[
						[
							306
						]
					],
					[
						[
							307
						]
					],
					[
						[
							308
						]
					],
					[
						[
							309
						]
					],
					[
						[
							310
						]
					],
					[
						[
							311
						]
					],
					[
						[
							312
						]
					],
					[
						[
							313
						]
					],
					[
						[
							316
						]
					],
					[
						[
							323
						]
					],
					[
						[
							324
						]
					],
					[
						[
							325
						]
					],
					[
						[
							326
						]
					],
					[
						[
							335
						]
					],
					[
						[
							336
						]
					],
					[
						[
							337
						]
					],
					[
						[
							339
						]
					],
					[
						[
							340
						]
					],
					[
						[
							344
						]
					],
					[
						[
							345
						]
					],
					[
						[
							354
						]
					],
					[
						[
							358
						]
					],
					[
						[
							359
						]
					],
					[
						[
							360
						]
					],
					[
						[
							361
						]
					],
					[
						[
							362
						]
					],
					[
						[
							363
						]
					],
					[
						[
							364
						]
					],
					[
						[
							365
						]
					],
					[
						[
							366
						]
					],
					[
						[
							367
						]
					],
					[
						[
							370
						]
					],
					[
						[
							371
						]
					],
					[
						[
							372
						]
					],
					[
						[
							373
						]
					],
					[
						[
							374
						]
					],
					[
						[
							375
						]
					],
					[
						[
							376
						]
					],
					[
						[
							377
						]
					],
					[
						[
							378
						]
					],
					[
						[
							379
						]
					],
					[
						[
							382
						]
					],
					[
						[
							383
						]
					],
					[
						[
							384
						]
					],
					[
						[
							385
						]
					],
					[
						[
							386
						]
					],
					[
						[
							387
						]
					],
					[
						[
							388
						]
					],
					[
						[
							389
						]
					],
					[
						[
							390
						]
					],
					[
						[
							391
						]
					],
					[
						[
							392
						]
					],
					[
						[
							393
						]
					],
					[
						[
							395
						]
					],
					[
						[
							396
						]
					],
					[
						[
							397
						]
					],
					[
						[
							398
						]
					],
					[
						[
							399
						]
					],
					[
						[
							400
						]
					],
					[
						[
							401
						]
					],
					[
						[
							402
						]
					],
					[
						[
							406
						]
					],
					[
						[
							407
						]
					],
					[
						[
							408
						]
					],
					[
						[
							409
						]
					],
					[
						[
							410
						]
					],
					[
						[
							411
						]
					],
					[
						[
							412
						]
					],
					[
						[
							415
						]
					],
					[
						[
							416
						]
					],
					[
						[
							417
						]
					]
				],
				type: "MultiPolygon"
			}
		],
		type: "GeometryCollection"
	},
	states: {
		geometries: [
			{
				arcs: [
					[
						[
							0
						]
					],
					[
						[
							1,
							2,
							3,
							4,
							5
						]
					]
				],
				id: "01",
				properties: {
					name: "Alabama"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							6
						]
					],
					[
						[
							7
						]
					],
					[
						[
							8
						]
					],
					[
						[
							9
						]
					],
					[
						[
							10
						]
					],
					[
						[
							11
						]
					],
					[
						[
							12
						]
					],
					[
						[
							13
						]
					],
					[
						[
							14
						]
					],
					[
						[
							15
						]
					],
					[
						[
							16
						]
					],
					[
						[
							17
						]
					],
					[
						[
							18
						]
					],
					[
						[
							19
						]
					],
					[
						[
							20
						]
					],
					[
						[
							21
						]
					],
					[
						[
							22
						]
					],
					[
						[
							23
						]
					],
					[
						[
							24
						]
					],
					[
						[
							25
						]
					],
					[
						[
							26
						]
					],
					[
						[
							27
						]
					],
					[
						[
							28
						]
					],
					[
						[
							29
						]
					],
					[
						[
							30
						]
					],
					[
						[
							31
						]
					],
					[
						[
							32
						]
					],
					[
						[
							33
						]
					],
					[
						[
							34
						]
					],
					[
						[
							35
						]
					],
					[
						[
							36
						]
					],
					[
						[
							37
						]
					],
					[
						[
							38
						]
					],
					[
						[
							39
						]
					],
					[
						[
							40
						]
					],
					[
						[
							41
						]
					],
					[
						[
							42
						]
					],
					[
						[
							43
						]
					],
					[
						[
							44
						]
					],
					[
						[
							45
						]
					],
					[
						[
							46
						]
					],
					[
						[
							47
						]
					],
					[
						[
							48
						]
					],
					[
						[
							49
						]
					],
					[
						[
							50
						]
					],
					[
						[
							51
						]
					],
					[
						[
							52
						]
					],
					[
						[
							53
						]
					],
					[
						[
							54
						]
					],
					[
						[
							55
						]
					],
					[
						[
							56
						]
					],
					[
						[
							57
						]
					],
					[
						[
							58
						]
					],
					[
						[
							59
						]
					],
					[
						[
							60
						]
					],
					[
						[
							61
						]
					],
					[
						[
							62
						]
					],
					[
						[
							63
						]
					],
					[
						[
							64
						]
					],
					[
						[
							65
						]
					],
					[
						[
							66
						]
					],
					[
						[
							67
						]
					],
					[
						[
							68
						]
					],
					[
						[
							69
						]
					],
					[
						[
							70
						]
					],
					[
						[
							71
						]
					],
					[
						[
							72
						]
					],
					[
						[
							73
						]
					],
					[
						[
							74
						]
					],
					[
						[
							75
						]
					],
					[
						[
							76
						]
					],
					[
						[
							77
						]
					],
					[
						[
							78
						]
					],
					[
						[
							79
						]
					],
					[
						[
							80
						]
					],
					[
						[
							81
						]
					],
					[
						[
							82
						]
					],
					[
						[
							83
						]
					],
					[
						[
							84
						]
					],
					[
						[
							85
						]
					],
					[
						[
							86
						]
					],
					[
						[
							87
						]
					],
					[
						[
							88
						]
					],
					[
						[
							89
						]
					],
					[
						[
							90
						]
					],
					[
						[
							91
						]
					],
					[
						[
							92
						]
					],
					[
						[
							93
						]
					],
					[
						[
							94
						]
					],
					[
						[
							95
						]
					],
					[
						[
							96
						]
					],
					[
						[
							97
						]
					],
					[
						[
							98
						]
					],
					[
						[
							99
						]
					],
					[
						[
							100
						]
					],
					[
						[
							101
						]
					],
					[
						[
							102
						]
					],
					[
						[
							103
						]
					],
					[
						[
							104
						]
					],
					[
						[
							105
						]
					],
					[
						[
							106
						]
					],
					[
						[
							107
						]
					],
					[
						[
							108
						]
					],
					[
						[
							109
						]
					],
					[
						[
							110
						]
					],
					[
						[
							111
						]
					],
					[
						[
							112
						]
					],
					[
						[
							113
						]
					],
					[
						[
							114
						]
					],
					[
						[
							115
						]
					],
					[
						[
							116
						]
					],
					[
						[
							117
						]
					],
					[
						[
							118
						]
					],
					[
						[
							119
						]
					],
					[
						[
							120
						]
					],
					[
						[
							121
						]
					],
					[
						[
							122
						]
					],
					[
						[
							123
						]
					],
					[
						[
							124
						]
					],
					[
						[
							125
						]
					],
					[
						[
							126
						]
					],
					[
						[
							127
						]
					],
					[
						[
							128
						]
					],
					[
						[
							129
						]
					],
					[
						[
							130
						]
					],
					[
						[
							131
						]
					],
					[
						[
							132
						]
					],
					[
						[
							133
						]
					],
					[
						[
							134
						]
					],
					[
						[
							135
						]
					],
					[
						[
							136
						]
					],
					[
						[
							137
						]
					],
					[
						[
							138
						]
					],
					[
						[
							139
						]
					],
					[
						[
							140
						]
					],
					[
						[
							141
						]
					],
					[
						[
							142
						]
					]
				],
				id: "02",
				properties: {
					name: "Alaska"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						143,
						144,
						145,
						146,
						147
					]
				],
				id: "04",
				properties: {
					name: "Arizona"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						148,
						149,
						150,
						151,
						152,
						153
					]
				],
				id: "08",
				properties: {
					name: "Colorado"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							154
						]
					],
					[
						[
							155
						]
					],
					[
						[
							156
						]
					],
					[
						[
							157
						]
					],
					[
						[
							158
						]
					],
					[
						[
							159
						]
					],
					[
						[
							160
						]
					],
					[
						[
							161
						]
					],
					[
						[
							162
						]
					],
					[
						[
							163,
							164,
							-4
						]
					]
				],
				id: "12",
				properties: {
					name: "Florida"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						165,
						166,
						167,
						168,
						-164,
						-3
					]
				],
				id: "13",
				properties: {
					name: "Georgia"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						169,
						170,
						171,
						172,
						173
					]
				],
				id: "18",
				properties: {
					name: "Indiana"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						174,
						175,
						176,
						-151
					]
				],
				id: "20",
				properties: {
					name: "Kansas"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							177
						]
					],
					[
						[
							178
						]
					],
					[
						[
							179
						]
					],
					[
						[
							180
						]
					],
					[
						[
							181
						]
					],
					[
						[
							182
						]
					],
					[
						[
							183
						]
					],
					[
						[
							184,
							185
						]
					]
				],
				id: "23",
				properties: {
					name: "Maine"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							186
						]
					],
					[
						[
							187
						]
					],
					[
						[
							188,
							189,
							190,
							191,
							192,
							193,
							194,
							195
						]
					]
				],
				id: "25",
				properties: {
					name: "Massachusetts"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						196,
						197,
						198,
						199,
						200
					]
				],
				id: "27",
				properties: {
					name: "Minnesota"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						201,
						202,
						203,
						204,
						205,
						206,
						207,
						208
					]
				],
				id: "34",
				properties: {
					name: "New Jersey"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							209
						]
					],
					[
						[
							210
						]
					],
					[
						[
							211,
							212,
							213,
							-167,
							214
						]
					]
				],
				id: "37",
				properties: {
					name: "North Carolina"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						215,
						-201,
						216,
						217
					]
				],
				id: "38",
				properties: {
					name: "North Dakota"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						-152,
						-177,
						218,
						219,
						220,
						221
					]
				],
				id: "40",
				properties: {
					name: "Oklahoma"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						222,
						223,
						-204,
						224,
						225,
						226,
						227
					]
				],
				id: "42",
				properties: {
					name: "Pennsylvania"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						228,
						-217,
						-200,
						229,
						230,
						231
					]
				],
				id: "46",
				properties: {
					name: "South Dakota"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						-221,
						232,
						233,
						234,
						235,
						236,
						237
					]
				],
				id: "48",
				properties: {
					name: "Texas"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						-232,
						238,
						-149,
						239,
						240,
						241
					]
				],
				id: "56",
				properties: {
					name: "Wyoming"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						-195,
						242,
						243,
						244
					]
				],
				id: "09",
				properties: {
					name: "Connecticut"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						245,
						246,
						247,
						248,
						249,
						250,
						251,
						-219,
						-176,
						252
					]
				],
				id: "29",
				properties: {
					name: "Missouri"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						253,
						-227,
						254,
						255,
						256
					]
				],
				id: "54",
				properties: {
					name: "West Virginia"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						257,
						258,
						259,
						-174,
						260,
						-247
					]
				],
				id: "17",
				properties: {
					name: "Illinois"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						-153,
						-222,
						-238,
						261,
						-147
					]
				],
				id: "35",
				properties: {
					name: "New Mexico"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						-252,
						262,
						263,
						264,
						-235,
						233,
						-233,
						-220
					]
				],
				id: "05",
				properties: {
					name: "Arkansas"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							265
						]
					],
					[
						[
							266
						]
					],
					[
						[
							267
						]
					],
					[
						[
							268
						]
					],
					[
						[
							269
						]
					],
					[
						[
							270
						]
					],
					[
						[
							271
						]
					],
					[
						[
							272
						]
					],
					[
						[
							273,
							274,
							275,
							-144,
							276
						]
					]
				],
				id: "06",
				properties: {
					name: "California"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							-209,
							277
						]
					],
					[
						[
							-225,
							-203,
							278,
							279
						]
					]
				],
				id: "10",
				properties: {
					name: "Delaware"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						280,
						281
					]
				],
				id: "11",
				properties: {
					name: "District of Columbia"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							282
						]
					],
					[
						[
							283
						]
					],
					[
						[
							284
						]
					],
					[
						[
							285
						]
					],
					[
						[
							286
						]
					],
					[
						[
							287
						]
					],
					[
						[
							288
						]
					],
					[
						[
							289
						]
					]
				],
				id: "15",
				properties: {
					name: "Hawaii"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						-199,
						290,
						-258,
						-246,
						291,
						-230
					]
				],
				id: "19",
				properties: {
					name: "Iowa"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							-261,
							-173,
							292,
							-257,
							293,
							294,
							-248
						]
					],
					[
						[
							295,
							-250
						]
					]
				],
				id: "21",
				properties: {
					name: "Kentucky"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							296,
							297
						]
					],
					[
						[
							298
						]
					],
					[
						[
							299
						]
					],
					[
						[
							-226,
							-280,
							300,
							301,
							302,
							303,
							-281,
							304,
							-255
						]
					]
				],
				id: "24",
				properties: {
					name: "Maryland"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							305
						]
					],
					[
						[
							306
						]
					],
					[
						[
							307
						]
					],
					[
						[
							308
						]
					],
					[
						[
							309
						]
					],
					[
						[
							310
						]
					],
					[
						[
							311
						]
					],
					[
						[
							312
						]
					],
					[
						[
							313
						]
					],
					[
						[
							314,
							315,
							-171
						]
					],
					[
						[
							316
						]
					],
					[
						[
							317,
							318,
							319,
							320,
							321,
							322
						]
					]
				],
				id: "26",
				properties: {
					name: "Michigan"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							323
						]
					],
					[
						[
							324
						]
					],
					[
						[
							325
						]
					],
					[
						[
							326
						]
					],
					[
						[
							-264,
							327,
							-6,
							328,
							329
						]
					]
				],
				id: "28",
				properties: {
					name: "Mississippi"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						330,
						-218,
						-229,
						-242,
						331
					]
				],
				id: "30",
				properties: {
					name: "Montana"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						332,
						-185,
						333,
						-190,
						334
					]
				],
				id: "33",
				properties: {
					name: "New Hampshire"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							335
						]
					],
					[
						[
							336
						]
					],
					[
						[
							337
						]
					],
					[
						[
							338,
							-207
						]
					],
					[
						[
							339
						]
					],
					[
						[
							340
						]
					],
					[
						[
							341,
							342,
							-196,
							-245,
							343,
							-205,
							-224
						]
					]
				],
				id: "36",
				properties: {
					name: "New York"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							344
						]
					],
					[
						[
							345
						]
					],
					[
						[
							-316,
							346,
							-228,
							-254,
							-293,
							-172
						]
					]
				],
				id: "39",
				properties: {
					name: "Ohio"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						347,
						348,
						349,
						274,
						-275,
						-274,
						350
					]
				],
				id: "41",
				properties: {
					name: "Oregon"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						-251,
						-296,
						-249,
						-295,
						351,
						-215,
						-166,
						-2,
						-328,
						-263
					]
				],
				id: "47",
				properties: {
					name: "Tennessee"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						352,
						-240,
						-154,
						-146,
						353
					]
				],
				id: "49",
				properties: {
					name: "Utah"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							354
						]
					],
					[
						[
							-302,
							355
						]
					],
					[
						[
							356,
							-297
						]
					],
					[
						[
							-256,
							-305,
							-282,
							-304,
							357,
							-212,
							-352,
							-294
						]
					]
				],
				id: "51",
				properties: {
					name: "Virginia"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							358
						]
					],
					[
						[
							359
						]
					],
					[
						[
							360
						]
					],
					[
						[
							361
						]
					],
					[
						[
							362
						]
					],
					[
						[
							363
						]
					],
					[
						[
							364
						]
					],
					[
						[
							365
						]
					],
					[
						[
							366
						]
					],
					[
						[
							367
						]
					],
					[
						[
							368,
							-348,
							369
						]
					]
				],
				id: "53",
				properties: {
					name: "Washington"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							370
						]
					],
					[
						[
							371
						]
					],
					[
						[
							372
						]
					],
					[
						[
							373
						]
					],
					[
						[
							374
						]
					],
					[
						[
							375
						]
					],
					[
						[
							376
						]
					],
					[
						[
							377
						]
					],
					[
						[
							378
						]
					],
					[
						[
							379
						]
					],
					[
						[
							380,
							-323,
							321,
							-321,
							319,
							-319,
							381,
							-259,
							-291,
							-198
						]
					]
				],
				id: "55",
				properties: {
					name: "Wisconsin"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							382
						]
					],
					[
						[
							383
						]
					],
					[
						[
							384
						]
					]
				],
				id: "60",
				properties: {
					name: "American Samoa"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							385
						]
					]
				],
				id: "66",
				properties: {
					name: "Guam"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							386
						]
					],
					[
						[
							387
						]
					],
					[
						[
							388
						]
					],
					[
						[
							389
						]
					],
					[
						[
							390
						]
					],
					[
						[
							391
						]
					],
					[
						[
							392
						]
					],
					[
						[
							393
						]
					]
				],
				id: "69",
				properties: {
					name: "Commonwealth of the Northern Mariana Islands"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						-231,
						-292,
						-253,
						-175,
						-150,
						-239
					]
				],
				id: "31",
				properties: {
					name: "Nebraska"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						-214,
						394,
						-168
					]
				],
				id: "45",
				properties: {
					name: "South Carolina"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							395
						]
					],
					[
						[
							396
						]
					],
					[
						[
							397
						]
					],
					[
						[
							398
						]
					],
					[
						[
							399
						]
					]
				],
				id: "72",
				properties: {
					name: "Puerto Rico"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							400
						]
					],
					[
						[
							401
						]
					],
					[
						[
							402
						]
					]
				],
				id: "78",
				properties: {
					name: "United States Virgin Islands"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						-369,
						403,
						-332,
						-241,
						-353,
						404,
						-349
					]
				],
				id: "16",
				properties: {
					name: "Idaho"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						-275,
						-350,
						-405,
						-354,
						-145,
						-276
					]
				],
				id: "32",
				properties: {
					name: "Nevada"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						405,
						-335,
						-189,
						-343
					]
				],
				id: "50",
				properties: {
					name: "Vermont"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							406
						]
					],
					[
						[
							407
						]
					],
					[
						[
							408
						]
					],
					[
						[
							409
						]
					],
					[
						[
							410
						]
					],
					[
						[
							411
						]
					],
					[
						[
							412
						]
					],
					[
						[
							-265,
							-330,
							413,
							-236
						]
					]
				],
				id: "22",
				properties: {
					name: "Louisiana"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							-192,
							414
						]
					],
					[
						[
							415
						]
					],
					[
						[
							416
						]
					],
					[
						[
							417
						]
					],
					[
						[
							-243,
							-194,
							418
						]
					]
				],
				id: "44",
				properties: {
					name: "Rhode Island"
				},
				type: "MultiPolygon"
			}
		],
		type: "GeometryCollection"
	}
};
var transform$1 = {
	scale: [
		0.003589293992939929,
		0.0008590596905969058
	],
	translate: [
		-179.14733999999999,
		-14.552548999999999
	]
};
var type$1 = "Topology";
var topology$1 = {
	arcs: arcs$1,
	bbox: bbox,
	objects: objects$1,
	transform: transform$1,
	type: type$1
};

var abbeville_la = {
	name: "Abbeville, LA",
	value: {
		lat: 29.9746502,
		lng: -92.13429210000001
	}
};
var aberdeen_sd = {
	name: "Aberdeen, SD",
	value: {
		lat: 45.4646985,
		lng: -98.4864829
	}
};
var aberdeen_wa = {
	name: "Aberdeen, WA",
	value: {
		lat: 46.9753708,
		lng: -123.8157218
	}
};
var abilene_tx = {
	name: "Abilene, TX",
	value: {
		lat: 32.4487364,
		lng: -99.73314390000002
	}
};
var ada_ok = {
	name: "Ada, OK",
	value: {
		lat: 34.774531,
		lng: -96.6783449
	}
};
var adrian_mi = {
	name: "Adrian, MI",
	value: {
		lat: 41.8975471,
		lng: -84.03716589999999
	}
};
var aguadilla_isabela_san_sebastian_pr = {
	name: "Aguadilla-Isabela-San Sebastian, PR",
	value: {
		lat: 18.4274454,
		lng: -67.1540698
	}
};
var akron_oh = {
	name: "Akron, OH",
	value: {
		lat: 41.0814447,
		lng: -81.51900529999999
	}
};
var alamogordo_nm = {
	name: "Alamogordo, NM",
	value: {
		lat: 32.8995325,
		lng: -105.960265
	}
};
var albany_ga = {
	name: "Albany, GA",
	value: {
		lat: 31.5785074,
		lng: -84.15574099999999
	}
};
var albany_lebanon_or = {
	name: "Albany-Lebanon, OR",
	value: {
		lat: 44.6365107,
		lng: -123.1059282
	}
};
var albany_schenectady_troy_ny = {
	name: "Albany-Schenectady-Troy, NY",
	value: {
		lat: 42.6525793,
		lng: -73.7562317
	}
};
var albemarle_nc = {
	name: "Albemarle, NC",
	value: {
		lat: 35.3501426,
		lng: -80.2000578
	}
};
var albert_lea_mn = {
	name: "Albert Lea, MN",
	value: {
		lat: 43.6478006,
		lng: -93.3686555
	}
};
var albertville_al = {
	name: "Albertville, AL",
	value: {
		lat: 34.2675937,
		lng: -86.20886689999999
	}
};
var albuquerque_nm = {
	name: "Albuquerque, NM",
	value: {
		lat: 35.0853336,
		lng: -106.6055534
	}
};
var alexander_city_al = {
	name: "Alexander City, AL",
	value: {
		lat: 32.944012,
		lng: -85.9538532
	}
};
var alexandria_la = {
	name: "Alexandria, LA",
	value: {
		lat: 31.3112936,
		lng: -92.4451371
	}
};
var alexandria_mn = {
	name: "Alexandria, MN",
	value: {
		lat: 45.8848164,
		lng: -95.3776663
	}
};
var alice_tx = {
	name: "Alice, TX",
	value: {
		lat: 27.7522487,
		lng: -98.0697249
	}
};
var allegan_mi = {
	name: "Allegan, MI",
	value: {
		lat: 42.5291989,
		lng: -85.8553031
	}
};
var allentown_bethlehem_easton_pa_nj = {
	name: "Allentown-Bethlehem-Easton, PA-NJ",
	value: {
		lat: 40.6084305,
		lng: -75.4901833
	}
};
var alma_mi = {
	name: "Alma, MI",
	value: {
		lat: 43.3789199,
		lng: -84.6597274
	}
};
var alpena_mi = {
	name: "Alpena, MI",
	value: {
		lat: 45.0616794,
		lng: -83.4327528
	}
};
var altoona_pa = {
	name: "Altoona, PA",
	value: {
		lat: 40.5186809,
		lng: -78.3947359
	}
};
var altus_ok = {
	name: "Altus, OK",
	value: {
		lat: 34.637765,
		lng: -99.3340442
	}
};
var amarillo_tx = {
	name: "Amarillo, TX",
	value: {
		lat: 35.2219971,
		lng: -101.8312969
	}
};
var americus_ga = {
	name: "Americus, GA",
	value: {
		lat: 32.0723861,
		lng: -84.23268759999999
	}
};
var ames_ia = {
	name: "Ames, IA",
	value: {
		lat: 42.0307812,
		lng: -93.63191309999999
	}
};
var amsterdam_ny = {
	name: "Amsterdam, NY",
	value: {
		lat: 42.9377453,
		lng: -74.190356
	}
};
var anchorage_ak = {
	name: "Anchorage, AK",
	value: {
		lat: 61.2180556,
		lng: -149.9002778
	}
};
var anderson_in = {
	name: "Anderson, IN",
	value: {
		lat: 40.1053196,
		lng: -85.6802541
	}
};
var anderson_sc = {
	name: "Anderson, SC",
	value: {
		lat: 34.5034394,
		lng: -82.6501332
	}
};
var andrews_tx = {
	name: "Andrews, TX",
	value: {
		lat: 32.31871580000001,
		lng: -102.5457155
	}
};
var angola_in = {
	name: "Angola, IN",
	value: {
		lat: 41.6347726,
		lng: -84.9994088
	}
};
var ann_arbor_mi = {
	name: "Ann Arbor, MI",
	value: {
		lat: 42.2808256,
		lng: -83.7430378
	}
};
var anniston_oxford_al = {
	name: "Anniston-Oxford, AL",
	value: {
		lat: 33.6598257,
		lng: -85.8316318
	}
};
var appleton_wi = {
	name: "Appleton, WI",
	value: {
		lat: 44.2619309,
		lng: -88.41538469999999
	}
};
var arcadia_fl = {
	name: "Arcadia, FL",
	value: {
		lat: 27.2158826,
		lng: -81.8584164
	}
};
var ardmore_ok = {
	name: "Ardmore, OK",
	value: {
		lat: 34.1742611,
		lng: -97.14362539999999
	}
};
var arkadelphia_ar = {
	name: "Arkadelphia, AR",
	value: {
		lat: 34.1209292,
		lng: -93.0537839
	}
};
var asheville_nc = {
	name: "Asheville, NC",
	value: {
		lat: 35.5950581,
		lng: -82.5514869
	}
};
var ashland_oh = {
	name: "Ashland, OH",
	value: {
		lat: 40.8686675,
		lng: -82.3182178
	}
};
var ashtabula_oh = {
	name: "Ashtabula, OH",
	value: {
		lat: 41.8650534,
		lng: -80.7898089
	}
};
var astoria_or = {
	name: "Astoria, OR",
	value: {
		lat: 46.1878841,
		lng: -123.8312534
	}
};
var atchison_ks = {
	name: "Atchison, KS",
	value: {
		lat: 39.5630521,
		lng: -95.12163559999999
	}
};
var athens_oh = {
	name: "Athens, OH",
	value: {
		lat: 39.3292396,
		lng: -82.1012554
	}
};
var athens_tn = {
	name: "Athens, TN",
	value: {
		lat: 35.4428512,
		lng: -84.5929898
	}
};
var athens_tx = {
	name: "Athens, TX",
	value: {
		lat: 32.2048735,
		lng: -95.8555207
	}
};
var athens_clarke_county_ga = {
	name: "Athens-Clarke County, GA",
	value: {
		lat: 33.9519347,
		lng: -83.357567
	}
};
var atlanta_sandy_springs_marietta_ga = {
	name: "Atlanta-Sandy Springs-Marietta, GA",
	value: {
		lat: 33.7489954,
		lng: -84.3879824
	}
};
var atlantic_city_nj = {
	name: "Atlantic City, NJ",
	value: {
		lat: 39.3642834,
		lng: -74.4229266
	}
};
var auburn_in = {
	name: "Auburn, IN",
	value: {
		lat: 41.3669942,
		lng: -85.0588575
	}
};
var auburn_ny = {
	name: "Auburn, NY",
	value: {
		lat: 42.9317335,
		lng: -76.5660529
	}
};
var auburn_opelika_al = {
	name: "Auburn-Opelika, AL",
	value: {
		lat: 32.6098566,
		lng: -85.48078249999999
	}
};
var augusta_richmond_county_ga_sc = {
	name: "Augusta-Richmond County, GA-SC",
	value: {
		lat: 33.4734978,
		lng: -82.0105148
	}
};
var augusta_waterville_me = {
	name: "Augusta-Waterville, ME",
	value: {
		lat: 44.3106241,
		lng: -69.7794897
	}
};
var austin_mn = {
	name: "Austin, MN",
	value: {
		lat: 43.6666296,
		lng: -92.97463669999999
	}
};
var austin_round_rock_tx = {
	name: "Austin-Round Rock, TX",
	value: {
		lat: 30.267153,
		lng: -97.7430608
	}
};
var bainbridge_ga = {
	name: "Bainbridge, GA",
	value: {
		lat: 30.9037995,
		lng: -84.57546990000002
	}
};
var bakersfield_ca = {
	name: "Bakersfield, CA",
	value: {
		lat: 35.3732921,
		lng: -119.0187125
	}
};
var baltimore_towson_md = {
	name: "Baltimore-Towson, MD",
	value: {
		lat: 39.2903848,
		lng: -76.6121893
	}
};
var bangor_me = {
	name: "Bangor, ME",
	value: {
		lat: 44.80118210000001,
		lng: -68.77781379999999
	}
};
var baraboo_wi = {
	name: "Baraboo, WI",
	value: {
		lat: 43.4710944,
		lng: -89.74429060000001
	}
};
var barnstable_town_ma = {
	name: "Barnstable Town, MA",
	value: {
		lat: 41.7003208,
		lng: -70.3002024
	}
};
var barre_vt = {
	name: "Barre, VT",
	value: {
		lat: 44.1767937,
		lng: -72.4687538
	}
};
var bartlesville_ok = {
	name: "Bartlesville, OK",
	value: {
		lat: 36.7473114,
		lng: -95.98081789999999
	}
};
var bastrop_la = {
	name: "Bastrop, LA",
	value: {
		lat: 32.7562463,
		lng: -91.8723497
	}
};
var batavia_ny = {
	name: "Batavia, NY",
	value: {
		lat: 42.9981156,
		lng: -78.1875167
	}
};
var batesville_ar = {
	name: "Batesville, AR",
	value: {
		lat: 35.769799,
		lng: -91.6409721
	}
};
var baton_rouge_la = {
	name: "Baton Rouge, LA",
	value: {
		lat: 30.4582829,
		lng: -91.1403196
	}
};
var battle_creek_mi = {
	name: "Battle Creek, MI",
	value: {
		lat: 42.3211522,
		lng: -85.17971419999999
	}
};
var bay_city_mi = {
	name: "Bay City, MI",
	value: {
		lat: 43.5944677,
		lng: -83.8888647
	}
};
var bay_city_tx = {
	name: "Bay City, TX",
	value: {
		lat: 28.9827565,
		lng: -95.969402
	}
};
var beatrice_ne = {
	name: "Beatrice, NE",
	value: {
		lat: 40.2659269,
		lng: -96.7466913
	}
};
var beaumont_port_arthur_tx = {
	name: "Beaumont-Port Arthur, TX",
	value: {
		lat: 30.080174,
		lng: -94.1265562
	}
};
var beaver_dam_wi = {
	name: "Beaver Dam, WI",
	value: {
		lat: 43.4577692,
		lng: -88.837329
	}
};
var beckley_wv = {
	name: "Beckley, WV",
	value: {
		lat: 37.7781702,
		lng: -81.1881557
	}
};
var bedford_in = {
	name: "Bedford, IN",
	value: {
		lat: 38.8611619,
		lng: -86.4872149
	}
};
var beeville_tx = {
	name: "Beeville, TX",
	value: {
		lat: 28.4008319,
		lng: -97.7483312
	}
};
var bellefontaine_oh = {
	name: "Bellefontaine, OH",
	value: {
		lat: 40.3611643,
		lng: -83.7596557
	}
};
var bellingham_wa = {
	name: "Bellingham, WA",
	value: {
		lat: 48.74908,
		lng: -122.4781473
	}
};
var bemidji_mn = {
	name: "Bemidji, MN",
	value: {
		lat: 47.4875361,
		lng: -94.8858492
	}
};
var bend_or = {
	name: "Bend, OR",
	value: {
		lat: 44.0581728,
		lng: -121.3153096
	}
};
var bennettsville_sc = {
	name: "Bennettsville, SC",
	value: {
		lat: 34.6173803,
		lng: -79.68478139999999
	}
};
var bennington_vt = {
	name: "Bennington, VT",
	value: {
		lat: 42.8781345,
		lng: -73.1967741
	}
};
var berlin_nh_vt = {
	name: "Berlin, NH-VT",
	value: {
		lat: 44.4686696,
		lng: -71.18507679999999
	}
};
var big_rapids_mi = {
	name: "Big Rapids, MI",
	value: {
		lat: 43.6980782,
		lng: -85.4836557
	}
};
var big_spring_tx = {
	name: "Big Spring, TX",
	value: {
		lat: 32.2503979,
		lng: -101.4787355
	}
};
var billings_mt = {
	name: "Billings, MT",
	value: {
		lat: 45.7832856,
		lng: -108.5006904
	}
};
var binghamton_ny = {
	name: "Binghamton, NY",
	value: {
		lat: 42.09868669999999,
		lng: -75.91797380000001
	}
};
var birmingham_hoover_al = {
	name: "Birmingham-Hoover, AL",
	value: {
		lat: 33.5206608,
		lng: -86.80248999999999
	}
};
var bishop_ca = {
	name: "Bishop, CA",
	value: {
		lat: 37.3614238,
		lng: -118.3996636
	}
};
var bismarck_nd = {
	name: "Bismarck, ND",
	value: {
		lat: 46.8083268,
		lng: -100.7837392
	}
};
var blackfoot_id = {
	name: "Blackfoot, ID",
	value: {
		lat: 43.19047090000001,
		lng: -112.3449773
	}
};
var blacksburg_christiansburg_radford_va = {
	name: "Blacksburg-Christiansburg-Radford, VA",
	value: {
		lat: 37.2295733,
		lng: -80.4139393
	}
};
var bloomington_in = {
	name: "Bloomington, IN",
	value: {
		lat: 39.165325,
		lng: -86.52638569999999
	}
};
var bloomington_normal_il = {
	name: "Bloomington-Normal, IL",
	value: {
		lat: 40.4842027,
		lng: -88.99368729999999
	}
};
var bloomsburg_berwick_pa = {
	name: "Bloomsburg-Berwick, PA",
	value: {
		lat: 41.003698,
		lng: -76.4549457
	}
};
var bluefield_wv_va = {
	name: "Bluefield, WV-VA",
	value: {
		lat: 37.2698395,
		lng: -81.2223195
	}
};
var blytheville_ar = {
	name: "Blytheville, AR",
	value: {
		lat: 35.9272953,
		lng: -89.9189753
	}
};
var bogalusa_la = {
	name: "Bogalusa, LA",
	value: {
		lat: 30.7910204,
		lng: -89.8486858
	}
};
var boise_city_nampa_id = {
	name: "Boise City-Nampa, ID",
	value: {
		lat: 43.6187102,
		lng: -116.2146068
	}
};
var bonham_tx = {
	name: "Bonham, TX",
	value: {
		lat: 33.5773275,
		lng: -96.1783111
	}
};
var boone_ia = {
	name: "Boone, IA",
	value: {
		lat: 42.0597047,
		lng: -93.8802273
	}
};
var boone_nc = {
	name: "Boone, NC",
	value: {
		lat: 36.216795,
		lng: -81.6745517
	}
};
var borger_tx = {
	name: "Borger, TX",
	value: {
		lat: 35.6678203,
		lng: -101.3973876
	}
};
var boston_cambridge_quincy_ma_nh = {
	name: "Boston-Cambridge-Quincy, MA-NH",
	value: {
		lat: 42.3600825,
		lng: -71.0588801
	}
};
var boulder_co = {
	name: "Boulder, CO",
	value: {
		lat: 40.0149856,
		lng: -105.2705456
	}
};
var bowling_green_ky = {
	name: "Bowling Green, KY",
	value: {
		lat: 36.9685219,
		lng: -86.4808043
	}
};
var bozeman_mt = {
	name: "Bozeman, MT",
	value: {
		lat: 45.6769979,
		lng: -111.0429339
	}
};
var bradford_pa = {
	name: "Bradford, PA",
	value: {
		lat: 41.9564953,
		lng: -78.649163
	}
};
var brainerd_mn = {
	name: "Brainerd, MN",
	value: {
		lat: 46.3526733,
		lng: -94.2020084
	}
};
var branson_mo = {
	name: "Branson, MO",
	value: {
		lat: 36.6436731,
		lng: -93.21851439999999
	}
};
var bremerton_silverdale_wa = {
	name: "Bremerton-Silverdale, WA",
	value: {
		lat: 47.5673202,
		lng: -122.6329356
	}
};
var brenham_tx = {
	name: "Brenham, TX",
	value: {
		lat: 30.1668828,
		lng: -96.39774419999999
	}
};
var brevard_nc = {
	name: "Brevard, NC",
	value: {
		lat: 35.2334472,
		lng: -82.7342919
	}
};
var bridgeport_stamford_norwalk_ct = {
	name: "Bridgeport-Stamford-Norwalk, CT",
	value: {
		lat: 41.1865478,
		lng: -73.19517669999999
	}
};
var brigham_city_ut = {
	name: "Brigham City, UT",
	value: {
		lat: 41.5102129,
		lng: -112.0155015
	}
};
var brookhaven_ms = {
	name: "Brookhaven, MS",
	value: {
		lat: 31.5790588,
		lng: -90.4406506
	}
};
var brookings_or = {
	name: "Brookings, OR",
	value: {
		lat: 42.0526114,
		lng: -124.2839819
	}
};
var brookings_sd = {
	name: "Brookings, SD",
	value: {
		lat: 44.3113573,
		lng: -96.79838769999999
	}
};
var brownsville_tn = {
	name: "Brownsville, TN",
	value: {
		lat: 35.5939671,
		lng: -89.26229099999999
	}
};
var brownsville_harlingen_tx = {
	name: "Brownsville-Harlingen, TX",
	value: {
		lat: 25.9017472,
		lng: -97.4974838
	}
};
var brownwood_tx = {
	name: "Brownwood, TX",
	value: {
		lat: 31.7093197,
		lng: -98.9911611
	}
};
var brunswick_ga = {
	name: "Brunswick, GA",
	value: {
		lat: 31.1499528,
		lng: -81.49148939999999
	}
};
var bucyrus_oh = {
	name: "Bucyrus, OH",
	value: {
		lat: 40.8083909,
		lng: -82.97546489999999
	}
};
var buffalo_niagara_falls_ny = {
	name: "Buffalo-Niagara Falls, NY",
	value: {
		lat: 42.88644679999999,
		lng: -78.8783689
	}
};
var burley_id = {
	name: "Burley, ID",
	value: {
		lat: 42.5357428,
		lng: -113.7927948
	}
};
var burlington_ia_il = {
	name: "Burlington, IA-IL",
	value: {
		lat: 40.8076529,
		lng: -91.1128901
	}
};
var burlington_nc = {
	name: "Burlington, NC",
	value: {
		lat: 36.0956918,
		lng: -79.43779909999999
	}
};
var burlington_south_burlington_vt = {
	name: "Burlington-South Burlington, VT",
	value: {
		lat: 44.4758825,
		lng: -73.21207199999999
	}
};
var butte_silver_bow_mt = {
	name: "Butte-Silver Bow, MT",
	value: {
		lat: 46.0038232,
		lng: -112.5347776
	}
};
var cadillac_mi = {
	name: "Cadillac, MI",
	value: {
		lat: 44.2519526,
		lng: -85.40116189999999
	}
};
var calhoun_ga = {
	name: "Calhoun, GA",
	value: {
		lat: 34.502587,
		lng: -84.9510542
	}
};
var cambridge_md = {
	name: "Cambridge, MD",
	value: {
		lat: 38.5631744,
		lng: -76.0788292
	}
};
var cambridge_oh = {
	name: "Cambridge, OH",
	value: {
		lat: 40.031183,
		lng: -81.5884561
	}
};
var camden_ar = {
	name: "Camden, AR",
	value: {
		lat: 33.5845581,
		lng: -92.8343294
	}
};
var campbellsville_ky = {
	name: "Campbellsville, KY",
	value: {
		lat: 37.3433974,
		lng: -85.3419069
	}
};
var canon_city_co = {
	name: "Canon City, CO",
	value: {
		lat: 38.4494063,
		lng: -105.2253316
	}
};
var canton_il = {
	name: "Canton, IL",
	value: {
		lat: 40.5580945,
		lng: -90.03511669999999
	}
};
var canton_massillon_oh = {
	name: "Canton-Massillon, OH",
	value: {
		lat: 40.79894729999999,
		lng: -81.378447
	}
};
var cape_coral_fort_myers_fl = {
	name: "Cape Coral-Fort Myers, FL",
	value: {
		lat: 26.5628537,
		lng: -81.9495331
	}
};
var cape_girardeau_jackson_mo_il = {
	name: "Cape Girardeau-Jackson, MO-IL",
	value: {
		lat: 37.3058839,
		lng: -89.51814759999999
	}
};
var carbondale_il = {
	name: "Carbondale, IL",
	value: {
		lat: 37.7272727,
		lng: -89.2167501
	}
};
var carlsbad_artesia_nm = {
	name: "Carlsbad-Artesia, NM",
	value: {
		lat: 32.4206736,
		lng: -104.2288375
	}
};
var carson_city_nv = {
	name: "Carson City, NV",
	value: {
		lat: 39.1637984,
		lng: -119.7674034
	}
};
var casper_wy = {
	name: "Casper, WY",
	value: {
		lat: 42.866632,
		lng: -106.313081
	}
};
var cedar_city_ut = {
	name: "Cedar City, UT",
	value: {
		lat: 37.67747689999999,
		lng: -113.0618931
	}
};
var cedar_rapids_ia = {
	name: "Cedar Rapids, IA",
	value: {
		lat: 41.9778795,
		lng: -91.6656232
	}
};
var cedartown_ga = {
	name: "Cedartown, GA",
	value: {
		lat: 34.0112715,
		lng: -85.25658229999999
	}
};
var celina_oh = {
	name: "Celina, OH",
	value: {
		lat: 40.5489358,
		lng: -84.5702338
	}
};
var central_city_ky = {
	name: "Central City, KY",
	value: {
		lat: 37.2939322,
		lng: -87.1233292
	}
};
var centralia_il = {
	name: "Centralia, IL",
	value: {
		lat: 38.5285169,
		lng: -89.1316944
	}
};
var centralia_wa = {
	name: "Centralia, WA",
	value: {
		lat: 46.7162136,
		lng: -122.9542972
	}
};
var chambersburg_pa = {
	name: "Chambersburg, PA",
	value: {
		lat: 39.9375911,
		lng: -77.6611022
	}
};
var champaign_urbana_il = {
	name: "Champaign-Urbana, IL",
	value: {
		lat: 40.1164204,
		lng: -88.2433829
	}
};
var charleston_wv = {
	name: "Charleston, WV",
	value: {
		lat: 38.3498195,
		lng: -81.6326234
	}
};
var charleston_mattoon_il = {
	name: "Charleston-Mattoon, IL",
	value: {
		lat: 39.4961458,
		lng: -88.1761521
	}
};
var charleston_north_charleston_sc = {
	name: "Charleston-North Charleston, SC",
	value: {
		lat: 32.7764749,
		lng: -79.93105120000001
	}
};
var charlotte_gastonia_concord_nc_sc = {
	name: "Charlotte-Gastonia-Concord, NC-SC",
	value: {
		lat: 35.2270869,
		lng: -80.8431267
	}
};
var charlottesville_va = {
	name: "Charlottesville, VA",
	value: {
		lat: 38.0293059,
		lng: -78.47667810000002
	}
};
var chattanooga_tn_ga = {
	name: "Chattanooga, TN-GA",
	value: {
		lat: 35.0456297,
		lng: -85.3096801
	}
};
var chester_sc = {
	name: "Chester, SC",
	value: {
		lat: 34.7048613,
		lng: -81.2142561
	}
};
var cheyenne_wy = {
	name: "Cheyenne, WY",
	value: {
		lat: 41.1399814,
		lng: -104.8202462
	}
};
var chicago_naperville_joliet_il_in_wi = {
	name: "Chicago-Naperville-Joliet, IL-IN-WI",
	value: {
		lat: 41.8781136,
		lng: -87.6297982
	}
};
var chico_ca = {
	name: "Chico, CA",
	value: {
		lat: 39.7284944,
		lng: -121.8374777
	}
};
var chillicothe_oh = {
	name: "Chillicothe, OH",
	value: {
		lat: 39.3331197,
		lng: -82.9824019
	}
};
var cincinnati_middletown_oh_ky_in = {
	name: "Cincinnati-Middletown, OH-KY-IN",
	value: {
		lat: 39.1031182,
		lng: -84.5120196
	}
};
var city_of_the_dalles_or = {
	name: "City of The Dalles, OR",
	value: {
		lat: 45.5945645,
		lng: -121.1786823
	}
};
var claremont_nh = {
	name: "Claremont, NH",
	value: {
		lat: 43.3728635,
		lng: -72.33787439999999
	}
};
var clarksburg_wv = {
	name: "Clarksburg, WV",
	value: {
		lat: 39.2806451,
		lng: -80.34453409999999
	}
};
var clarksdale_ms = {
	name: "Clarksdale, MS",
	value: {
		lat: 34.2001086,
		lng: -90.5709323
	}
};
var clarksville_tn_ky = {
	name: "Clarksville, TN-KY",
	value: {
		lat: 36.5297706,
		lng: -87.3594528
	}
};
var clearlake_ca = {
	name: "Clearlake, CA",
	value: {
		lat: 38.9582307,
		lng: -122.6263728
	}
};
var cleveland_ms = {
	name: "Cleveland, MS",
	value: {
		lat: 33.7440023,
		lng: -90.7248187
	}
};
var cleveland_tn = {
	name: "Cleveland, TN",
	value: {
		lat: 35.1595182,
		lng: -84.8766115
	}
};
var cleveland_elyria_mentor_oh = {
	name: "Cleveland-Elyria-Mentor, OH",
	value: {
		lat: 41.49932,
		lng: -81.6943605
	}
};
var clewiston_fl = {
	name: "Clewiston, FL",
	value: {
		lat: 26.7542312,
		lng: -80.93367529999999
	}
};
var clinton_ia = {
	name: "Clinton, IA",
	value: {
		lat: 41.8444735,
		lng: -90.1887379
	}
};
var clovis_nm = {
	name: "Clovis, NM",
	value: {
		lat: 34.4047987,
		lng: -103.2052272
	}
};
var coffeyville_ks = {
	name: "Coffeyville, KS",
	value: {
		lat: 37.0373005,
		lng: -95.6163665
	}
};
var coldwater_mi = {
	name: "Coldwater, MI",
	value: {
		lat: 41.9403263,
		lng: -85.00052149999999
	}
};
var college_station_bryan_tx = {
	name: "College Station-Bryan, TX",
	value: {
		lat: 30.627977,
		lng: -96.3344068
	}
};
var colorado_springs_co = {
	name: "Colorado Springs, CO",
	value: {
		lat: 38.8338816,
		lng: -104.8213634
	}
};
var columbia_mo = {
	name: "Columbia, MO",
	value: {
		lat: 38.9517053,
		lng: -92.3340724
	}
};
var columbia_sc = {
	name: "Columbia, SC",
	value: {
		lat: 34.0007104,
		lng: -81.0348144
	}
};
var columbia_tn = {
	name: "Columbia, TN",
	value: {
		lat: 35.6150716,
		lng: -87.0352831
	}
};
var columbus_ga_al = {
	name: "Columbus, GA-AL",
	value: {
		lat: 32.4609764,
		lng: -84.9877094
	}
};
var columbus_in = {
	name: "Columbus, IN",
	value: {
		lat: 39.2014404,
		lng: -85.9213796
	}
};
var columbus_ms = {
	name: "Columbus, MS",
	value: {
		lat: 33.4956744,
		lng: -88.4272627
	}
};
var columbus_ne = {
	name: "Columbus, NE",
	value: {
		lat: 41.43029730000001,
		lng: -97.3593904
	}
};
var columbus_oh = {
	name: "Columbus, OH",
	value: {
		lat: 39.9611755,
		lng: -82.99879419999999
	}
};
var concord_nh = {
	name: "Concord, NH",
	value: {
		lat: 43.2081366,
		lng: -71.5375718
	}
};
var connersville_in = {
	name: "Connersville, IN",
	value: {
		lat: 39.6411589,
		lng: -85.1410748
	}
};
var cookeville_tn = {
	name: "Cookeville, TN",
	value: {
		lat: 36.162839,
		lng: -85.5016423
	}
};
var coos_bay_or = {
	name: "Coos Bay, OR",
	value: {
		lat: 43.3665007,
		lng: -124.2178903
	}
};
var corbin_ky = {
	name: "Corbin, KY",
	value: {
		lat: 36.9486986,
		lng: -84.0968761
	}
};
var cordele_ga = {
	name: "Cordele, GA",
	value: {
		lat: 31.9635074,
		lng: -83.7823938
	}
};
var corinth_ms = {
	name: "Corinth, MS",
	value: {
		lat: 34.9342548,
		lng: -88.5222702
	}
};
var cornelia_ga = {
	name: "Cornelia, GA",
	value: {
		lat: 34.5114883,
		lng: -83.5271166
	}
};
var corning_ny = {
	name: "Corning, NY",
	value: {
		lat: 42.1428521,
		lng: -77.05469029999999
	}
};
var corpus_christi_tx = {
	name: "Corpus Christi, TX",
	value: {
		lat: 27.8005828,
		lng: -97.39638099999999
	}
};
var corsicana_tx = {
	name: "Corsicana, TX",
	value: {
		lat: 32.0954304,
		lng: -96.46887269999999
	}
};
var cortland_ny = {
	name: "Cortland, NY",
	value: {
		lat: 42.6011813,
		lng: -76.1804843
	}
};
var corvallis_or = {
	name: "Corvallis, OR",
	value: {
		lat: 44.5645659,
		lng: -123.2620435
	}
};
var coshocton_oh = {
	name: "Coshocton, OH",
	value: {
		lat: 40.2720151,
		lng: -81.8595756
	}
};
var crawfordsville_in = {
	name: "Crawfordsville, IN",
	value: {
		lat: 40.0411536,
		lng: -86.87445160000001
	}
};
var crescent_city_ca = {
	name: "Crescent City, CA",
	value: {
		lat: 41.7557501,
		lng: -124.2025913
	}
};
var crossville_tn = {
	name: "Crossville, TN",
	value: {
		lat: 35.9489566,
		lng: -85.0269014
	}
};
var crowley_la = {
	name: "Crowley, LA",
	value: {
		lat: 30.2140928,
		lng: -92.3745761
	}
};
var cullman_al = {
	name: "Cullman, AL",
	value: {
		lat: 34.1748208,
		lng: -86.8436124
	}
};
var culpeper_va = {
	name: "Culpeper, VA",
	value: {
		lat: 38.4729632,
		lng: -77.9962512
	}
};
var cumberland_md_wv = {
	name: "Cumberland, MD-WV",
	value: {
		lat: 39.6528654,
		lng: -78.7625185
	}
};
var dallas_fort_worth_arlington_tx = {
	name: "Dallas-Fort Worth-Arlington, TX",
	value: {
		lat: 32.7766642,
		lng: -96.79698789999999
	}
};
var dalton_ga = {
	name: "Dalton, GA",
	value: {
		lat: 34.7698021,
		lng: -84.9702228
	}
};
var danville_il = {
	name: "Danville, IL",
	value: {
		lat: 40.124481,
		lng: -87.6300207
	}
};
var danville_ky = {
	name: "Danville, KY",
	value: {
		lat: 37.6456329,
		lng: -84.77217019999999
	}
};
var danville_va = {
	name: "Danville, VA",
	value: {
		lat: 36.5859718,
		lng: -79.39502279999999
	}
};
var daphne_fairhope_foley_al = {
	name: "Daphne-Fairhope-Foley, AL",
	value: {
		lat: 30.6035255,
		lng: -87.9036047
	}
};
var davenport_moline_rock_island_ia_il = {
	name: "Davenport-Moline-Rock Island, IA-IL",
	value: {
		lat: 41.5236437,
		lng: -90.5776367
	}
};
var dayton_oh = {
	name: "Dayton, OH",
	value: {
		lat: 39.7589478,
		lng: -84.1916069
	}
};
var de_ridder_la = {
	name: "De Ridder, LA",
	value: {
		lat: 30.8463055,
		lng: -93.2890527
	}
};
var decatur_al = {
	name: "Decatur, AL",
	value: {
		lat: 34.6059253,
		lng: -86.9833417
	}
};
var decatur_il = {
	name: "Decatur, IL",
	value: {
		lat: 39.8403147,
		lng: -88.9548001
	}
};
var decatur_in = {
	name: "Decatur, IN",
	value: {
		lat: 40.830603,
		lng: -84.9291329
	}
};
var defiance_oh = {
	name: "Defiance, OH",
	value: {
		lat: 41.2844933,
		lng: -84.3557802
	}
};
var del_rio_tx = {
	name: "Del Rio, TX",
	value: {
		lat: 29.3708857,
		lng: -100.8958674
	}
};
var deltona_daytona_beach_ormond_beach_fl = {
	name: "Deltona-Daytona Beach-Ormond Beach, FL",
	value: {
		lat: 28.9005446,
		lng: -81.26367379999999
	}
};
var deming_nm = {
	name: "Deming, NM",
	value: {
		lat: 32.2686981,
		lng: -107.7586404
	}
};
var denver_aurora_co = {
	name: "Denver-Aurora, CO",
	value: {
		lat: 39.7392358,
		lng: -104.990251
	}
};
var des_moines_west_des_moines_ia = {
	name: "Des Moines-West Des Moines, IA",
	value: {
		lat: 41.6005448,
		lng: -93.6091064
	}
};
var detroit_warren_livonia_mi = {
	name: "Detroit-Warren-Livonia, MI",
	value: {
		lat: 42.331427,
		lng: -83.0457538
	}
};
var dickinson_nd = {
	name: "Dickinson, ND",
	value: {
		lat: 46.8791756,
		lng: -102.7896242
	}
};
var dillon_sc = {
	name: "Dillon, SC",
	value: {
		lat: 34.4165505,
		lng: -79.3711579
	}
};
var dixon_il = {
	name: "Dixon, IL",
	value: {
		lat: 41.8389213,
		lng: -89.47954779999999
	}
};
var dodge_city_ks = {
	name: "Dodge City, KS",
	value: {
		lat: 37.7527982,
		lng: -100.0170787
	}
};
var dothan_al = {
	name: "Dothan, AL",
	value: {
		lat: 31.2232313,
		lng: -85.3904888
	}
};
var douglas_ga = {
	name: "Douglas, GA",
	value: {
		lat: 31.5088073,
		lng: -82.8498654
	}
};
var dover_de = {
	name: "Dover, DE",
	value: {
		lat: 39.158168,
		lng: -75.5243682
	}
};
var dubois_pa = {
	name: "DuBois, PA",
	value: {
		lat: 41.1210115,
		lng: -78.7583257
	}
};
var dublin_ga = {
	name: "Dublin, GA",
	value: {
		lat: 32.5404447,
		lng: -82.90375399999999
	}
};
var dubuque_ia = {
	name: "Dubuque, IA",
	value: {
		lat: 42.5005583,
		lng: -90.66457179999999
	}
};
var duluth_mn_wi = {
	name: "Duluth, MN-WI",
	value: {
		lat: 46.78667189999999,
		lng: -92.1004852
	}
};
var dumas_tx = {
	name: "Dumas, TX",
	value: {
		lat: 35.8653789,
		lng: -101.9732236
	}
};
var duncan_ok = {
	name: "Duncan, OK",
	value: {
		lat: 34.5023028,
		lng: -97.9578128
	}
};
var dunn_nc = {
	name: "Dunn, NC",
	value: {
		lat: 35.3062743,
		lng: -78.6089028
	}
};
var durango_co = {
	name: "Durango, CO",
	value: {
		lat: 37.27528,
		lng: -107.8800667
	}
};
var durant_ok = {
	name: "Durant, OK",
	value: {
		lat: 33.9924186,
		lng: -96.39712329999999
	}
};
var durham_nc = {
	name: "Durham, NC",
	value: {
		lat: 35.9940329,
		lng: -78.898619
	}
};
var dyersburg_tn = {
	name: "Dyersburg, TN",
	value: {
		lat: 36.0345159,
		lng: -89.38562809999999
	}
};
var eagle_pass_tx = {
	name: "Eagle Pass, TX",
	value: {
		lat: 28.7091433,
		lng: -100.4995214
	}
};
var east_liverpool_salem_oh = {
	name: "East Liverpool-Salem, OH",
	value: {
		lat: 40.6186756,
		lng: -80.5772928
	}
};
var east_stroudsburg_pa = {
	name: "East Stroudsburg, PA",
	value: {
		lat: 40.9995386,
		lng: -75.1812913
	}
};
var easton_md = {
	name: "Easton, MD",
	value: {
		lat: 38.7742826,
		lng: -76.0763305
	}
};
var eau_claire_wi = {
	name: "Eau Claire, WI",
	value: {
		lat: 44.811349,
		lng: -91.4984941
	}
};
var edwards_co = {
	name: "Edwards, CO",
	value: {
		lat: 39.644986,
		lng: -106.5942
	}
};
var effingham_il = {
	name: "Effingham, IL",
	value: {
		lat: 39.1200418,
		lng: -88.5433829
	}
};
var el_campo_tx = {
	name: "El Campo, TX",
	value: {
		lat: 29.19664049999999,
		lng: -96.2696867
	}
};
var el_centro_ca = {
	name: "El Centro, CA",
	value: {
		lat: 32.792,
		lng: -115.5630514
	}
};
var el_dorado_ar = {
	name: "El Dorado, AR",
	value: {
		lat: 33.20763,
		lng: -92.6662674
	}
};
var el_paso_tx = {
	name: "El Paso, TX",
	value: {
		lat: 31.7618778,
		lng: -106.4850217
	}
};
var elizabeth_city_nc = {
	name: "Elizabeth City, NC",
	value: {
		lat: 36.2946008,
		lng: -76.2510461
	}
};
var elizabethtown_ky = {
	name: "Elizabethtown, KY",
	value: {
		lat: 37.7030646,
		lng: -85.8649408
	}
};
var elk_city_ok = {
	name: "Elk City, OK",
	value: {
		lat: 35.4119944,
		lng: -99.4042592
	}
};
var elkhart_goshen_in = {
	name: "Elkhart-Goshen, IN",
	value: {
		lat: 41.6819935,
		lng: -85.9766671
	}
};
var elko_nv = {
	name: "Elko, NV",
	value: {
		lat: 40.8324211,
		lng: -115.7631232
	}
};
var ellensburg_wa = {
	name: "Ellensburg, WA",
	value: {
		lat: 46.9965144,
		lng: -120.5478474
	}
};
var elmira_ny = {
	name: "Elmira, NY",
	value: {
		lat: 42.0897965,
		lng: -76.8077338
	}
};
var emporia_ks = {
	name: "Emporia, KS",
	value: {
		lat: 38.403903,
		lng: -96.18166260000001
	}
};
var enid_ok = {
	name: "Enid, OK",
	value: {
		lat: 36.3955891,
		lng: -97.8783911
	}
};
var enterprise_ozark_al = {
	name: "Enterprise-Ozark, AL",
	value: {
		lat: 31.3151708,
		lng: -85.85521609999999
	}
};
var erie_pa = {
	name: "Erie, PA",
	value: {
		lat: 42.12922409999999,
		lng: -80.085059
	}
};
var escanaba_mi = {
	name: "Escanaba, MI",
	value: {
		lat: 45.74524659999999,
		lng: -87.06458010000001
	}
};
var espanola_nm = {
	name: "Espanola, NM",
	value: {
		lat: 35.9910383,
		lng: -106.0818233
	}
};
var eufaula_al_ga = {
	name: "Eufaula, AL-GA",
	value: {
		lat: 31.8912717,
		lng: -85.1454876
	}
};
var eugene_springfield_or = {
	name: "Eugene-Springfield, OR",
	value: {
		lat: 44.0520691,
		lng: -123.0867536
	}
};
var eureka_arcata_fortuna_ca = {
	name: "Eureka-Arcata-Fortuna, CA",
	value: {
		lat: 40.8020712,
		lng: -124.1636729
	}
};
var evanston_wy = {
	name: "Evanston, WY",
	value: {
		lat: 41.2682794,
		lng: -110.9632373
	}
};
var evansville_in_ky = {
	name: "Evansville, IN-KY",
	value: {
		lat: 37.9715592,
		lng: -87.5710898
	}
};
var fairbanks_ak = {
	name: "Fairbanks, AK",
	value: {
		lat: 64.8377778,
		lng: -147.7163889
	}
};
var fairmont_mn = {
	name: "Fairmont, MN",
	value: {
		lat: 43.65217750000001,
		lng: -94.46108319999999
	}
};
var fairmont_wv = {
	name: "Fairmont, WV",
	value: {
		lat: 39.4850848,
		lng: -80.1425781
	}
};
var fajardo_pr = {
	name: "Fajardo, PR",
	value: {
		lat: 18.2065872,
		lng: -65.64879080000001
	}
};
var fallon_nv = {
	name: "Fallon, NV",
	value: {
		lat: 39.4748693,
		lng: -118.7770407
	}
};
var fargo_nd_mn = {
	name: "Fargo, ND-MN",
	value: {
		lat: 46.8771863,
		lng: -96.7898034
	}
};
var faribault_northfield_mn = {
	name: "Faribault-Northfield, MN",
	value: {
		lat: 44.2949636,
		lng: -93.268827
	}
};
var farmington_mo = {
	name: "Farmington, MO",
	value: {
		lat: 37.7808846,
		lng: -90.4217895
	}
};
var farmington_nm = {
	name: "Farmington, NM",
	value: {
		lat: 36.72805830000001,
		lng: -108.2186856
	}
};
var fayetteville_nc = {
	name: "Fayetteville, NC",
	value: {
		lat: 35.0526641,
		lng: -78.87835849999999
	}
};
var fayetteville_springdale_rogers_ar_mo = {
	name: "Fayetteville-Springdale-Rogers, AR-MO",
	value: {
		lat: 36.0625795,
		lng: -94.1574263
	}
};
var fergus_falls_mn = {
	name: "Fergus Falls, MN",
	value: {
		lat: 46.2835212,
		lng: -96.0777887
	}
};
var fernley_nv = {
	name: "Fernley, NV",
	value: {
		lat: 39.6079683,
		lng: -119.2518349
	}
};
var findlay_oh = {
	name: "Findlay, OH",
	value: {
		lat: 41.04422,
		lng: -83.6499321
	}
};
var fitzgerald_ga = {
	name: "Fitzgerald, GA",
	value: {
		lat: 31.7149082,
		lng: -83.25265449999999
	}
};
var flagstaff_az = {
	name: "Flagstaff, AZ",
	value: {
		lat: 35.1982836,
		lng: -111.651302
	}
};
var flint_mi = {
	name: "Flint, MI",
	value: {
		lat: 43.0125274,
		lng: -83.6874562
	}
};
var florence_sc = {
	name: "Florence, SC",
	value: {
		lat: 34.1954331,
		lng: -79.7625625
	}
};
var florence_muscle_shoals_al = {
	name: "Florence-Muscle Shoals, AL",
	value: {
		lat: 34.79981,
		lng: -87.677251
	}
};
var fond_du_lac_wi = {
	name: "Fond du Lac, WI",
	value: {
		lat: 43.7730448,
		lng: -88.4470508
	}
};
var forest_city_nc = {
	name: "Forest City, NC",
	value: {
		lat: 35.3340108,
		lng: -81.8651028
	}
};
var forrest_city_ar = {
	name: "Forrest City, AR",
	value: {
		lat: 35.0081474,
		lng: -90.7898342
	}
};
var fort_collins_loveland_co = {
	name: "Fort Collins-Loveland, CO",
	value: {
		lat: 40.5852602,
		lng: -105.084423
	}
};
var fort_dodge_ia = {
	name: "Fort Dodge, IA",
	value: {
		lat: 42.4974694,
		lng: -94.16801579999999
	}
};
var fort_leonard_wood_mo = {
	name: "Fort Leonard Wood, MO",
	value: {
		lat: 37.7252315,
		lng: -92.1646722
	}
};
var fort_madison_keokuk_ia_mo = {
	name: "Fort Madison-Keokuk, IA-MO",
	value: {
		lat: 40.6297634,
		lng: -91.31453499999999
	}
};
var fort_morgan_co = {
	name: "Fort Morgan, CO",
	value: {
		lat: 40.2502582,
		lng: -103.7999509
	}
};
var fort_payne_al = {
	name: "Fort Payne, AL",
	value: {
		lat: 34.4442547,
		lng: -85.7196893
	}
};
var fort_polk_south_la = {
	name: "Fort Polk South, LA",
	value: {
		lat: 31.0567117,
		lng: -93.2131232
	}
};
var fort_smith_ar_ok = {
	name: "Fort Smith, AR-OK",
	value: {
		lat: 35.3859242,
		lng: -94.39854749999999
	}
};
var fort_valley_ga = {
	name: "Fort Valley, GA",
	value: {
		lat: 32.5537585,
		lng: -83.8874084
	}
};
var fort_walton_beach_crestview_destin_fl = {
	name: "Fort Walton Beach-Crestview-Destin, FL",
	value: {
		lat: 30.42007079999999,
		lng: -86.6170308
	}
};
var fort_wayne_in = {
	name: "Fort Wayne, IN",
	value: {
		lat: 41.079273,
		lng: -85.1393513
	}
};
var frankfort_in = {
	name: "Frankfort, IN",
	value: {
		lat: 40.2794809,
		lng: -86.5108355
	}
};
var frankfort_ky = {
	name: "Frankfort, KY",
	value: {
		lat: 38.2009055,
		lng: -84.87328350000001
	}
};
var fredericksburg_tx = {
	name: "Fredericksburg, TX",
	value: {
		lat: 30.2752011,
		lng: -98.8719843
	}
};
var freeport_il = {
	name: "Freeport, IL",
	value: {
		lat: 42.2966861,
		lng: -89.6212271
	}
};
var fremont_ne = {
	name: "Fremont, NE",
	value: {
		lat: 41.4333909,
		lng: -96.49814669999999
	}
};
var fremont_oh = {
	name: "Fremont, OH",
	value: {
		lat: 41.3503303,
		lng: -83.1218634
	}
};
var fresno_ca = {
	name: "Fresno, CA",
	value: {
		lat: 36.7468422,
		lng: -119.7725868
	}
};
var gadsden_al = {
	name: "Gadsden, AL",
	value: {
		lat: 34.014264,
		lng: -86.0066386
	}
};
var gaffney_sc = {
	name: "Gaffney, SC",
	value: {
		lat: 35.0717945,
		lng: -81.64981949999999
	}
};
var gainesville_fl = {
	name: "Gainesville, FL",
	value: {
		lat: 29.6516344,
		lng: -82.32482619999999
	}
};
var gainesville_ga = {
	name: "Gainesville, GA",
	value: {
		lat: 34.2978794,
		lng: -83.8240663
	}
};
var gainesville_tx = {
	name: "Gainesville, TX",
	value: {
		lat: 33.62594139999999,
		lng: -97.1333453
	}
};
var galesburg_il = {
	name: "Galesburg, IL",
	value: {
		lat: 40.94781580000001,
		lng: -90.3712395
	}
};
var gallup_nm = {
	name: "Gallup, NM",
	value: {
		lat: 35.5280783,
		lng: -108.7425843
	}
};
var garden_city_ks = {
	name: "Garden City, KS",
	value: {
		lat: 37.9716898,
		lng: -100.8726618
	}
};
var gardnerville_ranchos_nv = {
	name: "Gardnerville Ranchos, NV",
	value: {
		lat: 38.8882398,
		lng: -119.7412875
	}
};
var georgetown_sc = {
	name: "Georgetown, SC",
	value: {
		lat: 33.376834,
		lng: -79.2944964
	}
};
var gettysburg_pa = {
	name: "Gettysburg, PA",
	value: {
		lat: 39.8309293,
		lng: -77.2310955
	}
};
var gillette_wy = {
	name: "Gillette, WY",
	value: {
		lat: 44.2910915,
		lng: -105.5022205
	}
};
var glasgow_ky = {
	name: "Glasgow, KY",
	value: {
		lat: 36.9958839,
		lng: -85.91192149999999
	}
};
var glens_falls_ny = {
	name: "Glens Falls, NY",
	value: {
		lat: 43.3095164,
		lng: -73.6440058
	}
};
var gloversville_ny = {
	name: "Gloversville, NY",
	value: {
		lat: 43.0528506,
		lng: -74.3437467
	}
};
var goldsboro_nc = {
	name: "Goldsboro, NC",
	value: {
		lat: 35.3848841,
		lng: -77.9927651
	}
};
var granbury_tx = {
	name: "Granbury, TX",
	value: {
		lat: 32.4420826,
		lng: -97.7941967
	}
};
var grand_forks_nd_mn = {
	name: "Grand Forks, ND-MN",
	value: {
		lat: 47.9252568,
		lng: -97.0328547
	}
};
var grand_island_ne = {
	name: "Grand Island, NE",
	value: {
		lat: 40.9263957,
		lng: -98.3420118
	}
};
var grand_junction_co = {
	name: "Grand Junction, CO",
	value: {
		lat: 39.0638705,
		lng: -108.5506486
	}
};
var grand_rapids_wyoming_mi = {
	name: "Grand Rapids-Wyoming, MI",
	value: {
		lat: 42.9633599,
		lng: -85.6680863
	}
};
var grants_pass_or = {
	name: "Grants Pass, OR",
	value: {
		lat: 42.4390069,
		lng: -123.3283925
	}
};
var grants_nm = {
	name: "Grants, NM",
	value: {
		lat: 35.14726,
		lng: -107.8514466
	}
};
var great_bend_ks = {
	name: "Great Bend, KS",
	value: {
		lat: 38.3644567,
		lng: -98.7648073
	}
};
var great_falls_mt = {
	name: "Great Falls, MT",
	value: {
		lat: 47.4941836,
		lng: -111.2833449
	}
};
var greeley_co = {
	name: "Greeley, CO",
	value: {
		lat: 40.4233142,
		lng: -104.7091322
	}
};
var green_bay_wi = {
	name: "Green Bay, WI",
	value: {
		lat: 44.51915899999999,
		lng: -88.019826
	}
};
var greeneville_tn = {
	name: "Greeneville, TN",
	value: {
		lat: 36.1631574,
		lng: -82.83098609999999
	}
};
var greensboro_high_point_nc = {
	name: "Greensboro-High Point, NC",
	value: {
		lat: 36.0726354,
		lng: -79.7919754
	}
};
var greensburg_in = {
	name: "Greensburg, IN",
	value: {
		lat: 39.3372722,
		lng: -85.483581
	}
};
var greenville_ms = {
	name: "Greenville, MS",
	value: {
		lat: 33.399661,
		lng: -91.0377029
	}
};
var greenville_nc = {
	name: "Greenville, NC",
	value: {
		lat: 35.612661,
		lng: -77.3663538
	}
};
var greenville_oh = {
	name: "Greenville, OH",
	value: {
		lat: 40.1028264,
		lng: -84.63301150000001
	}
};
var greenville_mauldin_easley_sc = {
	name: "Greenville-Mauldin-Easley, SC",
	value: {
		lat: 34.85261759999999,
		lng: -82.3940104
	}
};
var greenwood_ms = {
	name: "Greenwood, MS",
	value: {
		lat: 33.5162315,
		lng: -90.1795281
	}
};
var greenwood_sc = {
	name: "Greenwood, SC",
	value: {
		lat: 34.1954001,
		lng: -82.1617883
	}
};
var grenada_ms = {
	name: "Grenada, MS",
	value: {
		lat: 33.7690049,
		lng: -89.8084192
	}
};
var guayama_pr = {
	name: "Guayama, PR",
	value: {
		lat: 17.98413,
		lng: -66.11378
	}
};
var gulfport_biloxi_ms = {
	name: "Gulfport-Biloxi, MS",
	value: {
		lat: 30.3674198,
		lng: -89.0928155
	}
};
var guymon_ok = {
	name: "Guymon, OK",
	value: {
		lat: 36.6828041,
		lng: -101.4815493
	}
};
var hagerstown_martinsburg_md_wv = {
	name: "Hagerstown-Martinsburg, MD-WV",
	value: {
		lat: 39.6417629,
		lng: -77.71999319999999
	}
};
var hammond_la = {
	name: "Hammond, LA",
	value: {
		lat: 30.5043583,
		lng: -90.46119949999999
	}
};
var hanford_corcoran_ca = {
	name: "Hanford-Corcoran, CA",
	value: {
		lat: 36.3274502,
		lng: -119.6456844
	}
};
var hannibal_mo = {
	name: "Hannibal, MO",
	value: {
		lat: 39.7083789,
		lng: -91.35848159999999
	}
};
var harriman_tn = {
	name: "Harriman, TN",
	value: {
		lat: 35.9339638,
		lng: -84.5524358
	}
};
var harrisburg_il = {
	name: "Harrisburg, IL",
	value: {
		lat: 37.7383812,
		lng: -88.540607
	}
};
var harrisburg_carlisle_pa = {
	name: "Harrisburg-Carlisle, PA",
	value: {
		lat: 40.2731911,
		lng: -76.8867008
	}
};
var harrison_ar = {
	name: "Harrison, AR",
	value: {
		lat: 36.2297936,
		lng: -93.1076765
	}
};
var harrisonburg_va = {
	name: "Harrisonburg, VA",
	value: {
		lat: 38.4495688,
		lng: -78.8689155
	}
};
var hartford_west_hartford_east_hartford_ct = {
	name: "Hartford-West Hartford-East Hartford, CT",
	value: {
		lat: 41.76371109999999,
		lng: -72.6850932
	}
};
var hastings_ne = {
	name: "Hastings, NE",
	value: {
		lat: 40.5862583,
		lng: -98.38987259999999
	}
};
var hattiesburg_ms = {
	name: "Hattiesburg, MS",
	value: {
		lat: 31.3271189,
		lng: -89.29033919999999
	}
};
var havre_mt = {
	name: "Havre, MT",
	value: {
		lat: 48.549999,
		lng: -109.6840887
	}
};
var hays_ks = {
	name: "Hays, KS",
	value: {
		lat: 38.8791783,
		lng: -99.3267702
	}
};
var heber_ut = {
	name: "Heber, UT",
	value: {
		lat: 40.5070087,
		lng: -111.4133234
	}
};
var helena_mt = {
	name: "Helena, MT",
	value: {
		lat: 46.5883707,
		lng: -112.0245054
	}
};
var henderson_nc = {
	name: "Henderson, NC",
	value: {
		lat: 36.3295905,
		lng: -78.3991638
	}
};
var hereford_tx = {
	name: "Hereford, TX",
	value: {
		lat: 34.8150622,
		lng: -102.3977036
	}
};
var hickory_lenoir_morganton_nc = {
	name: "Hickory-Lenoir-Morganton, NC",
	value: {
		lat: 35.7344538,
		lng: -81.3444573
	}
};
var hilo_hi = {
	name: "Hilo, HI",
	value: {
		lat: 19.7297222,
		lng: -155.09
	}
};
var hilton_head_island_beaufort_sc = {
	name: "Hilton Head Island-Beaufort, SC",
	value: {
		lat: 32.216316,
		lng: -80.752608
	}
};
var hinesville_fort_stewart_ga = {
	name: "Hinesville-Fort Stewart, GA",
	value: {
		lat: 31.846877,
		lng: -81.5959453
	}
};
var hobbs_nm = {
	name: "Hobbs, NM",
	value: {
		lat: 32.7026116,
		lng: -103.1360403
	}
};
var holland_grand_haven_mi = {
	name: "Holland-Grand Haven, MI",
	value: {
		lat: 42.7875235,
		lng: -86.1089301
	}
};
var homosassa_springs_fl = {
	name: "Homosassa Springs, FL",
	value: {
		lat: 28.8037059,
		lng: -82.5761369
	}
};
var honolulu_hi = {
	name: "Honolulu, HI",
	value: {
		lat: 21.3069444,
		lng: -157.8583333
	}
};
var hood_river_or = {
	name: "Hood River, OR",
	value: {
		lat: 45.7053966,
		lng: -121.5214623
	}
};
var hope_ar = {
	name: "Hope, AR",
	value: {
		lat: 33.6670615,
		lng: -93.5915665
	}
};
var hot_springs_ar = {
	name: "Hot Springs, AR",
	value: {
		lat: 34.5037004,
		lng: -93.0551795
	}
};
var houghton_mi = {
	name: "Houghton, MI",
	value: {
		lat: 47.12113309999999,
		lng: -88.5694182
	}
};
var houma_bayou_cane_thibodaux_la = {
	name: "Houma-Bayou Cane-Thibodaux, LA",
	value: {
		lat: 29.5957696,
		lng: -90.71953479999999
	}
};
var houston_sugar_land_baytown_tx = {
	name: "Houston-Sugar Land-Baytown, TX",
	value: {
		lat: 29.7604267,
		lng: -95.3698028
	}
};
var hudson_ny = {
	name: "Hudson, NY",
	value: {
		lat: 42.2528649,
		lng: -73.790959
	}
};
var humboldt_tn = {
	name: "Humboldt, TN",
	value: {
		lat: 35.8197917,
		lng: -88.9158953
	}
};
var huntingdon_pa = {
	name: "Huntingdon, PA",
	value: {
		lat: 40.48479589999999,
		lng: -78.0102813
	}
};
var huntington_in = {
	name: "Huntington, IN",
	value: {
		lat: 40.8831011,
		lng: -85.49747599999999
	}
};
var huntington_ashland_wv_ky_oh = {
	name: "Huntington-Ashland, WV-KY-OH",
	value: {
		lat: 38.4192496,
		lng: -82.44515400000002
	}
};
var huntsville_al = {
	name: "Huntsville, AL",
	value: {
		lat: 34.7303688,
		lng: -86.5861037
	}
};
var huntsville_tx = {
	name: "Huntsville, TX",
	value: {
		lat: 30.7235263,
		lng: -95.55077709999999
	}
};
var huron_sd = {
	name: "Huron, SD",
	value: {
		lat: 44.3633173,
		lng: -98.21425719999999
	}
};
var hutchinson_ks = {
	name: "Hutchinson, KS",
	value: {
		lat: 38.0608445,
		lng: -97.92977429999999
	}
};
var hutchinson_mn = {
	name: "Hutchinson, MN",
	value: {
		lat: 44.89254830000001,
		lng: -94.3692926
	}
};
var idaho_falls_id = {
	name: "Idaho Falls, ID",
	value: {
		lat: 43.49165139999999,
		lng: -112.0339645
	}
};
var indiana_pa = {
	name: "Indiana, PA",
	value: {
		lat: 40.6214551,
		lng: -79.15253489999999
	}
};
var indianapolis_carmel_in = {
	name: "Indianapolis-Carmel, IN",
	value: {
		lat: 39.768403,
		lng: -86.158068
	}
};
var indianola_ms = {
	name: "Indianola, MS",
	value: {
		lat: 33.4509513,
		lng: -90.6550917
	}
};
var iowa_city_ia = {
	name: "Iowa City, IA",
	value: {
		lat: 41.6611277,
		lng: -91.5301683
	}
};
var iron_mountain_mi_wi = {
	name: "Iron Mountain, MI-WI",
	value: {
		lat: 45.8202334,
		lng: -88.0659603
	}
};
var ithaca_ny = {
	name: "Ithaca, NY",
	value: {
		lat: 42.4439614,
		lng: -76.5018807
	}
};
var jackson_mi = {
	name: "Jackson, MI",
	value: {
		lat: 42.245869,
		lng: -84.40134619999999
	}
};
var jackson_ms = {
	name: "Jackson, MS",
	value: {
		lat: 32.2987573,
		lng: -90.1848103
	}
};
var jackson_tn = {
	name: "Jackson, TN",
	value: {
		lat: 35.6145169,
		lng: -88.81394689999999
	}
};
var jackson_wy_id = {
	name: "Jackson, WY-ID",
	value: {
		lat: 43.4799291,
		lng: -110.7624282
	}
};
var jacksonville_fl = {
	name: "Jacksonville, FL",
	value: {
		lat: 30.3321838,
		lng: -81.65565099999999
	}
};
var jacksonville_il = {
	name: "Jacksonville, IL",
	value: {
		lat: 39.733936,
		lng: -90.2290098
	}
};
var jacksonville_nc = {
	name: "Jacksonville, NC",
	value: {
		lat: 34.7540524,
		lng: -77.4302414
	}
};
var jacksonville_tx = {
	name: "Jacksonville, TX",
	value: {
		lat: 31.963778,
		lng: -95.27050419999999
	}
};
var jamestown_nd = {
	name: "Jamestown, ND",
	value: {
		lat: 46.9105438,
		lng: -98.7084357
	}
};
var jamestown_dunkirk_fredonia_ny = {
	name: "Jamestown-Dunkirk-Fredonia, NY",
	value: {
		lat: 42.0970023,
		lng: -79.23532589999999
	}
};
var janesville_wi = {
	name: "Janesville, WI",
	value: {
		lat: 42.6827885,
		lng: -89.0187222
	}
};
var jasper_in = {
	name: "Jasper, IN",
	value: {
		lat: 38.3914418,
		lng: -86.9311094
	}
};
var jefferson_city_mo = {
	name: "Jefferson City, MO",
	value: {
		lat: 38.57670170000001,
		lng: -92.1735164
	}
};
var jennings_la = {
	name: "Jennings, LA",
	value: {
		lat: 30.22242839999999,
		lng: -92.657085
	}
};
var jesup_ga = {
	name: "Jesup, GA",
	value: {
		lat: 31.6074365,
		lng: -81.8853924
	}
};
var johnson_city_tn = {
	name: "Johnson City, TN",
	value: {
		lat: 36.3134397,
		lng: -82.3534727
	}
};
var johnstown_pa = {
	name: "Johnstown, PA",
	value: {
		lat: 40.32674069999999,
		lng: -78.9219698
	}
};
var jonesboro_ar = {
	name: "Jonesboro, AR",
	value: {
		lat: 35.84229670000001,
		lng: -90.704279
	}
};
var joplin_mo = {
	name: "Joplin, MO",
	value: {
		lat: 37.08422710000001,
		lng: -94.51328099999999
	}
};
var juneau_ak = {
	name: "Juneau, AK",
	value: {
		lat: 58.3019444,
		lng: -134.4197222
	}
};
var kahului_wailuku_hi = {
	name: "Kahului-Wailuku, HI",
	value: {
		lat: 20.8893351,
		lng: -156.4729469
	}
};
var kalamazoo_portage_mi = {
	name: "Kalamazoo-Portage, MI",
	value: {
		lat: 42.2917069,
		lng: -85.5872286
	}
};
var kalispell_mt = {
	name: "Kalispell, MT",
	value: {
		lat: 48.1919889,
		lng: -114.3168131
	}
};
var kankakee_bradley_il = {
	name: "Kankakee-Bradley, IL",
	value: {
		lat: 41.1200325,
		lng: -87.8611531
	}
};
var kansas_city_mo_ks = {
	name: "Kansas City, MO-KS",
	value: {
		lat: 39.0997265,
		lng: -94.5785667
	}
};
var kapaa_hi = {
	name: "Kapaa, HI",
	value: {
		lat: 22.0881391,
		lng: -159.3379818
	}
};
var kearney_ne = {
	name: "Kearney, NE",
	value: {
		lat: 40.69933030000001,
		lng: -99.0816784
	}
};
var keene_nh = {
	name: "Keene, NH",
	value: {
		lat: 42.933692,
		lng: -72.2781409
	}
};
var kendallville_in = {
	name: "Kendallville, IN",
	value: {
		lat: 41.4414384,
		lng: -85.2649754
	}
};
var kennett_mo = {
	name: "Kennett, MO",
	value: {
		lat: 36.2361762,
		lng: -90.0556493
	}
};
var kennewick_richland_pasco_wa = {
	name: "Kennewick-Richland-Pasco, WA",
	value: {
		lat: 46.2112458,
		lng: -119.1372338
	}
};
var kerrville_tx = {
	name: "Kerrville, TX",
	value: {
		lat: 30.0474332,
		lng: -99.1403189
	}
};
var ketchikan_ak = {
	name: "Ketchikan, AK",
	value: {
		lat: 55.34222219999999,
		lng: -131.6461111
	}
};
var key_west_fl = {
	name: "Key West, FL",
	value: {
		lat: 24.5550593,
		lng: -81.7799871
	}
};
var kill_devil_hills_nc = {
	name: "Kill Devil Hills, NC",
	value: {
		lat: 36.0307226,
		lng: -75.6760101
	}
};
var killeen_temple_fort_hood_tx = {
	name: "Killeen-Temple-Fort Hood, TX",
	value: {
		lat: 31.1171194,
		lng: -97.72779589999999
	}
};
var kingsport_bristol_bristol_tn_va = {
	name: "Kingsport-Bristol-Bristol, TN-VA",
	value: {
		lat: 36.548434,
		lng: -82.5618186
	}
};
var kingston_ny = {
	name: "Kingston, NY",
	value: {
		lat: 41.9270367,
		lng: -73.9973608
	}
};
var kingsville_tx = {
	name: "Kingsville, TX",
	value: {
		lat: 27.5158689,
		lng: -97.85610899999999
	}
};
var kinston_nc = {
	name: "Kinston, NC",
	value: {
		lat: 35.2626635,
		lng: -77.5816353
	}
};
var kirksville_mo = {
	name: "Kirksville, MO",
	value: {
		lat: 40.19475389999999,
		lng: -92.5832496
	}
};
var klamath_falls_or = {
	name: "Klamath Falls, OR",
	value: {
		lat: 42.224867,
		lng: -121.7816704
	}
};
var knoxville_tn = {
	name: "Knoxville, TN",
	value: {
		lat: 35.9606384,
		lng: -83.9207392
	}
};
var kodiak_ak = {
	name: "Kodiak, AK",
	value: {
		lat: 57.79000000000001,
		lng: -152.4072222
	}
};
var kokomo_in = {
	name: "Kokomo, IN",
	value: {
		lat: 40.486427,
		lng: -86.13360329999999
	}
};
var la_crosse_wi_mn = {
	name: "La Crosse, WI-MN",
	value: {
		lat: 43.8013556,
		lng: -91.23958069999999
	}
};
var la_follette_tn = {
	name: "La Follette, TN",
	value: {
		lat: 36.3828852,
		lng: -84.1199472
	}
};
var la_grande_or = {
	name: "La Grande, OR",
	value: {
		lat: 45.3245771,
		lng: -118.0877188
	}
};
var lagrange_ga = {
	name: "LaGrange, GA",
	value: {
		lat: 33.0362218,
		lng: -85.0322444
	}
};
var laconia_nh = {
	name: "Laconia, NH",
	value: {
		lat: 43.5278546,
		lng: -71.4703509
	}
};
var lafayette_in = {
	name: "Lafayette, IN",
	value: {
		lat: 40.4167022,
		lng: -86.87528689999999
	}
};
var lafayette_la = {
	name: "Lafayette, LA",
	value: {
		lat: 30.2240897,
		lng: -92.0198427
	}
};
var lake_charles_la = {
	name: "Lake Charles, LA",
	value: {
		lat: 30.2265949,
		lng: -93.2173758
	}
};
var lake_city_fl = {
	name: "Lake City, FL",
	value: {
		lat: 30.1896756,
		lng: -82.6392899
	}
};
var lake_havasu_city_kingman_az = {
	name: "Lake Havasu City-Kingman, AZ",
	value: {
		lat: 34.483901,
		lng: -114.3224548
	}
};
var lakeland_fl = {
	name: "Lakeland, FL",
	value: {
		lat: 28.0394654,
		lng: -81.9498042
	}
};
var lamesa_tx = {
	name: "Lamesa, TX",
	value: {
		lat: 32.7376001,
		lng: -101.950992
	}
};
var lancaster_pa = {
	name: "Lancaster, PA",
	value: {
		lat: 40.0378755,
		lng: -76.3055144
	}
};
var lancaster_sc = {
	name: "Lancaster, SC",
	value: {
		lat: 34.7204257,
		lng: -80.7709014
	}
};
var lansing_east_lansing_mi = {
	name: "Lansing-East Lansing, MI",
	value: {
		lat: 42.732535,
		lng: -84.5555347
	}
};
var laramie_wy = {
	name: "Laramie, WY",
	value: {
		lat: 41.3113669,
		lng: -105.5911007
	}
};
var laredo_tx = {
	name: "Laredo, TX",
	value: {
		lat: 27.5305671,
		lng: -99.48032409999999
	}
};
var las_cruces_nm = {
	name: "Las Cruces, NM",
	value: {
		lat: 32.3199396,
		lng: -106.7636538
	}
};
var las_vegas_nm = {
	name: "Las Vegas, NM",
	value: {
		lat: 35.5942137,
		lng: -105.2227978
	}
};
var las_vegas_paradise_nv = {
	name: "Las Vegas-Paradise, NV",
	value: {
		lat: 36.1699412,
		lng: -115.1398296
	}
};
var laurel_ms = {
	name: "Laurel, MS",
	value: {
		lat: 31.6940509,
		lng: -89.1306124
	}
};
var laurinburg_nc = {
	name: "Laurinburg, NC",
	value: {
		lat: 34.7740494,
		lng: -79.46282479999999
	}
};
var lawrence_ks = {
	name: "Lawrence, KS",
	value: {
		lat: 38.9716689,
		lng: -95.2352501
	}
};
var lawrenceburg_tn = {
	name: "Lawrenceburg, TN",
	value: {
		lat: 35.2423023,
		lng: -87.33473889999999
	}
};
var lawton_ok = {
	name: "Lawton, OK",
	value: {
		lat: 34.6035669,
		lng: -98.39592909999999
	}
};
var lebanon_mo = {
	name: "Lebanon, MO",
	value: {
		lat: 37.6805967,
		lng: -92.6637865
	}
};
var lebanon_nh_vt = {
	name: "Lebanon, NH-VT",
	value: {
		lat: 43.6422934,
		lng: -72.2517569
	}
};
var lebanon_pa = {
	name: "Lebanon, PA",
	value: {
		lat: 40.3409251,
		lng: -76.4113497
	}
};
var levelland_tx = {
	name: "Levelland, TX",
	value: {
		lat: 33.5873164,
		lng: -102.37796
	}
};
var lewisburg_pa = {
	name: "Lewisburg, PA",
	value: {
		lat: 40.9645293,
		lng: -76.8844101
	}
};
var lewisburg_tn = {
	name: "Lewisburg, TN",
	value: {
		lat: 35.4492404,
		lng: -86.7888887
	}
};
var lewiston_id_wa = {
	name: "Lewiston, ID-WA",
	value: {
		lat: 46.4004089,
		lng: -117.0011889
	}
};
var lewiston_auburn_me = {
	name: "Lewiston-Auburn, ME",
	value: {
		lat: 44.100351,
		lng: -70.21477639999999
	}
};
var lewistown_pa = {
	name: "Lewistown, PA",
	value: {
		lat: 40.5992395,
		lng: -77.571382
	}
};
var lexington_park_md = {
	name: "Lexington Park, MD",
	value: {
		lat: 38.2575517,
		lng: -76.4620928
	}
};
var lexington_ne = {
	name: "Lexington, NE",
	value: {
		lat: 40.7808398,
		lng: -99.74150449999999
	}
};
var lexington_fayette_ky = {
	name: "Lexington-Fayette, KY",
	value: {
		lat: 38.0405837,
		lng: -84.5037164
	}
};
var liberal_ks = {
	name: "Liberal, KS",
	value: {
		lat: 37.0430812,
		lng: -100.920999
	}
};
var lima_oh = {
	name: "Lima, OH",
	value: {
		lat: 40.742551,
		lng: -84.1052256
	}
};
var lincoln_il = {
	name: "Lincoln, IL",
	value: {
		lat: 40.1483768,
		lng: -89.3648183
	}
};
var lincoln_ne = {
	name: "Lincoln, NE",
	value: {
		lat: 40.8257625,
		lng: -96.6851982
	}
};
var lincolnton_nc = {
	name: "Lincolnton, NC",
	value: {
		lat: 35.473745,
		lng: -81.2545251
	}
};
var little_rock_north_little_rock_conway_ar = {
	name: "Little Rock-North Little Rock-Conway, AR",
	value: {
		lat: 34.7464809,
		lng: -92.28959479999999
	}
};
var lock_haven_pa = {
	name: "Lock Haven, PA",
	value: {
		lat: 41.1370133,
		lng: -77.4469263
	}
};
var logan_ut_id = {
	name: "Logan, UT-ID",
	value: {
		lat: 41.7369803,
		lng: -111.8338359
	}
};
var logansport_in = {
	name: "Logansport, IN",
	value: {
		lat: 40.7544843,
		lng: -86.3566659
	}
};
var london_ky = {
	name: "London, KY",
	value: {
		lat: 37.1289771,
		lng: -84.08326459999999
	}
};
var longview_tx = {
	name: "Longview, TX",
	value: {
		lat: 32.5007037,
		lng: -94.74048909999999
	}
};
var longview_wa = {
	name: "Longview, WA",
	value: {
		lat: 46.1381676,
		lng: -122.9381672
	}
};
var los_alamos_nm = {
	name: "Los Alamos, NM",
	value: {
		lat: 35.8800364,
		lng: -106.3031138
	}
};
var los_angeles_long_beach_santa_ana_ca = {
	name: "Los Angeles-Long Beach-Santa Ana, CA",
	value: {
		lat: 34.0522342,
		lng: -118.2436849
	}
};
var lubbock_tx = {
	name: "Lubbock, TX",
	value: {
		lat: 33.5778631,
		lng: -101.8551665
	}
};
var lufkin_tx = {
	name: "Lufkin, TX",
	value: {
		lat: 31.3382406,
		lng: -94.729097
	}
};
var lumberton_nc = {
	name: "Lumberton, NC",
	value: {
		lat: 34.6182199,
		lng: -79.0086424
	}
};
var lynchburg_va = {
	name: "Lynchburg, VA",
	value: {
		lat: 37.4137536,
		lng: -79.14224639999999
	}
};
var macomb_il = {
	name: "Macomb, IL",
	value: {
		lat: 40.4592076,
		lng: -90.67179709999999
	}
};
var macon_ga = {
	name: "Macon, GA",
	value: {
		lat: 32.8406946,
		lng: -83.6324022
	}
};
var madera_ca = {
	name: "Madera, CA",
	value: {
		lat: 36.9613356,
		lng: -120.0607176
	}
};
var madison_in = {
	name: "Madison, IN",
	value: {
		lat: 38.7358933,
		lng: -85.37995769999999
	}
};
var madison_wi = {
	name: "Madison, WI",
	value: {
		lat: 43.0730517,
		lng: -89.4012302
	}
};
var madisonville_ky = {
	name: "Madisonville, KY",
	value: {
		lat: 37.32810050000001,
		lng: -87.4988882
	}
};
var magnolia_ar = {
	name: "Magnolia, AR",
	value: {
		lat: 33.2670725,
		lng: -93.239334
	}
};
var malone_ny = {
	name: "Malone, NY",
	value: {
		lat: 44.8486596,
		lng: -74.29489830000001
	}
};
var manchester_nashua_nh = {
	name: "Manchester-Nashua, NH",
	value: {
		lat: 42.9956397,
		lng: -71.4547891
	}
};
var manhattan_ks = {
	name: "Manhattan, KS",
	value: {
		lat: 39.18360819999999,
		lng: -96.57166939999999
	}
};
var manitowoc_wi = {
	name: "Manitowoc, WI",
	value: {
		lat: 44.0886059,
		lng: -87.657584
	}
};
var mankato_north_mankato_mn = {
	name: "Mankato-North Mankato, MN",
	value: {
		lat: 44.1635775,
		lng: -93.99939959999999
	}
};
var mansfield_oh = {
	name: "Mansfield, OH",
	value: {
		lat: 40.75839,
		lng: -82.5154471
	}
};
var marinette_wi_mi = {
	name: "Marinette, WI-MI",
	value: {
		lat: 45.0999849,
		lng: -87.6306623
	}
};
var marion_in = {
	name: "Marion, IN",
	value: {
		lat: 40.5583739,
		lng: -85.6591442
	}
};
var marion_oh = {
	name: "Marion, OH",
	value: {
		lat: 40.5886699,
		lng: -83.1285242
	}
};
var marion_herrin_il = {
	name: "Marion-Herrin, IL",
	value: {
		lat: 37.7306054,
		lng: -88.9331256
	}
};
var marquette_mi = {
	name: "Marquette, MI",
	value: {
		lat: 46.5475825,
		lng: -87.39559539999999
	}
};
var marshall_mn = {
	name: "Marshall, MN",
	value: {
		lat: 44.448423,
		lng: -95.79119159999999
	}
};
var marshall_mo = {
	name: "Marshall, MO",
	value: {
		lat: 39.1230777,
		lng: -93.1968704
	}
};
var marshall_tx = {
	name: "Marshall, TX",
	value: {
		lat: 32.5448714,
		lng: -94.36741839999999
	}
};
var marshalltown_ia = {
	name: "Marshalltown, IA",
	value: {
		lat: 42.0494674,
		lng: -92.90803749999999
	}
};
var marshfield_wisconsin_rapids_wi = {
	name: "Marshfield-Wisconsin Rapids, WI",
	value: {
		lat: 44.6688524,
		lng: -90.1717987
	}
};
var martin_tn = {
	name: "Martin, TN",
	value: {
		lat: 36.3433965,
		lng: -88.8503379
	}
};
var martinsville_va = {
	name: "Martinsville, VA",
	value: {
		lat: 36.6915262,
		lng: -79.8725386
	}
};
var maryville_mo = {
	name: "Maryville, MO",
	value: {
		lat: 40.3461017,
		lng: -94.8724706
	}
};
var mason_city_ia = {
	name: "Mason City, IA",
	value: {
		lat: 43.1535728,
		lng: -93.20103669999999
	}
};
var mayaguez_pr = {
	name: "Mayaguez, PR",
	value: {
		lat: 18.1534243863,
		lng: -67.13833944669
	}
};
var mayfield_ky = {
	name: "Mayfield, KY",
	value: {
		lat: 36.7417235,
		lng: -88.6367154
	}
};
var maysville_ky = {
	name: "Maysville, KY",
	value: {
		lat: 38.6411854,
		lng: -83.744365
	}
};
var mcalester_ok = {
	name: "McAlester, OK",
	value: {
		lat: 34.9334298,
		lng: -95.76971309999999
	}
};
var mcallen_edinburg_mission_tx = {
	name: "McAllen-Edinburg-Mission, TX",
	value: {
		lat: 26.2034071,
		lng: -98.23001239999999
	}
};
var mccomb_ms = {
	name: "McComb, MS",
	value: {
		lat: 31.2437872,
		lng: -90.4531535
	}
};
var mcminnville_tn = {
	name: "McMinnville, TN",
	value: {
		lat: 35.6865889,
		lng: -85.7801453
	}
};
var mcpherson_ks = {
	name: "McPherson, KS",
	value: {
		lat: 38.3708415,
		lng: -97.66420869999999
	}
};
var meadville_pa = {
	name: "Meadville, PA",
	value: {
		lat: 41.6414438,
		lng: -80.15144839999999
	}
};
var medford_or = {
	name: "Medford, OR",
	value: {
		lat: 42.3265152,
		lng: -122.8755949
	}
};
var memphis_tn_ms_ar = {
	name: "Memphis, TN-MS-AR",
	value: {
		lat: 35.1495343,
		lng: -90.0489801
	}
};
var menomonie_wi = {
	name: "Menomonie, WI",
	value: {
		lat: 44.8755183,
		lng: -91.9193422
	}
};
var merced_ca = {
	name: "Merced, CA",
	value: {
		lat: 37.3021632,
		lng: -120.4829677
	}
};
var meridian_ms = {
	name: "Meridian, MS",
	value: {
		lat: 32.3643098,
		lng: -88.703656
	}
};
var merrill_wi = {
	name: "Merrill, WI",
	value: {
		lat: 45.1805223,
		lng: -89.683459
	}
};
var mexico_mo = {
	name: "Mexico, MO",
	value: {
		lat: 39.1730652,
		lng: -91.887271
	}
};
var miami_ok = {
	name: "Miami, OK",
	value: {
		lat: 36.8745146,
		lng: -94.8774554
	}
};
var miami_fort_lauderdale_pompano_beach_fl = {
	name: "Miami-Fort Lauderdale-Pompano Beach, FL",
	value: {
		lat: 25.7616798,
		lng: -80.1917902
	}
};
var michigan_city_la_porte_in = {
	name: "Michigan City-La Porte, IN",
	value: {
		lat: 41.70753939999999,
		lng: -86.8950297
	}
};
var middlesborough_ky = {
	name: "Middlesborough, KY",
	value: {
		lat: 36.6072567,
		lng: -83.7142848
	}
};
var midland_mi = {
	name: "Midland, MI",
	value: {
		lat: 43.6155825,
		lng: -84.2472116
	}
};
var midland_tx = {
	name: "Midland, TX",
	value: {
		lat: 31.9973456,
		lng: -102.0779146
	}
};
var milledgeville_ga = {
	name: "Milledgeville, GA",
	value: {
		lat: 33.0801429,
		lng: -83.2320991
	}
};
var milwaukee_waukesha_west_allis_wi = {
	name: "Milwaukee-Waukesha-West Allis, WI",
	value: {
		lat: 43.0389025,
		lng: -87.9064736
	}
};
var minden_la = {
	name: "Minden, LA",
	value: {
		lat: 32.6154278,
		lng: -93.2868354
	}
};
var mineral_wells_tx = {
	name: "Mineral Wells, TX",
	value: {
		lat: 32.8084605,
		lng: -98.1128223
	}
};
var minneapolis_st_paul_bloomington_mn_wi = {
	name: "Minneapolis-St. Paul-Bloomington, MN-WI",
	value: {
		lat: 44.977753,
		lng: -93.2650108
	}
};
var minot_nd = {
	name: "Minot, ND",
	value: {
		lat: 48.2329668,
		lng: -101.2922906
	}
};
var missoula_mt = {
	name: "Missoula, MT",
	value: {
		lat: 46.87871759999999,
		lng: -113.996586
	}
};
var mitchell_sd = {
	name: "Mitchell, SD",
	value: {
		lat: 43.7094283,
		lng: -98.0297992
	}
};
var moberly_mo = {
	name: "Moberly, MO",
	value: {
		lat: 39.4183689,
		lng: -92.43823669999999
	}
};
var mobile_al = {
	name: "Mobile, AL",
	value: {
		lat: 30.6953657,
		lng: -88.0398912
	}
};
var modesto_ca = {
	name: "Modesto, CA",
	value: {
		lat: 37.63909719999999,
		lng: -120.9968782
	}
};
var monroe_la = {
	name: "Monroe, LA",
	value: {
		lat: 32.5093109,
		lng: -92.1193012
	}
};
var monroe_mi = {
	name: "Monroe, MI",
	value: {
		lat: 41.9164343,
		lng: -83.3977101
	}
};
var monroe_wi = {
	name: "Monroe, WI",
	value: {
		lat: 42.60111939999999,
		lng: -89.6384532
	}
};
var montgomery_al = {
	name: "Montgomery, AL",
	value: {
		lat: 32.3668052,
		lng: -86.2999689
	}
};
var montrose_co = {
	name: "Montrose, CO",
	value: {
		lat: 38.4783198,
		lng: -107.8761738
	}
};
var morehead_city_nc = {
	name: "Morehead City, NC",
	value: {
		lat: 34.7229391,
		lng: -76.7260436
	}
};
var morgan_city_la = {
	name: "Morgan City, LA",
	value: {
		lat: 29.6993748,
		lng: -91.20676999999999
	}
};
var morgantown_wv = {
	name: "Morgantown, WV",
	value: {
		lat: 39.629526,
		lng: -79.95589679999999
	}
};
var morristown_tn = {
	name: "Morristown, TN",
	value: {
		lat: 36.2139814,
		lng: -83.29489219999999
	}
};
var moscow_id = {
	name: "Moscow, ID",
	value: {
		lat: 46.73238749999999,
		lng: -117.0001651
	}
};
var moses_lake_wa = {
	name: "Moses Lake, WA",
	value: {
		lat: 47.1301417,
		lng: -119.2780771
	}
};
var moultrie_ga = {
	name: "Moultrie, GA",
	value: {
		lat: 31.1799407,
		lng: -83.7888387
	}
};
var mount_airy_nc = {
	name: "Mount Airy, NC",
	value: {
		lat: 36.4993007,
		lng: -80.6072858
	}
};
var mount_pleasant_mi = {
	name: "Mount Pleasant, MI",
	value: {
		lat: 43.59780749999999,
		lng: -84.7675139
	}
};
var mount_pleasant_tx = {
	name: "Mount Pleasant, TX",
	value: {
		lat: 33.1567863,
		lng: -94.96826899999999
	}
};
var mount_sterling_ky = {
	name: "Mount Sterling, KY",
	value: {
		lat: 38.0564679,
		lng: -83.9432556
	}
};
var mount_vernon_il = {
	name: "Mount Vernon, IL",
	value: {
		lat: 38.3172714,
		lng: -88.9031201
	}
};
var mount_vernon_oh = {
	name: "Mount Vernon, OH",
	value: {
		lat: 40.3933956,
		lng: -82.4857181
	}
};
var mount_vernon_anacortes_wa = {
	name: "Mount Vernon-Anacortes, WA",
	value: {
		lat: 48.421216,
		lng: -122.3340474
	}
};
var mountain_home_ar = {
	name: "Mountain Home, AR",
	value: {
		lat: 36.3353949,
		lng: -92.381346
	}
};
var mountain_home_id = {
	name: "Mountain Home, ID",
	value: {
		lat: 43.1329504,
		lng: -115.6911975
	}
};
var muncie_in = {
	name: "Muncie, IN",
	value: {
		lat: 40.1933767,
		lng: -85.3863599
	}
};
var murray_ky = {
	name: "Murray, KY",
	value: {
		lat: 36.6103334,
		lng: -88.31476099999999
	}
};
var muscatine_ia = {
	name: "Muscatine, IA",
	value: {
		lat: 41.424473,
		lng: -91.0432051
	}
};
var muskegon_norton_shores_mi = {
	name: "Muskegon-Norton Shores, MI",
	value: {
		lat: 43.2341813,
		lng: -86.24839209999999
	}
};
var muskogee_ok = {
	name: "Muskogee, OK",
	value: {
		lat: 35.7478769,
		lng: -95.3696909
	}
};
var myrtle_beach_conway_north_myrtle_beach_sc = {
	name: "Myrtle Beach-Conway-North Myrtle Beach, SC",
	value: {
		lat: 33.6890603,
		lng: -78.8866943
	}
};
var nacogdoches_tx = {
	name: "Nacogdoches, TX",
	value: {
		lat: 31.6035129,
		lng: -94.6554874
	}
};
var napa_ca = {
	name: "Napa, CA",
	value: {
		lat: 38.2975381,
		lng: -122.286865
	}
};
var naples_marco_island_fl = {
	name: "Naples-Marco Island, FL",
	value: {
		lat: 26.1420358,
		lng: -81.7948103
	}
};
var nashville_davidson_murfreesboro_franklin_tn = {
	name: "Nashville-Davidson--Murfreesboro--Franklin, TN",
	value: {
		lat: 36.1626638,
		lng: -86.7816016
	}
};
var natchez_ms_la = {
	name: "Natchez, MS-LA",
	value: {
		lat: 31.5604442,
		lng: -91.40317100000001
	}
};
var natchitoches_la = {
	name: "Natchitoches, LA",
	value: {
		lat: 31.7607195,
		lng: -93.08627489999999
	}
};
var new_bern_nc = {
	name: "New Bern, NC",
	value: {
		lat: 35.108493,
		lng: -77.04411429999999
	}
};
var new_castle_in = {
	name: "New Castle, IN",
	value: {
		lat: 39.928935,
		lng: -85.3702476
	}
};
var new_castle_pa = {
	name: "New Castle, PA",
	value: {
		lat: 41.0036719,
		lng: -80.34700900000001
	}
};
var new_haven_milford_ct = {
	name: "New Haven-Milford, CT",
	value: {
		lat: 41.308274,
		lng: -72.9278835
	}
};
var new_iberia_la = {
	name: "New Iberia, LA",
	value: {
		lat: 30.0035365,
		lng: -91.81872849999999
	}
};
var new_orleans_metairie_kenner_la = {
	name: "New Orleans-Metairie-Kenner, LA",
	value: {
		lat: 29.95106579999999,
		lng: -90.0715323
	}
};
var new_philadelphia_dover_oh = {
	name: "New Philadelphia-Dover, OH",
	value: {
		lat: 40.4897871,
		lng: -81.4456706
	}
};
var new_ulm_mn = {
	name: "New Ulm, MN",
	value: {
		lat: 44.3144394,
		lng: -94.45930179999999
	}
};
var new_york_northern_new_jersey_long_island_ny_nj_pa = {
	name: "New York-Northern New Jersey-Long Island, NY-NJ-PA",
	value: {
		lat: 40.7127837,
		lng: -74.0059413
	}
};
var newberry_sc = {
	name: "Newberry, SC",
	value: {
		lat: 34.2745833,
		lng: -81.6187178
	}
};
var newport_tn = {
	name: "Newport, TN",
	value: {
		lat: 35.9670412,
		lng: -83.1876578
	}
};
var newton_ia = {
	name: "Newton, IA",
	value: {
		lat: 41.7033177,
		lng: -93.05735330000002
	}
};
var niles_benton_harbor_mi = {
	name: "Niles-Benton Harbor, MI",
	value: {
		lat: 41.8297694,
		lng: -86.2541768
	}
};
var nogales_az = {
	name: "Nogales, AZ",
	value: {
		lat: 31.3403775,
		lng: -110.9342532
	}
};
var norfolk_ne = {
	name: "Norfolk, NE",
	value: {
		lat: 42.03272339999999,
		lng: -97.41375529999999
	}
};
var north_platte_ne = {
	name: "North Platte, NE",
	value: {
		lat: 41.1402759,
		lng: -100.7601454
	}
};
var north_vernon_in = {
	name: "North Vernon, IN",
	value: {
		lat: 39.006165,
		lng: -85.6235796
	}
};
var north_wilkesboro_nc = {
	name: "North Wilkesboro, NC",
	value: {
		lat: 36.1584651,
		lng: -81.1475841
	}
};
var norwalk_oh = {
	name: "Norwalk, OH",
	value: {
		lat: 41.24255309999999,
		lng: -82.6157331
	}
};
var norwich_new_london_ct = {
	name: "Norwich-New London, CT",
	value: {
		lat: 41.5242649,
		lng: -72.07591049999999
	}
};
var oak_harbor_wa = {
	name: "Oak Harbor, WA",
	value: {
		lat: 48.2931559,
		lng: -122.6432245
	}
};
var oak_hill_wv = {
	name: "Oak Hill, WV",
	value: {
		lat: 37.9723339,
		lng: -81.1487135
	}
};
var ocala_fl = {
	name: "Ocala, FL",
	value: {
		lat: 29.1871986,
		lng: -82.14009229999999
	}
};
var ocean_city_nj = {
	name: "Ocean City, NJ",
	value: {
		lat: 39.2776156,
		lng: -74.5746001
	}
};
var ocean_pines_md = {
	name: "Ocean Pines, MD",
	value: {
		lat: 38.395392,
		lng: -75.15574149999999
	}
};
var odessa_tx = {
	name: "Odessa, TX",
	value: {
		lat: 31.8456816,
		lng: -102.3676431
	}
};
var ogden_clearfield_ut = {
	name: "Ogden-Clearfield, UT",
	value: {
		lat: 41.223,
		lng: -111.9738304
	}
};
var ogdensburg_massena_ny = {
	name: "Ogdensburg-Massena, NY",
	value: {
		lat: 44.6942291,
		lng: -75.48633640000001
	}
};
var oil_city_pa = {
	name: "Oil City, PA",
	value: {
		lat: 41.4339484,
		lng: -79.7064413
	}
};
var okeechobee_fl = {
	name: "Okeechobee, FL",
	value: {
		lat: 27.2439349,
		lng: -80.82978279999999
	}
};
var oklahoma_city_ok = {
	name: "Oklahoma City, OK",
	value: {
		lat: 35.4675602,
		lng: -97.5164276
	}
};
var olean_ny = {
	name: "Olean, NY",
	value: {
		lat: 42.083639,
		lng: -78.42992699999999
	}
};
var olympia_wa = {
	name: "Olympia, WA",
	value: {
		lat: 47.0378741,
		lng: -122.9006951
	}
};
var omaha_council_bluffs_ne_ia = {
	name: "Omaha-Council Bluffs, NE-IA",
	value: {
		lat: 41.2523634,
		lng: -95.99798829999999
	}
};
var oneonta_ny = {
	name: "Oneonta, NY",
	value: {
		lat: 42.4528571,
		lng: -75.0637746
	}
};
var ontario_or_id = {
	name: "Ontario, OR-ID",
	value: {
		lat: 44.0265525,
		lng: -116.9629378
	}
};
var opelousas_eunice_la = {
	name: "Opelousas-Eunice, LA",
	value: {
		lat: 30.5335302,
		lng: -92.081509
	}
};
var orangeburg_sc = {
	name: "Orangeburg, SC",
	value: {
		lat: 33.4918203,
		lng: -80.8556476
	}
};
var orlando_kissimmee_fl = {
	name: "Orlando-Kissimmee, FL",
	value: {
		lat: 28.5383355,
		lng: -81.3792365
	}
};
var oshkosh_neenah_wi = {
	name: "Oshkosh-Neenah, WI",
	value: {
		lat: 44.0247062,
		lng: -88.5426136
	}
};
var oskaloosa_ia = {
	name: "Oskaloosa, IA",
	value: {
		lat: 41.2916728,
		lng: -92.6493595
	}
};
var ottawa_streator_il = {
	name: "Ottawa-Streator, IL",
	value: {
		lat: 41.3455892,
		lng: -88.8425769
	}
};
var ottumwa_ia = {
	name: "Ottumwa, IA",
	value: {
		lat: 41.01602930000001,
		lng: -92.40830220000001
	}
};
var owatonna_mn = {
	name: "Owatonna, MN",
	value: {
		lat: 44.0855572,
		lng: -93.2259349
	}
};
var owensboro_ky = {
	name: "Owensboro, KY",
	value: {
		lat: 37.7719074,
		lng: -87.1111676
	}
};
var owosso_mi = {
	name: "Owosso, MI",
	value: {
		lat: 42.9978049,
		lng: -84.1766358
	}
};
var oxford_ms = {
	name: "Oxford, MS",
	value: {
		lat: 34.3664951,
		lng: -89.5192484
	}
};
var oxnard_thousand_oaks_ventura_ca = {
	name: "Oxnard-Thousand Oaks-Ventura, CA",
	value: {
		lat: 34.1975048,
		lng: -119.1770516
	}
};
var paducah_ky_il = {
	name: "Paducah, KY-IL",
	value: {
		lat: 37.0833893,
		lng: -88.6000478
	}
};
var pahrump_nv = {
	name: "Pahrump, NV",
	value: {
		lat: 36.2082943,
		lng: -115.9839147
	}
};
var palatka_fl = {
	name: "Palatka, FL",
	value: {
		lat: 29.6485801,
		lng: -81.6375819
	}
};
var palestine_tx = {
	name: "Palestine, TX",
	value: {
		lat: 31.7621153,
		lng: -95.6307891
	}
};
var palm_bay_melbourne_titusville_fl = {
	name: "Palm Bay-Melbourne-Titusville, FL",
	value: {
		lat: 28.0344621,
		lng: -80.5886646
	}
};
var palm_coast_fl = {
	name: "Palm Coast, FL",
	value: {
		lat: 29.5844524,
		lng: -81.20786989999999
	}
};
var pampa_tx = {
	name: "Pampa, TX",
	value: {
		lat: 35.5361559,
		lng: -100.9598709
	}
};
var panama_city_lynn_haven_fl = {
	name: "Panama City-Lynn Haven, FL",
	value: {
		lat: 30.1588129,
		lng: -85.6602058
	}
};
var paragould_ar = {
	name: "Paragould, AR",
	value: {
		lat: 36.0584021,
		lng: -90.4973286
	}
};
var paris_tn = {
	name: "Paris, TN",
	value: {
		lat: 36.3020023,
		lng: -88.32671069999999
	}
};
var paris_tx = {
	name: "Paris, TX",
	value: {
		lat: 33.6609389,
		lng: -95.55551299999999
	}
};
var parkersburg_marietta_vienna_wv_oh = {
	name: "Parkersburg-Marietta-Vienna, WV-OH",
	value: {
		lat: 39.2667418,
		lng: -81.56151349999999
	}
};
var parsons_ks = {
	name: "Parsons, KS",
	value: {
		lat: 37.34033840000001,
		lng: -95.2610838
	}
};
var pascagoula_ms = {
	name: "Pascagoula, MS",
	value: {
		lat: 30.3657552,
		lng: -88.5561272
	}
};
var payson_az = {
	name: "Payson, AZ",
	value: {
		lat: 34.2308684,
		lng: -111.3251355
	}
};
var pecos_tx = {
	name: "Pecos, TX",
	value: {
		lat: 31.4229124,
		lng: -103.4932293
	}
};
var pella_ia = {
	name: "Pella, IA",
	value: {
		lat: 41.4080327,
		lng: -92.91640500000001
	}
};
var pendleton_hermiston_or = {
	name: "Pendleton-Hermiston, OR",
	value: {
		lat: 45.672075,
		lng: -118.7885967
	}
};
var pensacola_ferry_pass_brent_fl = {
	name: "Pensacola-Ferry Pass-Brent, FL",
	value: {
		lat: 30.42130899999999,
		lng: -87.2169149
	}
};
var peoria_il = {
	name: "Peoria, IL",
	value: {
		lat: 40.6936488,
		lng: -89.5889864
	}
};
var peru_in = {
	name: "Peru, IN",
	value: {
		lat: 40.7536528,
		lng: -86.0688811
	}
};
var philadelphia_camden_wilmington_pa_nj_de_md = {
	name: "Philadelphia-Camden-Wilmington, PA-NJ-DE-MD",
	value: {
		lat: 39.9525839,
		lng: -75.1652215
	}
};
var phoenix_lake_cedar_ridge_ca = {
	name: "Phoenix Lake-Cedar Ridge, CA",
	value: {
		lat: 39.3754055,
		lng: -120.5225122
	}
};
var phoenix_mesa_scottsdale_az = {
	name: "Phoenix-Mesa-Scottsdale, AZ",
	value: {
		lat: 33.4483771,
		lng: -112.0740373
	}
};
var picayune_ms = {
	name: "Picayune, MS",
	value: {
		lat: 30.5254692,
		lng: -89.67950839999999
	}
};
var pierre_part_la = {
	name: "Pierre Part, LA",
	value: {
		lat: 29.9652016,
		lng: -91.2031593
	}
};
var pierre_sd = {
	name: "Pierre, SD",
	value: {
		lat: 44.3683156,
		lng: -100.3509665
	}
};
var pine_bluff_ar = {
	name: "Pine Bluff, AR",
	value: {
		lat: 34.2284312,
		lng: -92.00319549999999
	}
};
var pittsburg_ks = {
	name: "Pittsburg, KS",
	value: {
		lat: 37.410884,
		lng: -94.70496
	}
};
var pittsburgh_pa = {
	name: "Pittsburgh, PA",
	value: {
		lat: 40.44062479999999,
		lng: -79.9958864
	}
};
var pittsfield_ma = {
	name: "Pittsfield, MA",
	value: {
		lat: 42.4500845,
		lng: -73.2453824
	}
};
var plainview_tx = {
	name: "Plainview, TX",
	value: {
		lat: 34.1847936,
		lng: -101.7068417
	}
};
var platteville_wi = {
	name: "Platteville, WI",
	value: {
		lat: 42.73416,
		lng: -90.4784621
	}
};
var plattsburgh_ny = {
	name: "Plattsburgh, NY",
	value: {
		lat: 44.6994873,
		lng: -73.4529124
	}
};
var plymouth_in = {
	name: "Plymouth, IN",
	value: {
		lat: 41.3436554,
		lng: -86.3097278
	}
};
var pocatello_id = {
	name: "Pocatello, ID",
	value: {
		lat: 42.8713032,
		lng: -112.4455344
	}
};
var point_pleasant_wv_oh = {
	name: "Point Pleasant, WV-OH",
	value: {
		lat: 38.8445251,
		lng: -82.1370889
	}
};
var ponca_city_ok = {
	name: "Ponca City, OK",
	value: {
		lat: 36.706981,
		lng: -97.0855948
	}
};
var ponce_pr = {
	name: "Ponce, PR",
	value: {
		lat: 18.01108,
		lng: -66.61406
	}
};
var pontiac_il = {
	name: "Pontiac, IL",
	value: {
		lat: 40.8808666,
		lng: -88.62978389999999
	}
};
var poplar_bluff_mo = {
	name: "Poplar Bluff, MO",
	value: {
		lat: 36.7569994,
		lng: -90.392888
	}
};
var port_angeles_wa = {
	name: "Port Angeles, WA",
	value: {
		lat: 48.118146,
		lng: -123.4307413
	}
};
var port_st_lucie_fl = {
	name: "Port St. Lucie, FL",
	value: {
		lat: 27.2730492,
		lng: -80.3582261
	}
};
var portales_nm = {
	name: "Portales, NM",
	value: {
		lat: 34.1861922,
		lng: -103.3343978
	}
};
var portland_south_portland_biddeford_me = {
	name: "Portland-South Portland-Biddeford, ME",
	value: {
		lat: 43.66147100000001,
		lng: -70.2553259
	}
};
var portland_vancouver_beaverton_or_wa = {
	name: "Portland-Vancouver-Beaverton, OR-WA",
	value: {
		lat: 45.5230622,
		lng: -122.6764816
	}
};
var portsmouth_oh = {
	name: "Portsmouth, OH",
	value: {
		lat: 38.7317431,
		lng: -82.9976742
	}
};
var pottsville_pa = {
	name: "Pottsville, PA",
	value: {
		lat: 40.6856456,
		lng: -76.195499
	}
};
var poughkeepsie_newburgh_middletown_ny = {
	name: "Poughkeepsie-Newburgh-Middletown, NY",
	value: {
		lat: 41.7003713,
		lng: -73.9209701
	}
};
var prescott_az = {
	name: "Prescott, AZ",
	value: {
		lat: 34.5400242,
		lng: -112.4685025
	}
};
var price_ut = {
	name: "Price, UT",
	value: {
		lat: 39.5994095,
		lng: -110.8107148
	}
};
var prineville_or = {
	name: "Prineville, OR",
	value: {
		lat: 44.2998485,
		lng: -120.8344664
	}
};
var providence_new_bedford_fall_river_ri_ma = {
	name: "Providence-New Bedford-Fall River, RI-MA",
	value: {
		lat: 41.8239891,
		lng: -71.4128343
	}
};
var provo_orem_ut = {
	name: "Provo-Orem, UT",
	value: {
		lat: 40.2338438,
		lng: -111.6585337
	}
};
var pueblo_co = {
	name: "Pueblo, CO",
	value: {
		lat: 38.2544472,
		lng: -104.6091409
	}
};
var pullman_wa = {
	name: "Pullman, WA",
	value: {
		lat: 46.7297771,
		lng: -117.1817377
	}
};
var punta_gorda_fl = {
	name: "Punta Gorda, FL",
	value: {
		lat: 26.9297836,
		lng: -82.0453664
	}
};
var quincy_il_mo = {
	name: "Quincy, IL-MO",
	value: {
		lat: 39.9356016,
		lng: -91.4098726
	}
};
var racine_wi = {
	name: "Racine, WI",
	value: {
		lat: 42.7261309,
		lng: -87.78285230000002
	}
};
var raleigh_cary_nc = {
	name: "Raleigh-Cary, NC",
	value: {
		lat: 35.7795897,
		lng: -78.6381787
	}
};
var rapid_city_sd = {
	name: "Rapid City, SD",
	value: {
		lat: 44.0805434,
		lng: -103.2310149
	}
};
var raymondville_tx = {
	name: "Raymondville, TX",
	value: {
		lat: 26.4814565,
		lng: -97.783051
	}
};
var reading_pa = {
	name: "Reading, PA",
	value: {
		lat: 40.3356483,
		lng: -75.9268747
	}
};
var red_bluff_ca = {
	name: "Red Bluff, CA",
	value: {
		lat: 40.1784886,
		lng: -122.2358302
	}
};
var red_wing_mn = {
	name: "Red Wing, MN",
	value: {
		lat: 44.5660691,
		lng: -92.5369563
	}
};
var redding_ca = {
	name: "Redding, CA",
	value: {
		lat: 40.5865396,
		lng: -122.3916754
	}
};
var reno_sparks_nv = {
	name: "Reno-Sparks, NV",
	value: {
		lat: 39.5296329,
		lng: -119.8138027
	}
};
var rexburg_id = {
	name: "Rexburg, ID",
	value: {
		lat: 43.8231096,
		lng: -111.7924237
	}
};
var richmond_in = {
	name: "Richmond, IN",
	value: {
		lat: 39.8289369,
		lng: -84.8902382
	}
};
var richmond_va = {
	name: "Richmond, VA",
	value: {
		lat: 37.5407246,
		lng: -77.4360481
	}
};
var richmond_berea_ky = {
	name: "Richmond Berea, KY",
	value: {
		lat: 37.6921707,
		lng: -84.2594969
	}
};
var rio_grande_city_roma_tx = {
	name: "Rio Grande City-Roma, TX",
	value: {
		lat: 26.3797874,
		lng: -98.8203046
	}
};
var riverside_san_bernardino_ontario_ca = {
	name: "Riverside-San Bernardino-Ontario, CA",
	value: {
		lat: 33.9533487,
		lng: -117.3961564
	}
};
var riverton_wy = {
	name: "Riverton, WY",
	value: {
		lat: 43.0249592,
		lng: -108.3801036
	}
};
var roanoke_rapids_nc = {
	name: "Roanoke Rapids, NC",
	value: {
		lat: 36.4615395,
		lng: -77.6541464
	}
};
var roanoke_va = {
	name: "Roanoke, VA",
	value: {
		lat: 37.2709704,
		lng: -79.9414266
	}
};
var rochelle_il = {
	name: "Rochelle, IL",
	value: {
		lat: 41.9239178,
		lng: -89.0687073
	}
};
var rochester_mn = {
	name: "Rochester, MN",
	value: {
		lat: 44.0121221,
		lng: -92.4801989
	}
};
var rochester_ny = {
	name: "Rochester, NY",
	value: {
		lat: 43.16103,
		lng: -77.6109219
	}
};
var rock_springs_wy = {
	name: "Rock Springs, WY",
	value: {
		lat: 41.58746439999999,
		lng: -109.2029043
	}
};
var rockford_il = {
	name: "Rockford, IL",
	value: {
		lat: 42.2711311,
		lng: -89.0939952
	}
};
var rockingham_nc = {
	name: "Rockingham, NC",
	value: {
		lat: 34.9393201,
		lng: -79.7739457
	}
};
var rockland_me = {
	name: "Rockland, ME",
	value: {
		lat: 44.1036914,
		lng: -69.1089293
	}
};
var rocky_mount_nc = {
	name: "Rocky Mount, NC",
	value: {
		lat: 35.9382103,
		lng: -77.7905339
	}
};
var rolla_mo = {
	name: "Rolla, MO",
	value: {
		lat: 37.948544,
		lng: -91.7715303
	}
};
var rome_ga = {
	name: "Rome, GA",
	value: {
		lat: 34.257038,
		lng: -85.1646726
	}
};
var roseburg_or = {
	name: "Roseburg, OR",
	value: {
		lat: 43.216505,
		lng: -123.3417381
	}
};
var roswell_nm = {
	name: "Roswell, NM",
	value: {
		lat: 33.3942655,
		lng: -104.5230242
	}
};
var ruidoso_nm = {
	name: "Ruidoso, NM",
	value: {
		lat: 33.3672525,
		lng: -105.6588485
	}
};
var russellville_ar = {
	name: "Russellville, AR",
	value: {
		lat: 35.2784173,
		lng: -93.1337856
	}
};
var ruston_la = {
	name: "Ruston, LA",
	value: {
		lat: 32.5232053,
		lng: -92.63792699999999
	}
};
var rutland_vt = {
	name: "Rutland, VT",
	value: {
		lat: 43.6106237,
		lng: -72.9726065
	}
};
var sacramento_arden_arcade_roseville_ca = {
	name: "Sacramento--Arden-Arcade--Roseville, CA",
	value: {
		lat: 38.5815719,
		lng: -121.4943996
	}
};
var safford_az = {
	name: "Safford, AZ",
	value: {
		lat: 32.8339546,
		lng: -109.70758
	}
};
var saginaw_saginaw_township_north_mi = {
	name: "Saginaw-Saginaw Township North, MI",
	value: {
		lat: 43.4194699,
		lng: -83.9508068
	}
};
var salem_or = {
	name: "Salem, OR",
	value: {
		lat: 44.9428975,
		lng: -123.0350963
	}
};
var salina_ks = {
	name: "Salina, KS",
	value: {
		lat: 38.8402805,
		lng: -97.61142369999999
	}
};
var salinas_ca = {
	name: "Salinas, CA",
	value: {
		lat: 36.6777372,
		lng: -121.6555013
	}
};
var salisbury_md = {
	name: "Salisbury, MD",
	value: {
		lat: 38.3606736,
		lng: -75.5993692
	}
};
var salisbury_nc = {
	name: "Salisbury, NC",
	value: {
		lat: 35.6709727,
		lng: -80.4742261
	}
};
var salt_lake_city_ut = {
	name: "Salt Lake City, UT",
	value: {
		lat: 40.7607793,
		lng: -111.8910474
	}
};
var san_angelo_tx = {
	name: "San Angelo, TX",
	value: {
		lat: 31.4637723,
		lng: -100.4370375
	}
};
var san_antonio_tx = {
	name: "San Antonio, TX",
	value: {
		lat: 29.4241219,
		lng: -98.49362819999999
	}
};
var san_diego_carlsbad_san_marcos_ca = {
	name: "San Diego-Carlsbad-San Marcos, CA",
	value: {
		lat: 32.715738,
		lng: -117.1610838
	}
};
var san_francisco_oakland_fremont_ca = {
	name: "San Francisco-Oakland-Fremont, CA",
	value: {
		lat: 37.7749295,
		lng: -122.4194155
	}
};
var san_german_cabo_rojo_pr = {
	name: "San German-Cabo Rojo, PR",
	value: {
		lat: 18.080708,
		lng: -67.041107
	}
};
var san_jose_sunnyvale_santa_clara_ca = {
	name: "San Jose-Sunnyvale-Santa Clara, CA",
	value: {
		lat: 37.3382082,
		lng: -121.8863286
	}
};
var san_juan_caguas_guaynabo_pr = {
	name: "San Juan-Caguas-Guaynabo, PR",
	value: {
		lat: 18.466333,
		lng: -66.105721
	}
};
var san_luis_obispo_paso_robles_ca = {
	name: "San Luis Obispo-Paso Robles, CA",
	value: {
		lat: 35.2827524,
		lng: -120.6596156
	}
};
var sandusky_oh = {
	name: "Sandusky, OH",
	value: {
		lat: 41.4489396,
		lng: -82.7079605
	}
};
var sanford_nc = {
	name: "Sanford, NC",
	value: {
		lat: 35.4798757,
		lng: -79.1802994
	}
};
var santa_barbara_santa_maria_goleta_ca = {
	name: "Santa Barbara-Santa Maria-Goleta, CA",
	value: {
		lat: 34.4208305,
		lng: -119.6981901
	}
};
var santa_cruz_watsonville_ca = {
	name: "Santa Cruz-Watsonville, CA",
	value: {
		lat: 36.9741171,
		lng: -122.0307963
	}
};
var santa_fe_nm = {
	name: "Santa Fe, NM",
	value: {
		lat: 35.6869752,
		lng: -105.937799
	}
};
var santa_isabel_pr = {
	name: "Santa Isabel, PR",
	value: {
		lat: 17.985792,
		lng: -66.391441
	}
};
var santa_rosa_petaluma_ca = {
	name: "Santa Rosa-Petaluma, CA",
	value: {
		lat: 38.440429,
		lng: -122.7140548
	}
};
var sarasota_bradenton_venice_fl = {
	name: "Sarasota-Bradenton-Venice, FL",
	value: {
		lat: 27.3364347,
		lng: -82.53065269999999
	}
};
var sault_ste_marie_mi = {
	name: "Sault Ste. Marie, MI",
	value: {
		lat: 46.4952996,
		lng: -84.3453169
	}
};
var savannah_ga = {
	name: "Savannah, GA",
	value: {
		lat: 32.0835407,
		lng: -81.09983419999999
	}
};
var sayre_pa = {
	name: "Sayre, PA",
	value: {
		lat: 41.9789631,
		lng: -76.51549899999999
	}
};
var scottsbluff_ne = {
	name: "Scottsbluff, NE",
	value: {
		lat: 41.8666341,
		lng: -103.6671662
	}
};
var scottsboro_al = {
	name: "Scottsboro, AL",
	value: {
		lat: 34.6723069,
		lng: -86.03414629999999
	}
};
var scottsburg_in = {
	name: "Scottsburg, IN",
	value: {
		lat: 38.685614,
		lng: -85.7702451
	}
};
var scranton_wilkes_barre_pa = {
	name: "Scranton--Wilkes-Barre, PA",
	value: {
		lat: 41.408969,
		lng: -75.66241219999999
	}
};
var seaford_de = {
	name: "Seaford, DE",
	value: {
		lat: 38.6412256,
		lng: -75.6110381
	}
};
var searcy_ar = {
	name: "Searcy, AR",
	value: {
		lat: 35.2468204,
		lng: -91.73368459999999
	}
};
var seattle_tacoma_bellevue_wa = {
	name: "Seattle-Tacoma-Bellevue, WA",
	value: {
		lat: 47.6062095,
		lng: -122.3320708
	}
};
var sebastian_vero_beach_fl = {
	name: "Sebastian-Vero Beach, FL",
	value: {
		lat: 27.816415,
		lng: -80.4706078
	}
};
var sebring_fl = {
	name: "Sebring, FL",
	value: {
		lat: 27.495592,
		lng: -81.440907
	}
};
var sedalia_mo = {
	name: "Sedalia, MO",
	value: {
		lat: 38.7044609,
		lng: -93.2282613
	}
};
var selinsgrove_pa = {
	name: "Selinsgrove, PA",
	value: {
		lat: 40.7989735,
		lng: -76.8621935
	}
};
var selma_al = {
	name: "Selma, AL",
	value: {
		lat: 32.4073589,
		lng: -87.02110069999999
	}
};
var seneca_falls_ny = {
	name: "Seneca Falls, NY",
	value: {
		lat: 42.9106219,
		lng: -76.7966215
	}
};
var seneca_sc = {
	name: "Seneca, SC",
	value: {
		lat: 34.6856555,
		lng: -82.9532036
	}
};
var sevierville_tn = {
	name: "Sevierville, TN",
	value: {
		lat: 35.8681455,
		lng: -83.56183500000002
	}
};
var seymour_in = {
	name: "Seymour, IN",
	value: {
		lat: 38.9592201,
		lng: -85.8902547
	}
};
var shawnee_ok = {
	name: "Shawnee, OK",
	value: {
		lat: 35.3272928,
		lng: -96.9253004
	}
};
var sheboygan_wi = {
	name: "Sheboygan, WI",
	value: {
		lat: 43.7508284,
		lng: -87.71453
	}
};
var shelby_nc = {
	name: "Shelby, NC",
	value: {
		lat: 35.2923513,
		lng: -81.5356463
	}
};
var shelbyville_tn = {
	name: "Shelbyville, TN",
	value: {
		lat: 35.483406,
		lng: -86.46027169999999
	}
};
var shelton_wa = {
	name: "Shelton, WA",
	value: {
		lat: 47.2150945,
		lng: -123.1007066
	}
};
var sheridan_wy = {
	name: "Sheridan, WY",
	value: {
		lat: 44.7971939,
		lng: -106.9561791
	}
};
var sherman_denison_tx = {
	name: "Sherman-Denison, TX",
	value: {
		lat: 33.6356618,
		lng: -96.6088805
	}
};
var shreveport_bossier_city_la = {
	name: "Shreveport-Bossier City, LA",
	value: {
		lat: 32.5251516,
		lng: -93.7501789
	}
};
var sidney_oh = {
	name: "Sidney, OH",
	value: {
		lat: 40.2842164,
		lng: -84.1554987
	}
};
var sierra_vista_douglas_az = {
	name: "Sierra Vista-Douglas, AZ",
	value: {
		lat: 31.5455001,
		lng: -110.2772856
	}
};
var sikeston_mo = {
	name: "Sikeston, MO",
	value: {
		lat: 36.876719,
		lng: -89.5878579
	}
};
var silver_city_nm = {
	name: "Silver City, NM",
	value: {
		lat: 32.770075,
		lng: -108.280326
	}
};
var silverthorne_co = {
	name: "Silverthorne, CO",
	value: {
		lat: 39.6296191,
		lng: -106.0712941
	}
};
var sioux_city_ia_ne_sd = {
	name: "Sioux City, IA-NE-SD",
	value: {
		lat: 42.4999942,
		lng: -96.40030689999999
	}
};
var sioux_falls_sd = {
	name: "Sioux Falls, SD",
	value: {
		lat: 43.5445959,
		lng: -96.73110340000001
	}
};
var snyder_tx = {
	name: "Snyder, TX",
	value: {
		lat: 32.7178862,
		lng: -100.9176184
	}
};
var somerset_ky = {
	name: "Somerset, KY",
	value: {
		lat: 37.0920222,
		lng: -84.6041084
	}
};
var somerset_pa = {
	name: "Somerset, PA",
	value: {
		lat: 40.008411,
		lng: -79.0780831
	}
};
var south_bend_mishawaka_in_mi = {
	name: "South Bend-Mishawaka, IN-MI",
	value: {
		lat: 41.6763545,
		lng: -86.25198979999999
	}
};
var southern_pines_pinehurst_nc = {
	name: "Southern Pines-Pinehurst, NC",
	value: {
		lat: 35.1740471,
		lng: -79.3922539
	}
};
var spartanburg_sc = {
	name: "Spartanburg, SC",
	value: {
		lat: 34.9495672,
		lng: -81.9320482
	}
};
var spearfish_sd = {
	name: "Spearfish, SD",
	value: {
		lat: 44.4908172,
		lng: -103.8593698
	}
};
var spencer_ia = {
	name: "Spencer, IA",
	value: {
		lat: 43.1450748,
		lng: -95.144318
	}
};
var spirit_lake_ia = {
	name: "Spirit Lake, IA",
	value: {
		lat: 43.4226192,
		lng: -95.1022313
	}
};
var spokane_wa = {
	name: "Spokane, WA",
	value: {
		lat: 47.6587802,
		lng: -117.4260466
	}
};
var springfield_il = {
	name: "Springfield, IL",
	value: {
		lat: 39.78172130000001,
		lng: -89.6501481
	}
};
var springfield_ma = {
	name: "Springfield, MA",
	value: {
		lat: 42.1014831,
		lng: -72.589811
	}
};
var springfield_mo = {
	name: "Springfield, MO",
	value: {
		lat: 37.2089572,
		lng: -93.29229889999999
	}
};
var springfield_oh = {
	name: "Springfield, OH",
	value: {
		lat: 39.9242266,
		lng: -83.8088171
	}
};
var st_cloud_mn = {
	name: "St. Cloud, MN",
	value: {
		lat: 45.5579451,
		lng: -94.16324039999999
	}
};
var st_george_ut = {
	name: "St. George, UT",
	value: {
		lat: 37.0965278,
		lng: -113.5684164
	}
};
var st_joseph_mo_ks = {
	name: "St. Joseph, MO-KS",
	value: {
		lat: 39.7674578,
		lng: -94.84668099999999
	}
};
var st_louis_mo_il = {
	name: "St. Louis, MO-IL",
	value: {
		lat: 38.6270025,
		lng: -90.19940419999999
	}
};
var st_marys_ga = {
	name: "St. Marys, GA",
	value: {
		lat: 30.7478954,
		lng: -81.57061089999999
	}
};
var st_marys_pa = {
	name: "St. Marys, PA",
	value: {
		lat: 41.42737380000001,
		lng: -78.5609398
	}
};
var starkville_ms = {
	name: "Starkville, MS",
	value: {
		lat: 33.4503998,
		lng: -88.81838719999999
	}
};
var state_college_pa = {
	name: "State College, PA",
	value: {
		lat: 40.7933949,
		lng: -77.8600012
	}
};
var statesboro_ga = {
	name: "Statesboro, GA",
	value: {
		lat: 32.4487876,
		lng: -81.7831674
	}
};
var statesville_mooresville_nc = {
	name: "Statesville-Mooresville, NC",
	value: {
		lat: 35.7826363,
		lng: -80.8872959
	}
};
var staunton_waynesboro_va = {
	name: "Staunton-Waynesboro, VA",
	value: {
		lat: 38.149576,
		lng: -79.0716958
	}
};
var stephenville_tx = {
	name: "Stephenville, TX",
	value: {
		lat: 32.2206958,
		lng: -98.2022633
	}
};
var sterling_co = {
	name: "Sterling, CO",
	value: {
		lat: 40.6255415,
		lng: -103.207709
	}
};
var sterling_il = {
	name: "Sterling, IL",
	value: {
		lat: 41.788642,
		lng: -89.69621939999999
	}
};
var stevens_point_wi = {
	name: "Stevens Point, WI",
	value: {
		lat: 44.52357920000001,
		lng: -89.574563
	}
};
var stillwater_ok = {
	name: "Stillwater, OK",
	value: {
		lat: 36.1156071,
		lng: -97.0583681
	}
};
var stockton_ca = {
	name: "Stockton, CA",
	value: {
		lat: 37.9577016,
		lng: -121.2907796
	}
};
var storm_lake_ia = {
	name: "Storm Lake, IA",
	value: {
		lat: 42.6430359,
		lng: -95.2019399
	}
};
var sturgis_mi = {
	name: "Sturgis, MI",
	value: {
		lat: 41.799217,
		lng: -85.41914820000001
	}
};
var sulphur_springs_tx = {
	name: "Sulphur Springs, TX",
	value: {
		lat: 33.1384479,
		lng: -95.6010668
	}
};
var summerville_ga = {
	name: "Summerville, GA",
	value: {
		lat: 34.480642,
		lng: -85.3477343
	}
};
var sumter_sc = {
	name: "Sumter, SC",
	value: {
		lat: 33.9204354,
		lng: -80.3414693
	}
};
var sunbury_pa = {
	name: "Sunbury, PA",
	value: {
		lat: 40.862585,
		lng: -76.79441039999999
	}
};
var susanville_ca = {
	name: "Susanville, CA",
	value: {
		lat: 40.4162842,
		lng: -120.6530063
	}
};
var sweetwater_tx = {
	name: "Sweetwater, TX",
	value: {
		lat: 32.4709519,
		lng: -100.4059384
	}
};
var syracuse_ny = {
	name: "Syracuse, NY",
	value: {
		lat: 43.0481221,
		lng: -76.14742439999999
	}
};
var tahlequah_ok = {
	name: "Tahlequah, OK",
	value: {
		lat: 35.91537,
		lng: -94.969956
	}
};
var talladega_sylacauga_al = {
	name: "Talladega-Sylacauga, AL",
	value: {
		lat: 33.4359416,
		lng: -86.1058048
	}
};
var tallahassee_fl = {
	name: "Tallahassee, FL",
	value: {
		lat: 30.4382559,
		lng: -84.28073289999999
	}
};
var tallulah_la = {
	name: "Tallulah, LA",
	value: {
		lat: 32.4084765,
		lng: -91.1867771
	}
};
var tampa_st_petersburg_clearwater_fl = {
	name: "Tampa-St. Petersburg-Clearwater, FL",
	value: {
		lat: 27.950575,
		lng: -82.4571776
	}
};
var taos_nm = {
	name: "Taos, NM",
	value: {
		lat: 36.4072485,
		lng: -105.5730665
	}
};
var taylorville_il = {
	name: "Taylorville, IL",
	value: {
		lat: 39.548935,
		lng: -89.294533
	}
};
var terre_haute_in = {
	name: "Terre Haute, IN",
	value: {
		lat: 39.4667034,
		lng: -87.41390919999999
	}
};
var texarkana_tx_texarkana_ar = {
	name: "Texarkana, TX-Texarkana, AR",
	value: {
		lat: 33.425125,
		lng: -94.04768820000001
	}
};
var the_villages_fl = {
	name: "The Villages, FL",
	value: {
		lat: 28.927019,
		lng: -82.0037608
	}
};
var thomaston_ga = {
	name: "Thomaston, GA",
	value: {
		lat: 32.8881879,
		lng: -84.3265854
	}
};
var thomasville_ga = {
	name: "Thomasville, GA",
	value: {
		lat: 30.8365815,
		lng: -83.9787808
	}
};
var thomasville_lexington_nc = {
	name: "Thomasville-Lexington, NC",
	value: {
		lat: 35.8826369,
		lng: -80.0819879
	}
};
var tiffin_oh = {
	name: "Tiffin, OH",
	value: {
		lat: 41.1144992,
		lng: -83.1779746
	}
};
var tifton_ga = {
	name: "Tifton, GA",
	value: {
		lat: 31.4504629,
		lng: -83.5084973
	}
};
var toccoa_ga = {
	name: "Toccoa, GA",
	value: {
		lat: 34.5773206,
		lng: -83.3323851
	}
};
var toledo_oh = {
	name: "Toledo, OH",
	value: {
		lat: 41.6639383,
		lng: -83.55521200000001
	}
};
var topeka_ks = {
	name: "Topeka, KS",
	value: {
		lat: 39.0558235,
		lng: -95.68901849999999
	}
};
var torrington_ct = {
	name: "Torrington, CT",
	value: {
		lat: 41.8003049,
		lng: -73.1211715
	}
};
var traverse_city_mi = {
	name: "Traverse City, MI",
	value: {
		lat: 44.7630567,
		lng: -85.62063169999999
	}
};
var trenton_ewing_nj = {
	name: "Trenton-Ewing, NJ",
	value: {
		lat: 40.2170534,
		lng: -74.7429384
	}
};
var troy_al = {
	name: "Troy, AL",
	value: {
		lat: 31.8087678,
		lng: -85.969951
	}
};
var truckee_grass_valley_ca = {
	name: "Truckee-Grass Valley, CA",
	value: {
		lat: 39.327962,
		lng: -120.1832533
	}
};
var tucson_az = {
	name: "Tucson, AZ",
	value: {
		lat: 32.2217429,
		lng: -110.926479
	}
};
var tullahoma_tn = {
	name: "Tullahoma, TN",
	value: {
		lat: 35.3620235,
		lng: -86.20943419999999
	}
};
var tulsa_ok = {
	name: "Tulsa, OK",
	value: {
		lat: 36.1539816,
		lng: -95.99277500000001
	}
};
var tupelo_ms = {
	name: "Tupelo, MS",
	value: {
		lat: 34.2576066,
		lng: -88.7033859
	}
};
var tuscaloosa_al = {
	name: "Tuscaloosa, AL",
	value: {
		lat: 33.2098407,
		lng: -87.56917349999999
	}
};
var tuskegee_al = {
	name: "Tuskegee, AL",
	value: {
		lat: 32.430237,
		lng: -85.7077266
	}
};
var twin_falls_id = {
	name: "Twin Falls, ID",
	value: {
		lat: 42.5629668,
		lng: -114.4608711
	}
};
var tyler_tx = {
	name: "Tyler, TX",
	value: {
		lat: 32.3512601,
		lng: -95.30106239999999
	}
};
var ukiah_ca = {
	name: "Ukiah, CA",
	value: {
		lat: 39.1501709,
		lng: -123.2077831
	}
};
var union_city_tn_ky = {
	name: "Union City, TN-KY",
	value: {
		lat: 36.4242303,
		lng: -89.0570096
	}
};
var union_sc = {
	name: "Union, SC",
	value: {
		lat: 34.7154122,
		lng: -81.623711
	}
};
var urbana_oh = {
	name: "Urbana, OH",
	value: {
		lat: 40.1083912,
		lng: -83.7524298
	}
};
var utica_rome_ny = {
	name: "Utica-Rome, NY",
	value: {
		lat: 43.100903,
		lng: -75.232664
	}
};
var uvalde_tx = {
	name: "Uvalde, TX",
	value: {
		lat: 29.20968359999999,
		lng: -99.7861679
	}
};
var valdosta_ga = {
	name: "Valdosta, GA",
	value: {
		lat: 30.8327022,
		lng: -83.2784851
	}
};
var vallejo_fairfield_ca = {
	name: "Vallejo-Fairfield, CA",
	value: {
		lat: 38.1040864,
		lng: -122.2566367
	}
};
var valley_al = {
	name: "Valley, AL",
	value: {
		lat: 32.8187406,
		lng: -85.1793852
	}
};
var van_wert_oh = {
	name: "Van Wert, OH",
	value: {
		lat: 40.8694927,
		lng: -84.58412229999999
	}
};
var vermillion_sd = {
	name: "Vermillion, SD",
	value: {
		lat: 42.7794417,
		lng: -96.9292104
	}
};
var vernal_ut = {
	name: "Vernal, UT",
	value: {
		lat: 40.4555157,
		lng: -109.5287479
	}
};
var vernon_tx = {
	name: "Vernon, TX",
	value: {
		lat: 34.1545306,
		lng: -99.2650804
	}
};
var vicksburg_ms = {
	name: "Vicksburg, MS",
	value: {
		lat: 32.3526456,
		lng: -90.877882
	}
};
var victoria_tx = {
	name: "Victoria, TX",
	value: {
		lat: 28.8052674,
		lng: -97.0035982
	}
};
var vidalia_ga = {
	name: "Vidalia, GA",
	value: {
		lat: 32.2176855,
		lng: -82.4134614
	}
};
var vincennes_in = {
	name: "Vincennes, IN",
	value: {
		lat: 38.677269,
		lng: -87.5286325
	}
};
var vineland_millville_bridgeton_nj = {
	name: "Vineland-Millville-Bridgeton, NJ",
	value: {
		lat: 39.4863773,
		lng: -75.02596369999999
	}
};
var virginia_beach_norfolk_newport_news_va_nc = {
	name: "Virginia Beach-Norfolk-Newport News, VA-NC",
	value: {
		lat: 36.8529263,
		lng: -75.97798499999999
	}
};
var visalia_porterville_ca = {
	name: "Visalia-Porterville, CA",
	value: {
		lat: 36.3302284,
		lng: -119.2920585
	}
};
var wabash_in = {
	name: "Wabash, IN",
	value: {
		lat: 40.797821,
		lng: -85.8205411
	}
};
var waco_tx = {
	name: "Waco, TX",
	value: {
		lat: 31.549333,
		lng: -97.1466695
	}
};
var wahpeton_nd_mn = {
	name: "Wahpeton, ND-MN",
	value: {
		lat: 46.2652367,
		lng: -96.60590719999999
	}
};
var walla_walla_wa = {
	name: "Walla Walla, WA",
	value: {
		lat: 46.0645809,
		lng: -118.3430209
	}
};
var walterboro_sc = {
	name: "Walterboro, SC",
	value: {
		lat: 32.9051704,
		lng: -80.6667688
	}
};
var wapakoneta_oh = {
	name: "Wapakoneta, OH",
	value: {
		lat: 40.5678265,
		lng: -84.1935594
	}
};
var warner_robins_ga = {
	name: "Warner Robins, GA",
	value: {
		lat: 32.6130007,
		lng: -83.624201
	}
};
var warren_pa = {
	name: "Warren, PA",
	value: {
		lat: 41.8439486,
		lng: -79.1450445
	}
};
var warrensburg_mo = {
	name: "Warrensburg, MO",
	value: {
		lat: 38.7627893,
		lng: -93.73604979999999
	}
};
var warsaw_in = {
	name: "Warsaw, IN",
	value: {
		lat: 41.2381,
		lng: -85.8530469
	}
};
var washington_in = {
	name: "Washington, IN",
	value: {
		lat: 38.65921520000001,
		lng: -87.172789
	}
};
var washington_nc = {
	name: "Washington, NC",
	value: {
		lat: 35.54655169999999,
		lng: -77.0521742
	}
};
var washington_oh = {
	name: "Washington, OH",
	value: {
		lat: 39.5364511,
		lng: -83.4390843
	}
};
var washington_arlington_alexandria_dc_va_md_wv = {
	name: "Washington-Arlington-Alexandria, DC-VA-MD-WV",
	value: {
		lat: 38.9071923,
		lng: -77.0368707
	}
};
var waterloo_cedar_falls_ia = {
	name: "Waterloo-Cedar Falls, IA",
	value: {
		lat: 42.492786,
		lng: -92.34257749999999
	}
};
var watertown_sd = {
	name: "Watertown, SD",
	value: {
		lat: 44.8994088,
		lng: -97.1150732
	}
};
var watertown_fort_atkinson_wi = {
	name: "Watertown-Fort Atkinson, WI",
	value: {
		lat: 43.1947211,
		lng: -88.7289918
	}
};
var watertown_fort_drum_ny = {
	name: "Watertown-Fort Drum, NY",
	value: {
		lat: 43.9747838,
		lng: -75.91075649999999
	}
};
var wauchula_fl = {
	name: "Wauchula, FL",
	value: {
		lat: 27.5472589,
		lng: -81.8114715
	}
};
var wausau_wi = {
	name: "Wausau, WI",
	value: {
		lat: 44.9591352,
		lng: -89.6301221
	}
};
var waycross_ga = {
	name: "Waycross, GA",
	value: {
		lat: 31.2135511,
		lng: -82.3540178
	}
};
var weirton_steubenville_wv_oh = {
	name: "Weirton-Steubenville, WV-OH",
	value: {
		lat: 40.41895660000001,
		lng: -80.58951669999999
	}
};
var wenatchee_wa = {
	name: "Wenatchee, WA",
	value: {
		lat: 47.4234599,
		lng: -120.3103494
	}
};
var west_helena_ar = {
	name: "West Helena, AR",
	value: {
		lat: 34.550177,
		lng: -90.6413226
	}
};
var west_plains_mo = {
	name: "West Plains, MO",
	value: {
		lat: 36.7281154,
		lng: -91.8523711
	}
};
var west_point_ms = {
	name: "West Point, MS",
	value: {
		lat: 33.6076186,
		lng: -88.6503254
	}
};
var wheeling_wv_oh = {
	name: "Wheeling, WV-OH",
	value: {
		lat: 40.0639616,
		lng: -80.7209149
	}
};
var whitewater_wi = {
	name: "Whitewater, WI",
	value: {
		lat: 42.83362049999999,
		lng: -88.7323272
	}
};
var wichita_falls_tx = {
	name: "Wichita Falls, TX",
	value: {
		lat: 33.9137085,
		lng: -98.4933873
	}
};
var wichita_ks = {
	name: "Wichita, KS",
	value: {
		lat: 37.68717609999999,
		lng: -97.33005299999999
	}
};
var williamsport_pa = {
	name: "Williamsport, PA",
	value: {
		lat: 41.2411897,
		lng: -77.00107860000001
	}
};
var willimantic_ct = {
	name: "Willimantic, CT",
	value: {
		lat: 41.7106543,
		lng: -72.2081338
	}
};
var williston_nd = {
	name: "Williston, ND",
	value: {
		lat: 48.1469683,
		lng: -103.6179745
	}
};
var willmar_mn = {
	name: "Willmar, MN",
	value: {
		lat: 45.1223711,
		lng: -95.048659
	}
};
var wilmington_nc = {
	name: "Wilmington, NC",
	value: {
		lat: 34.2257255,
		lng: -77.9447102
	}
};
var wilmington_oh = {
	name: "Wilmington, OH",
	value: {
		lat: 39.4453393,
		lng: -83.8285375
	}
};
var wilson_nc = {
	name: "Wilson, NC",
	value: {
		lat: 35.7212689,
		lng: -77.9155395
	}
};
var winchester_va_wv = {
	name: "Winchester, VA-WV",
	value: {
		lat: 39.1856597,
		lng: -78.1633341
	}
};
var winfield_ks = {
	name: "Winfield, KS",
	value: {
		lat: 37.2397486,
		lng: -96.9955918
	}
};
var winona_mn = {
	name: "Winona, MN",
	value: {
		lat: 44.0553908,
		lng: -91.6663523
	}
};
var winston_salem_nc = {
	name: "Winston-Salem, NC",
	value: {
		lat: 36.1039642,
		lng: -80.254435
	}
};
var woodward_ok = {
	name: "Woodward, OK",
	value: {
		lat: 36.4336481,
		lng: -99.3903862
	}
};
var wooster_oh = {
	name: "Wooster, OH",
	value: {
		lat: 40.8050565,
		lng: -81.935143
	}
};
var worcester_ma = {
	name: "Worcester, MA",
	value: {
		lat: 42.2625932,
		lng: -71.8022934
	}
};
var worthington_mn = {
	name: "Worthington, MN",
	value: {
		lat: 43.6210985,
		lng: -95.59414360000001
	}
};
var yakima_wa = {
	name: "Yakima, WA",
	value: {
		lat: 46.6020711,
		lng: -120.5058987
	}
};
var yankton_sd = {
	name: "Yankton, SD",
	value: {
		lat: 42.87110879999999,
		lng: -97.39728129999999
	}
};
var yazoo_city_ms = {
	name: "Yazoo City, MS",
	value: {
		lat: 32.8551326,
		lng: -90.4056468
	}
};
var york_hanover_pa = {
	name: "York-Hanover, PA",
	value: {
		lat: 39.9625984,
		lng: -76.727745
	}
};
var youngstown_warren_boardman_oh_pa = {
	name: "Youngstown-Warren-Boardman, OH-PA",
	value: {
		lat: 41.0997803,
		lng: -80.6495194
	}
};
var yuba_city_ca = {
	name: "Yuba City, CA",
	value: {
		lat: 39.1404477,
		lng: -121.6169108
	}
};
var yuma_az = {
	name: "Yuma, AZ",
	value: {
		lat: 32.6926512,
		lng: -114.6276916
	}
};
var zanesville_oh = {
	name: "Zanesville, OH",
	value: {
		lat: 39.9403453,
		lng: -82.0131924
	}
};
var usaCounties = {
	abbeville_la: abbeville_la,
	aberdeen_sd: aberdeen_sd,
	aberdeen_wa: aberdeen_wa,
	abilene_tx: abilene_tx,
	ada_ok: ada_ok,
	adrian_mi: adrian_mi,
	aguadilla_isabela_san_sebastian_pr: aguadilla_isabela_san_sebastian_pr,
	akron_oh: akron_oh,
	alamogordo_nm: alamogordo_nm,
	albany_ga: albany_ga,
	albany_lebanon_or: albany_lebanon_or,
	albany_schenectady_troy_ny: albany_schenectady_troy_ny,
	albemarle_nc: albemarle_nc,
	albert_lea_mn: albert_lea_mn,
	albertville_al: albertville_al,
	albuquerque_nm: albuquerque_nm,
	alexander_city_al: alexander_city_al,
	alexandria_la: alexandria_la,
	alexandria_mn: alexandria_mn,
	alice_tx: alice_tx,
	allegan_mi: allegan_mi,
	allentown_bethlehem_easton_pa_nj: allentown_bethlehem_easton_pa_nj,
	alma_mi: alma_mi,
	alpena_mi: alpena_mi,
	altoona_pa: altoona_pa,
	altus_ok: altus_ok,
	amarillo_tx: amarillo_tx,
	americus_ga: americus_ga,
	ames_ia: ames_ia,
	amsterdam_ny: amsterdam_ny,
	anchorage_ak: anchorage_ak,
	anderson_in: anderson_in,
	anderson_sc: anderson_sc,
	andrews_tx: andrews_tx,
	angola_in: angola_in,
	ann_arbor_mi: ann_arbor_mi,
	anniston_oxford_al: anniston_oxford_al,
	appleton_wi: appleton_wi,
	arcadia_fl: arcadia_fl,
	ardmore_ok: ardmore_ok,
	arkadelphia_ar: arkadelphia_ar,
	asheville_nc: asheville_nc,
	ashland_oh: ashland_oh,
	ashtabula_oh: ashtabula_oh,
	astoria_or: astoria_or,
	atchison_ks: atchison_ks,
	athens_oh: athens_oh,
	athens_tn: athens_tn,
	athens_tx: athens_tx,
	athens_clarke_county_ga: athens_clarke_county_ga,
	atlanta_sandy_springs_marietta_ga: atlanta_sandy_springs_marietta_ga,
	atlantic_city_nj: atlantic_city_nj,
	auburn_in: auburn_in,
	auburn_ny: auburn_ny,
	auburn_opelika_al: auburn_opelika_al,
	augusta_richmond_county_ga_sc: augusta_richmond_county_ga_sc,
	augusta_waterville_me: augusta_waterville_me,
	austin_mn: austin_mn,
	austin_round_rock_tx: austin_round_rock_tx,
	bainbridge_ga: bainbridge_ga,
	bakersfield_ca: bakersfield_ca,
	baltimore_towson_md: baltimore_towson_md,
	bangor_me: bangor_me,
	baraboo_wi: baraboo_wi,
	barnstable_town_ma: barnstable_town_ma,
	barre_vt: barre_vt,
	bartlesville_ok: bartlesville_ok,
	bastrop_la: bastrop_la,
	batavia_ny: batavia_ny,
	batesville_ar: batesville_ar,
	baton_rouge_la: baton_rouge_la,
	battle_creek_mi: battle_creek_mi,
	bay_city_mi: bay_city_mi,
	bay_city_tx: bay_city_tx,
	beatrice_ne: beatrice_ne,
	beaumont_port_arthur_tx: beaumont_port_arthur_tx,
	beaver_dam_wi: beaver_dam_wi,
	beckley_wv: beckley_wv,
	bedford_in: bedford_in,
	beeville_tx: beeville_tx,
	bellefontaine_oh: bellefontaine_oh,
	bellingham_wa: bellingham_wa,
	bemidji_mn: bemidji_mn,
	bend_or: bend_or,
	bennettsville_sc: bennettsville_sc,
	bennington_vt: bennington_vt,
	berlin_nh_vt: berlin_nh_vt,
	big_rapids_mi: big_rapids_mi,
	big_spring_tx: big_spring_tx,
	billings_mt: billings_mt,
	binghamton_ny: binghamton_ny,
	birmingham_hoover_al: birmingham_hoover_al,
	bishop_ca: bishop_ca,
	bismarck_nd: bismarck_nd,
	blackfoot_id: blackfoot_id,
	blacksburg_christiansburg_radford_va: blacksburg_christiansburg_radford_va,
	bloomington_in: bloomington_in,
	bloomington_normal_il: bloomington_normal_il,
	bloomsburg_berwick_pa: bloomsburg_berwick_pa,
	bluefield_wv_va: bluefield_wv_va,
	blytheville_ar: blytheville_ar,
	bogalusa_la: bogalusa_la,
	boise_city_nampa_id: boise_city_nampa_id,
	bonham_tx: bonham_tx,
	boone_ia: boone_ia,
	boone_nc: boone_nc,
	borger_tx: borger_tx,
	boston_cambridge_quincy_ma_nh: boston_cambridge_quincy_ma_nh,
	boulder_co: boulder_co,
	bowling_green_ky: bowling_green_ky,
	bozeman_mt: bozeman_mt,
	bradford_pa: bradford_pa,
	brainerd_mn: brainerd_mn,
	branson_mo: branson_mo,
	bremerton_silverdale_wa: bremerton_silverdale_wa,
	brenham_tx: brenham_tx,
	brevard_nc: brevard_nc,
	bridgeport_stamford_norwalk_ct: bridgeport_stamford_norwalk_ct,
	brigham_city_ut: brigham_city_ut,
	brookhaven_ms: brookhaven_ms,
	brookings_or: brookings_or,
	brookings_sd: brookings_sd,
	brownsville_tn: brownsville_tn,
	brownsville_harlingen_tx: brownsville_harlingen_tx,
	brownwood_tx: brownwood_tx,
	brunswick_ga: brunswick_ga,
	bucyrus_oh: bucyrus_oh,
	buffalo_niagara_falls_ny: buffalo_niagara_falls_ny,
	burley_id: burley_id,
	burlington_ia_il: burlington_ia_il,
	burlington_nc: burlington_nc,
	burlington_south_burlington_vt: burlington_south_burlington_vt,
	butte_silver_bow_mt: butte_silver_bow_mt,
	cadillac_mi: cadillac_mi,
	calhoun_ga: calhoun_ga,
	cambridge_md: cambridge_md,
	cambridge_oh: cambridge_oh,
	camden_ar: camden_ar,
	campbellsville_ky: campbellsville_ky,
	canon_city_co: canon_city_co,
	canton_il: canton_il,
	canton_massillon_oh: canton_massillon_oh,
	cape_coral_fort_myers_fl: cape_coral_fort_myers_fl,
	cape_girardeau_jackson_mo_il: cape_girardeau_jackson_mo_il,
	carbondale_il: carbondale_il,
	carlsbad_artesia_nm: carlsbad_artesia_nm,
	carson_city_nv: carson_city_nv,
	casper_wy: casper_wy,
	cedar_city_ut: cedar_city_ut,
	cedar_rapids_ia: cedar_rapids_ia,
	cedartown_ga: cedartown_ga,
	celina_oh: celina_oh,
	central_city_ky: central_city_ky,
	centralia_il: centralia_il,
	centralia_wa: centralia_wa,
	chambersburg_pa: chambersburg_pa,
	champaign_urbana_il: champaign_urbana_il,
	charleston_wv: charleston_wv,
	charleston_mattoon_il: charleston_mattoon_il,
	charleston_north_charleston_sc: charleston_north_charleston_sc,
	charlotte_gastonia_concord_nc_sc: charlotte_gastonia_concord_nc_sc,
	charlottesville_va: charlottesville_va,
	chattanooga_tn_ga: chattanooga_tn_ga,
	chester_sc: chester_sc,
	cheyenne_wy: cheyenne_wy,
	chicago_naperville_joliet_il_in_wi: chicago_naperville_joliet_il_in_wi,
	chico_ca: chico_ca,
	chillicothe_oh: chillicothe_oh,
	cincinnati_middletown_oh_ky_in: cincinnati_middletown_oh_ky_in,
	city_of_the_dalles_or: city_of_the_dalles_or,
	claremont_nh: claremont_nh,
	clarksburg_wv: clarksburg_wv,
	clarksdale_ms: clarksdale_ms,
	clarksville_tn_ky: clarksville_tn_ky,
	clearlake_ca: clearlake_ca,
	cleveland_ms: cleveland_ms,
	cleveland_tn: cleveland_tn,
	cleveland_elyria_mentor_oh: cleveland_elyria_mentor_oh,
	clewiston_fl: clewiston_fl,
	clinton_ia: clinton_ia,
	clovis_nm: clovis_nm,
	"coeur_d'alene_id": {
	name: "Coeur d'Alene, ID",
	value: {
		lat: 47.6776832,
		lng: -116.7804664
	}
},
	coffeyville_ks: coffeyville_ks,
	coldwater_mi: coldwater_mi,
	college_station_bryan_tx: college_station_bryan_tx,
	colorado_springs_co: colorado_springs_co,
	columbia_mo: columbia_mo,
	columbia_sc: columbia_sc,
	columbia_tn: columbia_tn,
	columbus_ga_al: columbus_ga_al,
	columbus_in: columbus_in,
	columbus_ms: columbus_ms,
	columbus_ne: columbus_ne,
	columbus_oh: columbus_oh,
	concord_nh: concord_nh,
	connersville_in: connersville_in,
	cookeville_tn: cookeville_tn,
	coos_bay_or: coos_bay_or,
	corbin_ky: corbin_ky,
	cordele_ga: cordele_ga,
	corinth_ms: corinth_ms,
	cornelia_ga: cornelia_ga,
	corning_ny: corning_ny,
	corpus_christi_tx: corpus_christi_tx,
	corsicana_tx: corsicana_tx,
	cortland_ny: cortland_ny,
	corvallis_or: corvallis_or,
	coshocton_oh: coshocton_oh,
	crawfordsville_in: crawfordsville_in,
	crescent_city_ca: crescent_city_ca,
	crossville_tn: crossville_tn,
	crowley_la: crowley_la,
	cullman_al: cullman_al,
	culpeper_va: culpeper_va,
	cumberland_md_wv: cumberland_md_wv,
	dallas_fort_worth_arlington_tx: dallas_fort_worth_arlington_tx,
	dalton_ga: dalton_ga,
	danville_il: danville_il,
	danville_ky: danville_ky,
	danville_va: danville_va,
	daphne_fairhope_foley_al: daphne_fairhope_foley_al,
	davenport_moline_rock_island_ia_il: davenport_moline_rock_island_ia_il,
	dayton_oh: dayton_oh,
	de_ridder_la: de_ridder_la,
	decatur_al: decatur_al,
	decatur_il: decatur_il,
	decatur_in: decatur_in,
	defiance_oh: defiance_oh,
	del_rio_tx: del_rio_tx,
	deltona_daytona_beach_ormond_beach_fl: deltona_daytona_beach_ormond_beach_fl,
	deming_nm: deming_nm,
	denver_aurora_co: denver_aurora_co,
	des_moines_west_des_moines_ia: des_moines_west_des_moines_ia,
	detroit_warren_livonia_mi: detroit_warren_livonia_mi,
	dickinson_nd: dickinson_nd,
	dillon_sc: dillon_sc,
	dixon_il: dixon_il,
	dodge_city_ks: dodge_city_ks,
	dothan_al: dothan_al,
	douglas_ga: douglas_ga,
	dover_de: dover_de,
	dubois_pa: dubois_pa,
	dublin_ga: dublin_ga,
	dubuque_ia: dubuque_ia,
	duluth_mn_wi: duluth_mn_wi,
	dumas_tx: dumas_tx,
	duncan_ok: duncan_ok,
	dunn_nc: dunn_nc,
	durango_co: durango_co,
	durant_ok: durant_ok,
	durham_nc: durham_nc,
	dyersburg_tn: dyersburg_tn,
	eagle_pass_tx: eagle_pass_tx,
	east_liverpool_salem_oh: east_liverpool_salem_oh,
	east_stroudsburg_pa: east_stroudsburg_pa,
	easton_md: easton_md,
	eau_claire_wi: eau_claire_wi,
	edwards_co: edwards_co,
	effingham_il: effingham_il,
	el_campo_tx: el_campo_tx,
	el_centro_ca: el_centro_ca,
	el_dorado_ar: el_dorado_ar,
	el_paso_tx: el_paso_tx,
	elizabeth_city_nc: elizabeth_city_nc,
	elizabethtown_ky: elizabethtown_ky,
	elk_city_ok: elk_city_ok,
	elkhart_goshen_in: elkhart_goshen_in,
	elko_nv: elko_nv,
	ellensburg_wa: ellensburg_wa,
	elmira_ny: elmira_ny,
	emporia_ks: emporia_ks,
	enid_ok: enid_ok,
	enterprise_ozark_al: enterprise_ozark_al,
	erie_pa: erie_pa,
	escanaba_mi: escanaba_mi,
	espanola_nm: espanola_nm,
	eufaula_al_ga: eufaula_al_ga,
	eugene_springfield_or: eugene_springfield_or,
	eureka_arcata_fortuna_ca: eureka_arcata_fortuna_ca,
	evanston_wy: evanston_wy,
	evansville_in_ky: evansville_in_ky,
	fairbanks_ak: fairbanks_ak,
	fairmont_mn: fairmont_mn,
	fairmont_wv: fairmont_wv,
	fajardo_pr: fajardo_pr,
	fallon_nv: fallon_nv,
	fargo_nd_mn: fargo_nd_mn,
	faribault_northfield_mn: faribault_northfield_mn,
	farmington_mo: farmington_mo,
	farmington_nm: farmington_nm,
	fayetteville_nc: fayetteville_nc,
	fayetteville_springdale_rogers_ar_mo: fayetteville_springdale_rogers_ar_mo,
	fergus_falls_mn: fergus_falls_mn,
	fernley_nv: fernley_nv,
	findlay_oh: findlay_oh,
	fitzgerald_ga: fitzgerald_ga,
	flagstaff_az: flagstaff_az,
	flint_mi: flint_mi,
	florence_sc: florence_sc,
	florence_muscle_shoals_al: florence_muscle_shoals_al,
	fond_du_lac_wi: fond_du_lac_wi,
	forest_city_nc: forest_city_nc,
	forrest_city_ar: forrest_city_ar,
	fort_collins_loveland_co: fort_collins_loveland_co,
	fort_dodge_ia: fort_dodge_ia,
	fort_leonard_wood_mo: fort_leonard_wood_mo,
	fort_madison_keokuk_ia_mo: fort_madison_keokuk_ia_mo,
	fort_morgan_co: fort_morgan_co,
	fort_payne_al: fort_payne_al,
	fort_polk_south_la: fort_polk_south_la,
	fort_smith_ar_ok: fort_smith_ar_ok,
	fort_valley_ga: fort_valley_ga,
	fort_walton_beach_crestview_destin_fl: fort_walton_beach_crestview_destin_fl,
	fort_wayne_in: fort_wayne_in,
	frankfort_in: frankfort_in,
	frankfort_ky: frankfort_ky,
	fredericksburg_tx: fredericksburg_tx,
	freeport_il: freeport_il,
	fremont_ne: fremont_ne,
	fremont_oh: fremont_oh,
	fresno_ca: fresno_ca,
	gadsden_al: gadsden_al,
	gaffney_sc: gaffney_sc,
	gainesville_fl: gainesville_fl,
	gainesville_ga: gainesville_ga,
	gainesville_tx: gainesville_tx,
	galesburg_il: galesburg_il,
	gallup_nm: gallup_nm,
	garden_city_ks: garden_city_ks,
	gardnerville_ranchos_nv: gardnerville_ranchos_nv,
	georgetown_sc: georgetown_sc,
	gettysburg_pa: gettysburg_pa,
	gillette_wy: gillette_wy,
	glasgow_ky: glasgow_ky,
	glens_falls_ny: glens_falls_ny,
	gloversville_ny: gloversville_ny,
	goldsboro_nc: goldsboro_nc,
	granbury_tx: granbury_tx,
	grand_forks_nd_mn: grand_forks_nd_mn,
	grand_island_ne: grand_island_ne,
	grand_junction_co: grand_junction_co,
	grand_rapids_wyoming_mi: grand_rapids_wyoming_mi,
	grants_pass_or: grants_pass_or,
	grants_nm: grants_nm,
	great_bend_ks: great_bend_ks,
	great_falls_mt: great_falls_mt,
	greeley_co: greeley_co,
	green_bay_wi: green_bay_wi,
	greeneville_tn: greeneville_tn,
	greensboro_high_point_nc: greensboro_high_point_nc,
	greensburg_in: greensburg_in,
	greenville_ms: greenville_ms,
	greenville_nc: greenville_nc,
	greenville_oh: greenville_oh,
	greenville_mauldin_easley_sc: greenville_mauldin_easley_sc,
	greenwood_ms: greenwood_ms,
	greenwood_sc: greenwood_sc,
	grenada_ms: grenada_ms,
	guayama_pr: guayama_pr,
	gulfport_biloxi_ms: gulfport_biloxi_ms,
	guymon_ok: guymon_ok,
	hagerstown_martinsburg_md_wv: hagerstown_martinsburg_md_wv,
	hammond_la: hammond_la,
	hanford_corcoran_ca: hanford_corcoran_ca,
	hannibal_mo: hannibal_mo,
	harriman_tn: harriman_tn,
	harrisburg_il: harrisburg_il,
	harrisburg_carlisle_pa: harrisburg_carlisle_pa,
	harrison_ar: harrison_ar,
	harrisonburg_va: harrisonburg_va,
	hartford_west_hartford_east_hartford_ct: hartford_west_hartford_east_hartford_ct,
	hastings_ne: hastings_ne,
	hattiesburg_ms: hattiesburg_ms,
	havre_mt: havre_mt,
	hays_ks: hays_ks,
	heber_ut: heber_ut,
	helena_mt: helena_mt,
	henderson_nc: henderson_nc,
	hereford_tx: hereford_tx,
	hickory_lenoir_morganton_nc: hickory_lenoir_morganton_nc,
	hilo_hi: hilo_hi,
	hilton_head_island_beaufort_sc: hilton_head_island_beaufort_sc,
	hinesville_fort_stewart_ga: hinesville_fort_stewart_ga,
	hobbs_nm: hobbs_nm,
	holland_grand_haven_mi: holland_grand_haven_mi,
	homosassa_springs_fl: homosassa_springs_fl,
	honolulu_hi: honolulu_hi,
	hood_river_or: hood_river_or,
	hope_ar: hope_ar,
	hot_springs_ar: hot_springs_ar,
	houghton_mi: houghton_mi,
	houma_bayou_cane_thibodaux_la: houma_bayou_cane_thibodaux_la,
	houston_sugar_land_baytown_tx: houston_sugar_land_baytown_tx,
	hudson_ny: hudson_ny,
	humboldt_tn: humboldt_tn,
	huntingdon_pa: huntingdon_pa,
	huntington_in: huntington_in,
	huntington_ashland_wv_ky_oh: huntington_ashland_wv_ky_oh,
	huntsville_al: huntsville_al,
	huntsville_tx: huntsville_tx,
	huron_sd: huron_sd,
	hutchinson_ks: hutchinson_ks,
	hutchinson_mn: hutchinson_mn,
	idaho_falls_id: idaho_falls_id,
	indiana_pa: indiana_pa,
	indianapolis_carmel_in: indianapolis_carmel_in,
	indianola_ms: indianola_ms,
	iowa_city_ia: iowa_city_ia,
	iron_mountain_mi_wi: iron_mountain_mi_wi,
	ithaca_ny: ithaca_ny,
	jackson_mi: jackson_mi,
	jackson_ms: jackson_ms,
	jackson_tn: jackson_tn,
	jackson_wy_id: jackson_wy_id,
	jacksonville_fl: jacksonville_fl,
	jacksonville_il: jacksonville_il,
	jacksonville_nc: jacksonville_nc,
	jacksonville_tx: jacksonville_tx,
	jamestown_nd: jamestown_nd,
	jamestown_dunkirk_fredonia_ny: jamestown_dunkirk_fredonia_ny,
	janesville_wi: janesville_wi,
	jasper_in: jasper_in,
	jefferson_city_mo: jefferson_city_mo,
	jennings_la: jennings_la,
	jesup_ga: jesup_ga,
	johnson_city_tn: johnson_city_tn,
	johnstown_pa: johnstown_pa,
	jonesboro_ar: jonesboro_ar,
	joplin_mo: joplin_mo,
	juneau_ak: juneau_ak,
	kahului_wailuku_hi: kahului_wailuku_hi,
	kalamazoo_portage_mi: kalamazoo_portage_mi,
	kalispell_mt: kalispell_mt,
	kankakee_bradley_il: kankakee_bradley_il,
	kansas_city_mo_ks: kansas_city_mo_ks,
	kapaa_hi: kapaa_hi,
	kearney_ne: kearney_ne,
	keene_nh: keene_nh,
	kendallville_in: kendallville_in,
	kennett_mo: kennett_mo,
	kennewick_richland_pasco_wa: kennewick_richland_pasco_wa,
	kerrville_tx: kerrville_tx,
	ketchikan_ak: ketchikan_ak,
	key_west_fl: key_west_fl,
	kill_devil_hills_nc: kill_devil_hills_nc,
	killeen_temple_fort_hood_tx: killeen_temple_fort_hood_tx,
	kingsport_bristol_bristol_tn_va: kingsport_bristol_bristol_tn_va,
	kingston_ny: kingston_ny,
	kingsville_tx: kingsville_tx,
	kinston_nc: kinston_nc,
	kirksville_mo: kirksville_mo,
	klamath_falls_or: klamath_falls_or,
	knoxville_tn: knoxville_tn,
	kodiak_ak: kodiak_ak,
	kokomo_in: kokomo_in,
	la_crosse_wi_mn: la_crosse_wi_mn,
	la_follette_tn: la_follette_tn,
	la_grande_or: la_grande_or,
	lagrange_ga: lagrange_ga,
	laconia_nh: laconia_nh,
	lafayette_in: lafayette_in,
	lafayette_la: lafayette_la,
	lake_charles_la: lake_charles_la,
	lake_city_fl: lake_city_fl,
	lake_havasu_city_kingman_az: lake_havasu_city_kingman_az,
	lakeland_fl: lakeland_fl,
	lamesa_tx: lamesa_tx,
	lancaster_pa: lancaster_pa,
	lancaster_sc: lancaster_sc,
	lansing_east_lansing_mi: lansing_east_lansing_mi,
	laramie_wy: laramie_wy,
	laredo_tx: laredo_tx,
	las_cruces_nm: las_cruces_nm,
	las_vegas_nm: las_vegas_nm,
	las_vegas_paradise_nv: las_vegas_paradise_nv,
	laurel_ms: laurel_ms,
	laurinburg_nc: laurinburg_nc,
	lawrence_ks: lawrence_ks,
	lawrenceburg_tn: lawrenceburg_tn,
	lawton_ok: lawton_ok,
	lebanon_mo: lebanon_mo,
	lebanon_nh_vt: lebanon_nh_vt,
	lebanon_pa: lebanon_pa,
	levelland_tx: levelland_tx,
	lewisburg_pa: lewisburg_pa,
	lewisburg_tn: lewisburg_tn,
	lewiston_id_wa: lewiston_id_wa,
	lewiston_auburn_me: lewiston_auburn_me,
	lewistown_pa: lewistown_pa,
	lexington_park_md: lexington_park_md,
	lexington_ne: lexington_ne,
	lexington_fayette_ky: lexington_fayette_ky,
	liberal_ks: liberal_ks,
	lima_oh: lima_oh,
	lincoln_il: lincoln_il,
	lincoln_ne: lincoln_ne,
	lincolnton_nc: lincolnton_nc,
	little_rock_north_little_rock_conway_ar: little_rock_north_little_rock_conway_ar,
	lock_haven_pa: lock_haven_pa,
	logan_ut_id: logan_ut_id,
	logansport_in: logansport_in,
	london_ky: london_ky,
	longview_tx: longview_tx,
	longview_wa: longview_wa,
	los_alamos_nm: los_alamos_nm,
	los_angeles_long_beach_santa_ana_ca: los_angeles_long_beach_santa_ana_ca,
	"louisville/jefferson_county_ky_in": {
	name: "Louisville/Jefferson County, KY-IN",
	value: {
		lat: 38.2526647,
		lng: -85.7584557
	}
},
	lubbock_tx: lubbock_tx,
	lufkin_tx: lufkin_tx,
	lumberton_nc: lumberton_nc,
	lynchburg_va: lynchburg_va,
	macomb_il: macomb_il,
	macon_ga: macon_ga,
	madera_ca: madera_ca,
	madison_in: madison_in,
	madison_wi: madison_wi,
	madisonville_ky: madisonville_ky,
	magnolia_ar: magnolia_ar,
	malone_ny: malone_ny,
	manchester_nashua_nh: manchester_nashua_nh,
	manhattan_ks: manhattan_ks,
	manitowoc_wi: manitowoc_wi,
	mankato_north_mankato_mn: mankato_north_mankato_mn,
	mansfield_oh: mansfield_oh,
	marinette_wi_mi: marinette_wi_mi,
	marion_in: marion_in,
	marion_oh: marion_oh,
	marion_herrin_il: marion_herrin_il,
	marquette_mi: marquette_mi,
	marshall_mn: marshall_mn,
	marshall_mo: marshall_mo,
	marshall_tx: marshall_tx,
	marshalltown_ia: marshalltown_ia,
	marshfield_wisconsin_rapids_wi: marshfield_wisconsin_rapids_wi,
	martin_tn: martin_tn,
	martinsville_va: martinsville_va,
	maryville_mo: maryville_mo,
	mason_city_ia: mason_city_ia,
	mayaguez_pr: mayaguez_pr,
	mayfield_ky: mayfield_ky,
	maysville_ky: maysville_ky,
	mcalester_ok: mcalester_ok,
	mcallen_edinburg_mission_tx: mcallen_edinburg_mission_tx,
	mccomb_ms: mccomb_ms,
	mcminnville_tn: mcminnville_tn,
	mcpherson_ks: mcpherson_ks,
	meadville_pa: meadville_pa,
	medford_or: medford_or,
	memphis_tn_ms_ar: memphis_tn_ms_ar,
	menomonie_wi: menomonie_wi,
	merced_ca: merced_ca,
	meridian_ms: meridian_ms,
	merrill_wi: merrill_wi,
	mexico_mo: mexico_mo,
	miami_ok: miami_ok,
	miami_fort_lauderdale_pompano_beach_fl: miami_fort_lauderdale_pompano_beach_fl,
	michigan_city_la_porte_in: michigan_city_la_porte_in,
	middlesborough_ky: middlesborough_ky,
	midland_mi: midland_mi,
	midland_tx: midland_tx,
	milledgeville_ga: milledgeville_ga,
	milwaukee_waukesha_west_allis_wi: milwaukee_waukesha_west_allis_wi,
	minden_la: minden_la,
	mineral_wells_tx: mineral_wells_tx,
	minneapolis_st_paul_bloomington_mn_wi: minneapolis_st_paul_bloomington_mn_wi,
	minot_nd: minot_nd,
	missoula_mt: missoula_mt,
	mitchell_sd: mitchell_sd,
	moberly_mo: moberly_mo,
	mobile_al: mobile_al,
	modesto_ca: modesto_ca,
	monroe_la: monroe_la,
	monroe_mi: monroe_mi,
	monroe_wi: monroe_wi,
	montgomery_al: montgomery_al,
	montrose_co: montrose_co,
	morehead_city_nc: morehead_city_nc,
	morgan_city_la: morgan_city_la,
	morgantown_wv: morgantown_wv,
	morristown_tn: morristown_tn,
	moscow_id: moscow_id,
	moses_lake_wa: moses_lake_wa,
	moultrie_ga: moultrie_ga,
	mount_airy_nc: mount_airy_nc,
	mount_pleasant_mi: mount_pleasant_mi,
	mount_pleasant_tx: mount_pleasant_tx,
	mount_sterling_ky: mount_sterling_ky,
	mount_vernon_il: mount_vernon_il,
	mount_vernon_oh: mount_vernon_oh,
	mount_vernon_anacortes_wa: mount_vernon_anacortes_wa,
	mountain_home_ar: mountain_home_ar,
	mountain_home_id: mountain_home_id,
	muncie_in: muncie_in,
	murray_ky: murray_ky,
	muscatine_ia: muscatine_ia,
	muskegon_norton_shores_mi: muskegon_norton_shores_mi,
	muskogee_ok: muskogee_ok,
	myrtle_beach_conway_north_myrtle_beach_sc: myrtle_beach_conway_north_myrtle_beach_sc,
	nacogdoches_tx: nacogdoches_tx,
	napa_ca: napa_ca,
	naples_marco_island_fl: naples_marco_island_fl,
	nashville_davidson_murfreesboro_franklin_tn: nashville_davidson_murfreesboro_franklin_tn,
	natchez_ms_la: natchez_ms_la,
	natchitoches_la: natchitoches_la,
	new_bern_nc: new_bern_nc,
	new_castle_in: new_castle_in,
	new_castle_pa: new_castle_pa,
	new_haven_milford_ct: new_haven_milford_ct,
	new_iberia_la: new_iberia_la,
	new_orleans_metairie_kenner_la: new_orleans_metairie_kenner_la,
	new_philadelphia_dover_oh: new_philadelphia_dover_oh,
	new_ulm_mn: new_ulm_mn,
	new_york_northern_new_jersey_long_island_ny_nj_pa: new_york_northern_new_jersey_long_island_ny_nj_pa,
	newberry_sc: newberry_sc,
	newport_tn: newport_tn,
	newton_ia: newton_ia,
	niles_benton_harbor_mi: niles_benton_harbor_mi,
	nogales_az: nogales_az,
	norfolk_ne: norfolk_ne,
	north_platte_ne: north_platte_ne,
	north_vernon_in: north_vernon_in,
	north_wilkesboro_nc: north_wilkesboro_nc,
	norwalk_oh: norwalk_oh,
	norwich_new_london_ct: norwich_new_london_ct,
	oak_harbor_wa: oak_harbor_wa,
	oak_hill_wv: oak_hill_wv,
	ocala_fl: ocala_fl,
	ocean_city_nj: ocean_city_nj,
	ocean_pines_md: ocean_pines_md,
	odessa_tx: odessa_tx,
	ogden_clearfield_ut: ogden_clearfield_ut,
	ogdensburg_massena_ny: ogdensburg_massena_ny,
	oil_city_pa: oil_city_pa,
	okeechobee_fl: okeechobee_fl,
	oklahoma_city_ok: oklahoma_city_ok,
	olean_ny: olean_ny,
	olympia_wa: olympia_wa,
	omaha_council_bluffs_ne_ia: omaha_council_bluffs_ne_ia,
	oneonta_ny: oneonta_ny,
	ontario_or_id: ontario_or_id,
	opelousas_eunice_la: opelousas_eunice_la,
	orangeburg_sc: orangeburg_sc,
	orlando_kissimmee_fl: orlando_kissimmee_fl,
	oshkosh_neenah_wi: oshkosh_neenah_wi,
	oskaloosa_ia: oskaloosa_ia,
	ottawa_streator_il: ottawa_streator_il,
	ottumwa_ia: ottumwa_ia,
	owatonna_mn: owatonna_mn,
	owensboro_ky: owensboro_ky,
	owosso_mi: owosso_mi,
	oxford_ms: oxford_ms,
	oxnard_thousand_oaks_ventura_ca: oxnard_thousand_oaks_ventura_ca,
	paducah_ky_il: paducah_ky_il,
	pahrump_nv: pahrump_nv,
	palatka_fl: palatka_fl,
	palestine_tx: palestine_tx,
	palm_bay_melbourne_titusville_fl: palm_bay_melbourne_titusville_fl,
	palm_coast_fl: palm_coast_fl,
	pampa_tx: pampa_tx,
	panama_city_lynn_haven_fl: panama_city_lynn_haven_fl,
	paragould_ar: paragould_ar,
	paris_tn: paris_tn,
	paris_tx: paris_tx,
	parkersburg_marietta_vienna_wv_oh: parkersburg_marietta_vienna_wv_oh,
	parsons_ks: parsons_ks,
	pascagoula_ms: pascagoula_ms,
	payson_az: payson_az,
	pecos_tx: pecos_tx,
	pella_ia: pella_ia,
	pendleton_hermiston_or: pendleton_hermiston_or,
	pensacola_ferry_pass_brent_fl: pensacola_ferry_pass_brent_fl,
	peoria_il: peoria_il,
	peru_in: peru_in,
	philadelphia_camden_wilmington_pa_nj_de_md: philadelphia_camden_wilmington_pa_nj_de_md,
	phoenix_lake_cedar_ridge_ca: phoenix_lake_cedar_ridge_ca,
	phoenix_mesa_scottsdale_az: phoenix_mesa_scottsdale_az,
	picayune_ms: picayune_ms,
	pierre_part_la: pierre_part_la,
	pierre_sd: pierre_sd,
	pine_bluff_ar: pine_bluff_ar,
	pittsburg_ks: pittsburg_ks,
	pittsburgh_pa: pittsburgh_pa,
	pittsfield_ma: pittsfield_ma,
	plainview_tx: plainview_tx,
	platteville_wi: platteville_wi,
	plattsburgh_ny: plattsburgh_ny,
	plymouth_in: plymouth_in,
	pocatello_id: pocatello_id,
	point_pleasant_wv_oh: point_pleasant_wv_oh,
	ponca_city_ok: ponca_city_ok,
	ponce_pr: ponce_pr,
	pontiac_il: pontiac_il,
	poplar_bluff_mo: poplar_bluff_mo,
	port_angeles_wa: port_angeles_wa,
	port_st_lucie_fl: port_st_lucie_fl,
	portales_nm: portales_nm,
	portland_south_portland_biddeford_me: portland_south_portland_biddeford_me,
	portland_vancouver_beaverton_or_wa: portland_vancouver_beaverton_or_wa,
	portsmouth_oh: portsmouth_oh,
	pottsville_pa: pottsville_pa,
	poughkeepsie_newburgh_middletown_ny: poughkeepsie_newburgh_middletown_ny,
	prescott_az: prescott_az,
	price_ut: price_ut,
	prineville_or: prineville_or,
	providence_new_bedford_fall_river_ri_ma: providence_new_bedford_fall_river_ri_ma,
	provo_orem_ut: provo_orem_ut,
	pueblo_co: pueblo_co,
	pullman_wa: pullman_wa,
	punta_gorda_fl: punta_gorda_fl,
	quincy_il_mo: quincy_il_mo,
	racine_wi: racine_wi,
	raleigh_cary_nc: raleigh_cary_nc,
	rapid_city_sd: rapid_city_sd,
	raymondville_tx: raymondville_tx,
	reading_pa: reading_pa,
	red_bluff_ca: red_bluff_ca,
	red_wing_mn: red_wing_mn,
	redding_ca: redding_ca,
	reno_sparks_nv: reno_sparks_nv,
	rexburg_id: rexburg_id,
	richmond_in: richmond_in,
	richmond_va: richmond_va,
	richmond_berea_ky: richmond_berea_ky,
	rio_grande_city_roma_tx: rio_grande_city_roma_tx,
	riverside_san_bernardino_ontario_ca: riverside_san_bernardino_ontario_ca,
	riverton_wy: riverton_wy,
	roanoke_rapids_nc: roanoke_rapids_nc,
	roanoke_va: roanoke_va,
	rochelle_il: rochelle_il,
	rochester_mn: rochester_mn,
	rochester_ny: rochester_ny,
	rock_springs_wy: rock_springs_wy,
	rockford_il: rockford_il,
	rockingham_nc: rockingham_nc,
	rockland_me: rockland_me,
	rocky_mount_nc: rocky_mount_nc,
	rolla_mo: rolla_mo,
	rome_ga: rome_ga,
	roseburg_or: roseburg_or,
	roswell_nm: roswell_nm,
	ruidoso_nm: ruidoso_nm,
	russellville_ar: russellville_ar,
	ruston_la: ruston_la,
	rutland_vt: rutland_vt,
	sacramento_arden_arcade_roseville_ca: sacramento_arden_arcade_roseville_ca,
	safford_az: safford_az,
	saginaw_saginaw_township_north_mi: saginaw_saginaw_township_north_mi,
	salem_or: salem_or,
	salina_ks: salina_ks,
	salinas_ca: salinas_ca,
	salisbury_md: salisbury_md,
	salisbury_nc: salisbury_nc,
	salt_lake_city_ut: salt_lake_city_ut,
	san_angelo_tx: san_angelo_tx,
	san_antonio_tx: san_antonio_tx,
	san_diego_carlsbad_san_marcos_ca: san_diego_carlsbad_san_marcos_ca,
	san_francisco_oakland_fremont_ca: san_francisco_oakland_fremont_ca,
	san_german_cabo_rojo_pr: san_german_cabo_rojo_pr,
	san_jose_sunnyvale_santa_clara_ca: san_jose_sunnyvale_santa_clara_ca,
	san_juan_caguas_guaynabo_pr: san_juan_caguas_guaynabo_pr,
	san_luis_obispo_paso_robles_ca: san_luis_obispo_paso_robles_ca,
	sandusky_oh: sandusky_oh,
	sanford_nc: sanford_nc,
	santa_barbara_santa_maria_goleta_ca: santa_barbara_santa_maria_goleta_ca,
	santa_cruz_watsonville_ca: santa_cruz_watsonville_ca,
	santa_fe_nm: santa_fe_nm,
	santa_isabel_pr: santa_isabel_pr,
	santa_rosa_petaluma_ca: santa_rosa_petaluma_ca,
	sarasota_bradenton_venice_fl: sarasota_bradenton_venice_fl,
	sault_ste_marie_mi: sault_ste_marie_mi,
	savannah_ga: savannah_ga,
	sayre_pa: sayre_pa,
	scottsbluff_ne: scottsbluff_ne,
	scottsboro_al: scottsboro_al,
	scottsburg_in: scottsburg_in,
	scranton_wilkes_barre_pa: scranton_wilkes_barre_pa,
	seaford_de: seaford_de,
	searcy_ar: searcy_ar,
	seattle_tacoma_bellevue_wa: seattle_tacoma_bellevue_wa,
	sebastian_vero_beach_fl: sebastian_vero_beach_fl,
	sebring_fl: sebring_fl,
	sedalia_mo: sedalia_mo,
	selinsgrove_pa: selinsgrove_pa,
	selma_al: selma_al,
	seneca_falls_ny: seneca_falls_ny,
	seneca_sc: seneca_sc,
	sevierville_tn: sevierville_tn,
	seymour_in: seymour_in,
	shawnee_ok: shawnee_ok,
	sheboygan_wi: sheboygan_wi,
	shelby_nc: shelby_nc,
	shelbyville_tn: shelbyville_tn,
	shelton_wa: shelton_wa,
	sheridan_wy: sheridan_wy,
	sherman_denison_tx: sherman_denison_tx,
	shreveport_bossier_city_la: shreveport_bossier_city_la,
	sidney_oh: sidney_oh,
	sierra_vista_douglas_az: sierra_vista_douglas_az,
	sikeston_mo: sikeston_mo,
	silver_city_nm: silver_city_nm,
	silverthorne_co: silverthorne_co,
	sioux_city_ia_ne_sd: sioux_city_ia_ne_sd,
	sioux_falls_sd: sioux_falls_sd,
	snyder_tx: snyder_tx,
	somerset_ky: somerset_ky,
	somerset_pa: somerset_pa,
	south_bend_mishawaka_in_mi: south_bend_mishawaka_in_mi,
	southern_pines_pinehurst_nc: southern_pines_pinehurst_nc,
	spartanburg_sc: spartanburg_sc,
	spearfish_sd: spearfish_sd,
	spencer_ia: spencer_ia,
	spirit_lake_ia: spirit_lake_ia,
	spokane_wa: spokane_wa,
	springfield_il: springfield_il,
	springfield_ma: springfield_ma,
	springfield_mo: springfield_mo,
	springfield_oh: springfield_oh,
	st_cloud_mn: st_cloud_mn,
	st_george_ut: st_george_ut,
	st_joseph_mo_ks: st_joseph_mo_ks,
	st_louis_mo_il: st_louis_mo_il,
	st_marys_ga: st_marys_ga,
	st_marys_pa: st_marys_pa,
	starkville_ms: starkville_ms,
	state_college_pa: state_college_pa,
	statesboro_ga: statesboro_ga,
	statesville_mooresville_nc: statesville_mooresville_nc,
	staunton_waynesboro_va: staunton_waynesboro_va,
	stephenville_tx: stephenville_tx,
	sterling_co: sterling_co,
	sterling_il: sterling_il,
	stevens_point_wi: stevens_point_wi,
	stillwater_ok: stillwater_ok,
	stockton_ca: stockton_ca,
	storm_lake_ia: storm_lake_ia,
	sturgis_mi: sturgis_mi,
	sulphur_springs_tx: sulphur_springs_tx,
	summerville_ga: summerville_ga,
	sumter_sc: sumter_sc,
	sunbury_pa: sunbury_pa,
	susanville_ca: susanville_ca,
	sweetwater_tx: sweetwater_tx,
	syracuse_ny: syracuse_ny,
	tahlequah_ok: tahlequah_ok,
	talladega_sylacauga_al: talladega_sylacauga_al,
	tallahassee_fl: tallahassee_fl,
	tallulah_la: tallulah_la,
	tampa_st_petersburg_clearwater_fl: tampa_st_petersburg_clearwater_fl,
	taos_nm: taos_nm,
	taylorville_il: taylorville_il,
	terre_haute_in: terre_haute_in,
	texarkana_tx_texarkana_ar: texarkana_tx_texarkana_ar,
	the_villages_fl: the_villages_fl,
	thomaston_ga: thomaston_ga,
	thomasville_ga: thomasville_ga,
	thomasville_lexington_nc: thomasville_lexington_nc,
	tiffin_oh: tiffin_oh,
	tifton_ga: tifton_ga,
	toccoa_ga: toccoa_ga,
	toledo_oh: toledo_oh,
	topeka_ks: topeka_ks,
	torrington_ct: torrington_ct,
	traverse_city_mi: traverse_city_mi,
	trenton_ewing_nj: trenton_ewing_nj,
	troy_al: troy_al,
	truckee_grass_valley_ca: truckee_grass_valley_ca,
	tucson_az: tucson_az,
	tullahoma_tn: tullahoma_tn,
	tulsa_ok: tulsa_ok,
	tupelo_ms: tupelo_ms,
	tuscaloosa_al: tuscaloosa_al,
	tuskegee_al: tuskegee_al,
	twin_falls_id: twin_falls_id,
	tyler_tx: tyler_tx,
	ukiah_ca: ukiah_ca,
	union_city_tn_ky: union_city_tn_ky,
	union_sc: union_sc,
	urbana_oh: urbana_oh,
	utica_rome_ny: utica_rome_ny,
	uvalde_tx: uvalde_tx,
	valdosta_ga: valdosta_ga,
	vallejo_fairfield_ca: vallejo_fairfield_ca,
	valley_al: valley_al,
	van_wert_oh: van_wert_oh,
	vermillion_sd: vermillion_sd,
	vernal_ut: vernal_ut,
	vernon_tx: vernon_tx,
	vicksburg_ms: vicksburg_ms,
	victoria_tx: victoria_tx,
	vidalia_ga: vidalia_ga,
	vincennes_in: vincennes_in,
	vineland_millville_bridgeton_nj: vineland_millville_bridgeton_nj,
	virginia_beach_norfolk_newport_news_va_nc: virginia_beach_norfolk_newport_news_va_nc,
	visalia_porterville_ca: visalia_porterville_ca,
	wabash_in: wabash_in,
	waco_tx: waco_tx,
	wahpeton_nd_mn: wahpeton_nd_mn,
	walla_walla_wa: walla_walla_wa,
	walterboro_sc: walterboro_sc,
	wapakoneta_oh: wapakoneta_oh,
	warner_robins_ga: warner_robins_ga,
	warren_pa: warren_pa,
	warrensburg_mo: warrensburg_mo,
	warsaw_in: warsaw_in,
	washington_in: washington_in,
	washington_nc: washington_nc,
	washington_oh: washington_oh,
	washington_arlington_alexandria_dc_va_md_wv: washington_arlington_alexandria_dc_va_md_wv,
	waterloo_cedar_falls_ia: waterloo_cedar_falls_ia,
	watertown_sd: watertown_sd,
	watertown_fort_atkinson_wi: watertown_fort_atkinson_wi,
	watertown_fort_drum_ny: watertown_fort_drum_ny,
	wauchula_fl: wauchula_fl,
	wausau_wi: wausau_wi,
	waycross_ga: waycross_ga,
	weirton_steubenville_wv_oh: weirton_steubenville_wv_oh,
	wenatchee_wa: wenatchee_wa,
	west_helena_ar: west_helena_ar,
	west_plains_mo: west_plains_mo,
	west_point_ms: west_point_ms,
	wheeling_wv_oh: wheeling_wv_oh,
	whitewater_wi: whitewater_wi,
	wichita_falls_tx: wichita_falls_tx,
	wichita_ks: wichita_ks,
	williamsport_pa: williamsport_pa,
	willimantic_ct: willimantic_ct,
	williston_nd: williston_nd,
	willmar_mn: willmar_mn,
	wilmington_nc: wilmington_nc,
	wilmington_oh: wilmington_oh,
	wilson_nc: wilson_nc,
	winchester_va_wv: winchester_va_wv,
	winfield_ks: winfield_ks,
	winona_mn: winona_mn,
	winston_salem_nc: winston_salem_nc,
	woodward_ok: woodward_ok,
	wooster_oh: wooster_oh,
	worcester_ma: worcester_ma,
	worthington_mn: worthington_mn,
	yakima_wa: yakima_wa,
	yankton_sd: yankton_sd,
	yazoo_city_ms: yazoo_city_ms,
	york_hanover_pa: york_hanover_pa,
	youngstown_warren_boardman_oh_pa: youngstown_warren_boardman_oh_pa,
	yuba_city_ca: yuba_city_ca,
	yuma_az: yuma_az,
	zanesville_oh: zanesville_oh
};

var tooltipTimeout$7;

var _topojson$feature$1 = topojson.feature(topology$1, topology$1.objects.states),
    states = _topojson$feature$1.features;

var UsaMapChart = function UsaMapChart(_ref) {
  var _ref$type = _ref.type,
      type = _ref$type === void 0 ? 'states' : _ref$type,
      data = _ref.data,
      metric = _ref.metric,
      showMoreDetail = _ref.showMoreDetail,
      onItemClick = _ref.onItemClick,
      color = _ref.color,
      emptyDataMessage = _ref.emptyDataMessage;
  var svgRef = React.useRef(null);
  var chartId = React.useRef(uniqid());
  var isEmpty = !data || data.length === 0;

  var _useState = React.useState(0),
      width = _useState[0],
      setWidth = _useState[1];

  var _useState2 = React.useState(0),
      height = _useState2[0],
      setHeight = _useState2[1];

  var yMax = height;

  var _useTooltip = tooltip.useTooltip(),
      tooltipOpen = _useTooltip.tooltipOpen,
      tooltipLeft = _useTooltip.tooltipLeft,
      tooltipTop = _useTooltip.tooltipTop,
      tooltipData = _useTooltip.tooltipData,
      hideTooltip = _useTooltip.hideTooltip,
      showTooltip = _useTooltip.showTooltip;

  var windowSize = useWindowSize();
  var chartRef = React.useCallback(function (node) {
    if (node != null) {
      setWidth(node.getBoundingClientRect().width);
      setHeight(node.getBoundingClientRect().height);
    }
  }, [windowSize]);
  var counties = Object.keys(usaCounties).map(function (county) {
    return {
      id: county,
      abbr: county.substring(county.length - 2, county.length).toUpperCase(),
      label: usaCounties[county].name,
      lat: usaCounties[county].value.lat,
      lng: usaCounties[county].value.lng
    };
  });
  var handleMouseMove = React.useCallback(function (event$1, feature, color) {
    if (color === void 0) {
      color = '#000000';
    }

    if (tooltipTimeout$7) clearTimeout(tooltipTimeout$7);
    if (!svgRef.current) return;
    var point = event.localPoint(svgRef.current, event$1);
    showTooltip({
      tooltipData: _extends({}, feature, {
        color: color
      }),
      tooltipTop: point === null || point === void 0 ? void 0 : point.y,
      tooltipLeft: point === null || point === void 0 ? void 0 : point.x
    });
  }, [svgRef, showTooltip]);
  var handleMouseLeave = React.useCallback(function (event) {
    tooltipTimeout$7 = window.setTimeout(function () {
      hideTooltip();
    }, 0);
  }, [hideTooltip]);
  var tooltipContent = React.useMemo(function () {
    if (showMoreDetail) {
      return /*#__PURE__*/React__default.createElement(React__default.Fragment, null, tooltipOpen && tooltipData && /*#__PURE__*/React__default.createElement(ChartTooltip, {
        opened: tooltipOpen,
        top: tooltipTop || 0,
        left: tooltipLeft || 0,
        data: tooltipData
      }, isReach(metric) && /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Reach: "), FormatUtils.formattedValue(getPopulationPerc(tooltipData), METRICS.REACH)), metric === METRICS.AFFINITY && /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Affinity: "), FormatUtils.formattedValue(tooltipData.target_audience_affinity, METRICS.AFFINITY)), metric === METRICS.BASE && /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Base: "), FormatUtils.formattedValue(tooltipData.base_population_perc, METRICS.BASE)), metric === METRICS.PENETRATION && /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Penetration: "), FormatUtils.formattedValue(tooltipData.penetration, METRICS.PENETRATION)), metric === METRICS.RELEVANCY && /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Relevance: "), FormatUtils.formattedValue(tooltipData.relevancy, METRICS.RELEVANCY))));
    }

    return /*#__PURE__*/React__default.createElement(React__default.Fragment, null, tooltipOpen && tooltipData && /*#__PURE__*/React__default.createElement(StyledUsaMapChartTooltip, {
      top: tooltipTop,
      left: tooltipLeft
    }, /*#__PURE__*/React__default.createElement("div", null, tooltipData && tooltipData.label)));
  }, [showMoreDetail, tooltipLeft, tooltipTop, tooltipData, metric, tooltipOpen]);
  var scale$1 = (width + height) / 2;
  var centerX = width / 2;
  var centerY = height / 2;
  var max = data && Math.max.apply(Math, data.map(function (item) {
    return item[metric];
  })) || 0;
  var min = data && Math.min.apply(Math, data.map(function (item) {
    return item[metric];
  })) || 0;
  var colorsRange = getMapColors(color);
  var colorScale = React.useMemo(function () {
    return scale.scaleLinear({
      domain: [metric === METRICS.AFFINITY ? min : min * 100, metric === METRICS.AFFINITY ? max : max * 100],
      range: colorsRange
    });
  }, [metric, min, max, color]);
  var getFillColor = React.useCallback(function (item) {
    if (!metric) {
      return '#d8d7ea';
    }

    var value = item[metric] || 0;

    if (metric !== METRICS.AFFINITY) {
      value = value * 100;
    }

    return colorScale(value);
  }, [metric, colorScale]);
  var rScale = React.useMemo(function () {
    return scale.scaleSqrt({
      domain: [min, max],
      range: [0, 20],
      nice: true
    });
  }, [min, max]);
  var getCircles = React.useCallback(function (abbr, projection) {
    var stateCounties = counties.filter(function (county) {
      return abbr === county.abbr;
    });
    return stateCounties.map(function (county) {
      var countyData = data && data.find(function (item) {
        return item.id === county.id;
      });
      return {
        id: county.id,
        radius: metric && countyData && rScale(countyData[metric]) || 0,
        position: projection([county.lng, county.lat]),
        data: countyData
      };
    });
  }, [data, metric, rScale]);

  if (isEmpty) {
    return /*#__PURE__*/React__default.createElement(StyledUsaMapChartWrapper, null, /*#__PURE__*/React__default.createElement(hxReactComponents.Box, {
      minWidth: "100%"
    }, /*#__PURE__*/React__default.createElement(hxReactComponents.EmptyState, {
      icon: "analytics",
      mainText: emptyDataMessage,
      size: "large"
    })));
  }

  return /*#__PURE__*/React__default.createElement(StyledUsaMapChartWrapper, {
    ref: chartRef
  }, /*#__PURE__*/React__default.createElement("svg", {
    width: width,
    height: height,
    ref: svgRef
  }, /*#__PURE__*/React__default.createElement(geo.AlbersUsa, {
    data: states,
    scale: scale$1,
    translate: [centerX, centerY - 25]
  }, function (_ref2) {
    var features = _ref2.features;
    return features.map(function (_ref3, i) {
      var feature = _ref3.feature,
          path = _ref3.path;
      var abbr = statesAbbr.find(function (abbr) {
        return abbr.id === feature.id;
      });
      var abbrLabel = abbr && abbr.label || '';
      var included = data && data.find(function (item) {
        return item.id === abbrLabel;
      });

      if (!included || type === 'counties') {
        return /*#__PURE__*/React__default.createElement(React__default.Fragment, {
          key: "map-" + chartId.current + "-feature-fragment-" + i
        }, /*#__PURE__*/React__default.createElement(StyledMapFeatureSvg, {
          key: "map-" + chartId.current + "-feature-svg-" + i,
          selectable: false
        }, /*#__PURE__*/React__default.createElement("path", {
          key: "map-" + chartId.current + "-feature-" + i,
          d: path || '',
          fill: type === 'counties' ? '#e6ebee' : '#d8d7ea',
          stroke: type === 'counties' ? '#afb3b4' : '#ffffff',
          strokeWidth: 1
        })));
      }

      return /*#__PURE__*/React__default.createElement(React__default.Fragment, {
        key: "map-" + chartId.current + "-feature-fragment-" + i
      }, /*#__PURE__*/React__default.createElement(StyledMapFeatureSvg, {
        key: "map-" + chartId.current + "-feature-svg-" + i,
        metric: metric,
        selectable: true
      }, /*#__PURE__*/React__default.createElement("path", {
        key: "map-" + chartId.current + "-feature-" + i,
        d: path || '',
        fill: getFillColor(included),
        stroke: "#ffffff",
        strokeWidth: 1,
        onMouseOver: function onMouseOver(event) {
          return handleMouseMove(event, included, getFillColor(included));
        },
        onMouseMove: function onMouseMove(event) {
          return handleMouseMove(event, included, getFillColor(included));
        },
        onMouseLeave: function onMouseLeave(event) {
          return handleMouseLeave(event);
        },
        onClick: function onClick() {
          onItemClick && onItemClick(included);
        }
      })));
    });
  }), metric && type === 'counties' && /*#__PURE__*/React__default.createElement(geo.AlbersUsa, {
    data: states,
    scale: scale$1,
    translate: [centerX, centerY - 25]
  }, function (_ref4) {
    var features = _ref4.features;
    return features.map(function (_ref5, i) {
      var feature = _ref5.feature,
          projection = _ref5.projection;
      var abbr = statesAbbr.find(function (abbr) {
        return abbr.id === feature.id;
      });
      var abbrLabel = abbr && abbr.label || '';
      var circles = getCircles(abbrLabel, projection);
      return /*#__PURE__*/React__default.createElement(React__default.Fragment, {
        key: "map-" + chartId.current + "-feature-fragment-with-circle-" + i
      }, /*#__PURE__*/React__default.createElement(StyledMapFeatureSvg, {
        key: "map-" + chartId.current + "-feature-svg-with-circle-" + i,
        selectable: false
      }, circles && circles.map(function (circle, indx) {
        return /*#__PURE__*/React__default.createElement(shape.Circle, {
          key: "county-" + chartId.current + "-feature-" + i + "-" + indx,
          r: circle.radius,
          cx: circle.position && circle.position[0] || 0,
          cy: circle.position && circle.position[1] || 0,
          fill: color || '#41b6a8',
          fillOpacity: 0.5,
          onMouseOver: function onMouseOver(event) {
            return handleMouseMove(event, circle.data);
          },
          onMouseMove: function onMouseMove(event) {
            return handleMouseMove(event, circle.data);
          },
          onMouseLeave: function onMouseLeave(event) {
            return handleMouseLeave(event);
          }
        });
      })));
    });
  }), metric && type !== 'counties' && /*#__PURE__*/React__default.createElement(group.Group, {
    top: yMax - 40,
    left: centerX - 100
  }, /*#__PURE__*/React__default.createElement(gradient.LinearGradient, {
    from: colorsRange[0],
    to: colorsRange[1],
    id: "legend-gradient-" + color,
    vertical: false
  }), /*#__PURE__*/React__default.createElement(text.Text, {
    fontSize: "10px",
    fontWeight: "bold",
    textAnchor: "middle",
    verticalAnchor: "middle",
    fill: "#000000",
    width: 100,
    height: 20,
    x: 0,
    y: -10
  }, FormatUtils.formattedValue(min, metric)), /*#__PURE__*/React__default.createElement(text.Text, {
    fontSize: "10px",
    fontWeight: "bold",
    textAnchor: "middle",
    verticalAnchor: "middle",
    fill: "#000000",
    width: 100,
    height: 20,
    x: 200,
    y: -10
  }, "" + FormatUtils.formattedValue(max, metric)), /*#__PURE__*/React__default.createElement("rect", {
    width: 200,
    height: 20,
    fill: "url(#legend-gradient-" + color + ")"
  }), /*#__PURE__*/React__default.createElement(text.Text, {
    fontSize: "10px",
    fontWeight: "bold",
    textAnchor: "middle",
    verticalAnchor: "middle",
    fill: "#000000",
    width: 100,
    height: 20,
    x: 100,
    y: 30
  }, MAP_CHART_FIELDS_LABEL[metric]))), tooltipContent);
};

var BubbleImage = function BubbleImage(_ref) {
  var item = _ref.item,
      x = _ref.x,
      y = _ref.y,
      radius = _ref.radius,
      color = _ref.color,
      showItemsPreview = _ref.showItemsPreview,
      onMouseMove = _ref.onMouseMove,
      onMouseLeave = _ref.onMouseLeave,
      chartId = _ref.chartId;

  var _useState = React.useState(false),
      errorLoadingImage = _useState[0],
      setErrorLoadingImage = _useState[1];

  React.useEffect(function () {
    setErrorLoadingImage(false);
  }, [item.pic]);
  var onErrorLoadingImage = React.useCallback(function () {
    setErrorLoadingImage(true);
  }, []);

  if (!item.pic || !showItemsPreview || errorLoadingImage) {
    return /*#__PURE__*/React__default.createElement("svg", {
      overflow: "visible"
    }, /*#__PURE__*/React__default.createElement(group.Group, null, /*#__PURE__*/React__default.createElement(shape.Circle, {
      r: radius,
      cx: x,
      cy: y,
      fill: color,
      fillOpacity: 0.8,
      onMouseMove: onMouseMove,
      onMouseLeave: onMouseLeave,
      onTouchMove: onMouseMove,
      onTouchEnd: onMouseLeave
    }), /*#__PURE__*/React__default.createElement(text.Text, {
      height: radius * 2,
      width: radius * 2,
      x: x,
      y: y,
      fontSize: "10px",
      textAnchor: "middle",
      verticalAnchor: "middle",
      fill: "#000000"
    }, FormatUtils.capitalizeString(FormatUtils.truncateString(item.label, 15)))));
  }

  return /*#__PURE__*/React__default.createElement("svg", {
    overflow: "visible"
  }, /*#__PURE__*/React__default.createElement("image", {
    href: item.pic,
    height: radius * 2,
    width: radius * 2,
    clipPath: "url(#icon-" + chartId + "-" + item.id + ")",
    x: x - radius,
    y: y - radius,
    onMouseMove: onMouseMove,
    onMouseLeave: onMouseLeave,
    onTouchMove: onMouseMove,
    onTouchEnd: onMouseLeave,
    onError: onErrorLoadingImage
  }), /*#__PURE__*/React__default.createElement(clipPath.CircleClipPath, {
    id: "icon-" + chartId + "-" + item.id,
    key: "icon-" + chartId + "-" + item.id,
    className: "dot",
    r: radius,
    cx: x,
    cy: y
  }), /*#__PURE__*/React__default.createElement(shape.Circle, {
    r: radius,
    cx: x,
    cy: y,
    fill: "none",
    stroke: color,
    strokeWidth: "2"
  }));
};

function _templateObject$d() {
  var data = _taggedTemplateLiteralLoose(["\n  width: 100%;\n  height: 100%;\n  position: relative;\n  background-color: #ffffff;\n  padding: 10px;\n"]);

  _templateObject$d = function _templateObject() {
    return data;
  };

  return data;
}
var StyledBubbleChartWrapper = styled__default.div(_templateObject$d());
var tooltipTimeout$8;
var defaultMargin$7 = {
  top: 50,
  right: 50,
  bottom: 50,
  left: 100
};

var BubbleChart = function BubbleChart(_ref) {
  var data = _ref.data,
      _ref$margin = _ref.margin,
      margin = _ref$margin === void 0 ? defaultMargin$7 : _ref$margin,
      xAxis = _ref.xAxis,
      yAxis = _ref.yAxis,
      zAxis = _ref.zAxis,
      color = _ref.color,
      emptyDataMessage = _ref.emptyDataMessage,
      _ref$limit = _ref.limit,
      limit = _ref$limit === void 0 ? 'auto' : _ref$limit,
      showItemsPreview = _ref.showItemsPreview;
  var isEmpty = !data || data.length === 0;
  var svgRef = React.useRef(null);
  var chartId = React.useRef(uniqid());

  var _useState = React.useState(0),
      width = _useState[0],
      setWidth = _useState[1];

  var _useState2 = React.useState(0),
      height = _useState2[0],
      setHeight = _useState2[1];

  var _useTooltip = tooltip.useTooltip(),
      tooltipOpen = _useTooltip.tooltipOpen,
      tooltipLeft = _useTooltip.tooltipLeft,
      tooltipTop = _useTooltip.tooltipTop,
      tooltipData = _useTooltip.tooltipData,
      hideTooltip = _useTooltip.hideTooltip,
      showTooltip = _useTooltip.showTooltip;

  var windowSize = useWindowSize();
  var chartRef = React.useCallback(function (node) {
    if (node != null) {
      setWidth(node.getBoundingClientRect().width);
      setHeight(node.getBoundingClientRect().height);
    }
  }, [windowSize]);
  var filteredData = React.useMemo(function () {
    if (isEmpty) {
      return [];
    }

    return limit !== 'auto' ? data.slice(0, limit) : data;
  }, [isEmpty, data, limit]);

  var _ref2 = filteredData && filteredData.reduce(function (_ref3, item) {
    var xList = _ref3[0],
        yList = _ref3[1],
        rList = _ref3[2];
    xList.push(item[xAxis]);
    yList.push(item[yAxis]);
    rList.push(zAxis === METRICS.BASE ? item[zAxis] * 100 : item[zAxis]);
    return [xList, yList, rList];
  }, [[], [], []]) || [[], [], []],
      xValues = _ref2[0],
      yValues = _ref2[1],
      rValues = _ref2[2];

  var minMaxValues = React.useMemo(function () {
    return {
      xMin: Math.min.apply(Math, xValues),
      xMax: Math.max.apply(Math, xValues),
      yMin: Math.min.apply(Math, yValues),
      yMax: Math.max.apply(Math, yValues),
      rMin: Math.min.apply(Math, rValues),
      rMax: Math.max.apply(Math, rValues)
    };
  }, [xValues, yValues, rValues]);
  var xDiff = Math.max(minMaxValues.xMax - minMaxValues.xMin, 0);
  var yDiff = Math.max(minMaxValues.yMax - minMaxValues.yMin, 0);
  var yDomain = React.useMemo(function () {
    return [minMaxValues.yMin - yDiff / 3, minMaxValues.yMax + yDiff / 3];
  }, [minMaxValues, yDiff]);
  var xDomain = React.useMemo(function () {
    return [minMaxValues.xMin - xDiff / 10 < 0 ? 0 : minMaxValues.xMin - xDiff / 10, minMaxValues.xMax + xDiff / 10];
  }, [minMaxValues, xDiff]);
  var xScale = React.useMemo(function () {
    return scale.scaleLinear({
      domain: xDomain,
      range: [0, minMaxValues.xMax],
      nice: true
    });
  }, [minMaxValues, xDomain]);
  var yScale = React.useMemo(function () {
    return scale.scaleLinear({
      domain: yDomain,
      range: [minMaxValues.yMax, 0],
      nice: true
    });
  }, [minMaxValues, yDomain]);
  var rScale = React.useMemo(function () {
    return scale.scaleSqrt({
      domain: [minMaxValues.rMin, minMaxValues.rMax],
      range: [10, 50],
      nice: true
    });
  }, [minMaxValues]);
  var colorScale = React.useMemo(function () {
    return scale.scaleLinear({
      domain: [0, isEmpty ? 0 : filteredData.length / 2, isEmpty ? 0 : filteredData.length],
      range: getColors(color)
    });
  }, [isEmpty, filteredData, color]);
  var xMax = width - margin.left - margin.right;
  var yMax = height - margin.top - margin.bottom;
  xScale.rangeRound([0, xMax]);
  yScale.rangeRound([yMax, 0]);
  var yTicks = Math.min(yAxis === METRICS.AFFINITY ? yDiff : yDiff <= 0.01 ? 1 : yDiff * 100, 10);
  var xTicks = React.useMemo(function () {
    var min = xDiff < 1 ? 5 : xDiff + 4;

    if (xAxis !== METRICS.AFFINITY) {
      min = xDiff <= 0.01 ? 1 : xDiff * 100;
    }

    if (width < 520) {
      return Math.min(min, 2);
    }

    return Math.min(min, 10);
  }, [xDiff, width]);
  var handleMouseLeave = React.useCallback(function (event) {
    tooltipTimeout$8 = window.setTimeout(function () {
      hideTooltip();
    }, 0);
  }, [hideTooltip]);
  var handleMouseMove = React.useCallback(function (event$1, item, indx) {
    if (tooltipTimeout$8) clearTimeout(tooltipTimeout$8);
    var eventSvgCoords = event.localPoint(event$1);
    showTooltip({
      tooltipData: _extends({}, item, {
        color: item.color || colorScale(indx)
      }),
      tooltipTop: eventSvgCoords === null || eventSvgCoords === void 0 ? void 0 : eventSvgCoords.y,
      tooltipLeft: eventSvgCoords === null || eventSvgCoords === void 0 ? void 0 : eventSvgCoords.x
    });
  }, [showTooltip, colorScale]);

  if (isEmpty) {
    return /*#__PURE__*/React__default.createElement(StyledBubbleChartWrapper, null, /*#__PURE__*/React__default.createElement(hxReactComponents.Box, {
      minWidth: "100%"
    }, /*#__PURE__*/React__default.createElement(hxReactComponents.EmptyState, {
      icon: "analytics",
      mainText: emptyDataMessage,
      size: "large"
    })));
  }

  return /*#__PURE__*/React__default.createElement(StyledBubbleChartWrapper, {
    ref: chartRef
  }, /*#__PURE__*/React__default.createElement("svg", {
    ref: svgRef,
    width: width,
    height: height
  }, /*#__PURE__*/React__default.createElement("rect", {
    width: width,
    height: height,
    fill: "#ffffff",
    rx: 14
  }), /*#__PURE__*/React__default.createElement(grid.Grid, {
    top: margin.top,
    left: margin.left,
    xScale: xScale,
    yScale: yScale,
    width: xMax,
    height: yMax,
    numTicksRows: yTicks
  }), /*#__PURE__*/React__default.createElement(group.Group, {
    top: margin.top,
    left: margin.left,
    key: "group-" + chartId.current
  }, filteredData.map(function (item, indx) {
    var radius = rScale(zAxis === METRICS.BASE ? item[zAxis] * 100 : item[zAxis]);
    var bubbleX = xScale(item[xAxis]);
    var bubbleY = yScale(item[yAxis]);

    if (bubbleX && bubbleY) {
      return /*#__PURE__*/React__default.createElement(React__default.Fragment, {
        key: "bubble-" + chartId.current + "-" + item.id
      }, /*#__PURE__*/React__default.createElement(BubbleImage, {
        item: item,
        x: bubbleX,
        y: bubbleY,
        radius: radius,
        color: item.color || colorScale(indx),
        onMouseMove: function onMouseMove(event) {
          return handleMouseMove(event, item, indx);
        },
        onMouseLeave: function onMouseLeave(event) {
          return handleMouseLeave(event);
        },
        chartId: chartId.current,
        showItemsPreview: showItemsPreview
      }));
    }

    return null;
  }), /*#__PURE__*/React__default.createElement(axis.AxisLeft, {
    label: MAP_CHART_FIELDS_LABEL[yAxis],
    scale: yScale,
    stroke: "#9493A6",
    tickStroke: "#9493A6",
    tickFormat: function tickFormat(d) {
      return FormatUtils.formattedValue(d, yAxis);
    },
    tickLabelProps: function tickLabelProps() {
      return {
        fill: '#9493A6',
        fontSize: 11,
        textAnchor: 'end',
        dy: '0.33em',
        dx: '-0.33em',
        fontWeight: 'bold'
      };
    },
    labelProps: {
      fill: 'black',
      textAnchor: 'middle',
      fontSize: 14,
      fontWeight: 'bold',
      dx: '-1.2em'
    },
    numTicks: yTicks
  }), /*#__PURE__*/React__default.createElement(axis.AxisBottom, {
    label: MAP_CHART_FIELDS_LABEL[xAxis],
    top: yMax,
    scale: xScale,
    numTicks: xTicks,
    stroke: "#9493A6",
    tickStroke: "#9493A6",
    tickFormat: function tickFormat(d) {
      return FormatUtils.formattedValue(d, xAxis);
    },
    tickLabelProps: function tickLabelProps() {
      return {
        fill: '#9493A6',
        fontSize: 11,
        textAnchor: 'middle',
        fontWeight: 'bold'
      };
    },
    labelProps: {
      fill: 'black',
      textAnchor: 'middle',
      fontSize: 14,
      fontWeight: 'bold'
    }
  }))), tooltipOpen && tooltipData && /*#__PURE__*/React__default.createElement(ChartTooltip, {
    opened: tooltipOpen,
    top: tooltipTop || 0,
    left: tooltipLeft || 0,
    data: tooltipData
  }, /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Reach: "), FormatUtils.formattedValue(getPopulationPerc(tooltipData), METRICS.REACH)), /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Affinity: "), FormatUtils.formattedValue(tooltipData.target_audience_affinity, METRICS.AFFINITY)), /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Base: "), FormatUtils.formattedValue(tooltipData.base_population_perc, METRICS.BASE)), /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Penetration: "), FormatUtils.formattedValue(tooltipData.penetration, METRICS.PENETRATION))));
};

function _templateObject$e() {
  var data = _taggedTemplateLiteralLoose(["\n  position: relative;\n  width: 100%;\n  height: 100%;\n"]);

  _templateObject$e = function _templateObject() {
    return data;
  };

  return data;
}
var StyledCloudChartWrapper = styled__default.div(_templateObject$e());

function _templateObject8$1() {
  var data = _taggedTemplateLiteralLoose(["\n  width: 100%;\n  height: 100%;\n  transform-origin: top left;\n  position: absolute;\n  top: 50%;\n  left: 50%;\n  background-color: ", ";\n  transform: ", ";\n"]);

  _templateObject8$1 = function _templateObject8() {
    return data;
  };

  return data;
}

function _templateObject7$1() {
  var data = _taggedTemplateLiteralLoose(["\n  overflow: hidden;\n  position: absolute;\n  border-radius: 50%;\n  background-size: cover;\n  border: 1px solid rgba(205, 205, 205, 0.7);\n  cursor: pointer;\n  transition: all 0.4s;\n  width: 100%;\n  height: 100%;\n"]);

  _templateObject7$1 = function _templateObject7() {
    return data;
  };

  return data;
}

function _templateObject6$3() {
  var data = _taggedTemplateLiteralLoose(["\n  position: absolute;\n  top: 0;\n  left: 0;\n  width: 100%;\n  height: 100%;\n  display: flex;\n  align-items: center;\n  justify-content: center;\n  color: white;\n"]);

  _templateObject6$3 = function _templateObject6() {
    return data;
  };

  return data;
}

function _templateObject5$3() {
  var data = _taggedTemplateLiteralLoose(["\n  z-index: 2;\n  width: 49%;\n  padding-top: 49%;\n  border-radius: 50%;\n  display: inline-block;\n  position: relative;\n  background-color: ", ";\n"]);

  _templateObject5$3 = function _templateObject5() {
    return data;
  };

  return data;
}

function _templateObject4$5() {
  var data = _taggedTemplateLiteralLoose(["\n  position: relative;\n  width: 74%;\n  top: 57%;\n  left: 13%;\n"]);

  _templateObject4$5 = function _templateObject4() {
    return data;
  };

  return data;
}

function _templateObject3$7() {
  var data = _taggedTemplateLiteralLoose(["\n  color: white;\n  text-align: center;\n  font-size: 50%;\n  width: 100%;\n  height: 100%;\n  position: absolute;\n  border-radius: 50%;\n"]);

  _templateObject3$7 = function _templateObject3() {
    return data;
  };

  return data;
}

function _templateObject2$7() {
  var data = _taggedTemplateLiteralLoose(["\n  z-index: 1;\n  border: ", ";\n  background-size: cover;\n  transform: ", ";\n  width: 100%;\n  height: 100%;\n  position: absolute;\n  border-radius: 50%;\n"]);

  _templateObject2$7 = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$f() {
  var data = _taggedTemplateLiteralLoose(["\n  background-color: ", ";\n  color: white;\n  font-size: 10px;\n  text-align: center;\n  display: flex;\n  justify-content: center;\n  align-items: center;\n  z-index: 1;\n  width: 100%;\n  height: 100%;\n  position: absolute;\n  border-radius: 50%;\n  transform: ", ";\n"]);

  _templateObject$f = function _templateObject() {
    return data;
  };

  return data;
}
var StyledPreviewText = styled__default.div(_templateObject$f(), function (props) {
  return props.color;
}, function (props) {
  return props.isScaled && "scale(0.9)";
});
var StyledPreviewImg = styled__default.img(_templateObject2$7(), function (props) {
  return props.isScaled ? '' : "2px solid " + props.color;
}, function (props) {
  return props.isScaled && "scale(0.9)";
});
var StyledBubbleWrapper = styled__default.div(_templateObject3$7());
var StyledBubbleContainer = styled__default.div(_templateObject4$5());
var StyledBubble = styled__default.div(_templateObject5$3(), function (props) {
  return props.color;
});
var StyledBubbleContent = styled__default.div(_templateObject6$3());
var StyledSlicesWrapper = styled__default.div(_templateObject7$1());
var StyledBubbleSlice = styled__default.div(_templateObject8$1(), function (props) {
  return props.color;
}, function (props) {
  return "rotate(" + props.rotate + "deg) skew(" + props.skew + "deg)";
});

var CloudChartImage = function CloudChartImage(_ref) {
  var id = _ref.id,
      x = _ref.x,
      y = _ref.y,
      radius = _ref.radius,
      color = _ref.color,
      pic = _ref.pic,
      label = _ref.label,
      children = _ref.children,
      slices = _ref.slices;

  var _useState = React.useState(false),
      errorLoadingImage = _useState[0],
      setErrorLoadingImage = _useState[1];

  React.useEffect(function () {
    setErrorLoadingImage(false);
  }, [pic]);
  var onErrorLoadingImage = React.useCallback(function () {
    setErrorLoadingImage(true);
  }, []);

  if (!pic || errorLoadingImage) {
    return /*#__PURE__*/React__default.createElement("div", {
      style: {
        position: 'absolute',
        width: radius * 2 + 'px',
        height: radius * 2 + 'px',
        left: x - radius + 'px',
        top: y - radius + 'px',
        borderRadius: '50%',
        backgroundColor: color
      }
    }, /*#__PURE__*/React__default.createElement(StyledPreviewText, {
      isScaled: slices && slices.length > 0,
      color: color
    }, FormatUtils.capitalizeString(FormatUtils.truncateString(label, 15))), slices && /*#__PURE__*/React__default.createElement(StyledSlicesWrapper, null, slices.map(function (slice, i) {
      return /*#__PURE__*/React__default.createElement(StyledBubbleSlice, {
        key: "bubble-slice-" + i,
        rotate: slice.rotate,
        skew: slice.skew,
        color: slice.color
      });
    })), children && /*#__PURE__*/React__default.createElement(StyledBubbleWrapper, null, /*#__PURE__*/React__default.createElement(StyledBubbleContainer, null, children.map(function (bubble, i) {
      return /*#__PURE__*/React__default.createElement(StyledBubble, {
        key: "bubble-item-" + i + "-" + id,
        color: bubble.color
      }, /*#__PURE__*/React__default.createElement(StyledBubbleContent, null, bubble.label));
    }))));
  }

  return /*#__PURE__*/React__default.createElement("div", {
    style: {
      position: 'absolute',
      width: radius * 2 + 'px',
      height: radius * 2 + 'px',
      left: x - radius + 'px',
      top: y - radius + 'px',
      borderRadius: '50%',
      backgroundColor: color
    }
  }, /*#__PURE__*/React__default.createElement(StyledPreviewImg, {
    color: color,
    src: pic,
    onError: onErrorLoadingImage,
    isScaled: slices && slices.length > 0
  }), slices && /*#__PURE__*/React__default.createElement(StyledSlicesWrapper, null, slices.map(function (slice, i) {
    return /*#__PURE__*/React__default.createElement(StyledBubbleSlice, {
      key: "bubble-slice-" + i,
      rotate: slice.rotate,
      skew: slice.skew,
      color: slice.color
    });
  })), children && /*#__PURE__*/React__default.createElement(StyledBubbleWrapper, null, /*#__PURE__*/React__default.createElement(StyledBubbleContainer, null, children.map(function (bubble, i) {
    return /*#__PURE__*/React__default.createElement(StyledBubble, {
      key: "bubble-item-" + i + "-" + id,
      color: bubble.color
    }, /*#__PURE__*/React__default.createElement(StyledBubbleContent, null, bubble.label));
  }))));
};

var tooltipTimeout$9;

var CloudChart = function CloudChart(_ref) {
  var _pack;

  var data = _ref.data,
      metric = _ref.metric,
      _ref$limit = _ref.limit,
      limit = _ref$limit === void 0 ? 'auto' : _ref$limit,
      color = _ref.color,
      emptyDataMessage = _ref.emptyDataMessage;
  var svgRef = React.useRef(null);
  var chartId = React.useRef(uniqid());

  var _useState = React.useState(0),
      width = _useState[0],
      setWidth = _useState[1];

  var _useState2 = React.useState(0),
      height = _useState2[0],
      setHeight = _useState2[1];

  var isEmpty = !data || data.length === 0;

  var _useTooltip = tooltip.useTooltip(),
      tooltipOpen = _useTooltip.tooltipOpen,
      tooltipLeft = _useTooltip.tooltipLeft,
      tooltipTop = _useTooltip.tooltipTop,
      tooltipData = _useTooltip.tooltipData,
      hideTooltip = _useTooltip.hideTooltip,
      showTooltip = _useTooltip.showTooltip;

  var windowSize = useWindowSize();
  var chartRef = React.useCallback(function (node) {
    if (node != null) {
      setWidth(node.getBoundingClientRect().width);
      setHeight(node.getBoundingClientRect().height);
    }
  }, [windowSize]);
  var colorScale = React.useMemo(function () {
    return scale.scaleLinear({
      domain: [0, isEmpty ? 0 : data.length / 2, isEmpty ? 0 : data.length],
      range: getColors(color)
    });
  }, [isEmpty, data, color]);
  var handleMouseLeave = React.useCallback(function (event) {
    tooltipTimeout$9 = window.setTimeout(function () {
      hideTooltip();
    }, 0);
  }, [hideTooltip]);
  var handleMouseMove = React.useCallback(function (event$1, item) {
    if (tooltipTimeout$9) clearTimeout(tooltipTimeout$9);
    var eventSvgCoords = event.localPoint(svgRef.current, event$1);
    showTooltip({
      tooltipData: _extends({}, item),
      tooltipTop: eventSvgCoords === null || eventSvgCoords === void 0 ? void 0 : eventSvgCoords.y,
      tooltipLeft: eventSvgCoords === null || eventSvgCoords === void 0 ? void 0 : eventSvgCoords.x
    });
  }, [showTooltip, colorScale]);
  var packData = React.useMemo(function () {
    if (isEmpty) {
      return [];
    }

    var filteredData = limit !== 'auto' ? data.slice(0, limit) : data;
    var list = filteredData.map(function (item, index) {
      return _extends({}, item, {
        color: colorScale(index)
      });
    });
    list.sort(function (a, b) {
      return b[metric] - a[metric];
    });
    return list;
  }, [data, metric, limit]);

  if (isEmpty) {
    return /*#__PURE__*/React__default.createElement(StyledCloudChartWrapper, null, /*#__PURE__*/React__default.createElement(hxReactComponents.Box, {
      minWidth: "100%"
    }, /*#__PURE__*/React__default.createElement(hxReactComponents.EmptyState, {
      icon: "analytics",
      mainText: emptyDataMessage,
      size: "large"
    })));
  }

  var pack = (_pack = {
    children: packData,
    name: 'root'
  }, _pack[metric] = 0, _pack);
  var root = hierarchy.hierarchy(pack).sum(function (d) {
    return d[metric];
  });
  return /*#__PURE__*/React__default.createElement(StyledCloudChartWrapper, {
    ref: chartRef
  }, /*#__PURE__*/React__default.createElement("svg", {
    width: width,
    height: height,
    ref: svgRef
  }, /*#__PURE__*/React__default.createElement("rect", {
    fill: "white",
    width: width,
    height: height,
    rx: 14
  }), /*#__PURE__*/React__default.createElement(group.Group, {
    top: 0,
    left: 0,
    key: "group-" + chartId.current
  }, /*#__PURE__*/React__default.createElement(hierarchy.Pack, {
    root: root,
    size: [width, height]
  }, function (packData) {
    var circles = packData.descendants().slice(1);
    console.log(packData);
    return /*#__PURE__*/React__default.createElement("foreignObject", {
      x: "0",
      y: "0",
      width: width,
      height: height
    }, circles.map(function (circle, i) {
      if (circle.x >= 0 && circle.y >= 0 && circle.r >= 0 && !circle.data.parent) {
        return /*#__PURE__*/React__default.createElement("div", {
          key: "circle-" + chartId.current + "-" + i,
          onMouseMove: function onMouseMove(event) {
            return handleMouseMove(event, circle.data);
          },
          onMouseLeave: function onMouseLeave(event) {
            return handleMouseLeave(event);
          }
        }, /*#__PURE__*/React__default.createElement(CloudChartImage, {
          radius: circle.r,
          x: circle.x,
          y: circle.y,
          label: circle.data && circle.data.label,
          color: circle.data && circle.data.color || '#c6c6c6',
          pic: circle.data && circle.data.pic,
          children: circle.data.children,
          slices: circle.data.slices
        }));
      }
    }));
  }))), tooltipOpen && tooltipData && /*#__PURE__*/React__default.createElement(ChartTooltip, {
    opened: tooltipOpen,
    top: tooltipTop || 0,
    left: tooltipLeft || 0,
    data: tooltipData
  }, /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Reach: "), FormatUtils.formattedValue(getPopulationPerc(tooltipData), METRICS.REACH)), /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Affinity: "), FormatUtils.formattedValue(tooltipData.target_audience_affinity, METRICS.AFFINITY)), /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Base: "), FormatUtils.formattedValue(tooltipData.base_population_perc, METRICS.BASE)), /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Penetration: "), FormatUtils.formattedValue(tooltipData.penetration, METRICS.PENETRATION))));
};

function _templateObject$g() {
  var data = _taggedTemplateLiteralLoose(["\n  display: flex;\n  flex-direction: row;\n  width: 100%;\n  height: 100%;\n  position: relative;\n  background-color: #ffffff;\n  padding: 10px;\n"]);

  _templateObject$g = function _templateObject() {
    return data;
  };

  return data;
}
var StyledDoubleChartWrapper = styled__default.div(_templateObject$g());
var defaultMargin$8 = {
  left: {
    top: 50,
    right: 50,
    bottom: 50,
    left: 100
  },
  right: {
    top: 50,
    right: 50,
    bottom: 50,
    left: 20
  }
};

var DoubleChart = function DoubleChart(_ref) {
  var _ref$margin = _ref.margin,
      margin = _ref$margin === void 0 ? defaultMargin$8 : _ref$margin,
      data = _ref.data,
      x1Axis = _ref.x1Axis,
      x2Axis = _ref.x2Axis,
      zAxis = _ref.zAxis,
      color = _ref.color,
      emptyDataMessage = _ref.emptyDataMessage,
      _ref$limit = _ref.limit,
      limit = _ref$limit === void 0 ? 'auto' : _ref$limit,
      showItemsPreview = _ref.showItemsPreview,
      limitText = _ref.limitText,
      textWidth = _ref.textWidth;
  var chartId = React.useRef(uniqid());
  var isEmpty = !data || data.length === 0;

  if (isEmpty) {
    return /*#__PURE__*/React__default.createElement(StyledDoubleChartWrapper, null, /*#__PURE__*/React__default.createElement(hxReactComponents.Box, {
      minWidth: "100%"
    }, /*#__PURE__*/React__default.createElement(hxReactComponents.EmptyState, {
      icon: "analytics",
      mainText: emptyDataMessage,
      size: "large"
    })));
  }

  return /*#__PURE__*/React__default.createElement(StyledDoubleChartWrapper, null, /*#__PURE__*/React__default.createElement("div", {
    style: {
      width: '50%',
      height: '100%'
    }
  }, /*#__PURE__*/React__default.createElement(StackedChart, {
    key: "stacked-bar-left-" + chartId.current,
    limit: limit,
    xAxis: x1Axis,
    zAxis: zAxis,
    data: data,
    color: color,
    margin: margin.left,
    showItemsPreview: showItemsPreview,
    includedInDouble: true,
    limitText: limitText,
    textWidth: textWidth
  })), /*#__PURE__*/React__default.createElement("div", {
    style: {
      width: '50%',
      height: '100%'
    }
  }, /*#__PURE__*/React__default.createElement(StackedChart, {
    key: "stacked-bar-right-" + chartId.current,
    limit: limit,
    xAxis: x2Axis,
    zAxis: zAxis,
    data: data,
    color: color,
    margin: margin.right,
    showAxisLeft: false,
    includedInDouble: true,
    limitText: limitText,
    textWidth: textWidth
  })));
};

function _templateObject9$1() {
  var data = _taggedTemplateLiteralLoose(["\n  font-size: 14px;\n  font-weight: 500;\n  color: rgb(148, 147, 166);\n  margin-right: 10px;\n  text-align: end;\n"]);

  _templateObject9$1 = function _templateObject9() {
    return data;
  };

  return data;
}

function _templateObject8$2() {
  var data = _taggedTemplateLiteralLoose(["\n  font-size: 14px;\n  font-weight: 400;\n  color: rgb(148, 147, 166);\n  margin-right: 10px;\n"]);

  _templateObject8$2 = function _templateObject8() {
    return data;
  };

  return data;
}

function _templateObject7$2() {
  var data = _taggedTemplateLiteralLoose(["\n  padding-top: 10px;\n  font-size: 11px;\n  font-weight: 300;\n  color: rgb(148, 147, 166);\n"]);

  _templateObject7$2 = function _templateObject7() {
    return data;
  };

  return data;
}

function _templateObject6$4() {
  var data = _taggedTemplateLiteralLoose(["\n  font-size: 16px;\n  font-weight: 500;\n  color: rgb(148, 147, 166);\n"]);

  _templateObject6$4 = function _templateObject6() {
    return data;
  };

  return data;
}

function _templateObject5$4() {
  var data = _taggedTemplateLiteralLoose(["\n  width: 83%;\n  display: flex;\n  align-items: left;\n  flex-direction: column;\n  padding-left: 10px;\n"]);

  _templateObject5$4 = function _templateObject5() {
    return data;
  };

  return data;
}

function _templateObject4$6() {
  var data = _taggedTemplateLiteralLoose(["\n  width: 100%;\n  height: 86px;\n  border-bottom: 1px solid #cdcdcd;\n  display: flex;\n  align-items: center;\n  justify-content: space-between;\n  flex-direction: row;\n  position: relative;\n"]);

  _templateObject4$6 = function _templateObject4() {
    return data;
  };

  return data;
}

function _templateObject3$8() {
  var data = _taggedTemplateLiteralLoose(["\n  height: 100%;\n  overflow: hidden auto;\n"]);

  _templateObject3$8 = function _templateObject3() {
    return data;
  };

  return data;
}

function _templateObject2$8() {
  var data = _taggedTemplateLiteralLoose(["\n  z-index: 1;\n"]);

  _templateObject2$8 = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$h() {
  var data = _taggedTemplateLiteralLoose(["\n  width: 100%;\n  height: 100%;\n  position: relative;\n  background-color: #ffffff;\n  padding: 10px;\n"]);

  _templateObject$h = function _templateObject() {
    return data;
  };

  return data;
}
var StyledListChartWrapper = styled__default.div(_templateObject$h());
var StyledListChartSvg = styled__default.svg(_templateObject2$8());
var StyledListChartContent = styled__default.div(_templateObject3$8());
var StyledListItem = styled__default.div(_templateObject4$6());
var StyledListItemContent = styled__default.div(_templateObject5$4());
var StyledListItemTitle = styled__default.div(_templateObject6$4());
var StyledListItemSubTitle = styled__default.div(_templateObject7$2());
var StyledListItemValue = styled__default.div(_templateObject8$2());
var StyledListChartMetric = styled__default.div(_templateObject9$1());

function _templateObject3$9() {
  var data = _taggedTemplateLiteralLoose(["\n  font-size: 12px;\n  padding: 1px 1px 0 0;\n  background-color: #cdcdcd;\n  color: white;\n  width: 18px;\n  height: 18px;\n  border-radius: 50%;\n  text-align: center;\n  z-index: 1;\n  position: absolute;\n  left: 10px;\n"]);

  _templateObject3$9 = function _templateObject3() {
    return data;
  };

  return data;
}

function _templateObject2$9() {
  var data = _taggedTemplateLiteralLoose(["\n  margin-left: 10px;\n  width: 50px;\n  height: 50px;\n  border: 1px solid rgba(148, 147, 166, 0.5);\n  border-radius: 50%;\n"]);

  _templateObject2$9 = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$i() {
  var data = _taggedTemplateLiteralLoose(["\n  margin-left: 10px;\n  width: 50px;\n  height: 50px;\n  border: 1px solid rgba(148, 147, 166, 0.5);\n  border-radius: 50%;\n  background-color: ", ";\n"]);

  _templateObject$i = function _templateObject() {
    return data;
  };

  return data;
}
var StyledListItemPreview = styled__default.div(_templateObject$i(), function (props) {
  return props.color;
});
var StyledListItemPreviewImg = styled__default.img(_templateObject2$9());
var StyledListItemNumber = styled__default.div(_templateObject3$9());

var ListChartImage = function ListChartImage(_ref) {
  var index = _ref.index,
      color = _ref.color,
      image = _ref.image;

  var _useState = React.useState(false),
      errorLoadingImage = _useState[0],
      setErrorLoadingImage = _useState[1];

  React.useEffect(function () {
    setErrorLoadingImage(false);
  }, [image]);
  var onErrorLoadingImage = React.useCallback(function () {
    setErrorLoadingImage(true);
  }, []);

  if (!image || errorLoadingImage) {
    return /*#__PURE__*/React__default.createElement("div", null, index && /*#__PURE__*/React__default.createElement(StyledListItemNumber, null, index), /*#__PURE__*/React__default.createElement(StyledListItemPreview, {
      color: color
    }));
  }

  return /*#__PURE__*/React__default.createElement("div", null, index && /*#__PURE__*/React__default.createElement(StyledListItemNumber, null, index), /*#__PURE__*/React__default.createElement(StyledListItemPreviewImg, {
    src: image,
    onError: onErrorLoadingImage
  }));
};

var tooltipTimeout$a;

var ListChart = function ListChart(_ref) {
  var data = _ref.data,
      metric = _ref.metric,
      color = _ref.color;
  var svgRef = React.useRef(null);
  var chartId = React.useRef(uniqid());
  var isEmpty = !data || data.length === 0;

  var _useState = React.useState(0),
      width = _useState[0],
      setWidth = _useState[1];

  var _useState2 = React.useState(0),
      height = _useState2[0],
      setHeight = _useState2[1];

  var windowSize = useWindowSize();
  var chartRef = React.useCallback(function (node) {
    if (node != null) {
      setWidth(node.getBoundingClientRect().width);
      setHeight(node.getBoundingClientRect().height);
    }
  }, [windowSize]);

  var _useTooltip = tooltip.useTooltip(),
      tooltipOpen = _useTooltip.tooltipOpen,
      tooltipLeft = _useTooltip.tooltipLeft,
      tooltipTop = _useTooltip.tooltipTop,
      tooltipData = _useTooltip.tooltipData,
      hideTooltip = _useTooltip.hideTooltip,
      showTooltip = _useTooltip.showTooltip;

  var handleMouseLeave = React.useCallback(function (event) {
    tooltipTimeout$a = window.setTimeout(function () {
      hideTooltip();
    }, 0);
  }, [hideTooltip]);
  var handleMouseMove = React.useCallback(function (event$1, item) {
    if (tooltipTimeout$a) clearTimeout(tooltipTimeout$a);
    if (!svgRef.current) return;
    var eventSvgCoords = event.localPoint(svgRef.current, event$1);
    showTooltip({
      tooltipData: _extends({}, item),
      tooltipTop: eventSvgCoords === null || eventSvgCoords === void 0 ? void 0 : eventSvgCoords.y,
      tooltipLeft: eventSvgCoords === null || eventSvgCoords === void 0 ? void 0 : eventSvgCoords.x
    });
  }, [showTooltip]);
  var colorScale = React.useMemo(function () {
    return scale.scaleLinear({
      domain: [0, isEmpty ? 0 : data.length / 2, isEmpty ? 0 : data.length],
      range: getColors(color)
    });
  }, [isEmpty, data, color]);
  return /*#__PURE__*/React__default.createElement(StyledListChartWrapper, {
    ref: chartRef
  }, /*#__PURE__*/React__default.createElement(StyledListChartSvg, {
    ref: svgRef,
    width: width,
    height: height
  }, /*#__PURE__*/React__default.createElement("rect", {
    width: width,
    height: height,
    fill: "#ffffff"
  }), /*#__PURE__*/React__default.createElement(group.Group, {
    top: 0,
    left: 0,
    key: "group-" + chartId.current
  }, /*#__PURE__*/React__default.createElement("rect", {
    fill: "#ffffff",
    width: width,
    height: height
  }), /*#__PURE__*/React__default.createElement("foreignObject", {
    x: "0",
    y: "0",
    width: width,
    height: height
  }, /*#__PURE__*/React__default.createElement(StyledListChartContent, null, /*#__PURE__*/React__default.createElement(StyledListChartMetric, null, MAP_CHART_FIELDS_LABEL[metric]), data && data.map(function (item) {
    return /*#__PURE__*/React__default.createElement(StyledListItem, {
      key: "list-chart-item-" + item.id,
      onMouseMove: function onMouseMove(event) {
        return handleMouseMove(event, item);
      },
      onMouseLeave: function onMouseLeave(event) {
        return handleMouseLeave(event);
      }
    }, /*#__PURE__*/React__default.createElement(ListChartImage, {
      image: item.pic,
      color: "#d6d6d6",
      index: item.index + 1
    }), /*#__PURE__*/React__default.createElement(StyledListItemContent, null, /*#__PURE__*/React__default.createElement(StyledListItemTitle, null, item.label), /*#__PURE__*/React__default.createElement(StyledListItemSubTitle, null, item.taxonomy)), /*#__PURE__*/React__default.createElement(StyledListItemValue, null, isReach(metric) && /*#__PURE__*/React__default.createElement("div", null, FormatUtils.formattedValue(getPopulationPerc(item), METRICS.REACH)), metric === METRICS.AFFINITY && /*#__PURE__*/React__default.createElement("div", null, FormatUtils.formattedValue(item.target_audience_affinity, METRICS.AFFINITY)), metric === METRICS.BASE && /*#__PURE__*/React__default.createElement("div", null, FormatUtils.formattedValue(item.base_population_perc, METRICS.BASE)), metric === METRICS.PENETRATION && /*#__PURE__*/React__default.createElement("div", null, FormatUtils.formattedValue(item.penetration, METRICS.PENETRATION)), metric === METRICS.RELEVANCY && /*#__PURE__*/React__default.createElement("div", null, FormatUtils.formattedValue(item.relevancy, METRICS.RELEVANCY))));
  }))))), tooltipOpen && tooltipData && /*#__PURE__*/React__default.createElement(ChartTooltip, {
    opened: tooltipOpen,
    top: tooltipTop || 0,
    left: tooltipLeft || 0,
    data: tooltipData
  }, /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Reach: "), FormatUtils.formattedValue(getPopulationPerc(tooltipData), METRICS.REACH)), /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Affinity: "), FormatUtils.formattedValue(tooltipData.target_audience_affinity, METRICS.AFFINITY)), /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Base: "), FormatUtils.formattedValue(tooltipData.base_population_perc, METRICS.BASE)), /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Penetration: "), FormatUtils.formattedValue(tooltipData.penetration, METRICS.PENETRATION))));
};

var arcs$2 = [
	[
		[
			7080,
			7327
		],
		[
			-5,
			4
		],
		[
			-10,
			-10
		],
		[
			5,
			-6
		]
	],
	[
		[
			7070,
			7315
		],
		[
			-16,
			-12
		],
		[
			-9,
			5
		],
		[
			-28,
			-4
		],
		[
			-12,
			-6
		],
		[
			-1,
			-5
		],
		[
			-17,
			-18
		],
		[
			-11,
			-16
		],
		[
			6,
			-10
		],
		[
			6,
			-18
		],
		[
			-2,
			-15
		],
		[
			3,
			-8
		],
		[
			-18,
			-35
		],
		[
			4,
			-12
		],
		[
			-2,
			-18
		],
		[
			-7,
			-5
		],
		[
			-13,
			0
		],
		[
			-13,
			4
		],
		[
			3,
			-16
		],
		[
			6,
			-6
		],
		[
			-1,
			-9
		],
		[
			4,
			-9
		],
		[
			-12,
			-14
		],
		[
			-8,
			0
		],
		[
			-6,
			-18
		],
		[
			2,
			-7
		],
		[
			-6,
			-11
		],
		[
			2,
			-30
		],
		[
			-8,
			-17
		],
		[
			-6,
			-1
		],
		[
			-2,
			8
		],
		[
			-15,
			4
		],
		[
			-3,
			-8
		],
		[
			-14,
			-12
		],
		[
			6,
			-9
		],
		[
			-11,
			-7
		],
		[
			-13,
			6
		],
		[
			-7,
			-15
		],
		[
			-8,
			-7
		],
		[
			-3,
			-19
		],
		[
			2,
			-9
		],
		[
			-4,
			-35
		],
		[
			-32,
			-17
		],
		[
			-16,
			2
		],
		[
			-11,
			-11
		],
		[
			-14,
			6
		],
		[
			-30,
			-5
		],
		[
			-46,
			26
		]
	],
	[
		[
			6689,
			6902
		],
		[
			27,
			56
		],
		[
			1,
			10
		],
		[
			-4,
			21
		],
		[
			-24,
			7
		],
		[
			-1,
			9
		],
		[
			1,
			35
		],
		[
			-7,
			43
		],
		[
			0,
			9
		],
		[
			7,
			14
		],
		[
			1,
			9
		],
		[
			-10,
			5
		],
		[
			0,
			31
		],
		[
			11,
			8
		],
		[
			-5,
			13
		],
		[
			7,
			6
		],
		[
			5,
			26
		],
		[
			-1,
			11
		],
		[
			4,
			19
		]
	],
	[
		[
			6701,
			7234
		],
		[
			8,
			-10
		],
		[
			13,
			-1
		],
		[
			6,
			-7
		],
		[
			1,
			-9
		],
		[
			5,
			8
		],
		[
			5,
			-4
		],
		[
			13,
			13
		],
		[
			0,
			24
		],
		[
			9,
			0
		],
		[
			4,
			6
		],
		[
			20,
			11
		],
		[
			9,
			15
		],
		[
			0,
			16
		],
		[
			5,
			14
		],
		[
			-1,
			9
		],
		[
			9,
			8
		],
		[
			12,
			0
		],
		[
			4,
			16
		],
		[
			4,
			3
		],
		[
			15,
			-14
		],
		[
			5,
			2
		]
	],
	[
		[
			6847,
			7334
		],
		[
			14,
			2
		],
		[
			7,
			-12
		],
		[
			6,
			6
		],
		[
			8,
			-6
		]
	],
	[
		[
			6882,
			7324
		],
		[
			7,
			-15
		],
		[
			7,
			10
		],
		[
			15,
			9
		],
		[
			2,
			5
		],
		[
			10,
			-14
		],
		[
			5,
			7
		],
		[
			-2,
			13
		],
		[
			4,
			8
		],
		[
			21,
			2
		],
		[
			-3,
			18
		],
		[
			5,
			4
		],
		[
			12,
			26
		],
		[
			9,
			-2
		],
		[
			7,
			-9
		],
		[
			-1,
			-21
		],
		[
			6,
			3
		],
		[
			2,
			-8
		],
		[
			-3,
			-14
		],
		[
			-1,
			-35
		],
		[
			3,
			-12
		],
		[
			7,
			-4
		],
		[
			15,
			19
		],
		[
			9,
			1
		],
		[
			3,
			11
		],
		[
			14,
			14
		],
		[
			13,
			-2
		],
		[
			-1,
			-12
		],
		[
			14,
			8
		],
		[
			12,
			2
		],
		[
			7,
			-9
		]
	],
	[
		[
			5665,
			4557
		],
		[
			3,
			-32
		],
		[
			-3,
			-9
		],
		[
			0,
			-36
		],
		[
			2,
			-12
		],
		[
			-5,
			-22
		],
		[
			4,
			-12
		],
		[
			-56,
			0
		],
		[
			0,
			-182
		],
		[
			3,
			-21
		],
		[
			6,
			-7
		],
		[
			15,
			-33
		],
		[
			6,
			-7
		],
		[
			3,
			-10
		],
		[
			6,
			-7
		]
	],
	[
		[
			5649,
			4167
		],
		[
			-53,
			-21
		],
		[
			-11,
			4
		],
		[
			-8,
			-4
		],
		[
			-13,
			9
		],
		[
			-8,
			-3
		],
		[
			-17,
			2
		],
		[
			-5,
			4
		],
		[
			-10,
			0
		],
		[
			-7,
			9
		],
		[
			-5,
			14
		],
		[
			-52,
			0
		],
		[
			-66,
			0
		],
		[
			-7,
			-1
		],
		[
			-12,
			17
		],
		[
			-4,
			9
		],
		[
			-6,
			1
		],
		[
			-18,
			-16
		],
		[
			-15,
			4
		],
		[
			-6,
			-6
		]
	],
	[
		[
			5326,
			4189
		],
		[
			0,
			28
		],
		[
			2,
			-1
		],
		[
			-2,
			58
		],
		[
			7,
			9
		],
		[
			1,
			23
		],
		[
			6,
			24
		],
		[
			2,
			20
		],
		[
			0,
			23
		],
		[
			5,
			12
		],
		[
			0,
			26
		],
		[
			4,
			4
		],
		[
			8,
			20
		],
		[
			0,
			10
		],
		[
			6,
			12
		],
		[
			5,
			0
		],
		[
			8,
			20
		],
		[
			5,
			28
		],
		[
			-1,
			20
		],
		[
			2,
			29
		],
		[
			-2,
			15
		],
		[
			-7,
			15
		],
		[
			-8,
			46
		],
		[
			-7,
			29
		],
		[
			6,
			16
		],
		[
			6,
			7
		],
		[
			-1,
			21
		],
		[
			-3,
			9
		],
		[
			-10,
			48
		],
		[
			-2,
			4
		],
		[
			0,
			21
		],
		[
			-8,
			16
		],
		[
			-8,
			30
		],
		[
			16,
			4
		],
		[
			10,
			11
		]
	],
	[
		[
			5366,
			4846
		],
		[
			4,
			-2
		],
		[
			18,
			2
		],
		[
			12,
			-3
		],
		[
			21,
			2
		],
		[
			32,
			1
		],
		[
			7,
			-4
		],
		[
			4,
			-15
		],
		[
			0,
			-22
		],
		[
			3,
			-16
		],
		[
			3,
			-3
		],
		[
			0,
			-19
		],
		[
			10,
			-23
		],
		[
			0,
			-8
		],
		[
			9,
			-20
		],
		[
			7,
			4
		],
		[
			6,
			-4
		],
		[
			2,
			6
		],
		[
			33,
			0
		],
		[
			1,
			20
		],
		[
			4,
			12
		],
		[
			-2,
			8
		],
		[
			2,
			18
		],
		[
			21,
			0
		],
		[
			9,
			5
		],
		[
			-3,
			-22
		],
		[
			36,
			0
		],
		[
			1,
			-22
		],
		[
			-2,
			-20
		],
		[
			5,
			-23
		],
		[
			-4,
			-53
		],
		[
			1,
			-14
		],
		[
			6,
			-17
		],
		[
			3,
			-2
		],
		[
			4,
			-23
		],
		[
			0,
			-22
		],
		[
			-4,
			-9
		],
		[
			3,
			-18
		],
		[
			6,
			7
		],
		[
			13,
			-4
		],
		[
			14,
			9
		],
		[
			12,
			-3
		],
		[
			2,
			8
		]
	],
	[
		[
			5363,
			4916
		],
		[
			-7,
			-5
		],
		[
			-8,
			-18
		],
		[
			-1,
			-40
		],
		[
			-8,
			-2
		]
	],
	[
		[
			5339,
			4851
		],
		[
			-2,
			5
		],
		[
			2,
			14
		],
		[
			-6,
			24
		]
	],
	[
		[
			5333,
			4894
		],
		[
			10,
			23
		],
		[
			7,
			3
		],
		[
			4,
			10
		],
		[
			9,
			-14
		]
	],
	[
		[
			5582,
			7537
		],
		[
			-1,
			0
		]
	],
	[
		[
			5581,
			7537
		],
		[
			1,
			0
		]
	],
	[
		[
			5537,
			7617
		],
		[
			1,
			0
		]
	],
	[
		[
			5538,
			7617
		],
		[
			-1,
			0
		]
	],
	[
		[
			5557,
			7633
		],
		[
			4,
			-13
		],
		[
			7,
			-4
		],
		[
			3,
			-22
		]
	],
	[
		[
			5571,
			7594
		],
		[
			-4,
			-21
		],
		[
			6,
			-24
		]
	],
	[
		[
			5573,
			7549
		],
		[
			2,
			-10
		]
	],
	[
		[
			5575,
			7539
		],
		[
			6,
			-2
		]
	],
	[
		[
			5581,
			7537
		],
		[
			1,
			-1
		]
	],
	[
		[
			5582,
			7536
		],
		[
			0,
			0
		]
	],
	[
		[
			5582,
			7536
		],
		[
			0,
			-5
		]
	],
	[
		[
			5582,
			7531
		],
		[
			1,
			-5
		]
	],
	[
		[
			5583,
			7526
		],
		[
			0,
			0
		]
	],
	[
		[
			5583,
			7526
		],
		[
			-2,
			-13
		],
		[
			-5,
			-2
		],
		[
			-2,
			-17
		],
		[
			-11,
			-8
		],
		[
			3,
			-12
		],
		[
			-6,
			-8
		],
		[
			-5,
			3
		]
	],
	[
		[
			5555,
			7469
		],
		[
			-3,
			19
		],
		[
			-11,
			9
		],
		[
			-1,
			22
		],
		[
			-4,
			4
		],
		[
			4,
			16
		],
		[
			-1,
			29
		],
		[
			5,
			23
		],
		[
			-7,
			2
		]
	],
	[
		[
			5537,
			7593
		],
		[
			1,
			14
		]
	],
	[
		[
			5538,
			7607
		],
		[
			0,
			13
		]
	],
	[
		[
			5538,
			7620
		],
		[
			9,
			19
		],
		[
			3,
			-11
		],
		[
			7,
			5
		]
	],
	[
		[
			5553,
			8659
		],
		[
			10,
			-5
		],
		[
			-7,
			-11
		],
		[
			-10,
			6
		],
		[
			7,
			10
		]
	],
	[
		[
			5047,
			7630
		],
		[
			-7,
			-5
		],
		[
			-1,
			11
		]
	],
	[
		[
			5039,
			7636
		],
		[
			8,
			1
		],
		[
			0,
			-7
		]
	],
	[
		[
			6563,
			6637
		],
		[
			0,
			0
		]
	],
	[
		[
			6563,
			6659
		],
		[
			2,
			-2
		],
		[
			1,
			-36
		]
	],
	[
		[
			6566,
			6621
		],
		[
			-8,
			-14
		],
		[
			-3,
			13
		],
		[
			-6,
			-4
		],
		[
			-1,
			-38
		],
		[
			7,
			-9
		],
		[
			-11,
			-3
		],
		[
			-4,
			-6
		],
		[
			2,
			-9
		],
		[
			-10,
			-44
		],
		[
			0,
			-17
		]
	],
	[
		[
			6532,
			6490
		],
		[
			-2,
			-5
		],
		[
			-70,
			18
		],
		[
			-3,
			5
		],
		[
			-25,
			63
		],
		[
			0,
			9
		]
	],
	[
		[
			6432,
			6580
		],
		[
			6,
			-1
		],
		[
			0,
			-13
		],
		[
			12,
			-3
		],
		[
			10,
			11
		],
		[
			24,
			-2
		],
		[
			11,
			-4
		],
		[
			15,
			12
		],
		[
			6,
			14
		],
		[
			1,
			15
		],
		[
			11,
			12
		],
		[
			13,
			31
		],
		[
			11,
			13
		],
		[
			5,
			19
		]
	],
	[
		[
			6557,
			6684
		],
		[
			3,
			-2
		],
		[
			-1,
			-22
		],
		[
			4,
			-1
		]
	],
	[
		[
			6562,
			6642
		],
		[
			0,
			0
		]
	],
	[
		[
			3093,
			2021
		],
		[
			0,
			6
		]
	],
	[
		[
			3093,
			2027
		],
		[
			0,
			-6
		]
	],
	[
		[
			3093,
			2028
		],
		[
			0,
			123
		]
	],
	[
		[
			3093,
			2151
		],
		[
			10,
			-17
		],
		[
			-8,
			-15
		],
		[
			11,
			-6
		],
		[
			5,
			-17
		],
		[
			12,
			-13
		],
		[
			7,
			-13
		],
		[
			17,
			-13
		],
		[
			11,
			-14
		],
		[
			12,
			-7
		],
		[
			20,
			0
		],
		[
			-5,
			-16
		],
		[
			-18,
			1
		],
		[
			-11,
			-8
		],
		[
			-12,
			6
		],
		[
			-51,
			9
		]
	],
	[
		[
			3259,
			3902
		],
		[
			11,
			-14
		],
		[
			7,
			-29
		],
		[
			9,
			-17
		],
		[
			15,
			-17
		],
		[
			3,
			-11
		],
		[
			17,
			-13
		],
		[
			11,
			-1
		],
		[
			15,
			-18
		],
		[
			4,
			-9
		],
		[
			15,
			-17
		],
		[
			9,
			-5
		],
		[
			5,
			-8
		],
		[
			13,
			-5
		],
		[
			8,
			-20
		],
		[
			-6,
			-14
		],
		[
			-3,
			-19
		],
		[
			-8,
			-10
		],
		[
			-1,
			-25
		],
		[
			-3,
			-14
		],
		[
			-5,
			-4
		],
		[
			-5,
			-15
		],
		[
			4,
			-5
		],
		[
			13,
			1
		],
		[
			19,
			-8
		],
		[
			5,
			-5
		],
		[
			7,
			4
		],
		[
			5,
			-5
		],
		[
			6,
			3
		],
		[
			4,
			-8
		],
		[
			3,
			12
		],
		[
			5,
			5
		],
		[
			10,
			-9
		],
		[
			5,
			8
		],
		[
			-1,
			8
		],
		[
			6,
			12
		],
		[
			6,
			0
		],
		[
			11,
			18
		],
		[
			5,
			40
		],
		[
			0,
			22
		]
	],
	[
		[
			3483,
			3710
		],
		[
			5,
			-4
		],
		[
			6,
			7
		],
		[
			9,
			-9
		],
		[
			1,
			-17
		],
		[
			5,
			-14
		],
		[
			-2,
			-9
		],
		[
			0,
			-25
		],
		[
			-2,
			-17
		],
		[
			-13,
			-19
		],
		[
			-15,
			-5
		],
		[
			-6,
			-19
		],
		[
			-8,
			-4
		],
		[
			-6,
			-13
		],
		[
			-7,
			-5
		],
		[
			3,
			-10
		],
		[
			-6,
			-4
		],
		[
			-20,
			-39
		],
		[
			-2,
			-11
		],
		[
			-12,
			-25
		],
		[
			-5,
			-2
		],
		[
			-1,
			-10
		],
		[
			-8,
			-11
		]
	],
	[
		[
			3399,
			3445
		],
		[
			0,
			-7
		],
		[
			-7,
			-12
		],
		[
			2,
			-23
		],
		[
			-3,
			-20
		],
		[
			-5,
			-13
		],
		[
			3,
			-4
		],
		[
			-2,
			-14
		],
		[
			-4,
			-5
		],
		[
			3,
			-25
		],
		[
			-3,
			-8
		]
	],
	[
		[
			3383,
			3314
		],
		[
			2,
			-25
		],
		[
			-2,
			-12
		],
		[
			-6,
			0
		],
		[
			-4,
			-34
		],
		[
			5,
			-29
		],
		[
			-4,
			-14
		],
		[
			5,
			-12
		],
		[
			23,
			-21
		],
		[
			11,
			-25
		],
		[
			-7,
			-19
		],
		[
			0,
			-13
		],
		[
			7,
			-17
		],
		[
			12,
			-6
		],
		[
			1,
			-29
		],
		[
			-11,
			-30
		],
		[
			-13,
			-26
		],
		[
			-2,
			-16
		],
		[
			-27,
			-24
		],
		[
			-37,
			-16
		],
		[
			-27,
			-8
		],
		[
			-27,
			0
		],
		[
			-15,
			11
		],
		[
			3,
			-32
		],
		[
			5,
			-9
		],
		[
			-2,
			-21
		],
		[
			-4,
			3
		],
		[
			-1,
			-21
		],
		[
			-4,
			-5
		],
		[
			6,
			-17
		],
		[
			-2,
			-18
		],
		[
			-20,
			-16
		],
		[
			-21,
			0
		],
		[
			-26,
			20
		],
		[
			-8,
			2
		],
		[
			-4,
			-10
		],
		[
			5,
			-32
		],
		[
			-2,
			-24
		],
		[
			6,
			-16
		],
		[
			11,
			-4
		],
		[
			-4,
			-10
		],
		[
			13,
			0
		],
		[
			2,
			10
		],
		[
			-6,
			0
		],
		[
			14,
			11
		],
		[
			5,
			-13
		],
		[
			1,
			-17
		],
		[
			-3,
			-12
		],
		[
			-12,
			-5
		],
		[
			-3,
			16
		],
		[
			-13,
			5
		],
		[
			-9,
			-15
		],
		[
			19,
			-13
		],
		[
			-20,
			-17
		],
		[
			-8,
			-19
		],
		[
			3,
			-43
		],
		[
			-4,
			-11
		],
		[
			-9,
			-7
		],
		[
			0,
			-20
		],
		[
			-14,
			3
		],
		[
			-8,
			-5
		],
		[
			-1,
			-8
		],
		[
			-14,
			-5
		],
		[
			-9,
			-18
		],
		[
			0,
			-9
		],
		[
			-6,
			-9
		],
		[
			-2,
			-14
		],
		[
			7,
			-25
		],
		[
			7,
			-6
		],
		[
			8,
			-16
		],
		[
			6,
			-4
		],
		[
			17,
			0
		],
		[
			6,
			-6
		],
		[
			2,
			-20
		],
		[
			-5,
			-33
		],
		[
			-6,
			-2
		],
		[
			-12,
			-18
		],
		[
			-16,
			-14
		],
		[
			-3,
			-10
		],
		[
			-9,
			-10
		],
		[
			-6,
			-22
		],
		[
			2,
			-16
		],
		[
			-5,
			-18
		],
		[
			-5,
			-6
		],
		[
			-23,
			-14
		],
		[
			-5,
			-12
		],
		[
			-2,
			-21
		],
		[
			2,
			-24
		],
		[
			9,
			-34
		],
		[
			11,
			-24
		],
		[
			-3,
			-1
		]
	],
	[
		[
			3098,
			2168
		],
		[
			-15,
			10
		],
		[
			-26,
			10
		],
		[
			-55,
			1
		],
		[
			-4,
			12
		],
		[
			-11,
			13
		],
		[
			6,
			19
		],
		[
			-5,
			7
		],
		[
			5,
			13
		],
		[
			-2,
			14
		],
		[
			-13,
			1
		],
		[
			-11,
			-8
		],
		[
			-3,
			26
		],
		[
			-7,
			9
		],
		[
			2,
			22
		],
		[
			-3,
			11
		],
		[
			3,
			15
		],
		[
			9,
			1
		],
		[
			3,
			17
		],
		[
			12,
			10
		],
		[
			1,
			22
		],
		[
			7,
			7
		],
		[
			-1,
			15
		],
		[
			-5,
			7
		],
		[
			6,
			30
		],
		[
			8,
			13
		],
		[
			2,
			22
		],
		[
			8,
			9
		],
		[
			-3,
			32
		],
		[
			4,
			11
		],
		[
			-4,
			4
		],
		[
			0,
			15
		],
		[
			8,
			5
		],
		[
			5,
			13
		],
		[
			-8,
			17
		],
		[
			-14,
			5
		],
		[
			7,
			5
		],
		[
			17,
			3
		],
		[
			2,
			17
		],
		[
			-18,
			3
		],
		[
			-1,
			18
		],
		[
			5,
			7
		],
		[
			-4,
			14
		],
		[
			3,
			7
		],
		[
			-6,
			16
		],
		[
			5,
			9
		],
		[
			-11,
			7
		],
		[
			0,
			45
		],
		[
			3,
			8
		],
		[
			8,
			1
		],
		[
			-5,
			26
		],
		[
			2,
			43
		],
		[
			-3,
			11
		],
		[
			4,
			27
		],
		[
			5,
			21
		],
		[
			-2,
			18
		],
		[
			8,
			13
		],
		[
			0,
			25
		],
		[
			15,
			13
		],
		[
			-3,
			15
		],
		[
			-1,
			21
		],
		[
			-5,
			20
		],
		[
			3,
			35
		],
		[
			-2,
			24
		],
		[
			3,
			12
		],
		[
			10,
			4
		],
		[
			-1,
			8
		],
		[
			10,
			14
		],
		[
			-2,
			40
		],
		[
			-4,
			4
		],
		[
			6,
			6
		],
		[
			0,
			12
		],
		[
			9,
			39
		],
		[
			6,
			2
		],
		[
			-2,
			34
		],
		[
			3,
			18
		],
		[
			-9,
			9
		],
		[
			3,
			18
		],
		[
			-4,
			6
		],
		[
			0,
			16
		],
		[
			-5,
			12
		],
		[
			-2,
			14
		],
		[
			3,
			9
		],
		[
			-5,
			2
		],
		[
			-3,
			15
		],
		[
			1,
			24
		],
		[
			6,
			8
		],
		[
			0,
			13
		],
		[
			5,
			19
		],
		[
			7,
			8
		],
		[
			2,
			10
		],
		[
			-4,
			4
		],
		[
			2,
			16
		],
		[
			-4,
			31
		],
		[
			7,
			10
		],
		[
			1,
			26
		],
		[
			4,
			17
		],
		[
			13,
			33
		],
		[
			9,
			38
		],
		[
			6,
			-3
		],
		[
			8,
			7
		],
		[
			0,
			10
		],
		[
			-8,
			21
		],
		[
			0,
			10
		],
		[
			5,
			9
		],
		[
			-2,
			26
		],
		[
			-3,
			17
		],
		[
			2,
			15
		],
		[
			5,
			4
		],
		[
			-6,
			14
		],
		[
			2,
			14
		],
		[
			7,
			13
		],
		[
			25,
			20
		],
		[
			9,
			54
		],
		[
			-5,
			17
		]
	],
	[
		[
			3133,
			3869
		],
		[
			5,
			9
		],
		[
			0,
			8
		],
		[
			7,
			6
		],
		[
			2,
			12
		],
		[
			9,
			5
		],
		[
			4,
			19
		],
		[
			3,
			-2
		],
		[
			10,
			-17
		],
		[
			21,
			0
		],
		[
			12,
			-5
		],
		[
			6,
			-38
		],
		[
			3,
			20
		],
		[
			8,
			29
		],
		[
			32,
			1
		],
		[
			4,
			-14
		]
	],
	[
		[
			6265,
			7522
		],
		[
			0,
			0
		]
	],
	[
		[
			6249,
			7560
		],
		[
			2,
			-10
		],
		[
			15,
			-14
		],
		[
			-6,
			-16
		],
		[
			6,
			-11
		],
		[
			11,
			-10
		],
		[
			-3,
			-13
		],
		[
			-7,
			2
		],
		[
			15,
			-25
		],
		[
			9,
			-1
		],
		[
			-3,
			-13
		],
		[
			5,
			-7
		],
		[
			-5,
			-5
		],
		[
			3,
			-15
		]
	],
	[
		[
			6291,
			7422
		],
		[
			-10,
			-2
		]
	],
	[
		[
			6281,
			7420
		],
		[
			-4,
			23
		],
		[
			-7,
			7
		],
		[
			1,
			10
		],
		[
			-13,
			-1
		],
		[
			-8,
			14
		],
		[
			-7,
			-4
		]
	],
	[
		[
			6243,
			7469
		],
		[
			-8,
			16
		],
		[
			-12,
			1
		],
		[
			-11,
			7
		],
		[
			-3,
			20
		],
		[
			5,
			12
		],
		[
			-3,
			17
		],
		[
			-5,
			8
		]
	],
	[
		[
			6206,
			7550
		],
		[
			9,
			0
		],
		[
			11,
			7
		],
		[
			10,
			-3
		],
		[
			13,
			6
		]
	],
	[
		[
			6249,
			7546
		],
		[
			0,
			0
		]
	],
	[
		[
			6255,
			7542
		],
		[
			0,
			0
		]
	],
	[
		[
			488,
			408
		],
		[
			24,
			-7
		],
		[
			-48,
			-4
		],
		[
			-13,
			16
		],
		[
			37,
			-5
		]
	],
	[
		[
			542,
			484
		],
		[
			-90,
			7
		],
		[
			20,
			11
		],
		[
			65,
			-10
		],
		[
			5,
			-8
		]
	],
	[
		[
			3331,
			592
		],
		[
			8,
			-3
		],
		[
			-1,
			-57
		],
		[
			-23,
			-11
		],
		[
			-52,
			4
		],
		[
			-17,
			17
		],
		[
			-32,
			-10
		],
		[
			-67,
			20
		],
		[
			3,
			10
		],
		[
			19,
			-10
		],
		[
			115,
			3
		],
		[
			8,
			27
		],
		[
			39,
			10
		]
	],
	[
		[
			4135,
			588
		],
		[
			34,
			-2
		],
		[
			-10,
			-10
		],
		[
			-44,
			8
		],
		[
			-5,
			11
		],
		[
			25,
			-7
		]
	],
	[
		[
			3120,
			602
		],
		[
			25,
			-4
		],
		[
			35,
			-20
		],
		[
			-20,
			-7
		],
		[
			-40,
			31
		]
	],
	[
		[
			3137,
			618
		],
		[
			-11,
			-15
		],
		[
			-30,
			6
		],
		[
			41,
			9
		]
	],
	[
		[
			4054,
			618
		],
		[
			1,
			-6
		],
		[
			-76,
			3
		],
		[
			30,
			13
		],
		[
			45,
			-10
		]
	],
	[
		[
			547,
			618
		],
		[
			21,
			-9
		],
		[
			14,
			-23
		],
		[
			-47,
			-2
		],
		[
			-90,
			25
		],
		[
			-10,
			7
		],
		[
			5,
			17
		],
		[
			24,
			15
		],
		[
			25,
			0
		],
		[
			58,
			-30
		]
	],
	[
		[
			3143,
			666
		],
		[
			-58,
			-38
		],
		[
			-39,
			-36
		],
		[
			-31,
			3
		],
		[
			-10,
			10
		],
		[
			11,
			23
		],
		[
			23,
			11
		],
		[
			92,
			33
		],
		[
			12,
			-6
		]
	],
	[
		[
			9654,
			680
		],
		[
			-35,
			-8
		],
		[
			-8,
			14
		],
		[
			21,
			-7
		],
		[
			22,
			11
		],
		[
			0,
			-10
		]
	],
	[
		[
			3740,
			650
		],
		[
			1,
			-7
		],
		[
			44,
			2
		],
		[
			21,
			-39
		],
		[
			-7,
			-30
		],
		[
			-18,
			-1
		],
		[
			9,
			-11
		],
		[
			-158,
			-26
		],
		[
			-16,
			-9
		],
		[
			-121,
			-4
		],
		[
			1,
			17
		],
		[
			22,
			27
		],
		[
			26,
			-4
		],
		[
			60,
			37
		],
		[
			-13,
			14
		],
		[
			14,
			40
		],
		[
			31,
			33
		],
		[
			52,
			14
		],
		[
			37,
			-3
		],
		[
			38,
			-11
		],
		[
			19,
			-13
		],
		[
			-4,
			-20
		],
		[
			-38,
			-6
		]
	],
	[
		[
			9641,
			732
		],
		[
			63,
			-13
		],
		[
			-27,
			-10
		],
		[
			-42,
			-2
		],
		[
			-19,
			12
		],
		[
			25,
			13
		]
	],
	[
		[
			839,
			754
		],
		[
			14,
			-14
		],
		[
			-32,
			3
		],
		[
			-11,
			7
		],
		[
			29,
			4
		]
	],
	[
		[
			938,
			754
		],
		[
			-21,
			-7
		],
		[
			-2,
			12
		],
		[
			23,
			-5
		]
	],
	[
		[
			951,
			834
		],
		[
			16,
			-10
		],
		[
			-24,
			3
		],
		[
			8,
			7
		]
	],
	[
		[
			9561,
			885
		],
		[
			-8,
			-14
		],
		[
			-7,
			9
		],
		[
			15,
			5
		]
	],
	[
		[
			1342,
			903
		],
		[
			19,
			-12
		],
		[
			-6,
			-6
		],
		[
			-27,
			12
		],
		[
			14,
			6
		]
	],
	[
		[
			1458,
			897
		],
		[
			-1,
			-13
		],
		[
			-17,
			20
		],
		[
			18,
			-7
		]
	],
	[
		[
			1760,
			918
		],
		[
			-17,
			-8
		],
		[
			-3,
			7
		],
		[
			26,
			11
		],
		[
			-6,
			-10
		]
	],
	[
		[
			1680,
			914
		],
		[
			-12,
			3
		],
		[
			10,
			17
		],
		[
			17,
			-2
		],
		[
			-1,
			-10
		],
		[
			-14,
			-8
		]
	],
	[
		[
			1635,
			935
		],
		[
			17,
			0
		],
		[
			7,
			-14
		],
		[
			-23,
			-10
		],
		[
			0,
			-10
		],
		[
			-32,
			-4
		],
		[
			-22,
			7
		],
		[
			3,
			11
		],
		[
			15,
			12
		],
		[
			-27,
			3
		],
		[
			7,
			10
		],
		[
			55,
			-5
		]
	],
	[
		[
			4425,
			917
		],
		[
			9,
			-22
		],
		[
			-14,
			0
		],
		[
			-4,
			16
		],
		[
			-29,
			3
		],
		[
			20,
			7
		],
		[
			12,
			19
		],
		[
			11,
			1
		],
		[
			-5,
			-24
		]
	],
	[
		[
			9717,
			944
		],
		[
			-11,
			3
		],
		[
			8,
			14
		],
		[
			3,
			-17
		]
	],
	[
		[
			1498,
			961
		],
		[
			13,
			-7
		],
		[
			9,
			-16
		],
		[
			-11,
			-7
		],
		[
			29,
			6
		],
		[
			17,
			-9
		],
		[
			7,
			-11
		],
		[
			-6,
			-12
		],
		[
			-22,
			3
		],
		[
			-48,
			22
		],
		[
			0,
			8
		],
		[
			-19,
			7
		],
		[
			-3,
			16
		],
		[
			34,
			0
		]
	],
	[
		[
			2955,
			972
		],
		[
			-2,
			-10
		],
		[
			-13,
			0
		],
		[
			15,
			10
		]
	],
	[
		[
			2514,
			979
		],
		[
			-20,
			-5
		],
		[
			-4,
			5
		],
		[
			22,
			8
		],
		[
			2,
			-8
		]
	],
	[
		[
			2918,
			987
		],
		[
			18,
			-3
		],
		[
			-8,
			-40
		],
		[
			-36,
			14
		],
		[
			-7,
			10
		],
		[
			11,
			7
		],
		[
			18,
			0
		],
		[
			-19,
			10
		],
		[
			23,
			2
		]
	],
	[
		[
			2474,
			988
		],
		[
			-3,
			-19
		],
		[
			-14,
			-1
		],
		[
			6,
			17
		],
		[
			-10,
			16
		],
		[
			23,
			1
		],
		[
			-2,
			-14
		]
	],
	[
		[
			2365,
			999
		],
		[
			-10,
			3
		],
		[
			18,
			7
		],
		[
			-8,
			-10
		]
	],
	[
		[
			2270,
			1031
		],
		[
			14,
			-3
		],
		[
			-2,
			14
		],
		[
			10,
			0
		],
		[
			2,
			-17
		],
		[
			10,
			19
		],
		[
			19,
			1
		],
		[
			5,
			-10
		],
		[
			-23,
			-11
		],
		[
			8,
			-3
		],
		[
			27,
			11
		],
		[
			-6,
			-10
		],
		[
			13,
			-10
		],
		[
			-15,
			-1
		],
		[
			1,
			-9
		],
		[
			-72,
			2
		],
		[
			2,
			5
		],
		[
			-24,
			-1
		],
		[
			6,
			7
		],
		[
			-29,
			6
		],
		[
			-58,
			7
		],
		[
			6,
			10
		],
		[
			57,
			7
		],
		[
			8,
			-11
		],
		[
			7,
			7
		],
		[
			23,
			-12
		],
		[
			-13,
			13
		],
		[
			17,
			9
		],
		[
			15,
			-6
		],
		[
			-8,
			-14
		]
	],
	[
		[
			4919,
			1112
		],
		[
			8,
			-10
		],
		[
			14,
			1
		],
		[
			-17,
			-19
		],
		[
			-8,
			18
		],
		[
			-16,
			10
		],
		[
			19,
			0
		]
	],
	[
		[
			2947,
			1119
		],
		[
			8,
			-13
		],
		[
			-22,
			-10
		],
		[
			-48,
			-11
		],
		[
			-9,
			4
		],
		[
			2,
			12
		],
		[
			33,
			5
		],
		[
			9,
			12
		],
		[
			8,
			-13
		],
		[
			3,
			14
		],
		[
			16,
			0
		]
	],
	[
		[
			3313,
			1111
		],
		[
			-7,
			10
		],
		[
			11,
			1
		],
		[
			-4,
			-11
		]
	],
	[
		[
			4835,
			1126
		],
		[
			-5,
			-10
		],
		[
			-10,
			9
		],
		[
			15,
			1
		]
	],
	[
		[
			5082,
			1116
		],
		[
			-11,
			6
		],
		[
			19,
			4
		],
		[
			-8,
			-10
		]
	],
	[
		[
			4913,
			1121
		],
		[
			-10,
			0
		],
		[
			6,
			12
		],
		[
			12,
			3
		],
		[
			2,
			-14
		],
		[
			-10,
			-1
		]
	],
	[
		[
			7004,
			1113
		],
		[
			-10,
			3
		],
		[
			-5,
			16
		],
		[
			16,
			-11
		],
		[
			-1,
			-8
		]
	],
	[
		[
			5124,
			1122
		],
		[
			-12,
			11
		],
		[
			12,
			5
		],
		[
			0,
			-16
		]
	],
	[
		[
			5745,
			1129
		],
		[
			-22,
			0
		],
		[
			-2,
			11
		],
		[
			19,
			6
		],
		[
			5,
			-17
		]
	],
	[
		[
			5040,
			1146
		],
		[
			-7,
			-18
		],
		[
			-5,
			21
		],
		[
			12,
			-3
		]
	],
	[
		[
			2924,
			1165
		],
		[
			8,
			-12
		],
		[
			-12,
			-13
		],
		[
			-23,
			5
		],
		[
			-1,
			13
		],
		[
			8,
			7
		],
		[
			20,
			0
		]
	],
	[
		[
			5449,
			1148
		],
		[
			-17,
			8
		],
		[
			11,
			12
		],
		[
			19,
			-1
		],
		[
			-11,
			-8
		],
		[
			-2,
			-11
		]
	],
	[
		[
			3001,
			1170
		],
		[
			-23,
			2
		],
		[
			-6,
			7
		],
		[
			17,
			4
		],
		[
			12,
			-13
		]
	],
	[
		[
			3283,
			1179
		],
		[
			-6,
			-12
		],
		[
			-16,
			30
		],
		[
			11,
			2
		],
		[
			11,
			-20
		]
	],
	[
		[
			3055,
			1197
		],
		[
			19,
			-24
		],
		[
			1,
			-17
		],
		[
			16,
			-26
		],
		[
			11,
			-25
		],
		[
			3,
			-60
		],
		[
			-6,
			-23
		],
		[
			-20,
			-7
		],
		[
			-2,
			-10
		],
		[
			-40,
			-7
		],
		[
			-49,
			0
		],
		[
			-21,
			13
		],
		[
			10,
			8
		],
		[
			16,
			-3
		],
		[
			45,
			-2
		],
		[
			14,
			8
		],
		[
			-7,
			6
		],
		[
			-28,
			-9
		],
		[
			-18,
			10
		],
		[
			35,
			8
		],
		[
			1,
			5
		],
		[
			-31,
			0
		],
		[
			-14,
			17
		],
		[
			-11,
			-17
		],
		[
			-31,
			2
		],
		[
			10,
			-8
		],
		[
			-14,
			-9
		],
		[
			-38,
			14
		],
		[
			-1,
			15
		],
		[
			15,
			8
		],
		[
			16,
			-8
		],
		[
			-4,
			12
		],
		[
			9,
			4
		],
		[
			16,
			-13
		],
		[
			-4,
			14
		],
		[
			29,
			-2
		],
		[
			9,
			7
		],
		[
			-23,
			7
		],
		[
			10,
			6
		],
		[
			30,
			-6
		],
		[
			19,
			11
		],
		[
			20,
			0
		],
		[
			13,
			-11
		],
		[
			-2,
			16
		],
		[
			-35,
			7
		],
		[
			5,
			17
		],
		[
			24,
			8
		],
		[
			15,
			-4
		],
		[
			-18,
			14
		],
		[
			-20,
			-4
		],
		[
			-27,
			14
		],
		[
			7,
			34
		],
		[
			-10,
			5
		],
		[
			0,
			20
		],
		[
			45,
			10
		],
		[
			9,
			-7
		],
		[
			2,
			-18
		]
	],
	[
		[
			7385,
			1327
		],
		[
			-15,
			4
		],
		[
			8,
			9
		],
		[
			7,
			-13
		]
	],
	[
		[
			3111,
			1321
		],
		[
			9,
			-5
		],
		[
			-16,
			-13
		],
		[
			-8,
			-22
		],
		[
			-11,
			0
		],
		[
			-7,
			9
		],
		[
			22,
			44
		],
		[
			15,
			12
		],
		[
			5,
			-5
		],
		[
			-10,
			-11
		],
		[
			1,
			-9
		]
	],
	[
		[
			7686,
			1378
		],
		[
			4,
			-8
		],
		[
			-14,
			-2
		],
		[
			10,
			10
		]
	],
	[
		[
			3174,
			1408
		],
		[
			-3,
			-16
		],
		[
			-10,
			-2
		],
		[
			6,
			17
		],
		[
			7,
			1
		]
	],
	[
		[
			7805,
			1401
		],
		[
			-19,
			0
		],
		[
			-1,
			7
		],
		[
			12,
			10
		],
		[
			15,
			-7
		],
		[
			-7,
			-10
		]
	],
	[
		[
			7870,
			1413
		],
		[
			-16,
			19
		],
		[
			9,
			-2
		],
		[
			7,
			-17
		]
	],
	[
		[
			3410,
			1465
		],
		[
			-6,
			6
		],
		[
			14,
			7
		],
		[
			-8,
			-13
		]
	],
	[
		[
			3242,
			1481
		],
		[
			-2,
			-9
		],
		[
			14,
			-8
		],
		[
			-14,
			-12
		],
		[
			-26,
			3
		],
		[
			20,
			26
		],
		[
			8,
			0
		]
	],
	[
		[
			3270,
			1492
		],
		[
			2,
			-17
		],
		[
			-12,
			-8
		],
		[
			10,
			25
		]
	],
	[
		[
			3394,
			1508
		],
		[
			-2,
			-9
		],
		[
			20,
			-7
		],
		[
			-8,
			-17
		],
		[
			-7,
			6
		],
		[
			-7,
			-7
		],
		[
			-14,
			20
		],
		[
			5,
			8
		],
		[
			13,
			6
		]
	],
	[
		[
			3446,
			1521
		],
		[
			-9,
			7
		],
		[
			15,
			-2
		],
		[
			-6,
			-5
		]
	],
	[
		[
			0,
			324
		],
		[
			46,
			3
		],
		[
			68,
			-14
		],
		[
			19,
			8
		],
		[
			194,
			-14
		],
		[
			21,
			-11
		],
		[
			128,
			-2
		],
		[
			122,
			-11
		],
		[
			81,
			-3
		],
		[
			-58,
			13
		],
		[
			54,
			1
		],
		[
			-124,
			12
		],
		[
			-104,
			7
		],
		[
			24,
			11
		],
		[
			-55,
			17
		],
		[
			37,
			2
		],
		[
			-52,
			17
		],
		[
			-71,
			-3
		],
		[
			-37,
			23
		],
		[
			-127,
			27
		],
		[
			73,
			-2
		],
		[
			18,
			-14
		],
		[
			73,
			-4
		],
		[
			20,
			4
		],
		[
			70,
			-3
		],
		[
			6,
			-14
		],
		[
			50,
			10
		],
		[
			19,
			-11
		],
		[
			127,
			8
		],
		[
			18,
			9
		],
		[
			-44,
			5
		],
		[
			81,
			5
		],
		[
			16,
			14
		],
		[
			70,
			14
		],
		[
			-10,
			10
		],
		[
			-54,
			26
		],
		[
			31,
			11
		],
		[
			-19,
			10
		],
		[
			-74,
			13
		],
		[
			17,
			11
		],
		[
			109,
			6
		],
		[
			135,
			7
		],
		[
			0,
			5
		],
		[
			-77,
			24
		],
		[
			-11,
			11
		],
		[
			13,
			10
		],
		[
			43,
			-4
		],
		[
			46,
			10
		],
		[
			-17,
			11
		],
		[
			-75,
			12
		],
		[
			-55,
			17
		],
		[
			-3,
			5
		],
		[
			-68,
			8
		],
		[
			-43,
			21
		],
		[
			14,
			11
		],
		[
			48,
			6
		],
		[
			-2,
			14
		],
		[
			-71,
			-7
		],
		[
			-47,
			23
		],
		[
			14,
			18
		],
		[
			-3,
			26
		],
		[
			9,
			1
		],
		[
			24,
			-17
		],
		[
			21,
			17
		],
		[
			21,
			-5
		],
		[
			18,
			4
		],
		[
			38,
			-10
		],
		[
			-9,
			-10
		],
		[
			36,
			-3
		],
		[
			2,
			10
		],
		[
			72,
			-30
		],
		[
			30,
			16
		],
		[
			30,
			6
		],
		[
			-36,
			7
		],
		[
			7,
			14
		],
		[
			32,
			-17
		],
		[
			21,
			7
		],
		[
			13,
			-13
		],
		[
			27,
			0
		],
		[
			-16,
			13
		],
		[
			21,
			1
		],
		[
			-31,
			15
		],
		[
			29,
			-5
		],
		[
			-22,
			20
		],
		[
			-27,
			16
		],
		[
			-38,
			-3
		],
		[
			-33,
			3
		],
		[
			2,
			9
		],
		[
			28,
			4
		],
		[
			9,
			7
		],
		[
			69,
			-21
		],
		[
			6,
			8
		],
		[
			-27,
			13
		],
		[
			9,
			11
		],
		[
			56,
			6
		],
		[
			1,
			10
		],
		[
			41,
			4
		],
		[
			2,
			6
		],
		[
			19,
			-3
		],
		[
			9,
			-14
		],
		[
			18,
			0
		],
		[
			-10,
			14
		],
		[
			29,
			6
		],
		[
			16,
			14
		],
		[
			61,
			4
		],
		[
			30,
			-4
		],
		[
			-16,
			9
		],
		[
			4,
			14
		],
		[
			30,
			0
		],
		[
			11,
			11
		],
		[
			22,
			-4
		],
		[
			18,
			-16
		],
		[
			30,
			9
		],
		[
			58,
			-4
		],
		[
			20,
			-5
		],
		[
			64,
			13
		],
		[
			93,
			0
		],
		[
			8,
			-7
		],
		[
			45,
			3
		],
		[
			41,
			0
		],
		[
			59,
			10
		],
		[
			-3,
			10
		],
		[
			24,
			6
		],
		[
			6,
			-12
		],
		[
			33,
			-3
		],
		[
			51,
			6
		],
		[
			-7,
			21
		],
		[
			11,
			10
		],
		[
			21,
			0
		],
		[
			-9,
			-7
		],
		[
			19,
			2
		],
		[
			-8,
			-12
		],
		[
			4,
			-14
		],
		[
			15,
			3
		],
		[
			-18,
			-16
		],
		[
			-6,
			-21
		],
		[
			9,
			6
		],
		[
			46,
			8
		],
		[
			15,
			0
		],
		[
			-10,
			11
		],
		[
			0,
			20
		],
		[
			15,
			6
		],
		[
			35,
			-17
		],
		[
			-5,
			-19
		],
		[
			-34,
			-18
		],
		[
			4,
			-7
		],
		[
			45,
			4
		],
		[
			84,
			-10
		],
		[
			53,
			13
		],
		[
			28,
			-3
		],
		[
			14,
			4
		],
		[
			49,
			-4
		],
		[
			-3,
			-8
		],
		[
			20,
			-8
		],
		[
			70,
			13
		],
		[
			-27,
			6
		],
		[
			2,
			10
		],
		[
			-34,
			3
		],
		[
			17,
			7
		],
		[
			3,
			14
		],
		[
			-46,
			3
		],
		[
			5,
			11
		],
		[
			-7,
			15
		],
		[
			-33,
			5
		],
		[
			-4,
			20
		],
		[
			42,
			-4
		],
		[
			3,
			-6
		],
		[
			47,
			2
		],
		[
			-5,
			21
		],
		[
			-41,
			3
		],
		[
			-46,
			0
		],
		[
			-11,
			7
		],
		[
			-4,
			20
		],
		[
			11,
			7
		],
		[
			26,
			-4
		],
		[
			-17,
			-12
		],
		[
			21,
			-4
		],
		[
			33,
			4
		],
		[
			84,
			-1
		],
		[
			9,
			-7
		],
		[
			44,
			-11
		],
		[
			17,
			7
		],
		[
			24,
			-7
		],
		[
			21,
			8
		],
		[
			46,
			0
		],
		[
			33,
			-7
		],
		[
			16,
			10
		],
		[
			25,
			1
		],
		[
			6,
			10
		],
		[
			-10,
			17
		],
		[
			33,
			-4
		],
		[
			1,
			-10
		],
		[
			-15,
			-14
		],
		[
			9,
			-9
		],
		[
			30,
			6
		],
		[
			8,
			-11
		],
		[
			38,
			11
		],
		[
			5,
			-13
		],
		[
			28,
			-10
		],
		[
			20,
			2
		],
		[
			43,
			-19
		],
		[
			29,
			9
		],
		[
			-2,
			28
		],
		[
			24,
			-11
		],
		[
			-8,
			25
		],
		[
			28,
			-2
		],
		[
			24,
			-17
		],
		[
			-2,
			-16
		],
		[
			55,
			8
		],
		[
			5,
			-7
		],
		[
			-15,
			-14
		],
		[
			48,
			6
		],
		[
			7,
			5
		],
		[
			34,
			-5
		],
		[
			26,
			15
		],
		[
			57,
			12
		],
		[
			21,
			-2
		],
		[
			42,
			10
		],
		[
			35,
			16
		],
		[
			22,
			43
		],
		[
			-1,
			7
		],
		[
			-20,
			21
		],
		[
			-4,
			13
		],
		[
			6,
			23
		],
		[
			-15,
			38
		],
		[
			-15,
			16
		],
		[
			4,
			21
		],
		[
			-13,
			16
		],
		[
			15,
			0
		],
		[
			-1,
			7
		],
		[
			25,
			-14
		],
		[
			5,
			14
		],
		[
			11,
			6
		],
		[
			0,
			11
		],
		[
			-18,
			7
		],
		[
			14,
			5
		],
		[
			-5,
			17
		],
		[
			6,
			14
		],
		[
			-9,
			16
		],
		[
			12,
			3
		],
		[
			6,
			21
		],
		[
			-10,
			5
		],
		[
			-19,
			-1
		],
		[
			15,
			30
		],
		[
			6,
			0
		],
		[
			-2,
			-17
		],
		[
			15,
			-6
		],
		[
			1,
			26
		],
		[
			-4,
			14
		],
		[
			8,
			4
		],
		[
			14,
			-7
		],
		[
			5,
			34
		],
		[
			14,
			-2
		],
		[
			-5,
			11
		],
		[
			19,
			-4
		],
		[
			3,
			23
		],
		[
			16,
			1
		],
		[
			-5,
			27
		],
		[
			11,
			6
		],
		[
			16,
			-7
		],
		[
			-4,
			11
		],
		[
			20,
			14
		],
		[
			11,
			-3
		],
		[
			9,
			12
		],
		[
			10,
			1
		],
		[
			-1,
			10
		],
		[
			14,
			4
		],
		[
			-1,
			13
		],
		[
			30,
			14
		],
		[
			13,
			-2
		],
		[
			3,
			10
		],
		[
			12,
			2
		],
		[
			1,
			8
		],
		[
			21,
			4
		],
		[
			7,
			8
		],
		[
			13,
			6
		],
		[
			11,
			-3
		],
		[
			7,
			-20
		],
		[
			-10,
			-3
		],
		[
			-2,
			12
		],
		[
			-15,
			-12
		],
		[
			-10,
			0
		],
		[
			-15,
			-17
		],
		[
			-9,
			-22
		],
		[
			-9,
			-6
		],
		[
			-7,
			7
		],
		[
			-6,
			-6
		],
		[
			-19,
			-5
		],
		[
			-17,
			-29
		],
		[
			-20,
			3
		],
		[
			6,
			-10
		],
		[
			-18,
			-10
		],
		[
			9,
			-14
		],
		[
			-14,
			-14
		],
		[
			13,
			-19
		],
		[
			16,
			3
		],
		[
			0,
			10
		],
		[
			21,
			-2
		],
		[
			-16,
			-14
		],
		[
			-16,
			0
		],
		[
			-2,
			-16
		],
		[
			-5,
			16
		],
		[
			-19,
			-3
		],
		[
			1,
			-28
		],
		[
			-16,
			27
		],
		[
			-15,
			3
		],
		[
			-10,
			-29
		],
		[
			11,
			-10
		],
		[
			-9,
			-4
		],
		[
			-14,
			11
		],
		[
			-12,
			-15
		],
		[
			6,
			-16
		],
		[
			-15,
			-6
		],
		[
			-8,
			5
		],
		[
			-3,
			-33
		],
		[
			10,
			-6
		],
		[
			-12,
			-11
		],
		[
			21,
			6
		],
		[
			6,
			-6
		],
		[
			-20,
			-7
		],
		[
			14,
			-6
		],
		[
			-10,
			-7
		],
		[
			36,
			-17
		],
		[
			-2,
			17
		],
		[
			23,
			7
		],
		[
			-14,
			-17
		],
		[
			15,
			-6
		],
		[
			-5,
			-8
		],
		[
			14,
			-25
		],
		[
			14,
			-7
		],
		[
			-2,
			-21
		],
		[
			15,
			-13
		],
		[
			-1,
			-11
		],
		[
			-10,
			4
		],
		[
			5,
			-18
		],
		[
			22,
			1
		],
		[
			-16,
			-24
		],
		[
			20,
			4
		],
		[
			9,
			-21
		],
		[
			-5,
			-12
		],
		[
			-12,
			-1
		],
		[
			-14,
			-13
		],
		[
			14,
			-1
		],
		[
			11,
			10
		],
		[
			9,
			-8
		],
		[
			-7,
			-12
		],
		[
			-38,
			-3
		],
		[
			36,
			-14
		],
		[
			13,
			10
		],
		[
			0,
			-26
		],
		[
			-19,
			-2
		],
		[
			6,
			-18
		],
		[
			17,
			8
		],
		[
			-7,
			-24
		],
		[
			25,
			4
		],
		[
			-11,
			-19
		],
		[
			-9,
			8
		],
		[
			-3,
			-13
		],
		[
			-15,
			12
		],
		[
			-21,
			5
		],
		[
			13,
			-17
		],
		[
			21,
			-10
		],
		[
			-7,
			-23
		],
		[
			-21,
			5
		],
		[
			21,
			-13
		],
		[
			-23,
			-13
		],
		[
			31,
			7
		],
		[
			-9,
			-17
		],
		[
			-36,
			6
		],
		[
			17,
			-17
		],
		[
			-10,
			-13
		],
		[
			-13,
			-3
		],
		[
			-2,
			17
		],
		[
			-17,
			2
		],
		[
			6,
			-15
		],
		[
			-14,
			3
		],
		[
			-10,
			-10
		],
		[
			18,
			2
		],
		[
			7,
			-9
		],
		[
			-35,
			-4
		],
		[
			-2,
			-7
		],
		[
			33,
			-3
		],
		[
			-85,
			-34
		],
		[
			-52,
			-9
		],
		[
			4,
			-3
		],
		[
			-60,
			-13
		],
		[
			4,
			-11
		],
		[
			-17,
			-7
		],
		[
			-31,
			-1
		],
		[
			-20,
			4
		],
		[
			-46,
			0
		],
		[
			-31,
			8
		],
		[
			-64,
			0
		],
		[
			34,
			-42
		],
		[
			23,
			-15
		],
		[
			10,
			6
		],
		[
			66,
			-8
		],
		[
			-25,
			-26
		],
		[
			-38,
			-9
		],
		[
			-61,
			13
		],
		[
			-95,
			13
		],
		[
			-30,
			-6
		],
		[
			118,
			-34
		],
		[
			-9,
			-17
		],
		[
			-71,
			-7
		],
		[
			-61,
			21
		],
		[
			-37,
			30
		],
		[
			12,
			-23
		],
		[
			-13,
			-4
		],
		[
			17,
			-20
		],
		[
			42,
			-17
		],
		[
			17,
			-23
		],
		[
			18,
			-7
		],
		[
			2,
			20
		],
		[
			108,
			-4
		],
		[
			17,
			-13
		],
		[
			-20,
			-24
		],
		[
			-22,
			-3
		],
		[
			-62,
			0
		],
		[
			55,
			-10
		],
		[
			39,
			6
		],
		[
			24,
			-26
		],
		[
			-8,
			-7
		],
		[
			24,
			-16
		],
		[
			19,
			7
		],
		[
			38,
			-10
		],
		[
			7,
			13
		],
		[
			39,
			9
		],
		[
			21,
			-6
		],
		[
			9,
			-14
		],
		[
			46,
			-9
		],
		[
			89,
			-24
		],
		[
			77,
			-3
		],
		[
			-92,
			-8
		],
		[
			62,
			-5
		],
		[
			-2,
			-4
		],
		[
			-62,
			-1
		],
		[
			-6,
			-25
		],
		[
			26,
			-5
		],
		[
			52,
			8
		],
		[
			75,
			3
		],
		[
			-64,
			-17
		],
		[
			33,
			-33
		],
		[
			-6,
			-17
		],
		[
			66,
			-4
		],
		[
			49,
			30
		],
		[
			72,
			31
		],
		[
			52,
			14
		],
		[
			16,
			-1
		],
		[
			53,
			11
		],
		[
			65,
			5
		],
		[
			59,
			-2
		],
		[
			6,
			-17
		],
		[
			-17,
			-11
		],
		[
			31,
			-7
		],
		[
			67,
			24
		],
		[
			-2,
			10
		],
		[
			36,
			18
		],
		[
			9,
			16
		],
		[
			79,
			27
		],
		[
			42,
			-13
		],
		[
			34,
			10
		],
		[
			18,
			17
		],
		[
			53,
			0
		],
		[
			40,
			12
		],
		[
			42,
			-3
		],
		[
			-21,
			10
		],
		[
			37,
			0
		],
		[
			5,
			7
		],
		[
			153,
			6
		],
		[
			48,
			10
		],
		[
			-61,
			7
		],
		[
			-165,
			11
		],
		[
			31,
			17
		],
		[
			-27,
			0
		],
		[
			9,
			15
		],
		[
			-73,
			-12
		],
		[
			-96,
			23
		],
		[
			-5,
			14
		],
		[
			12,
			23
		],
		[
			11,
			3
		],
		[
			8,
			18
		],
		[
			24,
			0
		],
		[
			-7,
			12
		],
		[
			28,
			18
		],
		[
			34,
			10
		],
		[
			17,
			0
		],
		[
			5,
			10
		],
		[
			28,
			7
		],
		[
			15,
			13
		],
		[
			36,
			16
		],
		[
			52,
			10
		],
		[
			29,
			14
		],
		[
			48,
			10
		],
		[
			53,
			7
		],
		[
			31,
			-4
		],
		[
			22,
			14
		],
		[
			17,
			-6
		],
		[
			43,
			6
		],
		[
			-18,
			11
		],
		[
			29,
			26
		],
		[
			-3,
			10
		],
		[
			14,
			17
		],
		[
			24,
			3
		],
		[
			23,
			-7
		],
		[
			39,
			33
		],
		[
			-10,
			4
		],
		[
			-27,
			-10
		],
		[
			-22,
			3
		],
		[
			17,
			4
		],
		[
			-20,
			7
		],
		[
			1,
			13
		],
		[
			28,
			23
		],
		[
			18,
			3
		],
		[
			12,
			-9
		],
		[
			16,
			11
		],
		[
			-15,
			16
		],
		[
			29,
			-7
		],
		[
			14,
			11
		],
		[
			42,
			13
		],
		[
			3,
			19
		],
		[
			10,
			20
		],
		[
			-18,
			0
		],
		[
			-18,
			7
		],
		[
			-1,
			18
		],
		[
			16,
			2
		],
		[
			1,
			-9
		],
		[
			21,
			-10
		],
		[
			7,
			17
		],
		[
			16,
			9
		],
		[
			-12,
			10
		],
		[
			13,
			4
		],
		[
			3,
			-10
		],
		[
			22,
			-7
		],
		[
			10,
			-28
		],
		[
			15,
			7
		],
		[
			15,
			-5
		],
		[
			-4,
			9
		],
		[
			6,
			23
		],
		[
			-11,
			13
		],
		[
			13,
			5
		],
		[
			25,
			-7
		],
		[
			16,
			14
		],
		[
			13,
			-8
		],
		[
			-20,
			-29
		],
		[
			71,
			-3
		],
		[
			7,
			-9
		],
		[
			4,
			12
		],
		[
			18,
			3
		],
		[
			5,
			-6
		],
		[
			28,
			-5
		],
		[
			7,
			11
		],
		[
			12,
			-7
		],
		[
			-4,
			-14
		],
		[
			12,
			-9
		],
		[
			21,
			25
		],
		[
			13,
			8
		],
		[
			41,
			14
		],
		[
			105,
			20
		],
		[
			19,
			0
		],
		[
			28,
			7
		],
		[
			-5,
			17
		],
		[
			12,
			2
		],
		[
			-1,
			-17
		],
		[
			11,
			-3
		],
		[
			25,
			9
		],
		[
			-8,
			8
		],
		[
			9,
			9
		],
		[
			22,
			-23
		],
		[
			31,
			-14
		],
		[
			21,
			-5
		],
		[
			14,
			25
		],
		[
			18,
			7
		],
		[
			-16,
			10
		],
		[
			16,
			1
		],
		[
			8,
			-13
		],
		[
			22,
			-4
		],
		[
			22,
			3
		],
		[
			27,
			-4
		],
		[
			3,
			9
		],
		[
			17,
			3
		],
		[
			-3,
			-18
		],
		[
			45,
			-4
		],
		[
			11,
			1
		],
		[
			-6,
			11
		],
		[
			17,
			9
		],
		[
			11,
			-10
		],
		[
			-10,
			-23
		],
		[
			10,
			-10
		],
		[
			23,
			-1
		],
		[
			26,
			4
		],
		[
			3,
			13
		],
		[
			16,
			24
		],
		[
			24,
			-18
		],
		[
			-21,
			-6
		],
		[
			14,
			-7
		],
		[
			26,
			-5
		],
		[
			13,
			26
		],
		[
			15,
			-4
		],
		[
			0,
			-15
		],
		[
			27,
			-15
		],
		[
			31,
			-3
		],
		[
			35,
			17
		],
		[
			23,
			3
		],
		[
			38,
			21
		],
		[
			40,
			5
		],
		[
			38,
			11
		],
		[
			7,
			7
		],
		[
			2,
			33
		],
		[
			-12,
			13
		],
		[
			-1,
			13
		],
		[
			20,
			12
		],
		[
			28,
			0
		],
		[
			4,
			-8
		],
		[
			-21,
			-13
		],
		[
			24,
			-1
		],
		[
			20,
			-13
		],
		[
			-2,
			-23
		],
		[
			45,
			4
		],
		[
			8,
			-15
		],
		[
			7,
			9
		],
		[
			26,
			-1
		],
		[
			-5,
			-7
		],
		[
			19,
			-19
		],
		[
			2,
			12
		],
		[
			13,
			7
		],
		[
			-1,
			10
		],
		[
			15,
			4
		],
		[
			-2,
			32
		],
		[
			4,
			14
		],
		[
			26,
			6
		],
		[
			21,
			15
		],
		[
			28,
			4
		],
		[
			8,
			17
		],
		[
			32,
			8
		],
		[
			24,
			0
		],
		[
			-6,
			5
		],
		[
			34,
			13
		],
		[
			14,
			-6
		],
		[
			-2,
			23
		],
		[
			18,
			5
		],
		[
			14,
			-8
		],
		[
			-13,
			-7
		],
		[
			10,
			-3
		],
		[
			6,
			-12
		],
		[
			9,
			8
		],
		[
			16,
			-6
		],
		[
			-5,
			-17
		],
		[
			13,
			20
		],
		[
			-3,
			14
		],
		[
			16,
			5
		],
		[
			2,
			11
		],
		[
			-19,
			-3
		],
		[
			-6,
			13
		],
		[
			27,
			6
		],
		[
			-2,
			-9
		],
		[
			15,
			2
		],
		[
			0,
			-13
		],
		[
			11,
			8
		],
		[
			11,
			-7
		],
		[
			10,
			7
		],
		[
			-14,
			3
		],
		[
			10,
			16
		],
		[
			-16,
			1
		],
		[
			-1,
			12
		],
		[
			9,
			14
		],
		[
			23,
			4
		],
		[
			11,
			12
		],
		[
			30,
			4
		],
		[
			25,
			7
		],
		[
			40,
			-6
		],
		[
			19,
			-10
		],
		[
			15,
			-20
		],
		[
			11,
			3
		],
		[
			13,
			-8
		],
		[
			1,
			-9
		],
		[
			-36,
			3
		],
		[
			15,
			-8
		],
		[
			-11,
			-23
		],
		[
			1,
			-12
		],
		[
			7,
			13
		],
		[
			33,
			10
		],
		[
			23,
			-11
		],
		[
			12,
			1
		],
		[
			5,
			-20
		],
		[
			12,
			-4
		],
		[
			4,
			11
		],
		[
			24,
			0
		],
		[
			18,
			-7
		],
		[
			45,
			-7
		],
		[
			24,
			9
		],
		[
			30,
			-9
		],
		[
			45,
			-7
		],
		[
			48,
			-4
		],
		[
			9,
			-3
		],
		[
			35,
			8
		],
		[
			-1,
			-15
		],
		[
			14,
			-30
		],
		[
			-13,
			-3
		],
		[
			-7,
			-17
		],
		[
			13,
			0
		],
		[
			-16,
			-9
		],
		[
			12,
			-8
		],
		[
			0,
			-9
		],
		[
			-27,
			-3
		],
		[
			17,
			-14
		],
		[
			-13,
			-6
		],
		[
			9,
			-5
		],
		[
			-17,
			-12
		],
		[
			-13,
			18
		],
		[
			-18,
			-29
		],
		[
			13,
			-14
		],
		[
			34,
			8
		],
		[
			1,
			-21
		],
		[
			-15,
			-30
		],
		[
			-17,
			-8
		],
		[
			-5,
			-19
		],
		[
			-10,
			-7
		],
		[
			-6,
			-33
		],
		[
			-12,
			-36
		],
		[
			-15,
			-8
		],
		[
			25,
			-10
		],
		[
			22,
			10
		],
		[
			-3,
			26
		],
		[
			14,
			11
		],
		[
			34,
			3
		],
		[
			8,
			20
		],
		[
			20,
			6
		],
		[
			-6,
			7
		],
		[
			17,
			12
		],
		[
			14,
			3
		],
		[
			-11,
			7
		],
		[
			16,
			40
		],
		[
			17,
			7
		],
		[
			14,
			12
		],
		[
			-6,
			15
		],
		[
			22,
			23
		],
		[
			15,
			5
		],
		[
			8,
			-12
		],
		[
			28,
			6
		],
		[
			5,
			-7
		],
		[
			13,
			8
		],
		[
			-3,
			16
		],
		[
			35,
			18
		],
		[
			22,
			5
		],
		[
			7,
			21
		],
		[
			16,
			4
		],
		[
			-7,
			13
		],
		[
			9,
			12
		],
		[
			19,
			10
		],
		[
			73,
			24
		],
		[
			30,
			4
		],
		[
			13,
			-3
		],
		[
			-6,
			13
		],
		[
			29,
			18
		],
		[
			36,
			-4
		],
		[
			9,
			7
		],
		[
			18,
			0
		],
		[
			34,
			17
		],
		[
			8,
			-5
		],
		[
			14,
			4
		],
		[
			23,
			-4
		],
		[
			23,
			1
		],
		[
			19,
			14
		],
		[
			25,
			5
		],
		[
			12,
			-6
		],
		[
			34,
			1
		],
		[
			4,
			-10
		],
		[
			31,
			17
		],
		[
			11,
			-4
		],
		[
			8,
			-10
		],
		[
			13,
			6
		],
		[
			16,
			0
		],
		[
			16,
			6
		],
		[
			13,
			-10
		],
		[
			14,
			13
		],
		[
			9,
			0
		],
		[
			8,
			-26
		],
		[
			8,
			11
		],
		[
			13,
			3
		],
		[
			9,
			9
		],
		[
			27,
			7
		],
		[
			14,
			17
		],
		[
			0,
			7
		],
		[
			27,
			0
		],
		[
			8,
			6
		],
		[
			27,
			-9
		],
		[
			24,
			-3
		],
		[
			65,
			-22
		],
		[
			29,
			-6
		],
		[
			-3,
			-17
		],
		[
			12,
			13
		],
		[
			16,
			-19
		],
		[
			18,
			0
		],
		[
			29,
			17
		],
		[
			7,
			0
		],
		[
			-5,
			20
		],
		[
			13,
			14
		],
		[
			62,
			17
		],
		[
			35,
			-27
		],
		[
			-3,
			-15
		],
		[
			21,
			2
		],
		[
			16,
			-8
		],
		[
			3,
			-10
		],
		[
			-17,
			-16
		],
		[
			-31,
			-8
		],
		[
			-11,
			-15
		],
		[
			25,
			3
		],
		[
			22,
			10
		],
		[
			32,
			6
		],
		[
			13,
			10
		],
		[
			-3,
			-10
		],
		[
			19,
			3
		],
		[
			5,
			-6
		],
		[
			32,
			-1
		],
		[
			41,
			14
		],
		[
			0,
			-3
		],
		[
			-45,
			-17
		],
		[
			5,
			-7
		],
		[
			73,
			19
		],
		[
			18,
			14
		],
		[
			58,
			14
		],
		[
			13,
			-9
		],
		[
			11,
			6
		],
		[
			8,
			14
		],
		[
			14,
			6
		],
		[
			12,
			-14
		],
		[
			14,
			6
		],
		[
			-8,
			-12
		],
		[
			3,
			-11
		],
		[
			11,
			0
		],
		[
			0,
			-16
		],
		[
			28,
			6
		],
		[
			11,
			-7
		],
		[
			10,
			7
		],
		[
			6,
			-10
		],
		[
			11,
			13
		],
		[
			2,
			21
		],
		[
			16,
			19
		],
		[
			18,
			8
		],
		[
			28,
			-7
		],
		[
			30,
			4
		],
		[
			8,
			6
		],
		[
			19,
			-2
		],
		[
			13,
			-11
		],
		[
			-5,
			-11
		],
		[
			19,
			10
		],
		[
			11,
			0
		],
		[
			9,
			12
		],
		[
			4,
			-14
		],
		[
			13,
			7
		],
		[
			8,
			-8
		],
		[
			30,
			1
		],
		[
			20,
			-11
		],
		[
			35,
			-3
		],
		[
			12,
			-6
		],
		[
			28,
			-3
		],
		[
			10,
			-5
		],
		[
			20,
			3
		],
		[
			14,
			-13
		],
		[
			27,
			10
		],
		[
			12,
			-6
		],
		[
			-4,
			-11
		],
		[
			21,
			8
		],
		[
			5,
			-6
		],
		[
			-22,
			-38
		],
		[
			0,
			-10
		],
		[
			11,
			0
		],
		[
			26,
			23
		],
		[
			9,
			-10
		],
		[
			14,
			7
		],
		[
			14,
			-31
		],
		[
			13,
			5
		],
		[
			-8,
			-14
		],
		[
			8,
			-7
		],
		[
			23,
			3
		],
		[
			4,
			-6
		],
		[
			39,
			4
		],
		[
			35,
			-1
		],
		[
			10,
			4
		],
		[
			-1,
			-21
		],
		[
			16,
			-13
		],
		[
			0,
			14
		],
		[
			24,
			0
		],
		[
			17,
			-11
		],
		[
			23,
			7
		],
		[
			-5,
			24
		],
		[
			5,
			3
		],
		[
			24,
			-14
		],
		[
			2,
			-10
		],
		[
			16,
			-13
		],
		[
			14,
			-3
		],
		[
			17,
			-14
		],
		[
			19,
			3
		],
		[
			6,
			-10
		],
		[
			6,
			8
		],
		[
			17,
			-1
		],
		[
			45,
			-17
		],
		[
			14,
			-20
		],
		[
			-16,
			0
		],
		[
			28,
			-13
		],
		[
			19,
			-34
		],
		[
			-3,
			-13
		],
		[
			18,
			0
		],
		[
			2,
			34
		],
		[
			16,
			3
		],
		[
			22,
			-23
		],
		[
			21,
			2
		],
		[
			-3,
			7
		],
		[
			38,
			-3
		],
		[
			13,
			-6
		],
		[
			12,
			5
		],
		[
			13,
			-6
		],
		[
			-9,
			-6
		],
		[
			27,
			2
		],
		[
			18,
			-20
		],
		[
			10,
			-3
		],
		[
			48,
			-30
		],
		[
			2,
			21
		],
		[
			19,
			-31
		],
		[
			-5,
			-6
		],
		[
			-13,
			7
		],
		[
			-13,
			-34
		],
		[
			12,
			6
		],
		[
			-5,
			-17
		],
		[
			-39,
			15
		],
		[
			-11,
			-1
		],
		[
			16,
			-13
		],
		[
			29,
			-8
		],
		[
			-8,
			-19
		],
		[
			-20,
			-10
		],
		[
			-14,
			16
		],
		[
			-2,
			-13
		],
		[
			-32,
			1
		],
		[
			-12,
			5
		],
		[
			1,
			-16
		],
		[
			9,
			6
		],
		[
			23,
			-6
		],
		[
			-20,
			-4
		],
		[
			-5,
			-9
		],
		[
			-34,
			0
		],
		[
			9,
			-14
		],
		[
			-26,
			-1
		],
		[
			1,
			15
		],
		[
			-11,
			9
		],
		[
			-4,
			-20
		],
		[
			17,
			-14
		],
		[
			-15,
			0
		],
		[
			13,
			-30
		],
		[
			-24,
			1
		],
		[
			-20,
			-6
		],
		[
			-3,
			16
		],
		[
			-30,
			-30
		],
		[
			9,
			-7
		],
		[
			-5,
			-13
		],
		[
			-22,
			2
		],
		[
			-34,
			-12
		],
		[
			45,
			-1
		],
		[
			-4,
			-7
		],
		[
			21,
			-16
		],
		[
			-2,
			-16
		],
		[
			-18,
			-5
		],
		[
			18,
			-3
		],
		[
			4,
			-13
		],
		[
			-13,
			-11
		],
		[
			14,
			-5
		],
		[
			-14,
			-17
		],
		[
			18,
			0
		],
		[
			20,
			-30
		],
		[
			-7,
			-11
		],
		[
			27,
			-7
		],
		[
			-11,
			-20
		],
		[
			14,
			-7
		],
		[
			20,
			8
		],
		[
			12,
			-14
		],
		[
			36,
			-4
		],
		[
			-15,
			-13
		],
		[
			-12,
			9
		],
		[
			-47,
			-2
		],
		[
			-37,
			-7
		],
		[
			-14,
			-13
		],
		[
			-34,
			22
		],
		[
			20,
			-29
		],
		[
			-38,
			2
		],
		[
			-9,
			-8
		],
		[
			9,
			-14
		],
		[
			-23,
			-14
		],
		[
			27,
			3
		],
		[
			-37,
			-16
		],
		[
			52,
			-4
		],
		[
			-72,
			-17
		],
		[
			-6,
			-13
		],
		[
			61,
			6
		],
		[
			7,
			-8
		],
		[
			-35,
			-4
		],
		[
			40,
			-4
		],
		[
			-17,
			-13
		],
		[
			9,
			-23
		],
		[
			-22,
			5
		],
		[
			25,
			-20
		],
		[
			40,
			-9
		],
		[
			38,
			-31
		],
		[
			-89,
			-12
		],
		[
			59,
			-2
		],
		[
			53,
			8
		],
		[
			73,
			-27
		],
		[
			12,
			-14
		],
		[
			24,
			3
		],
		[
			-3,
			-20
		],
		[
			86,
			-9
		],
		[
			66,
			-23
		],
		[
			124,
			-12
		],
		[
			-9955,
			-15
		]
	],
	[
		[
			3456,
			1546
		],
		[
			12,
			-3
		],
		[
			-1,
			-9
		],
		[
			-17,
			4
		],
		[
			-19,
			-9
		],
		[
			3,
			13
		],
		[
			22,
			4
		]
	],
	[
		[
			3431,
			1556
		],
		[
			12,
			-2
		],
		[
			-6,
			-9
		],
		[
			-6,
			11
		]
	],
	[
		[
			3331,
			1581
		],
		[
			7,
			-5
		],
		[
			-12,
			-7
		],
		[
			-4,
			7
		],
		[
			-20,
			-3
		],
		[
			-1,
			6
		],
		[
			30,
			2
		]
	],
	[
		[
			3392,
			1616
		],
		[
			7,
			-6
		],
		[
			-33,
			-7
		],
		[
			10,
			13
		],
		[
			16,
			0
		]
	],
	[
		[
			3470,
			1665
		],
		[
			-6,
			-10
		],
		[
			-5,
			8
		],
		[
			11,
			2
		]
	],
	[
		[
			6916,
			2373
		],
		[
			5,
			-3
		],
		[
			-5,
			-12
		],
		[
			16,
			-14
		],
		[
			19,
			13
		],
		[
			7,
			-1
		],
		[
			-1,
			-15
		],
		[
			-9,
			1
		],
		[
			-11,
			-5
		],
		[
			2,
			-7
		],
		[
			13,
			1
		],
		[
			-1,
			-9
		],
		[
			-22,
			3
		],
		[
			-7,
			8
		],
		[
			-5,
			-13
		],
		[
			-8,
			4
		],
		[
			5,
			20
		],
		[
			-5,
			14
		],
		[
			1,
			12
		],
		[
			6,
			3
		]
	],
	[
		[
			9093,
			2685
		],
		[
			-7,
			-6
		],
		[
			5,
			12
		],
		[
			2,
			-6
		]
	],
	[
		[
			9020,
			2837
		],
		[
			14,
			-3
		],
		[
			13,
			-8
		],
		[
			2,
			-6
		],
		[
			17,
			-8
		],
		[
			24,
			13
		],
		[
			5,
			-4
		],
		[
			5,
			11
		],
		[
			5,
			-4
		],
		[
			4,
			9
		],
		[
			10,
			-13
		],
		[
			-1,
			-28
		],
		[
			1,
			-39
		],
		[
			-7,
			1
		],
		[
			-1,
			-22
		],
		[
			-4,
			-21
		],
		[
			3,
			-1
		],
		[
			0,
			-21
		],
		[
			-10,
			9
		],
		[
			6,
			10
		],
		[
			-14,
			1
		],
		[
			-4,
			-23
		],
		[
			-2,
			6
		],
		[
			-8,
			-26
		],
		[
			-9,
			6
		],
		[
			-14,
			-1
		],
		[
			-3,
			20
		],
		[
			-2,
			-6
		],
		[
			-4,
			15
		],
		[
			-7,
			9
		],
		[
			-6,
			24
		],
		[
			0,
			13
		],
		[
			9,
			-9
		],
		[
			-13,
			31
		],
		[
			-11,
			37
		],
		[
			-2,
			13
		],
		[
			4,
			15
		]
	],
	[
		[
			9121,
			2859
		],
		[
			-9,
			-6
		],
		[
			0,
			6
		],
		[
			9,
			0
		]
	],
	[
		[
			9109,
			2896
		],
		[
			9,
			-16
		],
		[
			1,
			-14
		],
		[
			-5,
			-2
		],
		[
			-11,
			22
		],
		[
			6,
			10
		]
	],
	[
		[
			9001,
			2876
		],
		[
			-5,
			-4
		],
		[
			-1,
			25
		],
		[
			7,
			3
		],
		[
			-1,
			-24
		]
	],
	[
		[
			8822,
			3134
		],
		[
			-1,
			-10
		],
		[
			12,
			1
		],
		[
			0,
			-11
		],
		[
			-11,
			1
		],
		[
			-5,
			-10
		],
		[
			-20,
			1
		],
		[
			-4,
			17
		],
		[
			21,
			11
		],
		[
			8,
			0
		]
	],
	[
		[
			9263,
			3604
		],
		[
			-1,
			-18
		],
		[
			-2,
			14
		],
		[
			3,
			4
		]
	],
	[
		[
			9261,
			3608
		],
		[
			-2,
			17
		],
		[
			3,
			2
		],
		[
			-1,
			-19
		]
	],
	[
		[
			8136,
			3714
		],
		[
			7,
			-36
		],
		[
			-7,
			19
		],
		[
			0,
			17
		]
	],
	[
		[
			9257,
			3758
		],
		[
			2,
			-20
		],
		[
			-10,
			-37
		],
		[
			1,
			32
		],
		[
			5,
			7
		],
		[
			-2,
			14
		],
		[
			4,
			4
		]
	],
	[
		[
			9195,
			3832
		],
		[
			5,
			-3
		],
		[
			0,
			-17
		],
		[
			-7,
			17
		],
		[
			2,
			3
		]
	],
	[
		[
			9061,
			4133
		],
		[
			3,
			-7
		],
		[
			-3,
			-7
		],
		[
			-4,
			13
		],
		[
			4,
			1
		]
	],
	[
		[
			8880,
			4236
		],
		[
			-7,
			-7
		],
		[
			0,
			-6
		],
		[
			-8,
			0
		],
		[
			1,
			8
		],
		[
			10,
			8
		],
		[
			4,
			-3
		]
	],
	[
		[
			8805,
			4285
		],
		[
			2,
			-15
		],
		[
			-4,
			8
		],
		[
			2,
			7
		]
	],
	[
		[
			8797,
			4395
		],
		[
			0,
			-9
		],
		[
			6,
			2
		],
		[
			-5,
			-8
		],
		[
			-1,
			-14
		],
		[
			6,
			-6
		],
		[
			-8,
			0
		],
		[
			-6,
			5
		],
		[
			-1,
			14
		],
		[
			9,
			16
		]
	],
	[
		[
			8621,
			4522
		],
		[
			5,
			-21
		],
		[
			-7,
			4
		],
		[
			-8,
			-2
		],
		[
			5,
			9
		],
		[
			-2,
			9
		],
		[
			6,
			10
		],
		[
			1,
			-9
		]
	],
	[
		[
			8624,
			4533
		],
		[
			6,
			-6
		],
		[
			14,
			10
		],
		[
			6,
			-2
		],
		[
			1,
			-21
		],
		[
			-14,
			-18
		],
		[
			-13,
			16
		],
		[
			-3,
			29
		],
		[
			3,
			-8
		]
	],
	[
		[
			8682,
			4547
		],
		[
			1,
			-13
		],
		[
			-4,
			6
		],
		[
			3,
			7
		]
	],
	[
		[
			8959,
			4566
		],
		[
			-1,
			-8
		],
		[
			6,
			-7
		],
		[
			3,
			-19
		],
		[
			0,
			-30
		],
		[
			10,
			-9
		],
		[
			-4,
			-20
		],
		[
			6,
			-4
		],
		[
			4,
			-11
		],
		[
			-2,
			-17
		],
		[
			5,
			2
		],
		[
			-1,
			-13
		],
		[
			3,
			-19
		],
		[
			-2,
			-19
		],
		[
			5,
			-20
		],
		[
			3,
			-22
		],
		[
			5,
			-2
		],
		[
			15,
			18
		],
		[
			4,
			-22
		],
		[
			18,
			-23
		],
		[
			-3,
			-12
		],
		[
			2,
			-6
		],
		[
			2,
			-37
		],
		[
			3,
			-8
		],
		[
			-2,
			-16
		],
		[
			6,
			-22
		],
		[
			9,
			-9
		],
		[
			-1,
			-11
		],
		[
			5,
			-19
		],
		[
			1,
			-16
		],
		[
			-3,
			-34
		],
		[
			9,
			-15
		],
		[
			-2,
			-17
		],
		[
			5,
			-14
		],
		[
			13,
			-15
		],
		[
			4,
			7
		],
		[
			2,
			-12
		],
		[
			8,
			0
		],
		[
			4,
			-6
		],
		[
			1,
			-14
		],
		[
			19,
			-12
		],
		[
			1,
			-10
		],
		[
			7,
			5
		],
		[
			3,
			-13
		],
		[
			4,
			1
		],
		[
			1,
			-10
		],
		[
			-4,
			-1
		],
		[
			-1,
			-10
		],
		[
			15,
			-24
		],
		[
			-1,
			-8
		],
		[
			8,
			-30
		],
		[
			0,
			-14
		],
		[
			3,
			-20
		],
		[
			8,
			-7
		],
		[
			5,
			-13
		],
		[
			-3,
			22
		],
		[
			4,
			5
		],
		[
			3,
			-9
		],
		[
			10,
			-13
		],
		[
			2,
			13
		],
		[
			6,
			-21
		],
		[
			-2,
			-15
		],
		[
			3,
			-36
		],
		[
			4,
			0
		],
		[
			4,
			-13
		],
		[
			5,
			-4
		],
		[
			6,
			-13
		],
		[
			6,
			3
		],
		[
			4,
			-6
		],
		[
			6,
			-27
		],
		[
			8,
			-7
		],
		[
			4,
			-25
		],
		[
			10,
			-6
		],
		[
			0,
			-27
		],
		[
			6,
			-16
		],
		[
			-2,
			-19
		],
		[
			4,
			-40
		],
		[
			-4,
			-3
		],
		[
			10,
			-41
		],
		[
			1,
			-17
		],
		[
			3,
			-4
		],
		[
			1,
			-40
		],
		[
			-7,
			-21
		],
		[
			-2,
			-39
		],
		[
			-7,
			-32
		],
		[
			0,
			-30
		],
		[
			-3,
			-28
		],
		[
			-5,
			-21
		],
		[
			-6,
			-11
		],
		[
			0,
			-23
		],
		[
			-13,
			-15
		],
		[
			-11,
			-20
		],
		[
			-6,
			-26
		],
		[
			-5,
			-3
		],
		[
			0,
			-26
		],
		[
			-9,
			-18
		],
		[
			-3,
			-27
		],
		[
			-4,
			-14
		],
		[
			2,
			-9
		],
		[
			-8,
			-7
		],
		[
			-9,
			-34
		],
		[
			0,
			-24
		],
		[
			-7,
			-34
		],
		[
			4,
			-21
		],
		[
			-2,
			-14
		],
		[
			-13,
			-16
		],
		[
			-33,
			-2
		],
		[
			-16,
			-10
		],
		[
			-10,
			-13
		],
		[
			-13,
			-24
		],
		[
			-19,
			-4
		],
		[
			3,
			-12
		],
		[
			4,
			7
		],
		[
			-2,
			-20
		],
		[
			-6,
			16
		],
		[
			-8,
			-3
		],
		[
			-4,
			16
		],
		[
			-3,
			-3
		],
		[
			-8,
			9
		],
		[
			5,
			8
		],
		[
			-2,
			9
		],
		[
			-6,
			0
		],
		[
			-1,
			-10
		],
		[
			-8,
			-5
		],
		[
			-6,
			8
		],
		[
			8,
			1
		],
		[
			3,
			17
		],
		[
			-6,
			10
		],
		[
			-15,
			-14
		],
		[
			10,
			-2
		],
		[
			-2,
			-8
		],
		[
			-6,
			0
		],
		[
			-10,
			-11
		],
		[
			-14,
			-22
		],
		[
			-32,
			28
		],
		[
			-5,
			-2
		],
		[
			-8,
			7
		],
		[
			-9,
			-1
		],
		[
			1,
			-6
		],
		[
			-8,
			1
		],
		[
			-4,
			13
		],
		[
			-14,
			5
		],
		[
			-10,
			11
		],
		[
			-3,
			13
		],
		[
			-13,
			23
		],
		[
			-3,
			18
		],
		[
			5,
			6
		],
		[
			0,
			13
		],
		[
			-9,
			34
		],
		[
			-14,
			26
		],
		[
			6,
			2
		],
		[
			3,
			10
		],
		[
			-4,
			3
		],
		[
			-21,
			-20
		],
		[
			-8,
			0
		],
		[
			-1,
			7
		],
		[
			9,
			12
		],
		[
			3,
			33
		],
		[
			-8,
			16
		],
		[
			-3,
			16
		],
		[
			-7,
			-13
		],
		[
			-1,
			-20
		],
		[
			-5,
			-23
		],
		[
			-7,
			4
		],
		[
			-15,
			-11
		],
		[
			3,
			23
		],
		[
			11,
			-3
		],
		[
			3,
			21
		],
		[
			-1,
			25
		],
		[
			4,
			17
		],
		[
			9,
			19
		],
		[
			-3,
			19
		],
		[
			6,
			4
		],
		[
			-8,
			34
		],
		[
			0,
			-26
		],
		[
			-3,
			2
		],
		[
			-6,
			-11
		],
		[
			-5,
			-27
		],
		[
			-25,
			-26
		],
		[
			-8,
			-24
		],
		[
			-4,
			-3
		],
		[
			-4,
			-16
		],
		[
			6,
			2
		],
		[
			0,
			-12
		],
		[
			-5,
			7
		],
		[
			-6,
			-5
		],
		[
			-6,
			18
		],
		[
			-1,
			21
		],
		[
			-3,
			17
		],
		[
			-11,
			20
		],
		[
			-4,
			27
		],
		[
			-12,
			0
		],
		[
			-2,
			13
		],
		[
			-4,
			1
		],
		[
			7,
			15
		],
		[
			-5,
			12
		],
		[
			-8,
			-5
		],
		[
			3,
			9
		],
		[
			-8,
			16
		],
		[
			-14,
			-5
		],
		[
			-10,
			14
		],
		[
			-7,
			1
		],
		[
			-9,
			-6
		],
		[
			-12,
			18
		],
		[
			-18,
			14
		],
		[
			-9,
			-7
		],
		[
			-18,
			2
		],
		[
			-33,
			-7
		],
		[
			-27,
			-23
		],
		[
			-20,
			-11
		],
		[
			-17,
			-2
		],
		[
			-14,
			5
		],
		[
			-18,
			-19
		],
		[
			-15,
			-10
		],
		[
			-2,
			-6
		],
		[
			-17,
			-8
		],
		[
			-4,
			-5
		],
		[
			-5,
			-28
		],
		[
			-7,
			-16
		],
		[
			-6,
			-7
		],
		[
			-4,
			3
		],
		[
			-6,
			-7
		],
		[
			-3,
			9
		],
		[
			-19,
			-3
		],
		[
			-8,
			-6
		],
		[
			0,
			8
		],
		[
			-14,
			3
		],
		[
			-20,
			-2
		],
		[
			-13,
			-6
		],
		[
			-16,
			-1
		],
		[
			-9,
			-16
		],
		[
			-2,
			-12
		],
		[
			-16,
			1
		],
		[
			-3,
			-11
		],
		[
			-7,
			-4
		],
		[
			-2,
			-11
		],
		[
			-20,
			-8
		],
		[
			-2,
			-5
		],
		[
			-12,
			7
		],
		[
			-18,
			-1
		],
		[
			-15,
			14
		],
		[
			-10,
			19
		],
		[
			-10,
			9
		],
		[
			-4,
			-3
		],
		[
			-4,
			15
		],
		[
			0,
			32
		],
		[
			6,
			-7
		],
		[
			7,
			3
		],
		[
			6,
			18
		],
		[
			-1,
			36
		],
		[
			3,
			8
		],
		[
			0,
			43
		],
		[
			-18,
			66
		],
		[
			-4,
			34
		],
		[
			1,
			32
		],
		[
			-5,
			22
		],
		[
			-7,
			17
		],
		[
			0,
			16
		],
		[
			-11,
			24
		],
		[
			-2,
			38
		],
		[
			-5,
			16
		],
		[
			-11,
			32
		],
		[
			-7,
			13
		],
		[
			5,
			14
		],
		[
			6,
			-26
		],
		[
			7,
			6
		],
		[
			0,
			9
		],
		[
			-9,
			14
		],
		[
			-4,
			27
		],
		[
			2,
			4
		],
		[
			7,
			-20
		],
		[
			-1,
			-17
		],
		[
			5,
			14
		],
		[
			2,
			-22
		],
		[
			7,
			-2
		],
		[
			0,
			30
		],
		[
			-5,
			13
		],
		[
			-6,
			26
		],
		[
			-4,
			4
		],
		[
			-3,
			21
		],
		[
			-5,
			16
		],
		[
			1,
			26
		],
		[
			4,
			22
		],
		[
			5,
			6
		],
		[
			0,
			24
		],
		[
			2,
			10
		],
		[
			-5,
			22
		],
		[
			3,
			7
		],
		[
			7,
			33
		],
		[
			4,
			4
		],
		[
			-2,
			-20
		],
		[
			1,
			-21
		],
		[
			7,
			4
		],
		[
			8,
			34
		],
		[
			23,
			20
		],
		[
			13,
			26
		],
		[
			21,
			22
		],
		[
			5,
			-3
		],
		[
			8,
			6
		],
		[
			7,
			-7
		],
		[
			12,
			7
		],
		[
			8,
			14
		],
		[
			17,
			3
		],
		[
			10,
			20
		],
		[
			12,
			-6
		],
		[
			7,
			6
		],
		[
			12,
			3
		],
		[
			16,
			11
		],
		[
			11,
			13
		],
		[
			9,
			25
		],
		[
			3,
			19
		],
		[
			4,
			4
		],
		[
			16,
			39
		],
		[
			-4,
			1
		],
		[
			-2,
			36
		],
		[
			3,
			14
		],
		[
			8,
			17
		],
		[
			6,
			3
		],
		[
			0,
			10
		],
		[
			7,
			12
		],
		[
			-1,
			-15
		],
		[
			5,
			-3
		],
		[
			0,
			-14
		],
		[
			12,
			-37
		],
		[
			-1,
			10
		],
		[
			3,
			13
		],
		[
			-2,
			11
		],
		[
			7,
			-10
		],
		[
			-3,
			24
		],
		[
			-6,
			5
		],
		[
			6,
			13
		],
		[
			-5,
			8
		],
		[
			5,
			2
		],
		[
			7,
			-7
		],
		[
			-1,
			9
		],
		[
			7,
			-9
		],
		[
			16,
			-1
		],
		[
			-10,
			3
		],
		[
			-1,
			9
		],
		[
			6,
			4
		],
		[
			1,
			18
		],
		[
			-4,
			-11
		],
		[
			-3,
			18
		],
		[
			1,
			9
		],
		[
			6,
			1
		],
		[
			3,
			9
		],
		[
			5,
			0
		],
		[
			4,
			-9
		],
		[
			1,
			10
		],
		[
			-6,
			3
		],
		[
			4,
			17
		],
		[
			11,
			-10
		],
		[
			0,
			9
		],
		[
			-8,
			16
		],
		[
			10,
			14
		],
		[
			3,
			-4
		],
		[
			7,
			6
		],
		[
			1,
			-11
		],
		[
			3,
			5
		],
		[
			4,
			26
		],
		[
			-5,
			5
		],
		[
			4,
			7
		],
		[
			3,
			-19
		],
		[
			9,
			16
		],
		[
			1,
			-16
		],
		[
			4,
			14
		],
		[
			4,
			0
		],
		[
			-3,
			11
		],
		[
			6,
			4
		],
		[
			4,
			-14
		],
		[
			9,
			1
		],
		[
			11,
			-28
		],
		[
			10,
			-16
		],
		[
			-3,
			-17
		],
		[
			0,
			-13
		],
		[
			4,
			-1
		],
		[
			-1,
			11
		],
		[
			5,
			14
		],
		[
			4,
			3
		],
		[
			12,
			-5
		],
		[
			9,
			-11
		],
		[
			-1,
			11
		],
		[
			7,
			-5
		],
		[
			3,
			-14
		],
		[
			4,
			1
		],
		[
			-3,
			18
		],
		[
			5,
			-1
		],
		[
			-6,
			15
		],
		[
			-7,
			11
		],
		[
			4,
			20
		],
		[
			7,
			4
		],
		[
			1,
			18
		],
		[
			4,
			9
		],
		[
			11,
			12
		],
		[
			-5,
			9
		],
		[
			0,
			14
		],
		[
			6,
			2
		],
		[
			0,
			12
		],
		[
			6,
			6
		],
		[
			2,
			11
		],
		[
			7,
			-14
		],
		[
			0,
			17
		],
		[
			4,
			-2
		],
		[
			-1,
			12
		],
		[
			9,
			5
		],
		[
			3,
			-13
		],
		[
			13,
			4
		],
		[
			4,
			-5
		],
		[
			9,
			5
		],
		[
			7,
			9
		],
		[
			2,
			24
		],
		[
			-7,
			12
		],
		[
			-9,
			-5
		],
		[
			-5,
			12
		],
		[
			-5,
			0
		],
		[
			7,
			11
		],
		[
			10,
			-1
		],
		[
			9,
			-21
		],
		[
			6,
			10
		],
		[
			7,
			-21
		],
		[
			14,
			-7
		],
		[
			4,
			6
		],
		[
			4,
			-11
		],
		[
			3,
			4
		],
		[
			4,
			-12
		],
		[
			6,
			-1
		],
		[
			8,
			7
		],
		[
			11,
			-18
		],
		[
			13,
			11
		],
		[
			6,
			2
		],
		[
			-4,
			-8
		],
		[
			2,
			-6
		],
		[
			5,
			7
		],
		[
			5,
			-5
		],
		[
			-2,
			-11
		],
		[
			7,
			-1
		],
		[
			3,
			14
		],
		[
			-5,
			3
		],
		[
			10,
			9
		],
		[
			4,
			-17
		],
		[
			3,
			7
		],
		[
			4,
			-11
		],
		[
			-12,
			-28
		],
		[
			4,
			-6
		],
		[
			-9,
			-21
		],
		[
			0,
			9
		],
		[
			-5,
			-6
		],
		[
			0,
			8
		],
		[
			-7,
			-9
		],
		[
			0,
			-26
		],
		[
			4,
			3
		],
		[
			-4,
			-29
		],
		[
			-3,
			-3
		],
		[
			-7,
			-24
		],
		[
			-4,
			-4
		],
		[
			2,
			-13
		],
		[
			22,
			-27
		],
		[
			0,
			-8
		],
		[
			10,
			-11
		],
		[
			4,
			-9
		],
		[
			7,
			1
		],
		[
			10,
			-14
		],
		[
			10,
			-7
		],
		[
			9,
			-21
		],
		[
			7,
			-8
		],
		[
			20,
			-9
		],
		[
			4,
			-7
		],
		[
			1,
			-15
		],
		[
			22,
			-24
		],
		[
			14,
			4
		],
		[
			10,
			13
		],
		[
			3,
			24
		],
		[
			7,
			18
		],
		[
			3,
			26
		],
		[
			3,
			9
		],
		[
			-2,
			9
		],
		[
			3,
			25
		],
		[
			5,
			20
		],
		[
			-4,
			40
		],
		[
			3,
			16
		],
		[
			-4,
			13
		],
		[
			1,
			21
		],
		[
			5,
			21
		],
		[
			-2,
			18
		],
		[
			6,
			14
		],
		[
			-2,
			11
		],
		[
			-5,
			-4
		],
		[
			6,
			28
		],
		[
			6,
			1
		],
		[
			-2,
			8
		],
		[
			6,
			41
		],
		[
			0,
			14
		],
		[
			5,
			2
		],
		[
			6,
			11
		]
	],
	[
		[
			5470,
			7982
		],
		[
			-2,
			-9
		],
		[
			5,
			-23
		],
		[
			3,
			-3
		]
	],
	[
		[
			5476,
			7947
		],
		[
			-3,
			-17
		],
		[
			-12,
			3
		],
		[
			-6,
			-6
		],
		[
			7,
			-3
		],
		[
			-5,
			-12
		],
		[
			-1,
			-22
		],
		[
			-9,
			-9
		]
	],
	[
		[
			5447,
			7881
		],
		[
			-19,
			-12
		],
		[
			-16,
			-2
		],
		[
			-9,
			-14
		],
		[
			-23,
			9
		]
	],
	[
		[
			5380,
			7862
		],
		[
			-32,
			7
		],
		[
			-12,
			17
		],
		[
			2,
			7
		],
		[
			-12,
			-5
		],
		[
			-17,
			-1
		],
		[
			-4,
			-11
		],
		[
			-15,
			6
		]
	],
	[
		[
			5290,
			7882
		],
		[
			-2,
			7
		],
		[
			-6,
			-8
		],
		[
			-16,
			12
		]
	],
	[
		[
			5266,
			7893
		],
		[
			-2,
			12
		]
	],
	[
		[
			5264,
			7905
		],
		[
			1,
			14
		]
	],
	[
		[
			5265,
			7919
		],
		[
			4,
			2
		]
	],
	[
		[
			5269,
			7921
		],
		[
			7,
			0
		],
		[
			8,
			-16
		],
		[
			6,
			15
		],
		[
			12,
			-1
		],
		[
			2,
			-7
		],
		[
			9,
			1
		],
		[
			9,
			10
		],
		[
			32,
			4
		],
		[
			6,
			-11
		],
		[
			3,
			9
		],
		[
			-5,
			5
		],
		[
			1,
			13
		],
		[
			-6,
			9
		],
		[
			4,
			7
		],
		[
			12,
			5
		],
		[
			4,
			16
		],
		[
			7,
			-3
		],
		[
			3,
			13
		]
	],
	[
		[
			5383,
			7990
		],
		[
			7,
			-9
		],
		[
			18,
			0
		],
		[
			7,
			11
		],
		[
			0,
			12
		],
		[
			11,
			-1
		],
		[
			20,
			-13
		],
		[
			10,
			3
		],
		[
			13,
			-6
		],
		[
			1,
			-5
		]
	],
	[
		[
			6281,
			7420
		],
		[
			-19,
			8
		],
		[
			-9,
			14
		],
		[
			-9,
			24
		]
	],
	[
		[
			6244,
			7466
		],
		[
			-1,
			3
		]
	],
	[
		[
			6289,
			7594
		],
		[
			9,
			-6
		],
		[
			11,
			-12
		],
		[
			5,
			-17
		],
		[
			16,
			-3
		],
		[
			5,
			15
		],
		[
			9,
			6
		],
		[
			5,
			16
		]
	],
	[
		[
			6349,
			7593
		],
		[
			15,
			-31
		],
		[
			1,
			-11
		],
		[
			10,
			-28
		],
		[
			15,
			-3
		],
		[
			8,
			-10
		],
		[
			-11,
			-3
		],
		[
			-13,
			-11
		],
		[
			0,
			-11
		],
		[
			-6,
			-28
		],
		[
			4,
			-11
		],
		[
			-5,
			0
		],
		[
			-1,
			-17
		],
		[
			-7,
			10
		],
		[
			-2,
			-43
		]
	],
	[
		[
			6357,
			7396
		],
		[
			-7,
			-2
		],
		[
			-6,
			12
		],
		[
			-11,
			12
		],
		[
			1,
			8
		],
		[
			7,
			2
		],
		[
			-5,
			18
		],
		[
			6,
			7
		],
		[
			-10,
			16
		],
		[
			-4,
			-1
		],
		[
			-26,
			-29
		],
		[
			-11,
			-17
		]
	],
	[
		[
			6249,
			7560
		],
		[
			8,
			10
		],
		[
			13,
			-8
		],
		[
			8,
			-9
		],
		[
			6,
			1
		],
		[
			6,
			-8
		],
		[
			4,
			3
		],
		[
			1,
			15
		],
		[
			-10,
			9
		],
		[
			-3,
			13
		],
		[
			7,
			8
		]
	],
	[
		[
			5848,
			5045
		],
		[
			-4,
			-15
		],
		[
			2,
			-14
		],
		[
			9,
			-5
		],
		[
			0,
			-17
		],
		[
			-9,
			-13
		],
		[
			-9,
			-34
		],
		[
			-11,
			-21
		],
		[
			-3,
			1
		]
	],
	[
		[
			5823,
			4927
		],
		[
			-9,
			39
		],
		[
			1,
			21
		],
		[
			-4,
			4
		]
	],
	[
		[
			5811,
			4991
		],
		[
			0,
			18
		],
		[
			-4,
			5
		],
		[
			-2,
			12
		]
	],
	[
		[
			5805,
			5026
		],
		[
			4,
			7
		],
		[
			5,
			-4
		],
		[
			0,
			-9
		],
		[
			11,
			1
		],
		[
			5,
			7
		],
		[
			1,
			21
		],
		[
			6,
			-6
		],
		[
			7,
			7
		],
		[
			4,
			-5
		]
	],
	[
		[
			5166,
			8104
		],
		[
			10,
			-14
		],
		[
			1,
			-10
		],
		[
			-8,
			-11
		]
	],
	[
		[
			5169,
			8069
		],
		[
			-7,
			-3
		],
		[
			-4,
			-16
		],
		[
			2,
			-14
		]
	],
	[
		[
			5160,
			8036
		],
		[
			-9,
			-3
		],
		[
			-4,
			10
		],
		[
			-13,
			7
		],
		[
			-1,
			21
		],
		[
			-9,
			-13
		],
		[
			-10,
			3
		],
		[
			2,
			15
		],
		[
			-5,
			5
		],
		[
			-10,
			0
		],
		[
			0,
			6
		],
		[
			-11,
			5
		],
		[
			-4,
			15
		],
		[
			-7,
			-6
		],
		[
			-7,
			8
		],
		[
			-2,
			15
		]
	],
	[
		[
			5070,
			8124
		],
		[
			16,
			14
		],
		[
			7,
			3
		]
	],
	[
		[
			5093,
			8141
		],
		[
			0,
			-6
		],
		[
			16,
			-3
		],
		[
			8,
			9
		]
	],
	[
		[
			5117,
			8141
		],
		[
			1,
			0
		]
	],
	[
		[
			5118,
			8141
		],
		[
			3,
			3
		],
		[
			16,
			-1
		],
		[
			7,
			-8
		],
		[
			9,
			0
		],
		[
			9,
			-11
		],
		[
			-6,
			-13
		],
		[
			10,
			-7
		]
	],
	[
		[
			5099,
			5856
		],
		[
			-3,
			-17
		],
		[
			7,
			-16
		],
		[
			0,
			-19
		],
		[
			3,
			-5
		],
		[
			-1,
			-16
		],
		[
			-5,
			0
		],
		[
			1,
			-14
		],
		[
			-3,
			-18
		],
		[
			-6,
			-3
		],
		[
			0,
			-9
		],
		[
			-5,
			-12
		],
		[
			-2,
			-20
		],
		[
			-8,
			-4
		],
		[
			-2,
			-15
		],
		[
			0,
			-41
		],
		[
			-1,
			-12
		],
		[
			2,
			-25
		],
		[
			1,
			-42
		],
		[
			-2,
			-18
		]
	],
	[
		[
			5075,
			5550
		],
		[
			-31,
			-9
		]
	],
	[
		[
			5044,
			5541
		],
		[
			5,
			3
		],
		[
			-5,
			18
		],
		[
			1,
			24
		],
		[
			0,
			73
		],
		[
			-1,
			5
		],
		[
			0,
			43
		],
		[
			-6,
			13
		],
		[
			-1,
			37
		],
		[
			-16,
			23
		],
		[
			0,
			19
		],
		[
			4,
			17
		]
	],
	[
		[
			5025,
			5816
		],
		[
			5,
			3
		],
		[
			1,
			13
		],
		[
			4,
			-1
		],
		[
			3,
			11
		],
		[
			6,
			-3
		],
		[
			11,
			2
		],
		[
			8,
			13
		],
		[
			3,
			14
		]
	],
	[
		[
			5066,
			5868
		],
		[
			-1,
			19
		],
		[
			14,
			10
		],
		[
			10,
			-21
		],
		[
			2,
			-8
		],
		[
			6,
			-4
		],
		[
			2,
			-8
		]
	],
	[
		[
			5006,
			6041
		],
		[
			-2,
			-21
		],
		[
			6,
			-16
		],
		[
			-1,
			-9
		],
		[
			7,
			-24
		],
		[
			5,
			0
		],
		[
			7,
			-13
		],
		[
			7,
			-7
		],
		[
			-9,
			-1
		],
		[
			0,
			-15
		],
		[
			6,
			-6
		],
		[
			11,
			-19
		],
		[
			8,
			-1
		],
		[
			3,
			7
		],
		[
			5,
			-3
		],
		[
			3,
			-15
		],
		[
			-6,
			-4
		],
		[
			10,
			-26
		]
	],
	[
		[
			5025,
			5816
		],
		[
			-12,
			0
		],
		[
			-18,
			8
		]
	],
	[
		[
			4995,
			5824
		],
		[
			-8,
			-3
		],
		[
			-5,
			-10
		],
		[
			-2,
			5
		],
		[
			-59,
			0
		],
		[
			-3,
			-22
		],
		[
			3,
			-11
		],
		[
			2,
			-25
		],
		[
			0,
			-24
		],
		[
			2,
			-5
		]
	],
	[
		[
			4925,
			5729
		],
		[
			-4,
			-4
		],
		[
			-10,
			24
		],
		[
			-6,
			5
		],
		[
			-10,
			1
		],
		[
			-11,
			-7
		],
		[
			-4,
			-11
		],
		[
			-11,
			3
		],
		[
			-4,
			12
		],
		[
			-3,
			-1
		],
		[
			-4,
			24
		],
		[
			-9,
			1
		],
		[
			-3,
			7
		]
	],
	[
		[
			4846,
			5783
		],
		[
			3,
			24
		],
		[
			-2,
			14
		],
		[
			6,
			9
		],
		[
			1,
			19
		],
		[
			-4,
			14
		],
		[
			8,
			10
		],
		[
			9,
			1
		],
		[
			10,
			18
		],
		[
			-1,
			24
		],
		[
			6,
			0
		],
		[
			0,
			14
		],
		[
			-3,
			11
		],
		[
			10,
			13
		],
		[
			15,
			-13
		],
		[
			5,
			7
		],
		[
			0,
			25
		],
		[
			6,
			-5
		],
		[
			5,
			21
		],
		[
			11,
			16
		],
		[
			12,
			-6
		],
		[
			1,
			16
		],
		[
			8,
			3
		],
		[
			11,
			13
		],
		[
			8,
			5
		],
		[
			8,
			15
		],
		[
			8,
			-4
		],
		[
			8,
			2
		],
		[
			11,
			-8
		]
	],
	[
		[
			7529,
			6456
		],
		[
			0,
			16
		],
		[
			3,
			-11
		],
		[
			-3,
			-5
		]
	],
	[
		[
			7521,
			6458
		],
		[
			-5,
			-7
		],
		[
			2,
			29
		],
		[
			-4,
			4
		],
		[
			3,
			11
		],
		[
			6,
			-20
		],
		[
			-2,
			-17
		]
	],
	[
		[
			7571,
			6448
		],
		[
			0,
			-29
		],
		[
			2,
			-10
		],
		[
			-12,
			7
		],
		[
			1,
			-20
		]
	],
	[
		[
			7562,
			6396
		],
		[
			1,
			-15
		],
		[
			-7,
			20
		],
		[
			-1,
			27
		],
		[
			-3,
			9
		],
		[
			-2,
			29
		],
		[
			-11,
			31
		],
		[
			-5,
			-14
		],
		[
			-9,
			0
		],
		[
			-8,
			26
		],
		[
			1,
			14
		],
		[
			-4,
			6
		],
		[
			-9,
			4
		],
		[
			11,
			-11
		],
		[
			-4,
			-10
		],
		[
			2,
			-12
		],
		[
			-3,
			-8
		],
		[
			5,
			-13
		],
		[
			-2,
			-18
		],
		[
			-6,
			-9
		],
		[
			-1,
			-11
		],
		[
			-7,
			1
		],
		[
			1,
			7
		],
		[
			-5,
			6
		],
		[
			-2,
			-15
		],
		[
			-12,
			-7
		],
		[
			0,
			14
		],
		[
			-4,
			-18
		],
		[
			-4,
			10
		],
		[
			-1,
			18
		]
	],
	[
		[
			7473,
			6457
		],
		[
			-6,
			48
		],
		[
			2,
			14
		],
		[
			-7,
			2
		],
		[
			3,
			13
		],
		[
			-6,
			8
		],
		[
			0,
			11
		],
		[
			5,
			8
		],
		[
			0,
			22
		],
		[
			-7,
			0
		],
		[
			-11,
			12
		],
		[
			-2,
			7
		],
		[
			4,
			12
		],
		[
			5,
			1
		],
		[
			3,
			18
		],
		[
			13,
			-1
		],
		[
			-3,
			18
		],
		[
			-8,
			1
		],
		[
			-3,
			11
		],
		[
			-9,
			14
		],
		[
			2,
			12
		],
		[
			5,
			4
		],
		[
			4,
			14
		],
		[
			5,
			-9
		],
		[
			11,
			-3
		],
		[
			7,
			-14
		],
		[
			7,
			-2
		],
		[
			2,
			15
		],
		[
			6,
			-18
		],
		[
			-2,
			-4
		],
		[
			1,
			-32
		],
		[
			15,
			-8
		],
		[
			23,
			2
		],
		[
			7,
			-3
		],
		[
			18,
			3
		],
		[
			11,
			-14
		],
		[
			-6,
			-2
		],
		[
			-5,
			-31
		],
		[
			-5,
			-2
		],
		[
			0,
			-9
		],
		[
			-8,
			2
		],
		[
			0,
			-6
		],
		[
			-7,
			0
		],
		[
			-7,
			-21
		],
		[
			2,
			-14
		],
		[
			9,
			-30
		],
		[
			7,
			5
		],
		[
			0,
			15
		],
		[
			5,
			8
		],
		[
			-1,
			11
		],
		[
			5,
			4
		],
		[
			8,
			-22
		],
		[
			0,
			-25
		],
		[
			3,
			-12
		],
		[
			3,
			-42
		]
	],
	[
		[
			5793,
			7702
		],
		[
			0,
			-17
		],
		[
			-11,
			-3
		],
		[
			-6,
			-14
		],
		[
			-2,
			-26
		],
		[
			-4,
			1
		],
		[
			-8,
			-16
		],
		[
			5,
			1
		],
		[
			11,
			-28
		]
	],
	[
		[
			5778,
			7600
		],
		[
			-13,
			-4
		],
		[
			-6,
			9
		],
		[
			-21,
			-5
		],
		[
			-7,
			-15
		]
	],
	[
		[
			5731,
			7585
		],
		[
			-8,
			0
		],
		[
			2,
			-21
		],
		[
			-25,
			-7
		],
		[
			-9,
			10
		],
		[
			-8,
			1
		],
		[
			-2,
			6
		],
		[
			-14,
			0
		],
		[
			-8,
			-7
		],
		[
			-13,
			0
		],
		[
			-10,
			-4
		]
	],
	[
		[
			5636,
			7563
		],
		[
			3,
			22
		],
		[
			-5,
			18
		],
		[
			-9,
			5
		],
		[
			-5,
			11
		]
	],
	[
		[
			5620,
			7619
		],
		[
			5,
			6
		],
		[
			-3,
			23
		],
		[
			9,
			5
		],
		[
			7,
			17
		],
		[
			-13,
			15
		],
		[
			-4,
			15
		],
		[
			1,
			17
		],
		[
			8,
			13
		]
	],
	[
		[
			5630,
			7730
		],
		[
			9,
			-8
		],
		[
			-4,
			-15
		],
		[
			17,
			3
		],
		[
			18,
			-8
		],
		[
			10,
			3
		],
		[
			21,
			-5
		],
		[
			4,
			-4
		],
		[
			11,
			5
		],
		[
			9,
			16
		],
		[
			25,
			10
		],
		[
			10,
			-10
		],
		[
			15,
			-2
		],
		[
			8,
			-13
		],
		[
			10,
			0
		]
	],
	[
		[
			6402,
			6694
		],
		[
			3,
			0
		],
		[
			0,
			-24
		],
		[
			-4,
			8
		],
		[
			1,
			16
		]
	],
	[
		[
			2971,
			6401
		],
		[
			-3,
			-10
		],
		[
			-15,
			-3
		],
		[
			-1,
			6
		],
		[
			9,
			10
		],
		[
			4,
			-4
		],
		[
			6,
			12
		],
		[
			0,
			-11
		]
	],
	[
		[
			2969,
			6475
		],
		[
			8,
			-3
		],
		[
			-7,
			-3
		],
		[
			-1,
			6
		]
	],
	[
		[
			2948,
			6491
		],
		[
			0,
			-14
		],
		[
			-5,
			9
		],
		[
			5,
			5
		]
	],
	[
		[
			2889,
			6546
		],
		[
			9,
			-13
		],
		[
			-10,
			9
		],
		[
			1,
			4
		]
	],
	[
		[
			2908,
			6546
		],
		[
			6,
			-21
		],
		[
			0,
			-8
		],
		[
			7,
			-10
		],
		[
			0,
			-8
		],
		[
			-7,
			15
		],
		[
			-1,
			14
		],
		[
			-5,
			18
		]
	],
	[
		[
			2840,
			6572
		],
		[
			6,
			0
		],
		[
			0,
			-20
		],
		[
			-8,
			5
		],
		[
			-3,
			13
		],
		[
			5,
			2
		]
	],
	[
		[
			2908,
			6577
		],
		[
			-3,
			0
		],
		[
			-4,
			16
		],
		[
			7,
			-16
		]
	],
	[
		[
			2830,
			6632
		],
		[
			3,
			0
		],
		[
			8,
			-40
		],
		[
			-8,
			-11
		],
		[
			-10,
			14
		],
		[
			7,
			37
		]
	],
	[
		[
			2869,
			6655
		],
		[
			0,
			-4
		],
		[
			16,
			-20
		],
		[
			-1,
			-29
		],
		[
			-2,
			7
		],
		[
			3,
			17
		],
		[
			-6,
			14
		],
		[
			-11,
			8
		],
		[
			1,
			7
		]
	],
	[
		[
			2819,
			6722
		],
		[
			15,
			-4
		],
		[
			-21,
			-5
		],
		[
			6,
			9
		]
	],
	[
		[
			2839,
			6733
		],
		[
			5,
			0
		],
		[
			16,
			-25
		],
		[
			0,
			-11
		],
		[
			-4,
			-3
		],
		[
			0,
			-19
		],
		[
			-6,
			5
		],
		[
			4,
			8
		],
		[
			0,
			18
		],
		[
			-8,
			23
		],
		[
			-7,
			4
		]
	],
	[
		[
			5528,
			7765
		],
		[
			9,
			0
		],
		[
			-7,
			-29
		],
		[
			14,
			-17
		],
		[
			-10,
			-5
		],
		[
			7,
			-13
		],
		[
			-1,
			-8
		],
		[
			-7,
			-3
		]
	],
	[
		[
			5533,
			7690
		],
		[
			-8,
			-3
		],
		[
			0,
			-8
		],
		[
			-7,
			-6
		],
		[
			-1,
			-13
		],
		[
			-4,
			0
		],
		[
			-1,
			-26
		]
	],
	[
		[
			5512,
			7634
		],
		[
			-22,
			19
		]
	],
	[
		[
			5490,
			7653
		],
		[
			-2,
			3
		]
	],
	[
		[
			5488,
			7656
		],
		[
			0,
			8
		],
		[
			-35,
			57
		],
		[
			-8,
			32
		],
		[
			-7,
			3
		],
		[
			0,
			29
		],
		[
			6,
			2
		],
		[
			10,
			-12
		],
		[
			3,
			10
		],
		[
			9,
			-1
		],
		[
			4,
			7
		],
		[
			4,
			-7
		],
		[
			22,
			-6
		],
		[
			4,
			4
		],
		[
			19,
			-3
		],
		[
			2,
			-11
		],
		[
			7,
			-3
		]
	],
	[
		[
			5781,
			8416
		],
		[
			4,
			-6
		],
		[
			9,
			3
		],
		[
			3,
			-8
		],
		[
			9,
			4
		],
		[
			11,
			-6
		],
		[
			1,
			-13
		],
		[
			12,
			9
		],
		[
			16,
			-3
		],
		[
			11,
			-11
		],
		[
			-2,
			-19
		],
		[
			6,
			-15
		],
		[
			-7,
			-13
		],
		[
			11,
			-10
		],
		[
			-3,
			-7
		],
		[
			7,
			-14
		],
		[
			15,
			-15
		],
		[
			-3,
			-11
		],
		[
			10,
			1
		],
		[
			11,
			-9
		],
		[
			6,
			-11
		],
		[
			-15,
			-22
		],
		[
			-22,
			5
		],
		[
			-4,
			-9
		],
		[
			8,
			-10
		],
		[
			2,
			-30
		],
		[
			5,
			-13
		]
	],
	[
		[
			5882,
			8183
		],
		[
			-23,
			-2
		],
		[
			-12,
			-29
		],
		[
			3,
			-14
		],
		[
			-7,
			-1
		],
		[
			-6,
			11
		],
		[
			-15,
			-1
		],
		[
			-9,
			-6
		],
		[
			-5,
			14
		],
		[
			-13,
			-11
		],
		[
			-11,
			13
		],
		[
			-16,
			-10
		],
		[
			1,
			7
		],
		[
			-13,
			0
		],
		[
			-1,
			7
		],
		[
			-21,
			5
		],
		[
			-10,
			6
		],
		[
			-28,
			2
		],
		[
			-19,
			-4
		],
		[
			-11,
			-18
		],
		[
			-11,
			3
		],
		[
			0,
			-5
		]
	],
	[
		[
			5655,
			8150
		],
		[
			0,
			34
		],
		[
			-12,
			10
		],
		[
			6,
			13
		],
		[
			15,
			11
		],
		[
			0,
			18
		],
		[
			-7,
			25
		],
		[
			-5,
			28
		]
	],
	[
		[
			5652,
			8289
		],
		[
			20,
			1
		],
		[
			5,
			-4
		],
		[
			12,
			5
		],
		[
			-1,
			7
		],
		[
			19,
			11
		],
		[
			1,
			-8
		],
		[
			8,
			6
		],
		[
			-7,
			3
		],
		[
			9,
			37
		],
		[
			8,
			1
		],
		[
			3,
			10
		],
		[
			9,
			-1
		],
		[
			6,
			10
		],
		[
			-8,
			1
		],
		[
			2,
			20
		]
	],
	[
		[
			5738,
			8388
		],
		[
			11,
			10
		],
		[
			17,
			-2
		],
		[
			8,
			17
		],
		[
			7,
			3
		]
	],
	[
		[
			2547,
			6247
		],
		[
			-3,
			-6
		],
		[
			9,
			0
		],
		[
			-1,
			-18
		],
		[
			-5,
			-28
		],
		[
			4,
			-4
		],
		[
			-4,
			-10
		],
		[
			2,
			-16
		],
		[
			-2,
			-24
		],
		[
			-7,
			-21
		],
		[
			-5,
			-2
		],
		[
			-5,
			-20
		]
	],
	[
		[
			2530,
			6098
		],
		[
			-9,
			0
		],
		[
			2,
			51
		],
		[
			0,
			60
		]
	],
	[
		[
			2523,
			6209
		],
		[
			4,
			10
		],
		[
			4,
			-6
		],
		[
			9,
			26
		],
		[
			0,
			6
		],
		[
			7,
			2
		]
	],
	[
		[
			3084,
			4249
		],
		[
			-4,
			-1
		]
	],
	[
		[
			3080,
			4248
		],
		[
			4,
			1
		]
	],
	[
		[
			3384,
			4022
		],
		[
			-1,
			21
		],
		[
			-24,
			29
		],
		[
			-24,
			0
		],
		[
			-51,
			-22
		],
		[
			-4,
			-23
		],
		[
			-10,
			-28
		],
		[
			0,
			-29
		],
		[
			-8,
			-54
		],
		[
			-3,
			-14
		]
	],
	[
		[
			3133,
			3869
		],
		[
			-10,
			-5
		],
		[
			-9,
			4
		],
		[
			1,
			16
		],
		[
			-3,
			11
		],
		[
			0,
			16
		],
		[
			-4,
			7
		],
		[
			-3,
			23
		],
		[
			0,
			15
		],
		[
			-6,
			20
		],
		[
			-4,
			2
		],
		[
			2,
			18
		],
		[
			-6,
			6
		],
		[
			1,
			10
		],
		[
			-3,
			14
		],
		[
			6,
			2
		],
		[
			1,
			8
		],
		[
			-5,
			11
		],
		[
			7,
			16
		],
		[
			-13,
			23
		],
		[
			-3,
			34
		],
		[
			-3,
			18
		],
		[
			2,
			6
		],
		[
			-7,
			5
		],
		[
			0,
			8
		],
		[
			-5,
			18
		]
	],
	[
		[
			3069,
			4175
		],
		[
			-4,
			17
		],
		[
			7,
			8
		],
		[
			10,
			30
		]
	],
	[
		[
			3082,
			4230
		],
		[
			5,
			-3
		],
		[
			-1,
			11
		],
		[
			8,
			5
		],
		[
			0,
			6
		],
		[
			-7,
			0
		],
		[
			-1,
			9
		],
		[
			4,
			4
		],
		[
			-7,
			3
		],
		[
			0,
			7
		],
		[
			-10,
			17
		]
	],
	[
		[
			3073,
			4289
		],
		[
			6,
			16
		],
		[
			-7,
			15
		],
		[
			6,
			28
		],
		[
			5,
			6
		],
		[
			3,
			20
		],
		[
			-6,
			22
		],
		[
			4,
			8
		],
		[
			-1,
			36
		],
		[
			7,
			11
		],
		[
			2,
			12
		],
		[
			-16,
			55
		],
		[
			-9,
			34
		]
	],
	[
		[
			3067,
			4552
		],
		[
			23,
			-3
		],
		[
			-1,
			-8
		],
		[
			10,
			6
		],
		[
			9,
			20
		],
		[
			11,
			3
		],
		[
			11,
			19
		],
		[
			7,
			3
		],
		[
			11,
			20
		],
		[
			19,
			8
		],
		[
			7,
			1
		],
		[
			4,
			-5
		],
		[
			5,
			9
		],
		[
			3,
			-32
		],
		[
			-4,
			-13
		],
		[
			3,
			-21
		],
		[
			-2,
			-18
		],
		[
			2,
			-19
		],
		[
			3,
			-2
		],
		[
			1,
			-14
		],
		[
			4,
			-2
		],
		[
			1,
			-12
		],
		[
			5,
			-1
		],
		[
			4,
			-10
		],
		[
			6,
			-4
		],
		[
			1,
			-11
		],
		[
			13,
			-4
		],
		[
			4,
			4
		],
		[
			10,
			-7
		],
		[
			4,
			-8
		],
		[
			5,
			4
		],
		[
			9,
			-20
		],
		[
			4,
			1
		],
		[
			8,
			-10
		],
		[
			7,
			0
		],
		[
			0,
			-6
		],
		[
			8,
			-17
		],
		[
			22,
			4
		],
		[
			18,
			-27
		],
		[
			-2,
			-20
		],
		[
			5,
			-18
		],
		[
			1,
			-28
		],
		[
			-9,
			-1
		],
		[
			9,
			-20
		],
		[
			3,
			-47
		],
		[
			47,
			-4
		],
		[
			3,
			3
		],
		[
			0,
			-13
		],
		[
			-4,
			-8
		],
		[
			2,
			-34
		],
		[
			11,
			-15
		],
		[
			6,
			-1
		],
		[
			0,
			-8
		],
		[
			6,
			-27
		],
		[
			0,
			-10
		],
		[
			-6,
			-46
		],
		[
			-9,
			-38
		],
		[
			7,
			-13
		],
		[
			-8,
			-10
		]
	],
	[
		[
			3651,
			3581
		],
		[
			1,
			22
		],
		[
			3,
			0
		],
		[
			-4,
			-22
		]
	],
	[
		[
			3650,
			3661
		],
		[
			-4,
			8
		],
		[
			6,
			7
		],
		[
			-2,
			-15
		]
	],
	[
		[
			3919,
			4412
		],
		[
			0,
			-16
		],
		[
			-4,
			16
		],
		[
			4,
			0
		]
	],
	[
		[
			3660,
			5124
		],
		[
			-3,
			3
		],
		[
			4,
			9
		],
		[
			-1,
			-12
		]
	],
	[
		[
			3588,
			5149
		],
		[
			0,
			-7
		],
		[
			-8,
			-7
		],
		[
			1,
			9
		],
		[
			7,
			5
		]
	],
	[
		[
			3577,
			5151
		],
		[
			2,
			-5
		],
		[
			-4,
			-19
		],
		[
			-3,
			-11
		],
		[
			-15,
			-19
		],
		[
			0,
			13
		],
		[
			7,
			10
		],
		[
			0,
			14
		],
		[
			2,
			11
		],
		[
			8,
			8
		],
		[
			3,
			-2
		]
	],
	[
		[
			3573,
			5156
		],
		[
			5,
			19
		],
		[
			0,
			-10
		],
		[
			-5,
			-9
		]
	],
	[
		[
			3608,
			5175
		],
		[
			11,
			-6
		],
		[
			9,
			5
		],
		[
			27,
			-7
		],
		[
			-2,
			-14
		],
		[
			-1,
			-20
		],
		[
			-4,
			-14
		],
		[
			-5,
			-5
		],
		[
			0,
			-14
		],
		[
			-7,
			-5
		],
		[
			-3,
			7
		],
		[
			0,
			-11
		],
		[
			-9,
			1
		],
		[
			-6,
			-12
		],
		[
			-14,
			3
		],
		[
			-4,
			-6
		],
		[
			-5,
			2
		],
		[
			-7,
			28
		],
		[
			1,
			13
		],
		[
			6,
			-5
		],
		[
			1,
			8
		],
		[
			-7,
			-1
		],
		[
			0,
			23
		],
		[
			2,
			17
		],
		[
			4,
			10
		],
		[
			5,
			5
		],
		[
			8,
			-2
		]
	],
	[
		[
			3586,
			5165
		],
		[
			-4,
			4
		],
		[
			1,
			13
		],
		[
			7,
			3
		],
		[
			2,
			-9
		],
		[
			-6,
			-11
		]
	],
	[
		[
			3625,
			5187
		],
		[
			3,
			-5
		],
		[
			-2,
			-7
		],
		[
			-11,
			2
		],
		[
			10,
			10
		]
	],
	[
		[
			3599,
			5183
		],
		[
			-5,
			0
		],
		[
			-2,
			9
		],
		[
			6,
			-1
		],
		[
			1,
			-8
		]
	],
	[
		[
			3624,
			5200
		],
		[
			-6,
			-5
		],
		[
			-3,
			-12
		],
		[
			-14,
			0
		],
		[
			-1,
			12
		],
		[
			8,
			1
		],
		[
			15,
			9
		],
		[
			1,
			-5
		]
	],
	[
		[
			3600,
			5213
		],
		[
			1,
			-14
		],
		[
			-2,
			-7
		],
		[
			0,
			23
		],
		[
			1,
			-2
		]
	],
	[
		[
			3609,
			5216
		],
		[
			-6,
			-13
		],
		[
			1,
			14
		],
		[
			5,
			-1
		]
	],
	[
		[
			3608,
			5236
		],
		[
			0,
			-10
		],
		[
			-5,
			0
		],
		[
			5,
			10
		]
	],
	[
		[
			3600,
			5305
		],
		[
			1,
			-11
		],
		[
			-5,
			4
		],
		[
			4,
			7
		]
	],
	[
		[
			3431,
			5295
		],
		[
			13,
			-7
		],
		[
			2,
			14
		],
		[
			-6,
			10
		],
		[
			5,
			17
		],
		[
			6,
			-8
		],
		[
			11,
			2
		],
		[
			0,
			4
		],
		[
			10,
			2
		],
		[
			8,
			-5
		],
		[
			3,
			-7
		]
	],
	[
		[
			3483,
			5317
		],
		[
			3,
			-7
		],
		[
			8,
			-3
		],
		[
			7,
			3
		],
		[
			6,
			9
		],
		[
			5,
			-7
		],
		[
			6,
			5
		],
		[
			9,
			-9
		],
		[
			9,
			11
		],
		[
			8,
			31
		],
		[
			1,
			14
		],
		[
			4,
			7
		],
		[
			15,
			44
		]
	],
	[
		[
			3564,
			5415
		],
		[
			5,
			24
		],
		[
			8,
			-16
		],
		[
			1,
			-21
		],
		[
			3,
			4
		],
		[
			-1,
			-29
		],
		[
			3,
			-31
		],
		[
			7,
			-22
		],
		[
			1,
			-18
		],
		[
			6,
			-18
		],
		[
			13,
			-4
		],
		[
			4,
			-8
		],
		[
			0,
			-19
		],
		[
			-7,
			-4
		],
		[
			7,
			-3
		],
		[
			-11,
			-17
		],
		[
			-5,
			-12
		],
		[
			-4,
			-17
		],
		[
			-5,
			-11
		],
		[
			-5,
			-1
		],
		[
			-9,
			-17
		],
		[
			-4,
			-19
		],
		[
			-8,
			-19
		],
		[
			0,
			-14
		],
		[
			-7,
			-8
		],
		[
			-1,
			-13
		],
		[
			-6,
			4
		],
		[
			-14,
			-13
		],
		[
			13,
			2
		],
		[
			0,
			-10
		],
		[
			9,
			7
		],
		[
			7,
			10
		],
		[
			11,
			11
		],
		[
			13,
			17
		],
		[
			-5,
			-12
		],
		[
			5,
			-5
		],
		[
			0,
			-14
		],
		[
			4,
			-9
		],
		[
			0,
			-11
		],
		[
			7,
			-14
		],
		[
			4,
			9
		],
		[
			6,
			4
		],
		[
			5,
			-7
		],
		[
			12,
			10
		],
		[
			1,
			-7
		],
		[
			-5,
			-41
		],
		[
			2,
			-2
		],
		[
			8,
			40
		],
		[
			7,
			18
		],
		[
			2,
			-8
		],
		[
			8,
			21
		],
		[
			3,
			-12
		],
		[
			1,
			19
		],
		[
			4,
			-2
		],
		[
			4,
			16
		],
		[
			1,
			15
		],
		[
			5,
			0
		],
		[
			5,
			12
		],
		[
			2,
			-11
		],
		[
			4,
			10
		],
		[
			11,
			-7
		],
		[
			19,
			-9
		],
		[
			0,
			-10
		],
		[
			7,
			-6
		],
		[
			8,
			5
		],
		[
			1,
			-7
		],
		[
			10,
			-9
		],
		[
			1,
			-8
		],
		[
			6,
			9
		],
		[
			-2,
			-11
		],
		[
			1,
			-13
		],
		[
			3,
			11
		],
		[
			5,
			4
		],
		[
			10,
			-14
		],
		[
			-3,
			-5
		],
		[
			6,
			-1
		],
		[
			3,
			-8
		],
		[
			-5,
			-16
		],
		[
			5,
			5
		],
		[
			3,
			-14
		],
		[
			-4,
			0
		],
		[
			-5,
			-36
		],
		[
			2,
			-9
		],
		[
			6,
			14
		],
		[
			1,
			23
		],
		[
			8,
			8
		],
		[
			1,
			-9
		],
		[
			-7,
			-12
		],
		[
			7,
			-2
		],
		[
			2,
			14
		],
		[
			9,
			4
		],
		[
			6,
			-4
		],
		[
			-1,
			12
		],
		[
			4,
			0
		],
		[
			18,
			-13
		],
		[
			6,
			-11
		],
		[
			15,
			-5
		],
		[
			3,
			6
		],
		[
			5,
			-9
		],
		[
			29,
			4
		],
		[
			3,
			2
		],
		[
			14,
			-3
		],
		[
			25,
			-31
		],
		[
			3,
			-1
		],
		[
			8,
			-15
		],
		[
			5,
			-2
		],
		[
			11,
			-27
		],
		[
			14,
			-26
		],
		[
			9,
			-6
		],
		[
			4,
			-12
		],
		[
			6,
			-1
		],
		[
			6,
			-8
		],
		[
			16,
			-1
		],
		[
			5,
			3
		],
		[
			13,
			-6
		],
		[
			4,
			-13
		],
		[
			9,
			-57
		],
		[
			1,
			-24
		],
		[
			5,
			-21
		],
		[
			-1,
			-53
		],
		[
			-7,
			-40
		],
		[
			-7,
			-25
		],
		[
			-10,
			-27
		],
		[
			-3,
			5
		],
		[
			-2,
			-16
		],
		[
			-12,
			-24
		],
		[
			-3,
			-13
		],
		[
			-10,
			-10
		],
		[
			-5,
			-9
		],
		[
			-11,
			-37
		],
		[
			-15,
			-52
		],
		[
			-13,
			-34
		],
		[
			-5,
			0
		],
		[
			0,
			14
		],
		[
			-4,
			9
		],
		[
			-4,
			-16
		],
		[
			0,
			-17
		],
		[
			-4,
			-7
		],
		[
			0,
			-27
		],
		[
			-2,
			-5
		],
		[
			2,
			-28
		],
		[
			-3,
			-20
		],
		[
			2,
			-9
		],
		[
			0,
			-24
		],
		[
			2,
			-28
		],
		[
			2,
			-6
		],
		[
			-4,
			-25
		],
		[
			-6,
			-53
		],
		[
			1,
			-31
		],
		[
			-2,
			-9
		],
		[
			-7,
			-8
		],
		[
			-7,
			-30
		],
		[
			2,
			-51
		],
		[
			-3,
			-13
		],
		[
			-6,
			-6
		],
		[
			-9,
			-44
		],
		[
			-13,
			-31
		],
		[
			-8,
			-25
		],
		[
			4,
			-27
		],
		[
			-5,
			-10
		],
		[
			-12,
			-7
		],
		[
			-13,
			-20
		],
		[
			0,
			-21
		],
		[
			-17,
			1
		],
		[
			-11,
			-3
		],
		[
			0,
			18
		],
		[
			-7,
			-5
		],
		[
			2,
			-13
		],
		[
			-22,
			-7
		],
		[
			10,
			7
		],
		[
			-9,
			3
		],
		[
			-8,
			-7
		],
		[
			-2,
			7
		],
		[
			-9,
			-7
		],
		[
			1,
			-17
		],
		[
			-10,
			-3
		],
		[
			-2,
			-6
		],
		[
			-10,
			-7
		],
		[
			-1,
			-11
		],
		[
			-12,
			4
		],
		[
			-8,
			-7
		],
		[
			-1,
			-7
		],
		[
			-11,
			-6
		],
		[
			-11,
			-13
		],
		[
			-5,
			-12
		],
		[
			-10,
			-9
		],
		[
			-10,
			-15
		],
		[
			-1,
			-15
		],
		[
			-8,
			-7
		],
		[
			-6,
			4
		],
		[
			1,
			-17
		],
		[
			-4,
			-17
		],
		[
			-1,
			-19
		],
		[
			-5,
			-6
		],
		[
			4,
			-6
		],
		[
			-3,
			-16
		],
		[
			3,
			-6
		],
		[
			2,
			-32
		],
		[
			-2,
			-52
		],
		[
			-4,
			-17
		],
		[
			-17,
			-23
		],
		[
			-5,
			-12
		],
		[
			-14,
			-39
		],
		[
			-8,
			-37
		],
		[
			-10,
			-34
		],
		[
			-12,
			-25
		],
		[
			-22,
			-27
		],
		[
			-3,
			-9
		],
		[
			0,
			17
		],
		[
			5,
			-4
		],
		[
			11,
			20
		],
		[
			5,
			3
		],
		[
			4,
			11
		],
		[
			-1,
			12
		],
		[
			5,
			1
		],
		[
			0,
			10
		],
		[
			9,
			9
		],
		[
			-1,
			22
		],
		[
			4,
			-6
		],
		[
			1,
			12
		],
		[
			-12,
			-4
		],
		[
			-9,
			8
		],
		[
			3,
			-7
		],
		[
			-6,
			-21
		],
		[
			-1,
			-24
		],
		[
			-6,
			-10
		],
		[
			-9,
			-4
		],
		[
			-3,
			-21
		],
		[
			-4,
			-3
		],
		[
			-1,
			-14
		],
		[
			5,
			-10
		],
		[
			-5,
			-7
		],
		[
			-6,
			-30
		],
		[
			-7,
			-26
		],
		[
			-18,
			-28
		]
	],
	[
		[
			3517,
			3240
		],
		[
			-4,
			10
		]
	],
	[
		[
			3513,
			3250
		],
		[
			2,
			1
		],
		[
			1,
			23
		],
		[
			5,
			4
		],
		[
			2,
			13
		],
		[
			5,
			6
		],
		[
			5,
			-10
		],
		[
			6,
			18
		],
		[
			-4,
			16
		],
		[
			-12,
			-19
		]
	],
	[
		[
			3523,
			3302
		],
		[
			-11,
			11
		],
		[
			-5,
			23
		],
		[
			-15,
			14
		],
		[
			-9,
			21
		],
		[
			-8,
			3
		],
		[
			-4,
			8
		],
		[
			-7,
			3
		],
		[
			-2,
			10
		],
		[
			-8,
			11
		],
		[
			-6,
			-13
		],
		[
			-4,
			0
		],
		[
			0,
			16
		],
		[
			-23,
			40
		],
		[
			-7,
			0
		],
		[
			-2,
			-8
		],
		[
			-11,
			-2
		],
		[
			-2,
			6
		]
	],
	[
		[
			3483,
			3710
		],
		[
			0,
			8
		]
	],
	[
		[
			3483,
			3718
		],
		[
			5,
			3
		],
		[
			0,
			26
		],
		[
			4,
			16
		],
		[
			0,
			34
		]
	],
	[
		[
			3492,
			3797
		],
		[
			-9,
			15
		],
		[
			-10,
			-10
		],
		[
			-13,
			1
		],
		[
			-3,
			21
		],
		[
			1,
			11
		],
		[
			-4,
			23
		],
		[
			1,
			21
		],
		[
			-7,
			19
		],
		[
			-9,
			1
		],
		[
			-6,
			12
		],
		[
			-12,
			-10
		],
		[
			-31,
			8
		],
		[
			0,
			36
		],
		[
			3,
			16
		],
		[
			-9,
			61
		]
	],
	[
		[
			3067,
			4552
		],
		[
			-11,
			2
		],
		[
			-7,
			-8
		],
		[
			-12,
			3
		],
		[
			0,
			41
		],
		[
			1,
			29
		],
		[
			2,
			20
		],
		[
			-10,
			-14
		],
		[
			-2,
			-7
		],
		[
			-9,
			-11
		],
		[
			-25,
			0
		],
		[
			-3,
			27
		],
		[
			-14,
			7
		],
		[
			-11,
			0
		],
		[
			7,
			16
		],
		[
			0,
			8
		],
		[
			-6,
			17
		],
		[
			-4,
			2
		],
		[
			-1,
			11
		],
		[
			-5,
			6
		],
		[
			-2,
			15
		],
		[
			-5,
			9
		],
		[
			2,
			9
		],
		[
			-8,
			14
		],
		[
			1,
			11
		],
		[
			7,
			2
		],
		[
			-3,
			13
		],
		[
			2,
			13
		],
		[
			11,
			17
		],
		[
			5,
			3
		],
		[
			1,
			12
		],
		[
			-3,
			14
		],
		[
			8,
			24
		],
		[
			1,
			30
		],
		[
			14,
			14
		],
		[
			14,
			21
		],
		[
			17,
			5
		],
		[
			10,
			6
		],
		[
			5,
			11
		],
		[
			9,
			1
		],
		[
			3,
			-6
		],
		[
			10,
			-5
		],
		[
			0,
			5
		]
	],
	[
		[
			3056,
			4939
		],
		[
			6,
			58
		],
		[
			0,
			9
		],
		[
			5,
			46
		],
		[
			0,
			10
		],
		[
			5,
			54
		],
		[
			-4,
			13
		],
		[
			-2,
			24
		],
		[
			-13,
			21
		],
		[
			1,
			42
		],
		[
			12,
			4
		],
		[
			3,
			5
		],
		[
			10,
			-6
		],
		[
			-2,
			21
		],
		[
			-4,
			4
		],
		[
			-14,
			0
		],
		[
			0,
			37
		],
		[
			8,
			4
		],
		[
			5,
			-3
		],
		[
			34,
			0
		],
		[
			-1,
			16
		],
		[
			7,
			-15
		],
		[
			5,
			4
		],
		[
			9,
			19
		],
		[
			4,
			-5
		],
		[
			7,
			-29
		],
		[
			-1,
			-21
		],
		[
			6,
			2
		]
	],
	[
		[
			3142,
			5253
		],
		[
			11,
			-21
		],
		[
			10,
			-7
		],
		[
			10,
			14
		],
		[
			6,
			-1
		],
		[
			-1,
			-17
		],
		[
			11,
			17
		],
		[
			1,
			10
		],
		[
			11,
			6
		],
		[
			10,
			16
		],
		[
			0,
			-8
		],
		[
			9,
			16
		],
		[
			0,
			14
		],
		[
			19,
			16
		],
		[
			1,
			14
		],
		[
			-20,
			4
		],
		[
			2,
			15
		],
		[
			-6,
			20
		],
		[
			0,
			30
		],
		[
			-13,
			22
		],
		[
			-4,
			12
		],
		[
			2,
			5
		],
		[
			4,
			-10
		],
		[
			12,
			0
		],
		[
			4,
			-14
		],
		[
			10,
			4
		],
		[
			4,
			-5
		],
		[
			4,
			7
		],
		[
			4,
			-5
		],
		[
			7,
			-18
		],
		[
			7,
			5
		],
		[
			-1,
			20
		],
		[
			6,
			1
		],
		[
			4,
			9
		],
		[
			7,
			-6
		],
		[
			18,
			12
		],
		[
			0,
			6
		],
		[
			16,
			10
		],
		[
			10,
			22
		],
		[
			-2,
			13
		],
		[
			-3,
			1
		]
	],
	[
		[
			3312,
			5482
		],
		[
			11,
			0
		],
		[
			3,
			4
		],
		[
			8,
			-12
		],
		[
			-3,
			-33
		],
		[
			6,
			0
		],
		[
			5,
			-8
		],
		[
			-2,
			-8
		],
		[
			4,
			-14
		],
		[
			0,
			-10
		],
		[
			-7,
			-12
		],
		[
			1,
			-13
		],
		[
			-4,
			-17
		],
		[
			-1,
			-22
		],
		[
			2,
			-17
		],
		[
			5,
			-5
		],
		[
			0,
			-26
		],
		[
			6,
			-8
		],
		[
			8,
			-19
		],
		[
			8,
			-4
		],
		[
			4,
			-7
		],
		[
			8,
			5
		],
		[
			0,
			10
		],
		[
			5,
			9
		],
		[
			9,
			-5
		],
		[
			6,
			11
		],
		[
			7,
			0
		],
		[
			3,
			11
		],
		[
			9,
			7
		],
		[
			9,
			-8
		],
		[
			9,
			4
		]
	],
	[
		[
			3347,
			5935
		],
		[
			-4,
			3
		],
		[
			0,
			13
		],
		[
			6,
			-10
		],
		[
			-2,
			-6
		]
	],
	[
		[
			8198,
			5465
		],
		[
			5,
			-34
		],
		[
			-7,
			5
		],
		[
			-2,
			24
		]
	],
	[
		[
			8194,
			5460
		],
		[
			4,
			5
		]
	],
	[
		[
			8166,
			5448
		],
		[
			6,
			-1
		],
		[
			7,
			5
		],
		[
			7,
			12
		],
		[
			9,
			10
		],
		[
			-2,
			-10
		]
	],
	[
		[
			8193,
			5464
		],
		[
			-7,
			-9
		],
		[
			2,
			-17
		],
		[
			0,
			-14
		],
		[
			-7,
			-10
		],
		[
			-7,
			23
		],
		[
			-8,
			11
		]
	],
	[
		[
			7545,
			6781
		],
		[
			-2,
			-8
		],
		[
			5,
			-11
		],
		[
			6,
			3
		],
		[
			3,
			-10
		],
		[
			-3,
			-11
		],
		[
			3,
			-13
		],
		[
			-5,
			-4
		],
		[
			-33,
			-3
		],
		[
			-10,
			8
		],
		[
			-6,
			-9
		],
		[
			-11,
			-3
		],
		[
			-12,
			9
		],
		[
			-6,
			-2
		],
		[
			-7,
			7
		],
		[
			-3,
			12
		],
		[
			4,
			10
		]
	],
	[
		[
			7468,
			6756
		],
		[
			3,
			13
		],
		[
			13,
			29
		],
		[
			11,
			14
		],
		[
			12,
			3
		],
		[
			0,
			-5
		],
		[
			9,
			-1
		],
		[
			-4,
			-10
		],
		[
			18,
			-5
		],
		[
			5,
			6
		],
		[
			10,
			-8
		],
		[
			0,
			-11
		]
	],
	[
		[
			5701,
			4158
		],
		[
			-1,
			-8
		],
		[
			8,
			-27
		],
		[
			7,
			-13
		],
		[
			6,
			-21
		],
		[
			4,
			-29
		],
		[
			8,
			-13
		],
		[
			14,
			-17
		],
		[
			7,
			-3
		],
		[
			3,
			-9
		],
		[
			0,
			-15
		],
		[
			12,
			-1
		],
		[
			-1,
			-34
		],
		[
			6,
			-12
		],
		[
			3,
			-15
		],
		[
			18,
			-5
		],
		[
			12,
			-10
		],
		[
			1,
			-14
		],
		[
			7,
			-7
		]
	],
	[
		[
			5815,
			3905
		],
		[
			-9,
			-3
		],
		[
			-3,
			-13
		],
		[
			-8,
			-7
		],
		[
			-12,
			-4
		],
		[
			-12,
			-27
		],
		[
			-5,
			-6
		],
		[
			-2,
			-10
		],
		[
			-11,
			-7
		],
		[
			-4,
			-13
		],
		[
			-5,
			-31
		],
		[
			-8,
			-10
		],
		[
			-3,
			-10
		],
		[
			-15,
			-6
		],
		[
			0,
			-10
		],
		[
			-8,
			-41
		],
		[
			-5,
			-7
		],
		[
			-10,
			1
		],
		[
			-4,
			-5
		],
		[
			-17,
			5
		],
		[
			-10,
			6
		],
		[
			-13,
			20
		],
		[
			-7,
			1
		],
		[
			-7,
			-5
		],
		[
			-6,
			-23
		],
		[
			0,
			-14
		],
		[
			-6,
			-13
		],
		[
			-8,
			-7
		],
		[
			-6,
			-18
		],
		[
			-7,
			-2
		],
		[
			-2,
			-10
		],
		[
			-15,
			0
		],
		[
			-15,
			4
		],
		[
			0,
			21
		],
		[
			5,
			11
		],
		[
			0,
			19
		],
		[
			-4,
			13
		],
		[
			-1,
			14
		],
		[
			-10,
			29
		],
		[
			-8,
			10
		]
	],
	[
		[
			5554,
			3757
		],
		[
			0,
			159
		],
		[
			28,
			0
		],
		[
			0,
			212
		],
		[
			23,
			4
		],
		[
			21,
			9
		],
		[
			21,
			5
		],
		[
			9,
			-27
		],
		[
			15,
			26
		],
		[
			7,
			4
		],
		[
			4,
			-6
		],
		[
			7,
			13
		],
		[
			12,
			2
		]
	],
	[
		[
			5634,
			5812
		],
		[
			4,
			-14
		],
		[
			8,
			-14
		],
		[
			10,
			-31
		],
		[
			1,
			-16
		],
		[
			-1,
			-21
		],
		[
			-5,
			-6
		],
		[
			3,
			-9
		],
		[
			-2,
			-17
		],
		[
			19,
			-1
		]
	],
	[
		[
			5671,
			5683
		],
		[
			2,
			-7
		],
		[
			-4,
			-11
		],
		[
			3,
			-6
		],
		[
			16,
			-5
		],
		[
			8,
			-17
		],
		[
			5,
			-3
		],
		[
			1,
			-11
		],
		[
			-4,
			-4
		],
		[
			6,
			-14
		],
		[
			18,
			-19
		],
		[
			2,
			-10
		],
		[
			8,
			-10
		],
		[
			-2,
			-16
		],
		[
			8,
			-21
		],
		[
			6,
			-2
		],
		[
			13,
			-23
		],
		[
			-1,
			-15
		],
		[
			6,
			-14
		]
	],
	[
		[
			5762,
			5475
		],
		[
			-12,
			7
		],
		[
			-4,
			-8
		],
		[
			-10,
			-1
		],
		[
			-12,
			12
		],
		[
			-6,
			-3
		],
		[
			-11,
			9
		],
		[
			-4,
			-5
		],
		[
			0,
			-13
		],
		[
			-18,
			-7
		],
		[
			-5,
			11
		],
		[
			-6,
			-10
		],
		[
			-27,
			-19
		],
		[
			-12,
			12
		],
		[
			-9,
			-34
		],
		[
			-3,
			-5
		],
		[
			-23,
			9
		],
		[
			-2,
			-3
		],
		[
			-20,
			12
		],
		[
			-7,
			-2
		],
		[
			-6,
			20
		],
		[
			-13,
			14
		],
		[
			-3,
			7
		],
		[
			-10,
			1
		],
		[
			-17,
			-34
		],
		[
			-1,
			-7
		],
		[
			-6,
			-3
		],
		[
			2,
			-12
		],
		[
			-1,
			-27
		],
		[
			1,
			-13
		]
	],
	[
		[
			5517,
			5383
		],
		[
			-4,
			9
		],
		[
			-11,
			-4
		],
		[
			-16,
			7
		],
		[
			-8,
			-6
		],
		[
			-15,
			-2
		],
		[
			-4,
			-7
		],
		[
			-3,
			-27
		],
		[
			1,
			-7
		],
		[
			-8,
			-34
		]
	],
	[
		[
			5449,
			5312
		],
		[
			-2,
			8
		],
		[
			0,
			26
		],
		[
			-4,
			13
		],
		[
			-5,
			3
		],
		[
			-15,
			32
		],
		[
			-6,
			21
		],
		[
			4,
			1
		],
		[
			-3,
			14
		],
		[
			-10,
			19
		],
		[
			-1,
			31
		],
		[
			-4,
			6
		],
		[
			2,
			8
		],
		[
			1,
			27
		],
		[
			-7,
			10
		],
		[
			10,
			13
		],
		[
			5,
			24
		],
		[
			3,
			4
		],
		[
			6,
			30
		],
		[
			6,
			14
		]
	],
	[
		[
			5429,
			5616
		],
		[
			9,
			-4
		],
		[
			7,
			8
		],
		[
			10,
			5
		],
		[
			4,
			11
		],
		[
			2,
			-12
		],
		[
			5,
			-7
		],
		[
			23,
			26
		],
		[
			7,
			-2
		],
		[
			5,
			4
		],
		[
			15,
			1
		],
		[
			15,
			36
		],
		[
			-6,
			7
		],
		[
			0,
			8
		],
		[
			5,
			5
		],
		[
			17,
			0
		],
		[
			10,
			7
		],
		[
			9,
			-1
		],
		[
			4,
			12
		],
		[
			8,
			5
		],
		[
			5,
			19
		],
		[
			13,
			24
		],
		[
			5,
			4
		],
		[
			3,
			10
		],
		[
			-1,
			14
		],
		[
			8,
			5
		],
		[
			0,
			5
		],
		[
			14,
			9
		],
		[
			9,
			-3
		]
	],
	[
		[
			2957,
			7804
		],
		[
			-12,
			-5
		],
		[
			13,
			16
		],
		[
			-1,
			-11
		]
	],
	[
		[
			2699,
			7829
		],
		[
			2,
			-7
		],
		[
			13,
			9
		],
		[
			3,
			-9
		],
		[
			5,
			9
		],
		[
			9,
			-4
		],
		[
			2,
			-11
		],
		[
			-7,
			-12
		],
		[
			-23,
			15
		],
		[
			-15,
			6
		],
		[
			11,
			4
		]
	],
	[
		[
			2665,
			7849
		],
		[
			6,
			-2
		],
		[
			-2,
			-11
		],
		[
			-4,
			13
		]
	],
	[
		[
			3319,
			7889
		],
		[
			6,
			-10
		],
		[
			-2,
			-13
		],
		[
			-7,
			-22
		],
		[
			5,
			3
		],
		[
			-19,
			-34
		],
		[
			10,
			5
		],
		[
			9,
			11
		],
		[
			-10,
			0
		],
		[
			12,
			21
		],
		[
			4,
			-8
		],
		[
			11,
			0
		],
		[
			-7,
			-23
		],
		[
			-16,
			-12
		],
		[
			-6,
			3
		],
		[
			-13,
			-5
		],
		[
			-5,
			21
		],
		[
			1,
			13
		],
		[
			6,
			7
		],
		[
			10,
			30
		],
		[
			7,
			14
		],
		[
			4,
			-1
		]
	],
	[
		[
			3221,
			7879
		],
		[
			6,
			-21
		],
		[
			3,
			6
		],
		[
			12,
			-8
		],
		[
			33,
			3
		],
		[
			3,
			-3
		],
		[
			-17,
			-10
		],
		[
			4,
			-13
		],
		[
			-11,
			-3
		],
		[
			-2,
			12
		],
		[
			-19,
			2
		],
		[
			-4,
			11
		],
		[
			-11,
			0
		],
		[
			2,
			14
		],
		[
			-9,
			-1
		],
		[
			4,
			16
		],
		[
			7,
			9
		],
		[
			-1,
			-14
		]
	],
	[
		[
			3503,
			7956
		],
		[
			10,
			3
		],
		[
			-1,
			-7
		],
		[
			-9,
			4
		]
	],
	[
		[
			2562,
			7993
		],
		[
			-9,
			-6
		],
		[
			0,
			8
		],
		[
			9,
			-2
		]
	],
	[
		[
			2924,
			7774
		],
		[
			20,
			14
		],
		[
			8,
			11
		],
		[
			6,
			0
		],
		[
			2,
			17
		],
		[
			7,
			17
		],
		[
			14,
			11
		],
		[
			5,
			9
		],
		[
			17,
			17
		],
		[
			5,
			-2
		],
		[
			32,
			22
		],
		[
			14,
			22
		],
		[
			0,
			4
		],
		[
			14,
			20
		],
		[
			0,
			5
		],
		[
			16,
			23
		],
		[
			21,
			20
		],
		[
			44,
			28
		],
		[
			28,
			8
		],
		[
			18,
			-3
		],
		[
			10,
			-5
		],
		[
			11,
			-14
		],
		[
			1,
			-8
		],
		[
			-11,
			8
		],
		[
			11,
			-15
		],
		[
			-4,
			-13
		],
		[
			-11,
			-4
		],
		[
			-1,
			-6
		],
		[
			-18,
			-13
		],
		[
			-16,
			11
		],
		[
			-3,
			-5
		],
		[
			-11,
			0
		],
		[
			18,
			-11
		],
		[
			9,
			-15
		],
		[
			8,
			9
		],
		[
			12,
			0
		],
		[
			3,
			-6
		],
		[
			-7,
			-14
		],
		[
			-1,
			-10
		],
		[
			-11,
			-13
		],
		[
			16,
			0
		],
		[
			-3,
			-15
		],
		[
			11,
			-32
		],
		[
			20,
			-8
		],
		[
			-8,
			-6
		],
		[
			7,
			-7
		],
		[
			10,
			0
		],
		[
			4,
			-9
		],
		[
			5,
			5
		],
		[
			24,
			-6
		],
		[
			10,
			10
		],
		[
			5,
			-15
		],
		[
			7,
			3
		],
		[
			7,
			-12
		],
		[
			-7,
			-5
		],
		[
			14,
			-3
		],
		[
			-1,
			-4
		],
		[
			-18,
			-7
		],
		[
			0,
			-3
		],
		[
			-32,
			-21
		],
		[
			-9,
			4
		],
		[
			-4,
			-9
		],
		[
			-8,
			1
		],
		[
			1,
			-9
		],
		[
			-11,
			0
		],
		[
			1,
			10
		],
		[
			-9,
			-5
		],
		[
			-4,
			-8
		],
		[
			2,
			-10
		],
		[
			-6,
			-5
		],
		[
			-8,
			-19
		],
		[
			-9,
			-10
		],
		[
			-6,
			1
		],
		[
			-9,
			-11
		],
		[
			-5,
			14
		],
		[
			-9,
			5
		],
		[
			-1,
			14
		],
		[
			7,
			29
		],
		[
			21,
			24
		],
		[
			22,
			18
		],
		[
			1,
			-13
		],
		[
			7,
			8
		],
		[
			20,
			9
		],
		[
			-34,
			2
		],
		[
			-5,
			-6
		],
		[
			-4,
			6
		],
		[
			13,
			15
		],
		[
			-3,
			9
		],
		[
			-5,
			-12
		],
		[
			-16,
			-9
		],
		[
			-17,
			-16
		],
		[
			-4,
			4
		],
		[
			-10,
			-10
		],
		[
			-12,
			-1
		],
		[
			-8,
			6
		]
	],
	[
		[
			3134,
			7784
		],
		[
			-9,
			6
		],
		[
			1,
			19
		]
	],
	[
		[
			3126,
			7809
		],
		[
			-10,
			9
		]
	],
	[
		[
			3116,
			7818
		],
		[
			1,
			1
		],
		[
			-1,
			74
		],
		[
			-14,
			17
		],
		[
			-16,
			-11
		],
		[
			-9,
			17
		],
		[
			-19,
			-37
		],
		[
			-4,
			-23
		],
		[
			-7,
			-12
		],
		[
			1,
			-17
		],
		[
			-12,
			-20
		],
		[
			1,
			-11
		],
		[
			-18,
			-5
		],
		[
			-6,
			-16
		],
		[
			-89,
			-1
		]
	],
	[
		[
			1546,
			8044
		],
		[
			6,
			-11
		],
		[
			-14,
			13
		],
		[
			8,
			-2
		]
	],
	[
		[
			1479,
			8054
		],
		[
			4,
			-13
		],
		[
			-7,
			0
		],
		[
			-4,
			9
		],
		[
			7,
			4
		]
	],
	[
		[
			3218,
			8058
		],
		[
			33,
			-11
		],
		[
			15,
			-14
		],
		[
			11,
			-6
		],
		[
			10,
			-14
		],
		[
			-16,
			-6
		],
		[
			-24,
			11
		],
		[
			-14,
			9
		],
		[
			-2,
			9
		],
		[
			-22,
			16
		],
		[
			9,
			6
		]
	],
	[
		[
			1494,
			8104
		],
		[
			-11,
			-4
		],
		[
			6,
			9
		],
		[
			5,
			-5
		]
	],
	[
		[
			1448,
			8112
		],
		[
			20,
			-17
		],
		[
			22,
			-5
		],
		[
			26,
			-13
		],
		[
			5,
			-19
		],
		[
			9,
			-12
		],
		[
			4,
			-16
		],
		[
			22,
			-13
		],
		[
			10,
			-22
		],
		[
			8,
			-25
		],
		[
			-6,
			-6
		],
		[
			-11,
			3
		],
		[
			-22,
			14
		],
		[
			-14,
			12
		],
		[
			9,
			11
		],
		[
			-18,
			-4
		],
		[
			-9,
			9
		],
		[
			4,
			11
		],
		[
			-8,
			0
		],
		[
			-1,
			10
		],
		[
			-14,
			-3
		],
		[
			0,
			11
		],
		[
			7,
			3
		],
		[
			-8,
			5
		],
		[
			-1,
			10
		],
		[
			-15,
			-2
		],
		[
			-33,
			43
		],
		[
			-2,
			7
		],
		[
			16,
			8
		]
	],
	[
		[
			3447,
			8155
		],
		[
			6,
			-8
		],
		[
			7,
			7
		],
		[
			-5,
			-17
		],
		[
			-12,
			4
		],
		[
			2,
			-12
		],
		[
			7,
			-5
		],
		[
			-28,
			-60
		],
		[
			-3,
			-27
		],
		[
			6,
			13
		],
		[
			13,
			21
		],
		[
			12,
			-13
		],
		[
			7,
			0
		],
		[
			-17,
			-14
		],
		[
			11,
			-17
		],
		[
			15,
			9
		],
		[
			-2,
			-16
		],
		[
			12,
			1
		],
		[
			8,
			14
		],
		[
			9,
			-8
		],
		[
			5,
			3
		],
		[
			15,
			-10
		],
		[
			-4,
			-13
		],
		[
			-17,
			-15
		],
		[
			10,
			3
		],
		[
			-3,
			-15
		],
		[
			12,
			-7
		],
		[
			3,
			10
		],
		[
			4,
			-6
		],
		[
			7,
			9
		],
		[
			-5,
			-19
		],
		[
			-11,
			-9
		],
		[
			-7,
			0
		],
		[
			6,
			-14
		],
		[
			-6,
			-9
		],
		[
			8,
			-15
		],
		[
			2,
			13
		],
		[
			6,
			14
		],
		[
			12,
			6
		],
		[
			-9,
			-18
		],
		[
			-1,
			-22
		],
		[
			8,
			8
		],
		[
			3,
			14
		],
		[
			5,
			-19
		],
		[
			-5,
			-10
		],
		[
			-2,
			-19
		],
		[
			-5,
			-17
		],
		[
			-6,
			3
		],
		[
			-10,
			-3
		],
		[
			4,
			26
		],
		[
			-2,
			5
		],
		[
			-14,
			-23
		],
		[
			-4,
			1
		],
		[
			8,
			31
		],
		[
			1,
			14
		],
		[
			-5,
			15
		],
		[
			-18,
			-29
		],
		[
			-10,
			-9
		],
		[
			0,
			-8
		],
		[
			-8,
			-11
		],
		[
			-9,
			-1
		],
		[
			-9,
			5
		],
		[
			3,
			7
		],
		[
			11,
			3
		],
		[
			15,
			28
		],
		[
			-11,
			3
		],
		[
			-6,
			-12
		],
		[
			-10,
			12
		],
		[
			-28,
			-4
		],
		[
			-25,
			3
		],
		[
			-6,
			4
		],
		[
			-18,
			-6
		],
		[
			-15,
			-2
		],
		[
			-4,
			17
		],
		[
			27,
			37
		],
		[
			-9,
			3
		],
		[
			-14,
			-6
		],
		[
			8,
			9
		],
		[
			6,
			-3
		],
		[
			9,
			33
		],
		[
			10,
			-9
		],
		[
			-2,
			9
		],
		[
			8,
			4
		],
		[
			-11,
			4
		],
		[
			25,
			78
		],
		[
			8,
			11
		],
		[
			8,
			28
		],
		[
			24,
			18
		]
	],
	[
		[
			1448,
			8147
		],
		[
			-7,
			0
		],
		[
			2,
			14
		],
		[
			5,
			-14
		]
	],
	[
		[
			1445,
			8181
		],
		[
			-2,
			-17
		],
		[
			-4,
			14
		],
		[
			6,
			3
		]
	],
	[
		[
			2798,
			8181
		],
		[
			-3,
			-7
		],
		[
			-8,
			3
		],
		[
			11,
			4
		]
	],
	[
		[
			1462,
			8192
		],
		[
			-15,
			-17
		],
		[
			2,
			14
		],
		[
			17,
			12
		],
		[
			-4,
			-9
		]
	],
	[
		[
			1430,
			8212
		],
		[
			1,
			-9
		],
		[
			-8,
			2
		],
		[
			7,
			7
		]
	],
	[
		[
			2738,
			8248
		],
		[
			8,
			-1
		],
		[
			10,
			-15
		],
		[
			3,
			-12
		],
		[
			-10,
			1
		],
		[
			-29,
			15
		],
		[
			6,
			10
		],
		[
			12,
			2
		]
	],
	[
		[
			1339,
			8249
		],
		[
			4,
			-12
		],
		[
			-6,
			-9
		],
		[
			6,
			-21
		],
		[
			17,
			-18
		],
		[
			-5,
			-5
		],
		[
			-20,
			26
		],
		[
			-16,
			32
		],
		[
			20,
			7
		]
	],
	[
		[
			1427,
			8244
		],
		[
			3,
			-10
		],
		[
			-2,
			-21
		],
		[
			-14,
			7
		],
		[
			-3,
			12
		],
		[
			2,
			20
		],
		[
			14,
			-8
		]
	],
	[
		[
			1419,
			8255
		],
		[
			-7,
			1
		],
		[
			4,
			10
		],
		[
			3,
			-11
		]
	],
	[
		[
			1382,
			8268
		],
		[
			9,
			-8
		],
		[
			5,
			-15
		],
		[
			-7,
			0
		],
		[
			-15,
			26
		],
		[
			8,
			-3
		]
	],
	[
		[
			1386,
			8270
		],
		[
			-9,
			4
		],
		[
			2,
			6
		],
		[
			7,
			-10
		]
	],
	[
		[
			1395,
			8273
		],
		[
			11,
			-17
		],
		[
			-5,
			-9
		],
		[
			-21,
			36
		],
		[
			3,
			5
		],
		[
			12,
			-15
		]
	],
	[
		[
			1380,
			8293
		],
		[
			-2,
			-10
		],
		[
			-7,
			7
		],
		[
			9,
			3
		]
	],
	[
		[
			1305,
			8302
		],
		[
			20,
			-3
		],
		[
			5,
			-14
		],
		[
			-15,
			-10
		],
		[
			13,
			-2
		],
		[
			2,
			21
		],
		[
			12,
			6
		],
		[
			-8,
			-28
		],
		[
			0,
			-22
		],
		[
			-13,
			-7
		],
		[
			-9,
			10
		],
		[
			7,
			6
		],
		[
			-11,
			3
		],
		[
			-7,
			25
		],
		[
			4,
			15
		]
	],
	[
		[
			2815,
			8428
		],
		[
			-1,
			-10
		],
		[
			-7,
			-3
		],
		[
			4,
			17
		],
		[
			4,
			-4
		]
	],
	[
		[
			2787,
			8429
		],
		[
			-11,
			-11
		],
		[
			1,
			8
		],
		[
			10,
			3
		]
	],
	[
		[
			2801,
			8446
		],
		[
			-3,
			-6
		],
		[
			9,
			-8
		],
		[
			-12,
			-27
		],
		[
			-8,
			-3
		],
		[
			2,
			12
		],
		[
			-9,
			-16
		],
		[
			-3,
			4
		],
		[
			14,
			23
		],
		[
			3,
			-5
		],
		[
			3,
			26
		],
		[
			4,
			0
		]
	],
	[
		[
			3293,
			8462
		],
		[
			1,
			-19
		],
		[
			-7,
			7
		],
		[
			6,
			12
		]
	],
	[
		[
			3204,
			8666
		],
		[
			5,
			-10
		],
		[
			-11,
			7
		],
		[
			6,
			3
		]
	],
	[
		[
			3109,
			8672
		],
		[
			7,
			-7
		],
		[
			-4,
			-10
		],
		[
			-10,
			-6
		],
		[
			-3,
			7
		],
		[
			5,
			16
		],
		[
			5,
			0
		]
	],
	[
		[
			3200,
			8731
		],
		[
			-2,
			-16
		],
		[
			-16,
			19
		],
		[
			18,
			-3
		]
	],
	[
		[
			2793,
			8775
		],
		[
			5,
			-7
		],
		[
			-8,
			-30
		],
		[
			-8,
			-9
		],
		[
			-10,
			11
		],
		[
			-2,
			14
		],
		[
			12,
			23
		],
		[
			11,
			-2
		]
	],
	[
		[
			3203,
			8784
		],
		[
			8,
			0
		],
		[
			-6,
			-10
		],
		[
			-9,
			3
		],
		[
			7,
			7
		]
	],
	[
		[
			3033,
			8802
		],
		[
			15,
			-11
		],
		[
			0,
			-7
		],
		[
			-13,
			1
		],
		[
			-7,
			15
		],
		[
			5,
			2
		]
	],
	[
		[
			2719,
			8809
		],
		[
			7,
			-3
		],
		[
			-2,
			-12
		],
		[
			-27,
			-27
		],
		[
			-23,
			-5
		],
		[
			-6,
			18
		],
		[
			18,
			27
		],
		[
			8,
			-5
		],
		[
			9,
			6
		],
		[
			16,
			1
		]
	],
	[
		[
			2822,
			8839
		],
		[
			21,
			-4
		],
		[
			4,
			-9
		],
		[
			-13,
			-10
		],
		[
			-16,
			17
		],
		[
			4,
			6
		]
	],
	[
		[
			3216,
			8833
		],
		[
			-8,
			14
		],
		[
			5,
			2
		],
		[
			3,
			-16
		]
	],
	[
		[
			2857,
			8849
		],
		[
			12,
			-6
		],
		[
			0,
			-11
		],
		[
			-20,
			14
		],
		[
			8,
			3
		]
	],
	[
		[
			3204,
			8862
		],
		[
			4,
			-12
		],
		[
			-12,
			8
		],
		[
			8,
			4
		]
	],
	[
		[
			3186,
			8910
		],
		[
			2,
			-6
		],
		[
			-13,
			-6
		],
		[
			11,
			12
		]
	],
	[
		[
			2625,
			8972
		],
		[
			12,
			-9
		],
		[
			-7,
			-5
		],
		[
			11,
			-20
		],
		[
			9,
			16
		],
		[
			14,
			-17
		],
		[
			20,
			-4
		],
		[
			4,
			-10
		],
		[
			19,
			-12
		],
		[
			5,
			2
		],
		[
			16,
			-14
		],
		[
			5,
			-23
		],
		[
			19,
			-8
		],
		[
			-1,
			8
		],
		[
			22,
			-21
		],
		[
			-8,
			-2
		],
		[
			-19,
			-16
		],
		[
			-26,
			14
		],
		[
			-12,
			-1
		],
		[
			-1,
			17
		],
		[
			-15,
			-1
		],
		[
			2,
			13
		],
		[
			-19,
			-10
		],
		[
			2,
			-14
		],
		[
			-19,
			-8
		],
		[
			-9,
			-19
		],
		[
			-25,
			-10
		],
		[
			-5,
			33
		],
		[
			-27,
			-2
		],
		[
			-14,
			-5
		],
		[
			8,
			20
		],
		[
			20,
			13
		],
		[
			-6,
			24
		],
		[
			6,
			15
		],
		[
			0,
			28
		],
		[
			5,
			23
		],
		[
			13,
			12
		],
		[
			1,
			-7
		]
	],
	[
		[
			2638,
			8984
		],
		[
			9,
			-10
		],
		[
			0,
			-16
		],
		[
			-12,
			13
		],
		[
			3,
			13
		]
	],
	[
		[
			2657,
			8990
		],
		[
			18,
			-11
		],
		[
			-3,
			-6
		],
		[
			15,
			-10
		],
		[
			-15,
			2
		],
		[
			-15,
			25
		]
	],
	[
		[
			2936,
			9103
		],
		[
			24,
			-5
		],
		[
			1,
			-12
		],
		[
			-28,
			0
		],
		[
			-10,
			16
		],
		[
			13,
			1
		]
	],
	[
		[
			2601,
			9095
		],
		[
			-7,
			-12
		],
		[
			-8,
			5
		],
		[
			-3,
			16
		],
		[
			9,
			13
		],
		[
			7,
			-6
		],
		[
			2,
			-16
		]
	],
	[
		[
			2900,
			9117
		],
		[
			16,
			-9
		],
		[
			-4,
			-11
		],
		[
			3,
			-24
		],
		[
			-9,
			-11
		],
		[
			-14,
			-6
		],
		[
			-31,
			-1
		],
		[
			-7,
			12
		],
		[
			0,
			22
		],
		[
			15,
			25
		],
		[
			31,
			3
		]
	],
	[
		[
			2096,
			9122
		],
		[
			-15,
			8
		],
		[
			14,
			1
		],
		[
			1,
			-9
		]
	],
	[
		[
			2919,
			9131
		],
		[
			3,
			-14
		],
		[
			-16,
			10
		],
		[
			2,
			12
		],
		[
			11,
			-8
		]
	],
	[
		[
			2173,
			9144
		],
		[
			-3,
			-12
		],
		[
			-12,
			5
		],
		[
			15,
			7
		]
	],
	[
		[
			2218,
			9152
		],
		[
			-13,
			-10
		],
		[
			2,
			17
		],
		[
			11,
			-7
		]
	],
	[
		[
			2820,
			9179
		],
		[
			-10,
			-28
		],
		[
			-16,
			-3
		],
		[
			26,
			31
		]
	],
	[
		[
			2860,
			9180
		],
		[
			10,
			-6
		],
		[
			-13,
			-11
		],
		[
			-6,
			16
		],
		[
			9,
			1
		]
	],
	[
		[
			2315,
			9189
		],
		[
			14,
			0
		],
		[
			-4,
			-11
		],
		[
			-10,
			11
		]
	],
	[
		[
			2342,
			9191
		],
		[
			8,
			-12
		],
		[
			-14,
			-3
		],
		[
			6,
			15
		]
	],
	[
		[
			3114,
			9197
		],
		[
			-2,
			-10
		],
		[
			-10,
			3
		],
		[
			12,
			7
		]
	],
	[
		[
			2834,
			9196
		],
		[
			-16,
			-12
		],
		[
			-9,
			1
		],
		[
			20,
			15
		],
		[
			5,
			-4
		]
	],
	[
		[
			2787,
			9204
		],
		[
			9,
			-8
		],
		[
			-21,
			-3
		],
		[
			4,
			-8
		],
		[
			-24,
			10
		],
		[
			16,
			8
		],
		[
			16,
			1
		]
	],
	[
		[
			2294,
			9191
		],
		[
			5,
			5
		],
		[
			10,
			-12
		],
		[
			22,
			-14
		],
		[
			6,
			-20
		],
		[
			18,
			-3
		],
		[
			-17,
			-6
		],
		[
			-13,
			-15
		],
		[
			-33,
			4
		],
		[
			-9,
			7
		],
		[
			-25,
			7
		],
		[
			-3,
			8
		],
		[
			-11,
			-6
		],
		[
			-11,
			11
		],
		[
			33,
			17
		],
		[
			-4,
			16
		],
		[
			12,
			-9
		],
		[
			-6,
			16
		],
		[
			10,
			11
		],
		[
			18,
			-11
		],
		[
			-2,
			-6
		]
	],
	[
		[
			3004,
			9275
		],
		[
			14,
			-3
		],
		[
			-20,
			-12
		],
		[
			-5,
			8
		],
		[
			11,
			7
		]
	],
	[
		[
			2924,
			7774
		],
		[
			-11,
			-4
		],
		[
			-19,
			-25
		]
	],
	[
		[
			2894,
			7745
		],
		[
			-6,
			-7
		],
		[
			-19,
			-10
		],
		[
			-11,
			-18
		],
		[
			-17,
			9
		],
		[
			-5,
			-3
		],
		[
			-30,
			-8
		],
		[
			-17,
			-15
		],
		[
			-5,
			-17
		],
		[
			13,
			-6
		],
		[
			7,
			4
		]
	],
	[
		[
			2804,
			7674
		],
		[
			-1,
			-9
		]
	],
	[
		[
			2803,
			7665
		],
		[
			5,
			-11
		],
		[
			-36,
			-7
		],
		[
			-9,
			-13
		],
		[
			-11,
			6
		],
		[
			-12,
			-1
		],
		[
			-32,
			-36
		],
		[
			-12,
			-2
		],
		[
			-5,
			4
		],
		[
			0,
			12
		],
		[
			5,
			4
		],
		[
			13,
			-1
		],
		[
			1,
			10
		],
		[
			-6,
			4
		]
	],
	[
		[
			2704,
			7634
		],
		[
			5,
			9
		],
		[
			1,
			17
		]
	],
	[
		[
			2710,
			7660
		],
		[
			8,
			4
		],
		[
			12,
			20
		],
		[
			-1,
			38
		],
		[
			4,
			14
		],
		[
			9,
			16
		],
		[
			0,
			12
		],
		[
			-12,
			25
		],
		[
			11,
			0
		],
		[
			1,
			-14
		],
		[
			14,
			-17
		],
		[
			18,
			-14
		],
		[
			0,
			17
		],
		[
			4,
			6
		],
		[
			6,
			-5
		],
		[
			-9,
			17
		],
		[
			2,
			14
		],
		[
			-10,
			3
		],
		[
			-10,
			32
		],
		[
			-12,
			0
		],
		[
			-10,
			8
		],
		[
			-39,
			6
		],
		[
			-3,
			0
		],
		[
			-30,
			10
		]
	],
	[
		[
			2663,
			7852
		],
		[
			0,
			10
		],
		[
			-10,
			-4
		]
	],
	[
		[
			2653,
			7858
		],
		[
			-3,
			4
		],
		[
			4,
			24
		],
		[
			-8,
			1
		],
		[
			3,
			23
		],
		[
			-11,
			14
		],
		[
			5,
			20
		],
		[
			-25,
			0
		],
		[
			-8,
			9
		],
		[
			-12,
			39
		],
		[
			-22,
			-2
		],
		[
			-24,
			14
		],
		[
			-2,
			-22
		],
		[
			-7,
			-2
		],
		[
			3,
			15
		],
		[
			-6,
			-2
		],
		[
			-5,
			-26
		],
		[
			-5,
			-3
		],
		[
			3,
			16
		],
		[
			-10,
			-5
		],
		[
			-5,
			-22
		],
		[
			-7,
			-6
		]
	],
	[
		[
			2511,
			7947
		],
		[
			-9,
			-1
		],
		[
			-4,
			7
		],
		[
			-20,
			0
		],
		[
			-2,
			7
		],
		[
			-16,
			-11
		],
		[
			-8,
			4
		],
		[
			-10,
			14
		],
		[
			-8,
			-7
		],
		[
			-3,
			12
		],
		[
			-14,
			11
		],
		[
			-22,
			-6
		],
		[
			-3,
			7
		],
		[
			-17,
			3
		],
		[
			-6,
			5
		],
		[
			-4,
			31
		],
		[
			-9,
			3
		],
		[
			0,
			-22
		],
		[
			-79,
			0
		],
		[
			-80,
			0
		],
		[
			-55,
			0
		],
		[
			-79,
			0
		],
		[
			-79,
			0
		],
		[
			-49,
			0
		],
		[
			-49,
			0
		],
		[
			-80,
			0
		],
		[
			-61,
			0
		],
		[
			-74,
			0
		],
		[
			-81,
			0
		]
	],
	[
		[
			1590,
			8004
		],
		[
			-8,
			0
		]
	],
	[
		[
			1582,
			8004
		],
		[
			-1,
			0
		]
	],
	[
		[
			1581,
			8004
		],
		[
			-7,
			20
		],
		[
			2,
			14
		],
		[
			-8,
			-11
		],
		[
			-12,
			8
		],
		[
			-1,
			15
		],
		[
			-14,
			0
		],
		[
			-6,
			8
		],
		[
			3,
			18
		],
		[
			-3,
			5
		],
		[
			-9,
			0
		],
		[
			-20,
			12
		],
		[
			-13,
			-2
		],
		[
			6,
			17
		],
		[
			-14,
			1
		],
		[
			-10,
			6
		],
		[
			-4,
			-6
		],
		[
			-14,
			11
		],
		[
			-8,
			12
		],
		[
			9,
			23
		],
		[
			13,
			3
		],
		[
			-9,
			3
		],
		[
			-10,
			-15
		],
		[
			-4,
			12
		],
		[
			0,
			14
		],
		[
			19,
			25
		],
		[
			0,
			13
		],
		[
			-12,
			-16
		],
		[
			-7,
			-5
		],
		[
			-8,
			17
		],
		[
			-4,
			-12
		],
		[
			4,
			26
		],
		[
			-10,
			9
		],
		[
			-10,
			34
		],
		[
			10,
			-5
		],
		[
			-8,
			12
		],
		[
			5,
			21
		],
		[
			-17,
			-20
		],
		[
			-3,
			-14
		],
		[
			-21,
			32
		],
		[
			-4,
			26
		],
		[
			-6,
			-3
		],
		[
			1,
			17
		],
		[
			7,
			4
		],
		[
			10,
			33
		],
		[
			-5,
			0
		],
		[
			-4,
			28
		],
		[
			2,
			8
		]
	],
	[
		[
			1387,
			8402
		],
		[
			0,
			0
		]
	],
	[
		[
			1387,
			8402
		],
		[
			-1,
			12
		],
		[
			-9,
			1
		],
		[
			-9,
			13
		],
		[
			-10,
			3
		],
		[
			-14,
			11
		],
		[
			-7,
			0
		],
		[
			0,
			11
		],
		[
			-7,
			4
		],
		[
			2,
			10
		],
		[
			-29,
			56
		],
		[
			-20,
			40
		],
		[
			-12,
			8
		],
		[
			-4,
			12
		],
		[
			-21,
			22
		],
		[
			3,
			8
		],
		[
			-13,
			13
		],
		[
			-25,
			-11
		],
		[
			-2,
			-20
		],
		[
			-27,
			-20
		],
		[
			-5,
			17
		],
		[
			-43,
			50
		],
		[
			3,
			16
		],
		[
			-17,
			-1
		],
		[
			-9,
			-8
		],
		[
			-12,
			6
		],
		[
			-16,
			1
		],
		[
			0,
			538
		]
	],
	[
		[
			1083,
			9194
		],
		[
			29,
			-2
		],
		[
			23,
			-6
		],
		[
			15,
			-16
		],
		[
			50,
			-21
		],
		[
			26,
			2
		],
		[
			-3,
			18
		],
		[
			20,
			5
		],
		[
			-1,
			8
		],
		[
			29,
			8
		],
		[
			12,
			-5
		],
		[
			-9,
			-9
		],
		[
			24,
			4
		],
		[
			10,
			14
		],
		[
			16,
			0
		],
		[
			45,
			28
		],
		[
			22,
			-4
		],
		[
			5,
			11
		],
		[
			9,
			-11
		],
		[
			-45,
			-25
		],
		[
			-27,
			-6
		],
		[
			-3,
			-10
		],
		[
			-18,
			-6
		],
		[
			-4,
			-15
		],
		[
			-9,
			3
		],
		[
			-4,
			-11
		],
		[
			24,
			-3
		],
		[
			-11,
			15
		],
		[
			29,
			13
		],
		[
			15,
			12
		],
		[
			12,
			-9
		],
		[
			14,
			21
		],
		[
			35,
			9
		],
		[
			0,
			-10
		],
		[
			23,
			16
		],
		[
			-2,
			9
		],
		[
			22,
			7
		],
		[
			-13,
			3
		],
		[
			0,
			17
		],
		[
			23,
			-16
		],
		[
			14,
			-32
		],
		[
			15,
			-16
		],
		[
			20,
			-9
		],
		[
			9,
			4
		],
		[
			-8,
			12
		],
		[
			10,
			9
		],
		[
			8,
			18
		],
		[
			10,
			-1
		],
		[
			-2,
			-19
		],
		[
			12,
			0
		],
		[
			-13,
			-19
		],
		[
			24,
			-2
		],
		[
			14,
			8
		],
		[
			6,
			20
		],
		[
			36,
			-3
		],
		[
			23,
			-10
		],
		[
			23,
			-16
		],
		[
			31,
			-5
		],
		[
			23,
			-13
		],
		[
			57,
			-13
		],
		[
			-9,
			8
		],
		[
			11,
			4
		],
		[
			38,
			-17
		],
		[
			18,
			-18
		],
		[
			-3,
			-9
		],
		[
			-26,
			2
		],
		[
			-8,
			-18
		],
		[
			-9,
			-3
		],
		[
			47,
			-13
		],
		[
			40,
			-1
		],
		[
			3,
			4
		],
		[
			36,
			1
		],
		[
			22,
			14
		],
		[
			13,
			-16
		],
		[
			18,
			0
		],
		[
			7,
			-21
		],
		[
			6,
			15
		],
		[
			20,
			-23
		],
		[
			-7,
			-21
		],
		[
			25,
			-29
		],
		[
			-12,
			23
		],
		[
			1,
			18
		],
		[
			16,
			-14
		],
		[
			-4,
			15
		],
		[
			-9,
			8
		],
		[
			0,
			15
		],
		[
			-12,
			12
		],
		[
			7,
			19
		],
		[
			35,
			18
		],
		[
			21,
			5
		],
		[
			1,
			13
		],
		[
			-24,
			-7
		],
		[
			2,
			-8
		],
		[
			-22,
			-7
		],
		[
			-16,
			5
		],
		[
			7,
			-11
		],
		[
			-22,
			-3
		],
		[
			-2,
			12
		],
		[
			-10,
			-3
		],
		[
			14,
			20
		],
		[
			27,
			5
		],
		[
			31,
			14
		],
		[
			12,
			-3
		],
		[
			9,
			-11
		],
		[
			4,
			-20
		],
		[
			19,
			-6
		],
		[
			4,
			-12
		],
		[
			20,
			-1
		],
		[
			9,
			8
		],
		[
			5,
			-11
		],
		[
			27,
			-14
		],
		[
			21,
			-3
		],
		[
			23,
			10
		],
		[
			26,
			-1
		],
		[
			15,
			-7
		],
		[
			25,
			5
		],
		[
			22,
			-12
		],
		[
			12,
			11
		],
		[
			-16,
			12
		],
		[
			-10,
			-9
		],
		[
			-10,
			10
		],
		[
			3,
			9
		],
		[
			-11,
			11
		],
		[
			27,
			1
		],
		[
			-8,
			9
		],
		[
			21,
			-3
		],
		[
			5,
			-12
		],
		[
			18,
			3
		],
		[
			-11,
			-15
		],
		[
			26,
			12
		],
		[
			-16,
			-41
		],
		[
			11,
			-19
		],
		[
			10,
			8
		],
		[
			11,
			-20
		],
		[
			4,
			16
		],
		[
			-15,
			26
		],
		[
			7,
			19
		],
		[
			17,
			-3
		],
		[
			18,
			14
		],
		[
			18,
			33
		],
		[
			-10,
			8
		],
		[
			-5,
			-13
		],
		[
			-15,
			0
		],
		[
			11,
			34
		],
		[
			18,
			-2
		],
		[
			2,
			13
		],
		[
			-22,
			-5
		],
		[
			-9,
			14
		],
		[
			-7,
			-7
		],
		[
			-25,
			10
		],
		[
			-21,
			22
		],
		[
			1,
			14
		],
		[
			9,
			15
		],
		[
			-12,
			9
		],
		[
			5,
			30
		],
		[
			14,
			6
		],
		[
			8,
			-7
		],
		[
			5,
			12
		],
		[
			-13,
			4
		],
		[
			18,
			9
		],
		[
			2,
			13
		],
		[
			18,
			3
		],
		[
			4,
			-19
		],
		[
			7,
			7
		],
		[
			32,
			-24
		],
		[
			4,
			-30
		],
		[
			37,
			-41
		],
		[
			-25,
			2
		],
		[
			-4,
			-6
		],
		[
			18,
			-3
		],
		[
			-25,
			-18
		],
		[
			20,
			-9
		],
		[
			18,
			7
		],
		[
			10,
			-9
		],
		[
			19,
			-1
		],
		[
			-23,
			-12
		],
		[
			14,
			-11
		],
		[
			6,
			-20
		],
		[
			-2,
			-17
		],
		[
			9,
			-12
		],
		[
			11,
			12
		],
		[
			4,
			31
		],
		[
			11,
			15
		],
		[
			9,
			1
		],
		[
			28,
			-27
		],
		[
			5,
			-32
		],
		[
			-16,
			2
		],
		[
			1,
			-19
		],
		[
			8,
			-19
		],
		[
			17,
			-15
		],
		[
			-1,
			-14
		],
		[
			15,
			7
		],
		[
			-3,
			7
		],
		[
			14,
			-1
		],
		[
			1,
			20
		],
		[
			17,
			23
		],
		[
			7,
			37
		],
		[
			25,
			0
		],
		[
			-10,
			13
		],
		[
			11,
			7
		],
		[
			-20,
			11
		],
		[
			-2,
			10
		],
		[
			6,
			23
		],
		[
			7,
			-4
		],
		[
			20,
			5
		],
		[
			16,
			-9
		],
		[
			30,
			-1
		],
		[
			15,
			-23
		],
		[
			22,
			-5
		],
		[
			-6,
			-12
		],
		[
			-12,
			-5
		],
		[
			20,
			-5
		],
		[
			1,
			-10
		],
		[
			-20,
			-13
		],
		[
			-17,
			6
		],
		[
			-2,
			-7
		],
		[
			18,
			-11
		],
		[
			-5,
			-13
		],
		[
			26,
			-30
		],
		[
			-7,
			-27
		],
		[
			-13,
			-1
		],
		[
			-17,
			-24
		],
		[
			-12,
			-1
		],
		[
			-10,
			-11
		],
		[
			-25,
			21
		],
		[
			16,
			-30
		],
		[
			-4,
			-2
		],
		[
			-19,
			14
		],
		[
			4,
			-14
		],
		[
			-25,
			7
		],
		[
			-5,
			17
		],
		[
			-19,
			-5
		],
		[
			-18,
			2
		],
		[
			7,
			-12
		],
		[
			19,
			-9
		],
		[
			-16,
			-15
		],
		[
			-3,
			-13
		],
		[
			-23,
			-20
		],
		[
			-16,
			0
		],
		[
			-17,
			15
		],
		[
			-31,
			20
		],
		[
			-10,
			-3
		],
		[
			-30,
			2
		],
		[
			32,
			-7
		],
		[
			14,
			-11
		],
		[
			11,
			-16
		],
		[
			56,
			-5
		],
		[
			2,
			-11
		],
		[
			-16,
			-20
		],
		[
			-14,
			-27
		],
		[
			-18,
			-15
		],
		[
			-24,
			1
		],
		[
			-12,
			10
		],
		[
			4,
			-14
		],
		[
			-10,
			-17
		],
		[
			-21,
			-3
		],
		[
			-19,
			10
		],
		[
			-14,
			0
		],
		[
			-37,
			16
		],
		[
			-8,
			-2
		],
		[
			11,
			-10
		],
		[
			4,
			5
		],
		[
			31,
			-11
		],
		[
			-10,
			-11
		],
		[
			18,
			11
		],
		[
			6,
			-8
		],
		[
			25,
			-12
		],
		[
			2,
			-18
		],
		[
			-22,
			-16
		],
		[
			-19,
			5
		],
		[
			-10,
			-3
		],
		[
			15,
			-16
		],
		[
			-19,
			5
		],
		[
			-2,
			-20
		],
		[
			-8,
			-12
		],
		[
			-18,
			-12
		],
		[
			11,
			-4
		],
		[
			-17,
			-12
		],
		[
			-19,
			-60
		],
		[
			-8,
			-31
		],
		[
			3,
			-40
		],
		[
			-3,
			-17
		],
		[
			13,
			-17
		],
		[
			3,
			4
		],
		[
			29,
			-1
		],
		[
			2,
			-15
		],
		[
			10,
			-37
		],
		[
			9,
			-24
		],
		[
			-3,
			-25
		],
		[
			12,
			2
		],
		[
			30,
			12
		],
		[
			15,
			-3
		],
		[
			15,
			-12
		],
		[
			30,
			-8
		],
		[
			12,
			-15
		],
		[
			13,
			-10
		],
		[
			7,
			-15
		],
		[
			10,
			-12
		],
		[
			11,
			-1
		],
		[
			32,
			-17
		],
		[
			21,
			-20
		],
		[
			12,
			-3
		],
		[
			19,
			5
		],
		[
			15,
			-6
		],
		[
			12,
			1
		],
		[
			18,
			-9
		],
		[
			3,
			-14
		],
		[
			-6,
			-25
		],
		[
			0,
			-12
		],
		[
			8,
			-17
		],
		[
			-2,
			-23
		],
		[
			3,
			-13
		],
		[
			-5,
			-19
		],
		[
			20,
			-28
		],
		[
			6,
			-21
		],
		[
			10,
			-5
		],
		[
			15,
			-30
		],
		[
			1,
			-10
		],
		[
			19,
			-11
		],
		[
			1,
			16
		],
		[
			10,
			15
		],
		[
			11,
			-20
		],
		[
			6,
			11
		],
		[
			-9,
			15
		],
		[
			13,
			19
		],
		[
			2,
			22
		],
		[
			-6,
			4
		],
		[
			1,
			19
		],
		[
			-5,
			0
		],
		[
			-5,
			42
		],
		[
			-2,
			32
		],
		[
			-7,
			2
		],
		[
			-6,
			25
		],
		[
			-5,
			1
		],
		[
			39,
			22
		],
		[
			16,
			14
		],
		[
			19,
			23
		],
		[
			12,
			21
		],
		[
			4,
			16
		],
		[
			0,
			44
		],
		[
			-8,
			34
		],
		[
			-9,
			20
		],
		[
			-24,
			23
		],
		[
			-13,
			16
		],
		[
			-2,
			16
		],
		[
			22,
			21
		],
		[
			-1,
			20
		],
		[
			14,
			6
		],
		[
			-1,
			13
		],
		[
			-7,
			2
		],
		[
			-7,
			35
		],
		[
			6,
			6
		],
		[
			-16,
			2
		],
		[
			10,
			15
		],
		[
			2,
			20
		],
		[
			6,
			5
		],
		[
			-13,
			13
		],
		[
			-4,
			34
		],
		[
			18,
			16
		],
		[
			21,
			-4
		],
		[
			32,
			-14
		],
		[
			34,
			-1
		],
		[
			14,
			12
		],
		[
			18,
			-9
		],
		[
			17,
			-14
		],
		[
			-1,
			-8
		],
		[
			30,
			-19
		],
		[
			-9,
			-10
		],
		[
			14,
			-16
		],
		[
			23,
			-5
		],
		[
			11,
			2
		],
		[
			2,
			-11
		],
		[
			12,
			-1
		],
		[
			2,
			12
		],
		[
			5,
			-18
		],
		[
			-12,
			-15
		],
		[
			6,
			-26
		],
		[
			2,
			-26
		],
		[
			-6,
			-6
		],
		[
			3,
			-9
		],
		[
			11,
			-2
		],
		[
			-8,
			-8
		],
		[
			2,
			-18
		],
		[
			-19,
			-7
		],
		[
			10,
			-3
		],
		[
			15,
			12
		],
		[
			13,
			1
		],
		[
			11,
			-6
		],
		[
			5,
			-24
		],
		[
			7,
			10
		],
		[
			9,
			-20
		],
		[
			28,
			15
		],
		[
			6,
			21
		],
		[
			10,
			-9
		],
		[
			5,
			18
		],
		[
			7,
			3
		],
		[
			-2,
			12
		],
		[
			8,
			8
		],
		[
			-3,
			22
		],
		[
			8,
			2
		],
		[
			7,
			25
		],
		[
			14,
			2
		],
		[
			0,
			-12
		],
		[
			9,
			-6
		],
		[
			-1,
			-17
		],
		[
			6,
			0
		],
		[
			5,
			-15
		],
		[
			12,
			-13
		],
		[
			-11,
			-9
		],
		[
			13,
			3
		],
		[
			1,
			-13
		],
		[
			7,
			1
		],
		[
			4,
			-11
		],
		[
			-9,
			-11
		],
		[
			16,
			0
		],
		[
			-2,
			-19
		],
		[
			15,
			-12
		],
		[
			7,
			-20
		],
		[
			-14,
			-11
		],
		[
			10,
			2
		],
		[
			6,
			-6
		],
		[
			-6,
			-7
		],
		[
			18,
			-7
		],
		[
			-8,
			-18
		],
		[
			-7,
			0
		],
		[
			5,
			-13
		],
		[
			-9,
			-4
		],
		[
			11,
			-10
		],
		[
			-12,
			-2
		],
		[
			5,
			-5
		],
		[
			14,
			1
		],
		[
			-3,
			-13
		],
		[
			10,
			-2
		],
		[
			1,
			-7
		],
		[
			22,
			-5
		],
		[
			-4,
			-5
		],
		[
			3,
			-16
		],
		[
			-4,
			-16
		],
		[
			20,
			12
		],
		[
			-2,
			-10
		],
		[
			10,
			-5
		],
		[
			10,
			9
		],
		[
			6,
			-22
		],
		[
			30,
			-6
		],
		[
			14,
			-10
		],
		[
			-9,
			-11
		],
		[
			-15,
			-1
		],
		[
			-1,
			-6
		],
		[
			-33,
			-12
		],
		[
			21,
			5
		],
		[
			3,
			-3
		],
		[
			-30,
			-15
		],
		[
			-13,
			-3
		],
		[
			2,
			-15
		],
		[
			-11,
			-14
		],
		[
			38,
			24
		],
		[
			6,
			15
		],
		[
			19,
			9
		],
		[
			-5,
			7
		],
		[
			24,
			-1
		],
		[
			11,
			-22
		],
		[
			-12,
			-11
		],
		[
			6,
			-9
		],
		[
			9,
			15
		],
		[
			30,
			-19
		],
		[
			4,
			-15
		],
		[
			-6,
			-7
		],
		[
			5,
			-9
		],
		[
			-7,
			-12
		],
		[
			8,
			-9
		],
		[
			4,
			-17
		],
		[
			-8,
			-15
		],
		[
			-20,
			-17
		],
		[
			-10,
			-13
		],
		[
			-8,
			5
		],
		[
			-25,
			-14
		],
		[
			-8,
			3
		],
		[
			-7,
			-12
		],
		[
			-8,
			-5
		],
		[
			1,
			-12
		],
		[
			-13,
			-8
		],
		[
			0,
			-8
		],
		[
			-11,
			-6
		],
		[
			-3,
			-10
		],
		[
			-38,
			-3
		],
		[
			-10,
			-5
		],
		[
			-6,
			7
		],
		[
			-51,
			4
		],
		[
			-26,
			-2
		],
		[
			-37,
			0
		],
		[
			-5,
			-5
		],
		[
			-8,
			5
		],
		[
			-19,
			-25
		],
		[
			-3,
			-23
		],
		[
			-4,
			-6
		],
		[
			-19,
			-3
		],
		[
			-4,
			-11
		],
		[
			-24,
			-18
		],
		[
			-10,
			-28
		],
		[
			-7,
			-9
		],
		[
			-19,
			14
		],
		[
			-5,
			-2
		],
		[
			22,
			-14
		],
		[
			-5,
			-20
		],
		[
			-10,
			-17
		],
		[
			-6,
			-3
		],
		[
			-6,
			-17
		],
		[
			-17,
			-23
		],
		[
			-15,
			-1
		],
		[
			-21,
			-24
		],
		[
			-10,
			-4
		],
		[
			-7,
			-18
		],
		[
			-12,
			-11
		],
		[
			-7,
			-11
		],
		[
			-6,
			-2
		],
		[
			5,
			-8
		],
		[
			-15,
			-12
		],
		[
			-6,
			-8
		]
	],
	[
		[
			1827,
			9404
		],
		[
			6,
			-29
		],
		[
			-17,
			-11
		],
		[
			32,
			3
		],
		[
			-4,
			6
		],
		[
			17,
			15
		],
		[
			49,
			-17
		],
		[
			-3,
			-15
		],
		[
			17,
			6
		],
		[
			18,
			-8
		],
		[
			8,
			4
		],
		[
			-26,
			29
		],
		[
			23,
			-2
		],
		[
			24,
			-23
		],
		[
			11,
			-1
		],
		[
			-1,
			-11
		],
		[
			13,
			-38
		],
		[
			6,
			-4
		],
		[
			21,
			15
		],
		[
			-15,
			14
		],
		[
			-9,
			45
		],
		[
			0,
			25
		],
		[
			29,
			-10
		],
		[
			8,
			7
		],
		[
			26,
			-17
		],
		[
			18,
			-30
		],
		[
			4,
			-24
		],
		[
			19,
			-29
		],
		[
			-7,
			-28
		],
		[
			16,
			-17
		],
		[
			25,
			-16
		],
		[
			8,
			1
		],
		[
			35,
			-23
		],
		[
			16,
			4
		],
		[
			4,
			-24
		],
		[
			-13,
			-6
		],
		[
			-4,
			13
		],
		[
			-5,
			-14
		],
		[
			-19,
			11
		],
		[
			-14,
			-26
		],
		[
			22,
			5
		],
		[
			-2,
			-17
		],
		[
			9,
			-10
		],
		[
			-19,
			-8
		],
		[
			-24,
			-5
		],
		[
			-49,
			6
		],
		[
			4,
			12
		],
		[
			-40,
			5
		],
		[
			-4,
			18
		],
		[
			-10,
			-16
		],
		[
			-17,
			-13
		],
		[
			-28,
			-6
		],
		[
			-12,
			-9
		],
		[
			-56,
			-11
		],
		[
			-59,
			-3
		],
		[
			-16,
			19
		],
		[
			2,
			22
		],
		[
			-18,
			5
		],
		[
			-26,
			-3
		],
		[
			-22,
			4
		],
		[
			-18,
			9
		],
		[
			0,
			6
		],
		[
			-18,
			12
		],
		[
			-4,
			14
		],
		[
			39,
			12
		],
		[
			41,
			5
		],
		[
			53,
			-7
		],
		[
			9,
			7
		],
		[
			22,
			-3
		],
		[
			-18,
			14
		],
		[
			-19,
			2
		],
		[
			-18,
			8
		],
		[
			-58,
			-6
		],
		[
			-19,
			4
		],
		[
			-40,
			-1
		],
		[
			-19,
			23
		],
		[
			17,
			8
		],
		[
			41,
			11
		],
		[
			13,
			11
		],
		[
			-48,
			-10
		],
		[
			-21,
			6
		],
		[
			13,
			5
		],
		[
			-36,
			7
		],
		[
			0,
			11
		],
		[
			16,
			17
		],
		[
			13,
			3
		],
		[
			-13,
			15
		],
		[
			34,
			25
		],
		[
			50,
			16
		],
		[
			27,
			11
		],
		[
			10,
			-5
		]
	],
	[
		[
			2094,
			9405
		],
		[
			-16,
			-22
		],
		[
			-8,
			1
		],
		[
			-18,
			19
		],
		[
			-26,
			12
		],
		[
			13,
			13
		],
		[
			42,
			1
		],
		[
			16,
			-10
		],
		[
			-3,
			-14
		]
	],
	[
		[
			2768,
			9430
		],
		[
			25,
			-7
		],
		[
			37,
			2
		],
		[
			19,
			-6
		],
		[
			32,
			-26
		],
		[
			-1,
			-17
		],
		[
			-52,
			5
		],
		[
			-28,
			-9
		],
		[
			-22,
			6
		],
		[
			-4,
			22
		],
		[
			-21,
			5
		],
		[
			1,
			25
		],
		[
			14,
			0
		]
	],
	[
		[
			2595,
			9436
		],
		[
			41,
			-3
		],
		[
			4,
			-8
		],
		[
			-30,
			-21
		],
		[
			-18,
			-26
		],
		[
			10,
			-20
		],
		[
			-3,
			-28
		],
		[
			9,
			-14
		],
		[
			19,
			-16
		],
		[
			14,
			-5
		],
		[
			-16,
			-13
		],
		[
			-13,
			0
		],
		[
			-8,
			-10
		],
		[
			21,
			10
		],
		[
			18,
			-2
		],
		[
			8,
			17
		],
		[
			-4,
			14
		],
		[
			-16,
			-1
		],
		[
			-8,
			13
		],
		[
			2,
			21
		],
		[
			16,
			1
		],
		[
			-18,
			12
		],
		[
			-3,
			25
		],
		[
			14,
			2
		],
		[
			-6,
			11
		],
		[
			26,
			-5
		],
		[
			-19,
			15
		],
		[
			63,
			24
		],
		[
			37,
			-1
		],
		[
			11,
			-27
		],
		[
			14,
			-5
		],
		[
			0,
			-14
		],
		[
			10,
			-10
		],
		[
			-26,
			-24
		],
		[
			18,
			11
		],
		[
			-11,
			-18
		],
		[
			5,
			-13
		],
		[
			12,
			5
		],
		[
			16,
			25
		],
		[
			23,
			-13
		],
		[
			11,
			14
		],
		[
			26,
			14
		],
		[
			67,
			-15
		],
		[
			7,
			-14
		],
		[
			-14,
			-14
		],
		[
			33,
			4
		],
		[
			0,
			-15
		],
		[
			-32,
			-17
		],
		[
			31,
			12
		],
		[
			19,
			-1
		],
		[
			-10,
			-9
		],
		[
			-4,
			-17
		],
		[
			12,
			19
		],
		[
			3,
			-12
		],
		[
			15,
			-7
		],
		[
			13,
			23
		],
		[
			32,
			-12
		],
		[
			8,
			-11
		],
		[
			-10,
			-12
		],
		[
			-11,
			3
		],
		[
			-13,
			-14
		],
		[
			4,
			-6
		],
		[
			25,
			7
		],
		[
			4,
			9
		],
		[
			15,
			2
		],
		[
			3,
			-9
		],
		[
			-13,
			-17
		],
		[
			30,
			15
		],
		[
			-3,
			-16
		],
		[
			15,
			10
		],
		[
			31,
			-11
		],
		[
			-10,
			-16
		],
		[
			-31,
			-9
		],
		[
			32,
			3
		],
		[
			-1,
			-16
		],
		[
			12,
			9
		],
		[
			6,
			14
		],
		[
			24,
			-23
		],
		[
			2,
			-12
		],
		[
			-26,
			3
		],
		[
			-15,
			-11
		],
		[
			19,
			-8
		],
		[
			19,
			1
		],
		[
			16,
			-11
		],
		[
			-2,
			-8
		],
		[
			-26,
			2
		],
		[
			-15,
			8
		],
		[
			-22,
			3
		],
		[
			22,
			-8
		],
		[
			13,
			-10
		],
		[
			-8,
			-4
		],
		[
			5,
			-11
		],
		[
			-43,
			2
		],
		[
			33,
			-6
		],
		[
			-9,
			-8
		],
		[
			29,
			-2
		],
		[
			23,
			-6
		],
		[
			-10,
			-6
		],
		[
			8,
			-11
		],
		[
			37,
			-12
		],
		[
			12,
			7
		],
		[
			-2,
			-12
		],
		[
			18,
			-4
		],
		[
			13,
			-28
		],
		[
			-21,
			-10
		],
		[
			47,
			10
		],
		[
			-7,
			-18
		],
		[
			22,
			-5
		],
		[
			5,
			9
		],
		[
			18,
			-10
		],
		[
			10,
			-16
		],
		[
			-20,
			-10
		],
		[
			14,
			-3
		],
		[
			-30,
			-8
		],
		[
			14,
			-7
		],
		[
			-7,
			-17
		],
		[
			-15,
			-3
		],
		[
			7,
			-7
		],
		[
			-17,
			-1
		],
		[
			-7,
			16
		],
		[
			3,
			-21
		],
		[
			-9,
			-4
		],
		[
			9,
			-9
		],
		[
			-5,
			-24
		],
		[
			-17,
			9
		],
		[
			-9,
			14
		],
		[
			-1,
			-9
		],
		[
			-18,
			16
		],
		[
			-1,
			14
		],
		[
			-9,
			5
		],
		[
			19,
			17
		],
		[
			-31,
			-5
		],
		[
			-2,
			9
		],
		[
			-22,
			20
		],
		[
			2,
			8
		],
		[
			-13,
			-6
		],
		[
			-6,
			-11
		],
		[
			-16,
			12
		],
		[
			7,
			-15
		],
		[
			16,
			-12
		],
		[
			-1,
			-7
		],
		[
			-20,
			-1
		],
		[
			-9,
			18
		],
		[
			-2,
			-18
		],
		[
			12,
			-16
		],
		[
			14,
			3
		],
		[
			-2,
			-10
		],
		[
			10,
			-2
		],
		[
			10,
			-39
		],
		[
			1,
			14
		],
		[
			31,
			-16
		],
		[
			-3,
			-16
		],
		[
			17,
			0
		],
		[
			-10,
			-10
		],
		[
			11,
			-14
		],
		[
			11,
			-5
		],
		[
			-9,
			-11
		],
		[
			12,
			-6
		],
		[
			0,
			-25
		],
		[
			-7,
			5
		],
		[
			-4,
			18
		],
		[
			-2,
			-14
		],
		[
			10,
			-29
		],
		[
			-17,
			5
		],
		[
			8,
			-19
		],
		[
			-7,
			-5
		],
		[
			-1,
			13
		],
		[
			-12,
			11
		],
		[
			-12,
			-3
		],
		[
			-13,
			13
		],
		[
			-5,
			-5
		],
		[
			-20,
			21
		],
		[
			-6,
			12
		],
		[
			-1,
			-16
		],
		[
			-27,
			24
		],
		[
			-8,
			-3
		],
		[
			23,
			-33
		],
		[
			17,
			-6
		],
		[
			17,
			-21
		],
		[
			5,
			0
		],
		[
			16,
			-26
		],
		[
			7,
			-2
		],
		[
			-9,
			-20
		],
		[
			-30,
			16
		],
		[
			-35,
			7
		],
		[
			-12,
			7
		],
		[
			-25,
			24
		],
		[
			-9,
			-2
		],
		[
			-38,
			22
		],
		[
			-5,
			14
		],
		[
			15,
			10
		],
		[
			-16,
			12
		],
		[
			-2,
			-7
		],
		[
			-15,
			9
		],
		[
			-13,
			14
		],
		[
			-15,
			33
		],
		[
			-20,
			-9
		],
		[
			4,
			15
		],
		[
			-14,
			-6
		],
		[
			-5,
			-14
		],
		[
			-30,
			14
		],
		[
			-5,
			-12
		],
		[
			-24,
			-12
		],
		[
			-14,
			2
		],
		[
			-18,
			11
		],
		[
			-4,
			27
		],
		[
			5,
			9
		],
		[
			18,
			8
		],
		[
			-3,
			15
		],
		[
			21,
			-2
		],
		[
			25,
			-11
		],
		[
			9,
			-9
		],
		[
			-6,
			-7
		],
		[
			10,
			-12
		],
		[
			-2,
			16
		],
		[
			-16,
			17
		],
		[
			23,
			-3
		],
		[
			1,
			7
		],
		[
			15,
			-3
		],
		[
			11,
			12
		],
		[
			19,
			-5
		],
		[
			-7,
			19
		],
		[
			-8,
			4
		],
		[
			-13,
			18
		],
		[
			41,
			32
		],
		[
			5,
			19
		],
		[
			15,
			6
		],
		[
			-4,
			22
		],
		[
			-12,
			18
		],
		[
			-4,
			23
		],
		[
			-23,
			5
		],
		[
			3,
			18
		],
		[
			-19,
			-6
		],
		[
			-13,
			16
		],
		[
			2,
			15
		],
		[
			-9,
			-11
		],
		[
			-10,
			2
		],
		[
			-32,
			-14
		],
		[
			0,
			20
		],
		[
			28,
			3
		],
		[
			1,
			9
		],
		[
			-30,
			19
		],
		[
			-15,
			5
		],
		[
			10,
			9
		],
		[
			-23,
			0
		],
		[
			0,
			21
		],
		[
			-20,
			2
		],
		[
			-10,
			12
		],
		[
			-21,
			2
		],
		[
			21,
			-15
		],
		[
			3,
			-13
		],
		[
			-29,
			-7
		],
		[
			-6,
			8
		],
		[
			-39,
			3
		],
		[
			15,
			-14
		],
		[
			-9,
			-2
		],
		[
			-14,
			13
		],
		[
			-15,
			-11
		],
		[
			-25,
			12
		],
		[
			-15,
			-3
		],
		[
			-31,
			3
		],
		[
			-5,
			4
		],
		[
			-39,
			2
		],
		[
			-21,
			21
		],
		[
			1,
			-11
		],
		[
			-47,
			11
		],
		[
			-21,
			25
		],
		[
			9,
			7
		],
		[
			22,
			-4
		],
		[
			27,
			0
		],
		[
			-15,
			18
		],
		[
			-6,
			-3
		],
		[
			-47,
			6
		],
		[
			-5,
			7
		],
		[
			5,
			17
		],
		[
			-9,
			11
		],
		[
			5,
			24
		],
		[
			25,
			52
		],
		[
			36,
			27
		],
		[
			33,
			8
		]
	],
	[
		[
			2227,
			9438
		],
		[
			17,
			-9
		],
		[
			57,
			6
		],
		[
			4,
			-12
		],
		[
			-12,
			-6
		],
		[
			8,
			-7
		],
		[
			-19,
			-7
		],
		[
			-19,
			-16
		],
		[
			35,
			-3
		],
		[
			9,
			-16
		],
		[
			12,
			3
		],
		[
			5,
			-18
		],
		[
			-9,
			-6
		],
		[
			3,
			-27
		],
		[
			-25,
			-13
		],
		[
			-26,
			2
		],
		[
			9,
			-8
		],
		[
			-13,
			-13
		],
		[
			-19,
			3
		],
		[
			-13,
			25
		],
		[
			-27,
			24
		],
		[
			-21,
			3
		],
		[
			-34,
			24
		],
		[
			-4,
			9
		],
		[
			14,
			16
		],
		[
			11,
			-4
		],
		[
			16,
			-18
		],
		[
			24,
			2
		],
		[
			10,
			8
		],
		[
			-4,
			14
		],
		[
			-11,
			1
		],
		[
			-28,
			20
		],
		[
			11,
			7
		],
		[
			16,
			-9
		],
		[
			3,
			8
		],
		[
			-13,
			12
		],
		[
			33,
			5
		]
	],
	[
		[
			2287,
			9448
		],
		[
			-13,
			-11
		],
		[
			-23,
			-4
		],
		[
			-12,
			7
		],
		[
			34,
			10
		],
		[
			14,
			-2
		]
	],
	[
		[
			2423,
			9449
		],
		[
			18,
			-8
		],
		[
			8,
			5
		],
		[
			45,
			-7
		],
		[
			-28,
			-33
		],
		[
			-12,
			-21
		],
		[
			-14,
			-14
		],
		[
			-33,
			4
		],
		[
			-13,
			-4
		],
		[
			10,
			-16
		],
		[
			-18,
			-22
		],
		[
			-29,
			-6
		],
		[
			-2,
			33
		],
		[
			-11,
			9
		],
		[
			-2,
			60
		],
		[
			11,
			2
		],
		[
			1,
			14
		],
		[
			44,
			9
		],
		[
			25,
			-5
		]
	],
	[
		[
			1623,
			9476
		],
		[
			28,
			-12
		],
		[
			41,
			-10
		],
		[
			46,
			4
		],
		[
			58,
			-41
		],
		[
			-3,
			-6
		],
		[
			-28,
			-9
		],
		[
			-76,
			-37
		],
		[
			-3,
			-15
		],
		[
			-14,
			-8
		],
		[
			-13,
			1
		],
		[
			-3,
			-32
		],
		[
			-7,
			-11
		],
		[
			-22,
			-7
		],
		[
			-9,
			5
		],
		[
			-11,
			-12
		],
		[
			-27,
			-10
		],
		[
			-26,
			36
		],
		[
			-34,
			14
		],
		[
			-14,
			0
		],
		[
			0,
			10
		],
		[
			14,
			22
		],
		[
			9,
			4
		],
		[
			-4,
			18
		],
		[
			17,
			2
		],
		[
			-12,
			9
		],
		[
			14,
			21
		],
		[
			16,
			15
		],
		[
			-10,
			9
		],
		[
			-14,
			28
		],
		[
			87,
			12
		]
	],
	[
		[
			2118,
			9518
		],
		[
			-3,
			-12
		],
		[
			-30,
			4
		],
		[
			15,
			17
		],
		[
			18,
			-9
		]
	],
	[
		[
			2378,
			9537
		],
		[
			25,
			-20
		],
		[
			2,
			-24
		],
		[
			-5,
			-11
		],
		[
			-41,
			1
		],
		[
			-43,
			18
		],
		[
			23,
			30
		],
		[
			25,
			8
		],
		[
			14,
			-2
		]
	],
	[
		[
			2325,
			9539
		],
		[
			-16,
			-17
		],
		[
			-5,
			9
		],
		[
			21,
			8
		]
	],
	[
		[
			2164,
			9558
		],
		[
			-14,
			-12
		],
		[
			-20,
			-1
		],
		[
			7,
			9
		],
		[
			27,
			4
		]
	],
	[
		[
			2380,
			9546
		],
		[
			-17,
			10
		],
		[
			11,
			3
		],
		[
			6,
			-13
		]
	],
	[
		[
			2157,
			9563
		],
		[
			-38,
			-10
		],
		[
			11,
			8
		],
		[
			27,
			2
		]
	],
	[
		[
			1732,
			9567
		],
		[
			5,
			-3
		],
		[
			-22,
			-28
		],
		[
			-10,
			-5
		],
		[
			-22,
			5
		],
		[
			20,
			18
		],
		[
			29,
			13
		]
	],
	[
		[
			2805,
			9567
		],
		[
			0,
			-15
		],
		[
			-16,
			-3
		],
		[
			16,
			18
		]
	],
	[
		[
			2149,
			9575
		],
		[
			-6,
			-11
		],
		[
			-43,
			0
		],
		[
			2,
			8
		],
		[
			47,
			3
		]
	],
	[
		[
			2113,
			9595
		],
		[
			25,
			-12
		],
		[
			-38,
			-5
		],
		[
			-7,
			16
		],
		[
			20,
			1
		]
	],
	[
		[
			2266,
			9598
		],
		[
			21,
			-11
		],
		[
			7,
			-58
		],
		[
			-18,
			1
		],
		[
			14,
			-20
		],
		[
			-11,
			-7
		],
		[
			-47,
			-3
		],
		[
			-20,
			3
		],
		[
			-11,
			19
		],
		[
			33,
			20
		],
		[
			-52,
			-5
		],
		[
			-33,
			-7
		],
		[
			2,
			14
		],
		[
			20,
			10
		],
		[
			-6,
			28
		],
		[
			18,
			3
		],
		[
			35,
			-31
		],
		[
			7,
			21
		],
		[
			-30,
			12
		],
		[
			15,
			9
		],
		[
			23,
			0
		],
		[
			13,
			-10
		],
		[
			20,
			12
		]
	],
	[
		[
			2213,
			9601
		],
		[
			-38,
			-8
		],
		[
			20,
			9
		],
		[
			18,
			-1
		]
	],
	[
		[
			2508,
			9589
		],
		[
			-10,
			-2
		],
		[
			-15,
			15
		],
		[
			17,
			6
		],
		[
			8,
			-19
		]
	],
	[
		[
			1981,
			9607
		],
		[
			-3,
			-11
		],
		[
			20,
			-20
		],
		[
			-11,
			-11
		],
		[
			22,
			-7
		],
		[
			-10,
			-10
		],
		[
			27,
			5
		],
		[
			12,
			10
		],
		[
			31,
			-10
		],
		[
			1,
			-18
		],
		[
			-15,
			-30
		],
		[
			-28,
			-8
		],
		[
			-21,
			7
		],
		[
			-19,
			-7
		],
		[
			-5,
			8
		],
		[
			-25,
			-11
		],
		[
			-22,
			-4
		],
		[
			-24,
			-12
		],
		[
			-34,
			-10
		],
		[
			-29,
			0
		],
		[
			-27,
			17
		],
		[
			52,
			17
		],
		[
			27,
			0
		],
		[
			19,
			13
		],
		[
			-36,
			-6
		],
		[
			-3,
			5
		],
		[
			-44,
			-9
		],
		[
			-5,
			24
		],
		[
			-10,
			-23
		],
		[
			-35,
			-6
		],
		[
			-55,
			16
		],
		[
			12,
			13
		],
		[
			30,
			0
		],
		[
			31,
			14
		],
		[
			-30,
			-8
		],
		[
			-32,
			0
		],
		[
			10,
			12
		],
		[
			57,
			5
		],
		[
			-39,
			0
		],
		[
			-12,
			12
		],
		[
			23,
			10
		],
		[
			10,
			12
		],
		[
			36,
			1
		],
		[
			7,
			-17
		],
		[
			28,
			5
		],
		[
			33,
			-21
		],
		[
			14,
			-22
		],
		[
			62,
			-1
		],
		[
			6,
			7
		],
		[
			-32,
			17
		],
		[
			18,
			11
		],
		[
			-30,
			11
		],
		[
			18,
			11
		],
		[
			15,
			19
		],
		[
			15,
			0
		]
	],
	[
		[
			1840,
			9610
		],
		[
			3,
			-10
		],
		[
			-34,
			3
		],
		[
			31,
			7
		]
	],
	[
		[
			2354,
			9618
		],
		[
			44,
			-6
		],
		[
			16,
			-16
		],
		[
			46,
			3
		],
		[
			26,
			-13
		],
		[
			-26,
			0
		],
		[
			59,
			-9
		],
		[
			-2,
			-7
		],
		[
			-52,
			-1
		],
		[
			30,
			-6
		],
		[
			28,
			-18
		],
		[
			2,
			-16
		],
		[
			14,
			11
		],
		[
			11,
			-8
		],
		[
			26,
			6
		],
		[
			13,
			-9
		],
		[
			59,
			10
		],
		[
			21,
			10
		],
		[
			23,
			-5
		],
		[
			16,
			6
		],
		[
			39,
			-3
		],
		[
			40,
			-18
		],
		[
			6,
			-11
		],
		[
			-25,
			-15
		],
		[
			16,
			1
		],
		[
			10,
			-9
		],
		[
			-23,
			-7
		],
		[
			-1,
			-11
		],
		[
			-29,
			0
		],
		[
			-12,
			-6
		],
		[
			-33,
			5
		],
		[
			-7,
			16
		],
		[
			-11,
			-16
		],
		[
			-84,
			-5
		],
		[
			-53,
			2
		],
		[
			2,
			20
		],
		[
			-21,
			-15
		],
		[
			-21,
			-3
		],
		[
			-30,
			10
		],
		[
			-10,
			-4
		],
		[
			-19,
			9
		],
		[
			1,
			10
		],
		[
			-13,
			14
		],
		[
			11,
			38
		],
		[
			-14,
			8
		],
		[
			-14,
			21
		],
		[
			-17,
			-6
		],
		[
			-37,
			-3
		],
		[
			6,
			7
		],
		[
			-27,
			3
		],
		[
			-11,
			14
		],
		[
			-18,
			4
		],
		[
			15,
			6
		],
		[
			-15,
			7
		],
		[
			13,
			6
		],
		[
			32,
			-1
		]
	],
	[
		[
			1774,
			9644
		],
		[
			20,
			-9
		],
		[
			-25,
			-7
		],
		[
			-2,
			-15
		],
		[
			13,
			-14
		],
		[
			-30,
			-8
		],
		[
			-9,
			-17
		],
		[
			-20,
			9
		],
		[
			5,
			24
		],
		[
			-19,
			-6
		],
		[
			-1,
			-22
		],
		[
			-34,
			-26
		],
		[
			-19,
			-3
		],
		[
			-7,
			19
		],
		[
			-15,
			-12
		],
		[
			-46,
			8
		],
		[
			9,
			15
		],
		[
			31,
			5
		],
		[
			9,
			14
		],
		[
			22,
			7
		],
		[
			15,
			17
		],
		[
			27,
			15
		],
		[
			26,
			1
		],
		[
			18,
			-6
		],
		[
			32,
			11
		]
	],
	[
		[
			2491,
			9653
		],
		[
			17,
			-10
		],
		[
			-11,
			-14
		],
		[
			-30,
			11
		],
		[
			0,
			13
		],
		[
			24,
			0
		]
	],
	[
		[
			2083,
			9641
		],
		[
			18,
			-11
		],
		[
			-11,
			-7
		],
		[
			-23,
			12
		],
		[
			-14,
			25
		],
		[
			13,
			0
		],
		[
			17,
			-19
		]
	],
	[
		[
			2350,
			9662
		],
		[
			51,
			0
		],
		[
			13,
			-7
		],
		[
			-11,
			-10
		],
		[
			-70,
			0
		],
		[
			-6,
			13
		],
		[
			23,
			4
		]
	],
	[
		[
			2196,
			9660
		],
		[
			-42,
			-1
		],
		[
			0,
			9
		],
		[
			21,
			1
		],
		[
			21,
			-9
		]
	],
	[
		[
			1824,
			9675
		],
		[
			20,
			-11
		],
		[
			-15,
			-6
		],
		[
			-27,
			14
		],
		[
			22,
			3
		]
	],
	[
		[
			1955,
			9679
		],
		[
			-35,
			-12
		],
		[
			21,
			-5
		],
		[
			-3,
			-16
		],
		[
			-52,
			-10
		],
		[
			-31,
			11
		],
		[
			3,
			23
		],
		[
			51,
			10
		],
		[
			46,
			-1
		]
	],
	[
		[
			1933,
			9718
		],
		[
			31,
			-15
		],
		[
			-4,
			-11
		],
		[
			-50,
			5
		],
		[
			-52,
			-7
		],
		[
			-5,
			8
		],
		[
			40,
			8
		],
		[
			40,
			12
		]
	],
	[
		[
			2308,
			9715
		],
		[
			18,
			-10
		],
		[
			40,
			-9
		],
		[
			-15,
			-7
		],
		[
			9,
			-16
		],
		[
			-51,
			-11
		],
		[
			-22,
			18
		],
		[
			22,
			2
		],
		[
			-33,
			10
		],
		[
			-10,
			12
		],
		[
			7,
			18
		],
		[
			35,
			-7
		]
	],
	[
		[
			2120,
			9752
		],
		[
			22,
			-6
		],
		[
			10,
			-21
		],
		[
			25,
			12
		],
		[
			58,
			-29
		],
		[
			-8,
			-16
		],
		[
			22,
			-13
		],
		[
			0,
			-11
		],
		[
			-25,
			-6
		],
		[
			-19,
			5
		],
		[
			-12,
			19
		],
		[
			-45,
			10
		],
		[
			-50,
			-6
		],
		[
			-10,
			18
		],
		[
			38,
			-3
		],
		[
			1,
			15
		],
		[
			-18,
			11
		],
		[
			-27,
			-9
		],
		[
			10,
			11
		],
		[
			-26,
			2
		],
		[
			4,
			16
		],
		[
			50,
			1
		]
	],
	[
		[
			2237,
			9796
		],
		[
			21,
			-8
		],
		[
			-5,
			-17
		],
		[
			-36,
			22
		],
		[
			20,
			3
		]
	],
	[
		[
			2423,
			9866
		],
		[
			56,
			-44
		],
		[
			40,
			-1
		],
		[
			1,
			-15
		],
		[
			22,
			9
		],
		[
			22,
			-2
		],
		[
			19,
			-26
		],
		[
			-9,
			-26
		],
		[
			20,
			9
		],
		[
			23,
			-2
		],
		[
			24,
			-19
		],
		[
			-46,
			-14
		],
		[
			-69,
			-50
		],
		[
			-26,
			25
		],
		[
			15,
			-26
		],
		[
			-24,
			10
		],
		[
			0,
			-11
		],
		[
			-49,
			4
		],
		[
			-22,
			17
		],
		[
			34,
			3
		],
		[
			-45,
			2
		],
		[
			-28,
			21
		],
		[
			25,
			12
		],
		[
			79,
			3
		],
		[
			-58,
			1
		],
		[
			0,
			12
		],
		[
			-36,
			-11
		],
		[
			-3,
			7
		],
		[
			-33,
			-6
		],
		[
			-14,
			15
		],
		[
			27,
			4
		],
		[
			-31,
			3
		],
		[
			-21,
			14
		],
		[
			-4,
			14
		],
		[
			53,
			-6
		],
		[
			21,
			9
		],
		[
			-36,
			-4
		],
		[
			-32,
			9
		],
		[
			14,
			17
		],
		[
			41,
			2
		],
		[
			7,
			8
		],
		[
			-33,
			3
		],
		[
			17,
			15
		],
		[
			39,
			0
		],
		[
			7,
			9
		],
		[
			-28,
			8
		],
		[
			41,
			-2
		]
	],
	[
		[
			3064,
			9969
		],
		[
			92,
			-13
		],
		[
			-63,
			-13
		],
		[
			33,
			0
		],
		[
			64,
			14
		],
		[
			63,
			-22
		],
		[
			36,
			-2
		],
		[
			8,
			-17
		],
		[
			-85,
			-27
		],
		[
			-75,
			-6
		],
		[
			11,
			-7
		],
		[
			-78,
			-18
		],
		[
			137,
			21
		],
		[
			-4,
			-9
		],
		[
			-119,
			-45
		],
		[
			-9,
			-11
		],
		[
			-28,
			-4
		],
		[
			-23,
			-32
		],
		[
			-31,
			-8
		],
		[
			-32,
			7
		],
		[
			7,
			-13
		],
		[
			-52,
			-10
		],
		[
			-85,
			-2
		],
		[
			20,
			-4
		],
		[
			80,
			-3
		],
		[
			-1,
			-11
		],
		[
			-35,
			3
		],
		[
			-9,
			7
		],
		[
			-57,
			-2
		],
		[
			56,
			-5
		],
		[
			-45,
			-3
		],
		[
			55,
			-3
		],
		[
			-14,
			-6
		],
		[
			38,
			-1
		],
		[
			8,
			-15
		],
		[
			-22,
			-5
		],
		[
			-30,
			2
		],
		[
			38,
			-10
		],
		[
			-14,
			-14
		],
		[
			-35,
			-13
		],
		[
			-43,
			0
		],
		[
			19,
			-17
		],
		[
			-14,
			-13
		],
		[
			-47,
			-6
		],
		[
			-38,
			9
		],
		[
			-17,
			14
		],
		[
			5,
			-14
		],
		[
			18,
			-8
		],
		[
			57,
			-7
		],
		[
			-10,
			-14
		],
		[
			19,
			-6
		],
		[
			18,
			11
		],
		[
			7,
			-22
		],
		[
			-21,
			-10
		],
		[
			-5,
			7
		],
		[
			-22,
			-15
		],
		[
			-42,
			-11
		],
		[
			8,
			17
		],
		[
			-36,
			5
		],
		[
			-6,
			-7
		],
		[
			-40,
			2
		],
		[
			-13,
			10
		],
		[
			-6,
			-17
		],
		[
			-23,
			-1
		],
		[
			-61,
			10
		],
		[
			-4,
			-7
		],
		[
			-37,
			4
		],
		[
			-15,
			10
		],
		[
			-1,
			17
		],
		[
			33,
			15
		],
		[
			23,
			-1
		],
		[
			15,
			8
		],
		[
			-21,
			5
		],
		[
			-15,
			25
		],
		[
			29,
			7
		],
		[
			27,
			-6
		],
		[
			22,
			-23
		],
		[
			54,
			-3
		],
		[
			27,
			35
		],
		[
			-39,
			-27
		],
		[
			-38,
			10
		],
		[
			15,
			39
		],
		[
			-21,
			-13
		],
		[
			-21,
			5
		],
		[
			-35,
			-4
		],
		[
			1,
			19
		],
		[
			24,
			20
		],
		[
			44,
			7
		],
		[
			35,
			-5
		],
		[
			56,
			1
		],
		[
			-53,
			4
		],
		[
			-30,
			6
		],
		[
			11,
			9
		],
		[
			-23,
			27
		],
		[
			-37,
			6
		],
		[
			0,
			32
		],
		[
			75,
			-4
		],
		[
			67,
			-35
		],
		[
			-7,
			16
		],
		[
			-44,
			23
		],
		[
			80,
			9
		],
		[
			54,
			8
		],
		[
			-44,
			0
		],
		[
			94,
			17
		],
		[
			-62,
			-3
		],
		[
			-2,
			9
		],
		[
			57,
			26
		],
		[
			-37,
			-9
		],
		[
			-40,
			-28
		],
		[
			-44,
			-11
		],
		[
			-53,
			-5
		],
		[
			27,
			11
		],
		[
			-48,
			2
		],
		[
			1,
			-13
		],
		[
			-55,
			-1
		],
		[
			-26,
			5
		],
		[
			26,
			19
		],
		[
			85,
			11
		],
		[
			-93,
			-8
		],
		[
			-33,
			-21
		],
		[
			-58,
			14
		],
		[
			99,
			12
		],
		[
			30,
			12
		],
		[
			-43,
			-8
		],
		[
			-98,
			-8
		],
		[
			-15,
			8
		],
		[
			12,
			11
		],
		[
			45,
			14
		],
		[
			-57,
			-12
		],
		[
			12,
			13
		],
		[
			-22,
			4
		],
		[
			-21,
			-8
		],
		[
			-14,
			7
		],
		[
			27,
			11
		],
		[
			83,
			15
		],
		[
			87,
			-6
		],
		[
			-56,
			12
		],
		[
			43,
			5
		],
		[
			-12,
			10
		],
		[
			30,
			1
		],
		[
			59,
			-23
		],
		[
			-11,
			12
		],
		[
			82,
			-19
		],
		[
			-75,
			24
		],
		[
			18,
			17
		],
		[
			41,
			-8
		],
		[
			-28,
			15
		],
		[
			47,
			-2
		],
		[
			16,
			12
		],
		[
			41,
			-3
		],
		[
			44,
			-11
		],
		[
			-31,
			15
		],
		[
			35,
			4
		],
		[
			54,
			-3
		],
		[
			10,
			-8
		],
		[
			24,
			12
		],
		[
			91,
			2
		]
	],
	[
		[
			5255,
			7927
		],
		[
			0,
			0
		]
	],
	[
		[
			5255,
			7927
		],
		[
			0,
			0
		]
	],
	[
		[
			5255,
			7927
		],
		[
			10,
			-8
		]
	],
	[
		[
			5264,
			7905
		],
		[
			2,
			-12
		]
	],
	[
		[
			5290,
			7882
		],
		[
			-2,
			-13
		],
		[
			-10,
			-7
		],
		[
			4,
			-15
		],
		[
			-6,
			6
		],
		[
			-12,
			-4
		],
		[
			-2,
			10
		],
		[
			-5,
			0
		],
		[
			-1,
			-14
		],
		[
			-5,
			-6
		],
		[
			-1,
			-18
		],
		[
			-7,
			10
		],
		[
			2,
			5
		],
		[
			-11,
			9
		],
		[
			0,
			13
		],
		[
			-10,
			-11
		],
		[
			1,
			-8
		],
		[
			-9,
			-12
		],
		[
			-8,
			4
		],
		[
			-13,
			-4
		]
	],
	[
		[
			5195,
			7827
		],
		[
			-7,
			15
		],
		[
			0,
			14
		]
	],
	[
		[
			5188,
			7856
		],
		[
			-5,
			6
		],
		[
			-8,
			-4
		],
		[
			-3,
			-9
		]
	],
	[
		[
			5172,
			7849
		],
		[
			-4,
			7
		],
		[
			2,
			10
		],
		[
			8,
			9
		],
		[
			0,
			11
		],
		[
			7,
			4
		],
		[
			12,
			28
		],
		[
			8,
			-5
		],
		[
			5,
			10
		]
	],
	[
		[
			5210,
			7923
		],
		[
			14,
			-1
		],
		[
			9,
			5
		],
		[
			4,
			9
		],
		[
			9,
			-9
		],
		[
			9,
			0
		]
	],
	[
		[
			3101,
			2016
		],
		[
			-9,
			-10
		],
		[
			13,
			-7
		],
		[
			6,
			-18
		],
		[
			-2,
			-7
		],
		[
			-8,
			14
		],
		[
			-15,
			-2
		],
		[
			2,
			19
		],
		[
			-18,
			-5
		],
		[
			-1,
			-4
		],
		[
			-14,
			10
		],
		[
			3,
			5
		],
		[
			39,
			9
		],
		[
			4,
			-4
		]
	],
	[
		[
			3116,
			2021
		],
		[
			14,
			-1
		],
		[
			7,
			-9
		],
		[
			-5,
			-12
		],
		[
			-7,
			7
		],
		[
			-9,
			-6
		],
		[
			-8,
			1
		],
		[
			-2,
			15
		],
		[
			10,
			5
		]
	],
	[
		[
			3041,
			2018
		],
		[
			7,
			-9
		],
		[
			-19,
			2
		],
		[
			-1,
			8
		],
		[
			13,
			-1
		]
	],
	[
		[
			3069,
			2021
		],
		[
			8,
			-5
		],
		[
			-19,
			-3
		],
		[
			-1,
			8
		],
		[
			12,
			0
		]
	],
	[
		[
			3013,
			2074
		],
		[
			7,
			-1
		],
		[
			8,
			-15
		],
		[
			-5,
			-7
		],
		[
			-8,
			10
		],
		[
			-4,
			-3
		],
		[
			-2,
			16
		],
		[
			4,
			0
		]
	],
	[
		[
			3003,
			2080
		],
		[
			6,
			-2
		],
		[
			-5,
			-24
		],
		[
			-11,
			16
		],
		[
			0,
			7
		],
		[
			10,
			3
		]
	],
	[
		[
			3044,
			2081
		],
		[
			2,
			-8
		],
		[
			-9,
			4
		],
		[
			3,
			-17
		],
		[
			-9,
			10
		],
		[
			-1,
			10
		],
		[
			8,
			1
		],
		[
			-2,
			10
		],
		[
			6,
			7
		],
		[
			2,
			-17
		]
	],
	[
		[
			2972,
			2103
		],
		[
			2,
			3
		],
		[
			22,
			-21
		],
		[
			-6,
			-2
		],
		[
			-14,
			-18
		],
		[
			4,
			15
		],
		[
			-9,
			1
		],
		[
			-7,
			-7
		],
		[
			1,
			12
		],
		[
			-8,
			1
		],
		[
			3,
			17
		],
		[
			12,
			-1
		]
	],
	[
		[
			2925,
			2147
		],
		[
			15,
			-16
		],
		[
			8,
			0
		],
		[
			21,
			-22
		],
		[
			-10,
			3
		],
		[
			-11,
			14
		],
		[
			-13,
			-1
		],
		[
			-10,
			22
		]
	],
	[
		[
			3093,
			2028
		],
		[
			0,
			-1
		]
	],
	[
		[
			3093,
			2021
		],
		[
			-12,
			-3
		],
		[
			-17,
			9
		],
		[
			-13,
			-4
		],
		[
			-23,
			10
		],
		[
			-10,
			10
		],
		[
			-17,
			-8
		],
		[
			-1,
			12
		],
		[
			8,
			-7
		],
		[
			10,
			12
		],
		[
			7,
			-9
		],
		[
			6,
			12
		],
		[
			-2,
			12
		],
		[
			20,
			-15
		],
		[
			7,
			5
		],
		[
			13,
			-4
		],
		[
			10,
			-11
		],
		[
			3,
			8
		],
		[
			-28,
			18
		],
		[
			-4,
			19
		],
		[
			24,
			15
		],
		[
			-1,
			8
		],
		[
			-25,
			-6
		],
		[
			-6,
			8
		],
		[
			1,
			17
		],
		[
			9,
			1
		],
		[
			0,
			8
		],
		[
			12,
			7
		],
		[
			2,
			13
		],
		[
			6,
			4
		],
		[
			5,
			-11
		],
		[
			16,
			0
		]
	],
	[
		[
			2952,
			2165
		],
		[
			-2,
			-17
		],
		[
			-9,
			0
		],
		[
			-2,
			7
		],
		[
			13,
			10
		]
	],
	[
		[
			2921,
			2176
		],
		[
			8,
			-2
		],
		[
			-6,
			-7
		],
		[
			-2,
			9
		]
	],
	[
		[
			2938,
			2182
		],
		[
			8,
			-11
		],
		[
			-5,
			-6
		],
		[
			-3,
			17
		]
	],
	[
		[
			2920,
			2209
		],
		[
			3,
			-4
		],
		[
			-3,
			-19
		],
		[
			-5,
			7
		],
		[
			5,
			16
		]
	],
	[
		[
			2943,
			2211
		],
		[
			3,
			-10
		],
		[
			-9,
			5
		],
		[
			6,
			5
		]
	],
	[
		[
			2925,
			2234
		],
		[
			1,
			-8
		],
		[
			-9,
			1
		],
		[
			8,
			7
		]
	],
	[
		[
			2931,
			2257
		],
		[
			2,
			-13
		],
		[
			-14,
			-1
		],
		[
			-1,
			9
		],
		[
			9,
			-2
		],
		[
			4,
			7
		]
	],
	[
		[
			2924,
			2263
		],
		[
			1,
			-11
		],
		[
			-8,
			7
		],
		[
			7,
			4
		]
	],
	[
		[
			2906,
			2275
		],
		[
			8,
			0
		],
		[
			-10,
			-15
		],
		[
			2,
			15
		]
	],
	[
		[
			2931,
			2276
		],
		[
			3,
			1
		],
		[
			5,
			-22
		],
		[
			-5,
			0
		],
		[
			-6,
			13
		],
		[
			3,
			8
		]
	],
	[
		[
			2908,
			2302
		],
		[
			14,
			-5
		],
		[
			0,
			-6
		],
		[
			-18,
			-9
		],
		[
			1,
			12
		],
		[
			7,
			-5
		],
		[
			-4,
			13
		]
	],
	[
		[
			2903,
			2329
		],
		[
			8,
			-14
		],
		[
			-12,
			3
		],
		[
			4,
			11
		]
	],
	[
		[
			2914,
			2359
		],
		[
			5,
			-2
		],
		[
			0,
			-12
		],
		[
			-9,
			10
		],
		[
			4,
			4
		]
	],
	[
		[
			2906,
			2359
		],
		[
			2,
			-6
		],
		[
			-9,
			-5
		],
		[
			7,
			11
		]
	],
	[
		[
			2925,
			2377
		],
		[
			5,
			0
		],
		[
			2,
			-27
		],
		[
			-3,
			-27
		],
		[
			3,
			-13
		],
		[
			-9,
			-10
		],
		[
			-4,
			6
		],
		[
			1,
			25
		],
		[
			-4,
			-21
		],
		[
			-7,
			11
		],
		[
			-2,
			25
		],
		[
			13,
			-3
		],
		[
			2,
			12
		],
		[
			-7,
			18
		],
		[
			10,
			4
		]
	],
	[
		[
			2906,
			2392
		],
		[
			1,
			-9
		],
		[
			-7,
			-5
		],
		[
			-2,
			13
		],
		[
			8,
			1
		]
	],
	[
		[
			2924,
			2406
		],
		[
			4,
			-8
		],
		[
			2,
			-18
		],
		[
			-14,
			4
		],
		[
			-1,
			6
		],
		[
			9,
			16
		]
	],
	[
		[
			2913,
			2413
		],
		[
			9,
			-4
		],
		[
			-1,
			-11
		],
		[
			-7,
			-2
		],
		[
			-5,
			19
		],
		[
			4,
			-2
		]
	],
	[
		[
			2907,
			2415
		],
		[
			7,
			-32
		],
		[
			-6,
			0
		],
		[
			0,
			16
		],
		[
			-5,
			-5
		],
		[
			-3,
			20
		],
		[
			7,
			1
		]
	],
	[
		[
			2921,
			2430
		],
		[
			3,
			-17
		],
		[
			-11,
			6
		],
		[
			-1,
			6
		],
		[
			9,
			5
		]
	],
	[
		[
			2945,
			2427
		],
		[
			4,
			-6
		],
		[
			-19,
			2
		],
		[
			7,
			7
		],
		[
			8,
			-3
		]
	],
	[
		[
			2914,
			2436
		],
		[
			-3,
			-8
		],
		[
			-5,
			6
		],
		[
			8,
			2
		]
	],
	[
		[
			2924,
			2545
		],
		[
			-1,
			-11
		],
		[
			-10,
			7
		],
		[
			11,
			4
		]
	],
	[
		[
			2936,
			2556
		],
		[
			-5,
			-9
		],
		[
			0,
			15
		],
		[
			5,
			-6
		]
	],
	[
		[
			2955,
			2556
		],
		[
			-6,
			-2
		],
		[
			3,
			11
		],
		[
			3,
			-9
		]
	],
	[
		[
			2948,
			2591
		],
		[
			3,
			-16
		],
		[
			-7,
			2
		],
		[
			-6,
			12
		],
		[
			10,
			2
		]
	],
	[
		[
			2946,
			2594
		],
		[
			-9,
			-4
		],
		[
			3,
			9
		],
		[
			6,
			-5
		]
	],
	[
		[
			2946,
			2613
		],
		[
			2,
			-4
		],
		[
			-11,
			-6
		],
		[
			-4,
			10
		],
		[
			13,
			0
		]
	],
	[
		[
			2974,
			2623
		],
		[
			6,
			-4
		],
		[
			-12,
			-23
		],
		[
			-4,
			-1
		],
		[
			-5,
			16
		],
		[
			7,
			2
		],
		[
			-1,
			11
		],
		[
			9,
			-1
		]
	],
	[
		[
			2948,
			2662
		],
		[
			3,
			-7
		],
		[
			-11,
			0
		],
		[
			8,
			7
		]
	],
	[
		[
			2945,
			2775
		],
		[
			11,
			1
		],
		[
			5,
			-30
		],
		[
			-8,
			-2
		],
		[
			-4,
			-15
		],
		[
			9,
			-10
		],
		[
			-6,
			-5
		],
		[
			6,
			-13
		],
		[
			-7,
			-2
		],
		[
			2,
			-14
		],
		[
			-17,
			3
		],
		[
			-3,
			4
		],
		[
			7,
			21
		],
		[
			-1,
			36
		],
		[
			4,
			8
		],
		[
			2,
			18
		]
	],
	[
		[
			3098,
			2168
		],
		[
			-21,
			9
		],
		[
			-7,
			-4
		],
		[
			-3,
			-12
		],
		[
			-8,
			-1
		],
		[
			-27,
			-20
		],
		[
			-3,
			-19
		],
		[
			-1,
			-36
		],
		[
			-7,
			-5
		],
		[
			-24,
			11
		],
		[
			-10,
			15
		],
		[
			5,
			11
		],
		[
			15,
			1
		],
		[
			10,
			5
		],
		[
			6,
			18
		],
		[
			-5,
			1
		],
		[
			-22,
			-19
		],
		[
			-5,
			6
		],
		[
			-7,
			-20
		],
		[
			1,
			-10
		],
		[
			-20,
			22
		],
		[
			9,
			0
		],
		[
			-1,
			20
		],
		[
			14,
			1
		],
		[
			13,
			9
		],
		[
			14,
			0
		],
		[
			-2,
			5
		],
		[
			-21,
			3
		],
		[
			-19,
			-19
		],
		[
			1,
			-11
		],
		[
			-6,
			-4
		],
		[
			-8,
			6
		],
		[
			6,
			5
		],
		[
			-9,
			6
		],
		[
			9,
			1
		],
		[
			2,
			11
		],
		[
			-11,
			-5
		],
		[
			0,
			29
		],
		[
			6,
			-2
		],
		[
			15,
			16
		],
		[
			9,
			-1
		],
		[
			0,
			13
		],
		[
			-7,
			-6
		],
		[
			-15,
			13
		],
		[
			10,
			-15
		],
		[
			-6,
			-4
		],
		[
			-4,
			-13
		],
		[
			-8,
			7
		],
		[
			0,
			17
		],
		[
			-9,
			7
		],
		[
			-1,
			13
		],
		[
			6,
			2
		],
		[
			1,
			13
		],
		[
			-6,
			-6
		],
		[
			-7,
			4
		],
		[
			-1,
			17
		],
		[
			11,
			-2
		],
		[
			-1,
			9
		],
		[
			-6,
			-4
		],
		[
			-5,
			21
		],
		[
			-13,
			14
		],
		[
			9,
			8
		],
		[
			1,
			26
		],
		[
			3,
			6
		],
		[
			-5,
			9
		],
		[
			0,
			44
		],
		[
			10,
			11
		],
		[
			-11,
			13
		],
		[
			-3,
			13
		],
		[
			21,
			-4
		],
		[
			6,
			-13
		],
		[
			5,
			5
		],
		[
			-10,
			27
		],
		[
			-1,
			-6
		],
		[
			-21,
			1
		],
		[
			-2,
			12
		],
		[
			9,
			-2
		],
		[
			-7,
			11
		],
		[
			6,
			12
		],
		[
			5,
			0
		],
		[
			6,
			11
		],
		[
			-6,
			2
		],
		[
			-3,
			12
		],
		[
			-11,
			0
		],
		[
			-1,
			-5
		],
		[
			-11,
			14
		],
		[
			4,
			11
		],
		[
			-13,
			-16
		],
		[
			2,
			-11
		],
		[
			-6,
			-3
		],
		[
			-4,
			19
		],
		[
			13,
			13
		],
		[
			3,
			10
		],
		[
			12,
			11
		],
		[
			0,
			11
		],
		[
			14,
			3
		],
		[
			6,
			-14
		],
		[
			-1,
			-8
		],
		[
			7,
			-4
		],
		[
			-7,
			-18
		],
		[
			4,
			-3
		],
		[
			5,
			16
		],
		[
			4,
			49
		],
		[
			8,
			10
		],
		[
			-3,
			20
		],
		[
			4,
			-1
		],
		[
			14,
			13
		],
		[
			1,
			15
		],
		[
			-14,
			13
		],
		[
			4,
			39
		],
		[
			-1,
			17
		],
		[
			9,
			12
		],
		[
			-3,
			14
		],
		[
			0,
			18
		],
		[
			5,
			2
		],
		[
			-3,
			15
		],
		[
			5,
			3
		],
		[
			4,
			-15
		],
		[
			0,
			27
		],
		[
			-8,
			-3
		],
		[
			-4,
			6
		],
		[
			8,
			12
		],
		[
			-10,
			13
		],
		[
			-3,
			-13
		],
		[
			-12,
			-6
		],
		[
			-7,
			4
		],
		[
			2,
			7
		],
		[
			-5,
			11
		],
		[
			-2,
			27
		],
		[
			5,
			20
		],
		[
			1,
			37
		],
		[
			9,
			7
		],
		[
			4,
			19
		],
		[
			1,
			19
		],
		[
			-9,
			38
		],
		[
			2,
			30
		],
		[
			-6,
			26
		],
		[
			1,
			22
		],
		[
			9,
			-3
		],
		[
			5,
			16
		],
		[
			0,
			18
		],
		[
			4,
			-4
		],
		[
			5,
			42
		],
		[
			6,
			9
		],
		[
			-1,
			15
		],
		[
			6,
			18
		],
		[
			5,
			6
		],
		[
			1,
			15
		],
		[
			4,
			12
		],
		[
			1,
			31
		],
		[
			6,
			21
		],
		[
			4,
			4
		],
		[
			1,
			12
		],
		[
			-4,
			23
		],
		[
			6,
			5
		],
		[
			4,
			37
		],
		[
			-4,
			9
		],
		[
			1,
			25
		],
		[
			-5,
			52
		],
		[
			0,
			24
		],
		[
			2,
			12
		],
		[
			7,
			5
		],
		[
			2,
			44
		],
		[
			-5,
			10
		],
		[
			-1,
			19
		],
		[
			6,
			11
		],
		[
			4,
			20
		],
		[
			0,
			18
		],
		[
			3,
			22
		],
		[
			4,
			2
		],
		[
			-1,
			30
		],
		[
			4,
			5
		],
		[
			2,
			15
		],
		[
			2,
			41
		],
		[
			-2,
			11
		],
		[
			2,
			19
		],
		[
			6,
			8
		],
		[
			-1,
			24
		],
		[
			-2,
			5
		],
		[
			1,
			62
		],
		[
			3,
			17
		],
		[
			-6,
			0
		],
		[
			1,
			25
		],
		[
			6,
			1
		],
		[
			4,
			33
		],
		[
			0,
			23
		],
		[
			2,
			25
		],
		[
			2,
			3
		],
		[
			0,
			24
		],
		[
			-3,
			10
		],
		[
			0,
			37
		],
		[
			2,
			6
		],
		[
			-1,
			31
		],
		[
			-5,
			51
		],
		[
			0,
			21
		],
		[
			-2,
			8
		]
	],
	[
		[
			3044,
			4127
		],
		[
			12,
			4
		],
		[
			4,
			9
		],
		[
			0,
			26
		],
		[
			9,
			9
		]
	],
	[
		[
			8073,
			6343
		],
		[
			8,
			-9
		],
		[
			1,
			-20
		],
		[
			-9,
			-13
		],
		[
			-7,
			-43
		],
		[
			-4,
			0
		],
		[
			-5,
			-15
		],
		[
			-9,
			-1
		],
		[
			-2,
			-11
		],
		[
			-14,
			6
		],
		[
			-14,
			12
		],
		[
			-1,
			42
		],
		[
			10,
			19
		],
		[
			8,
			9
		],
		[
			-1,
			10
		],
		[
			7,
			-3
		],
		[
			5,
			9
		],
		[
			8,
			-6
		],
		[
			10,
			10
		],
		[
			8,
			-9
		],
		[
			1,
			13
		]
	],
	[
		[
			8066,
			6398
		],
		[
			4,
			-5
		],
		[
			-8,
			-2
		],
		[
			4,
			7
		]
	],
	[
		[
			8393,
			6916
		],
		[
			2,
			-7
		],
		[
			-8,
			4
		],
		[
			6,
			3
		]
	],
	[
		[
			8386,
			6994
		],
		[
			-10,
			4
		],
		[
			-11,
			15
		],
		[
			6,
			2
		],
		[
			9,
			-11
		],
		[
			8,
			-5
		],
		[
			-2,
			-5
		]
	],
	[
		[
			8689,
			7778
		],
		[
			-2,
			10
		],
		[
			-10,
			6
		],
		[
			-11,
			-7
		]
	],
	[
		[
			8666,
			7787
		],
		[
			-4,
			7
		],
		[
			-12,
			-22
		],
		[
			-11,
			-4
		],
		[
			0,
			-9
		],
		[
			6,
			-40
		],
		[
			-2,
			-28
		],
		[
			3,
			-6
		],
		[
			-5,
			-31
		],
		[
			-19,
			-10
		],
		[
			3,
			-13
		]
	],
	[
		[
			8625,
			7631
		],
		[
			-8,
			13
		],
		[
			0,
			9
		],
		[
			-9,
			7
		],
		[
			-4,
			-13
		],
		[
			-1,
			-19
		],
		[
			-14,
			-5
		],
		[
			-1,
			-10
		],
		[
			-7,
			-10
		],
		[
			-26,
			-3
		],
		[
			8,
			-20
		],
		[
			-3,
			-13
		],
		[
			-30,
			7
		],
		[
			-2,
			12
		],
		[
			-9,
			1
		],
		[
			-12,
			-34
		],
		[
			-9,
			-16
		],
		[
			-6,
			0
		],
		[
			-8,
			-10
		],
		[
			-16,
			-14
		],
		[
			-14,
			-21
		]
	],
	[
		[
			8454,
			7492
		],
		[
			-5,
			-13
		],
		[
			-6,
			-5
		],
		[
			-9,
			3
		],
		[
			-11,
			-3
		],
		[
			-28,
			-28
		],
		[
			-3,
			-9
		],
		[
			-8,
			-11
		],
		[
			-3,
			5
		],
		[
			-7,
			-13
		],
		[
			-10,
			-4
		],
		[
			0,
			12
		],
		[
			15,
			8
		],
		[
			-10,
			29
		],
		[
			6,
			0
		],
		[
			-2,
			11
		],
		[
			12,
			12
		],
		[
			11,
			27
		],
		[
			-3,
			13
		],
		[
			-22,
			14
		],
		[
			-12,
			-7
		],
		[
			0,
			-7
		],
		[
			-10,
			-13
		],
		[
			-4,
			-16
		],
		[
			-14,
			-7
		],
		[
			-17,
			-19
		],
		[
			-1,
			-19
		],
		[
			-10,
			-15
		],
		[
			-10,
			0
		],
		[
			-7,
			-8
		],
		[
			-11,
			11
		],
		[
			-6,
			-6
		],
		[
			-5,
			-28
		],
		[
			5,
			-14
		],
		[
			10,
			-13
		],
		[
			14,
			-4
		],
		[
			7,
			5
		],
		[
			12,
			-25
		],
		[
			-7,
			-1
		],
		[
			-2,
			-21
		],
		[
			10,
			-12
		],
		[
			13,
			1
		],
		[
			2,
			11
		],
		[
			10,
			10
		],
		[
			3,
			9
		],
		[
			12,
			10
		],
		[
			11,
			-8
		],
		[
			0,
			-6
		],
		[
			9,
			-7
		],
		[
			34,
			-4
		],
		[
			-7,
			-15
		],
		[
			3,
			-13
		],
		[
			-9,
			-5
		],
		[
			-5,
			9
		],
		[
			-28,
			-23
		],
		[
			-6,
			3
		],
		[
			4,
			-11
		],
		[
			-7,
			-1
		],
		[
			0,
			-17
		],
		[
			-11,
			-5
		],
		[
			2,
			8
		],
		[
			-8,
			2
		],
		[
			2,
			-13
		],
		[
			-7,
			-22
		],
		[
			-8,
			-4
		],
		[
			-7,
			-26
		],
		[
			-5,
			-3
		],
		[
			1,
			-16
		],
		[
			12,
			-14
		],
		[
			17,
			-12
		],
		[
			6,
			-38
		],
		[
			11,
			-36
		],
		[
			-1,
			-21
		],
		[
			15,
			-16
		],
		[
			0,
			-13
		],
		[
			11,
			-10
		],
		[
			4,
			-16
		],
		[
			-8,
			1
		],
		[
			-9,
			9
		],
		[
			-10,
			-3
		],
		[
			-4,
			11
		],
		[
			-11,
			2
		],
		[
			-5,
			-7
		],
		[
			-7,
			4
		],
		[
			-3,
			16
		],
		[
			-6,
			2
		],
		[
			3,
			-11
		],
		[
			11,
			-13
		],
		[
			16,
			4
		],
		[
			2,
			-9
		],
		[
			7,
			-5
		],
		[
			8,
			-15
		],
		[
			9,
			-9
		],
		[
			6,
			-12
		],
		[
			2,
			-13
		],
		[
			-9,
			-2
		],
		[
			-12,
			-10
		],
		[
			-8,
			-11
		],
		[
			-5,
			-15
		],
		[
			6,
			-2
		],
		[
			6,
			9
		],
		[
			6,
			-1
		],
		[
			8,
			-19
		],
		[
			13,
			-6
		],
		[
			-13,
			-19
		],
		[
			7,
			5
		],
		[
			0,
			-22
		],
		[
			-4,
			-6
		],
		[
			-5,
			3
		],
		[
			1,
			-27
		],
		[
			-5,
			-3
		],
		[
			5,
			-23
		],
		[
			-5,
			2
		],
		[
			-4,
			-10
		],
		[
			-3,
			12
		],
		[
			-9,
			-28
		],
		[
			-8,
			-17
		],
		[
			-3,
			-23
		],
		[
			-6,
			-4
		],
		[
			-1,
			-11
		],
		[
			-9,
			-7
		],
		[
			-1,
			-8
		],
		[
			-5,
			9
		],
		[
			-4,
			-6
		],
		[
			5,
			-6
		],
		[
			2,
			-11
		],
		[
			-5,
			4
		],
		[
			2,
			-10
		],
		[
			-5,
			-15
		],
		[
			5,
			-3
		],
		[
			-3,
			-18
		],
		[
			-4,
			0
		],
		[
			6,
			-17
		],
		[
			-11,
			10
		],
		[
			-4,
			-8
		],
		[
			5,
			-14
		],
		[
			-9,
			1
		],
		[
			-3,
			-9
		],
		[
			3,
			-10
		],
		[
			-10,
			0
		],
		[
			4,
			-9
		],
		[
			-3,
			-8
		],
		[
			-6,
			3
		],
		[
			-5,
			-5
		],
		[
			-2,
			8
		],
		[
			-5,
			-13
		],
		[
			3,
			-11
		],
		[
			-5,
			-4
		],
		[
			-1,
			-10
		],
		[
			-6,
			-1
		],
		[
			-7,
			-13
		],
		[
			-4,
			1
		],
		[
			-5,
			-14
		],
		[
			-6,
			5
		],
		[
			0,
			-9
		],
		[
			-10,
			-21
		],
		[
			-1,
			-10
		],
		[
			-6,
			1
		],
		[
			-13,
			-12
		],
		[
			-7,
			6
		],
		[
			0,
			-11
		],
		[
			-14,
			8
		],
		[
			-5,
			-13
		],
		[
			-6,
			11
		],
		[
			-5,
			-7
		],
		[
			4,
			-8
		],
		[
			-4,
			-3
		],
		[
			-2,
			9
		],
		[
			-5,
			-3
		]
	],
	[
		[
			8172,
			6482
		],
		[
			-4,
			-2
		]
	],
	[
		[
			8168,
			6480
		],
		[
			-7,
			-3
		],
		[
			-2,
			17
		],
		[
			-3,
			-1
		],
		[
			-2,
			15
		],
		[
			-6,
			-8
		],
		[
			6,
			-17
		],
		[
			0,
			-15
		],
		[
			-2,
			-9
		],
		[
			-10,
			20
		],
		[
			7,
			-19
		],
		[
			-10,
			-14
		],
		[
			-5,
			1
		],
		[
			-13,
			-12
		],
		[
			-10,
			3
		],
		[
			-11,
			-15
		],
		[
			-25,
			-8
		],
		[
			-3,
			-10
		],
		[
			-6,
			-1
		],
		[
			-7,
			-13
		],
		[
			5,
			-7
		],
		[
			-1,
			-13
		],
		[
			7,
			-9
		],
		[
			-4,
			-10
		],
		[
			-13,
			-2
		],
		[
			-1,
			10
		],
		[
			-7,
			25
		],
		[
			3,
			28
		],
		[
			5,
			0
		],
		[
			0,
			8
		],
		[
			-8,
			1
		],
		[
			-2,
			14
		],
		[
			-1,
			-16
		],
		[
			-12,
			1
		],
		[
			0,
			6
		],
		[
			-9,
			2
		],
		[
			-9,
			13
		],
		[
			2,
			-16
		],
		[
			-6,
			7
		],
		[
			0,
			-8
		],
		[
			-9,
			-5
		]
	],
	[
		[
			7999,
			6420
		],
		[
			-7,
			10
		],
		[
			-9,
			-4
		],
		[
			-12,
			14
		],
		[
			1,
			6
		],
		[
			-10,
			2
		],
		[
			0,
			14
		],
		[
			-4,
			7
		],
		[
			0,
			14
		],
		[
			5,
			0
		],
		[
			0,
			16
		],
		[
			-14,
			0
		],
		[
			-18,
			12
		],
		[
			-7,
			14
		],
		[
			-14,
			-13
		],
		[
			1,
			-9
		],
		[
			-14,
			-14
		],
		[
			-3,
			8
		],
		[
			-6,
			-8
		],
		[
			0,
			-9
		],
		[
			-11,
			16
		],
		[
			-4,
			-12
		],
		[
			-5,
			11
		],
		[
			-7,
			-21
		],
		[
			-5,
			10
		],
		[
			-13,
			9
		],
		[
			-4,
			-20
		],
		[
			-3,
			0
		]
	],
	[
		[
			7836,
			6473
		],
		[
			-13,
			3
		],
		[
			-4,
			-12
		],
		[
			1,
			-10
		],
		[
			5,
			-15
		],
		[
			0,
			-39
		],
		[
			-5,
			6
		],
		[
			-9,
			-2
		],
		[
			-2,
			20
		]
	],
	[
		[
			7809,
			6424
		],
		[
			-2,
			12
		],
		[
			-7,
			-6
		],
		[
			-3,
			-8
		],
		[
			-8,
			-4
		],
		[
			-2,
			5
		],
		[
			-5,
			-6
		],
		[
			-2,
			13
		],
		[
			-4,
			3
		],
		[
			-1,
			19
		],
		[
			-14,
			5
		],
		[
			-6,
			-1
		],
		[
			0,
			16
		],
		[
			4,
			5
		],
		[
			-1,
			14
		],
		[
			6,
			11
		],
		[
			-5,
			13
		],
		[
			-8,
			-2
		],
		[
			-7,
			5
		],
		[
			2,
			6
		],
		[
			-6,
			40
		],
		[
			6,
			9
		],
		[
			-9,
			-3
		],
		[
			-13,
			1
		],
		[
			-14,
			-14
		],
		[
			-2,
			5
		],
		[
			5,
			10
		],
		[
			-1,
			18
		],
		[
			-4,
			0
		],
		[
			0,
			17
		],
		[
			7,
			8
		],
		[
			-2,
			12
		],
		[
			4,
			11
		],
		[
			2,
			-3
		],
		[
			6,
			10
		],
		[
			0,
			13
		],
		[
			6,
			-3
		],
		[
			3,
			13
		],
		[
			7,
			6
		],
		[
			-4,
			6
		],
		[
			5,
			33
		],
		[
			0,
			29
		],
		[
			-2,
			31
		],
		[
			-7,
			4
		],
		[
			-1,
			-9
		],
		[
			-7,
			20
		],
		[
			0,
			16
		],
		[
			-8,
			13
		],
		[
			-9,
			9
		],
		[
			-5,
			-18
		]
	],
	[
		[
			7703,
			6808
		],
		[
			-7,
			9
		],
		[
			-4,
			-3
		],
		[
			-7,
			15
		],
		[
			-7,
			1
		],
		[
			5,
			6
		],
		[
			-4,
			17
		],
		[
			-9,
			21
		],
		[
			-12,
			-9
		],
		[
			-6,
			0
		],
		[
			-6,
			-9
		],
		[
			-9,
			4
		],
		[
			-9,
			11
		],
		[
			-8,
			-6
		],
		[
			-3,
			-16
		],
		[
			-9,
			-6
		],
		[
			-6,
			-8
		],
		[
			-7,
			-1
		],
		[
			-9,
			-16
		],
		[
			-12,
			-14
		],
		[
			0,
			-11
		],
		[
			-9,
			-9
		],
		[
			-12,
			-5
		],
		[
			-8,
			2
		]
	],
	[
		[
			7468,
			6756
		],
		[
			-4,
			12
		],
		[
			3,
			18
		],
		[
			-1,
			10
		],
		[
			-6,
			5
		],
		[
			-13,
			-14
		]
	],
	[
		[
			7447,
			6787
		],
		[
			-8,
			2
		],
		[
			-4,
			-5
		],
		[
			-15,
			1
		],
		[
			-3,
			7
		],
		[
			-14,
			9
		],
		[
			-4,
			-11
		],
		[
			-9,
			10
		],
		[
			-3,
			-11
		],
		[
			-2,
			13
		],
		[
			-6,
			7
		],
		[
			-16,
			3
		],
		[
			2,
			17
		],
		[
			-4,
			3
		],
		[
			-7,
			-6
		],
		[
			-9,
			11
		],
		[
			-7,
			12
		],
		[
			-2,
			16
		],
		[
			-5,
			5
		],
		[
			-13,
			-7
		],
		[
			-9,
			26
		],
		[
			-9,
			2
		],
		[
			-9,
			15
		],
		[
			-10,
			8
		],
		[
			-1,
			15
		],
		[
			-14,
			5
		],
		[
			-11,
			-23
		],
		[
			-7,
			11
		]
	],
	[
		[
			7248,
			6922
		],
		[
			-11,
			15
		],
		[
			-10,
			6
		],
		[
			1,
			9
		],
		[
			-14,
			15
		],
		[
			-4,
			-3
		],
		[
			-9,
			13
		],
		[
			-5,
			16
		],
		[
			-9,
			-8
		],
		[
			-2,
			12
		],
		[
			4,
			5
		],
		[
			-4,
			7
		],
		[
			2,
			15
		],
		[
			-9,
			14
		],
		[
			-2,
			20
		],
		[
			9,
			4
		],
		[
			6,
			-16
		],
		[
			10,
			8
		],
		[
			7,
			13
		],
		[
			-5,
			14
		],
		[
			0,
			12
		],
		[
			-7,
			3
		],
		[
			-8,
			16
		],
		[
			-3,
			33
		],
		[
			8,
			8
		],
		[
			0,
			7
		],
		[
			-10,
			12
		],
		[
			-9,
			5
		],
		[
			-8,
			41
		],
		[
			1,
			9
		],
		[
			-7,
			0
		]
	],
	[
		[
			7160,
			7227
		],
		[
			-18,
			1
		],
		[
			-11,
			8
		]
	],
	[
		[
			7131,
			7236
		],
		[
			-5,
			6
		],
		[
			0,
			8
		],
		[
			-13,
			-4
		],
		[
			-4,
			10
		],
		[
			1,
			27
		],
		[
			-7,
			15
		],
		[
			-9,
			1
		],
		[
			0,
			7
		],
		[
			-8,
			7
		],
		[
			-7,
			-2
		],
		[
			-9,
			4
		]
	],
	[
		[
			7080,
			7327
		],
		[
			7,
			10
		],
		[
			-8,
			13
		],
		[
			3,
			7
		],
		[
			-5,
			17
		],
		[
			-1,
			26
		],
		[
			-12,
			9
		],
		[
			-6,
			0
		],
		[
			-2,
			-9
		],
		[
			-6,
			3
		],
		[
			-4,
			16
		],
		[
			4,
			9
		],
		[
			-6,
			12
		],
		[
			1,
			14
		]
	],
	[
		[
			7045,
			7454
		],
		[
			8,
			8
		],
		[
			-3,
			9
		],
		[
			4,
			18
		],
		[
			11,
			3
		],
		[
			10,
			14
		],
		[
			3,
			10
		],
		[
			11,
			-4
		],
		[
			8,
			11
		],
		[
			4,
			-20
		],
		[
			18,
			4
		],
		[
			9,
			13
		],
		[
			0,
			10
		],
		[
			5,
			15
		],
		[
			18,
			-2
		],
		[
			11,
			5
		],
		[
			5,
			-2
		],
		[
			8,
			19
		],
		[
			26,
			23
		],
		[
			27,
			15
		],
		[
			-1,
			8
		]
	],
	[
		[
			7227,
			7611
		],
		[
			1,
			3
		],
		[
			-3,
			23
		],
		[
			3,
			11
		],
		[
			9,
			6
		],
		[
			-7,
			5
		],
		[
			13,
			6
		],
		[
			-4,
			13
		],
		[
			2,
			7
		],
		[
			-11,
			37
		],
		[
			0,
			32
		],
		[
			5,
			5
		],
		[
			-18,
			8
		],
		[
			7,
			9
		],
		[
			21,
			5
		],
		[
			23,
			13
		],
		[
			3,
			-9
		],
		[
			13,
			3
		],
		[
			7,
			-7
		],
		[
			4,
			17
		],
		[
			-11,
			7
		],
		[
			7,
			21
		],
		[
			9,
			47
		],
		[
			5,
			14
		],
		[
			0,
			14
		],
		[
			24,
			-13
		],
		[
			21,
			1
		],
		[
			4,
			-10
		],
		[
			13,
			13
		],
		[
			7,
			0
		],
		[
			5,
			9
		],
		[
			-4,
			41
		],
		[
			4,
			25
		],
		[
			25,
			10
		],
		[
			4,
			10
		],
		[
			0,
			17
		],
		[
			4,
			6
		],
		[
			12,
			-1
		]
	],
	[
		[
			7424,
			8009
		],
		[
			15,
			5
		]
	],
	[
		[
			7439,
			8014
		],
		[
			-4,
			-17
		],
		[
			9,
			-8
		],
		[
			-2,
			-9
		],
		[
			16,
			-10
		],
		[
			2,
			-12
		],
		[
			14,
			-12
		],
		[
			11,
			1
		],
		[
			7,
			-11
		],
		[
			9,
			3
		],
		[
			11,
			-21
		],
		[
			0,
			-11
		],
		[
			15,
			-34
		],
		[
			1,
			-11
		],
		[
			-5,
			-14
		],
		[
			3,
			-17
		],
		[
			-7,
			-13
		],
		[
			-2,
			-16
		],
		[
			6,
			-17
		],
		[
			6,
			2
		],
		[
			16,
			-9
		],
		[
			23,
			-4
		],
		[
			11,
			2
		],
		[
			23,
			-8
		],
		[
			6,
			-13
		],
		[
			7,
			0
		],
		[
			14,
			-19
		],
		[
			9,
			-5
		],
		[
			11,
			2
		],
		[
			-2,
			-16
		],
		[
			6,
			-3
		],
		[
			9,
			-41
		],
		[
			12,
			-19
		],
		[
			2,
			-11
		],
		[
			23,
			4
		],
		[
			63,
			-13
		],
		[
			14,
			6
		],
		[
			49,
			-12
		],
		[
			7,
			-15
		],
		[
			29,
			-11
		],
		[
			18,
			-15
		],
		[
			23,
			7
		],
		[
			0,
			-12
		],
		[
			13,
			-5
		],
		[
			6,
			10
		],
		[
			44,
			30
		],
		[
			36,
			10
		],
		[
			20,
			-3
		],
		[
			20,
			4
		],
		[
			25,
			19
		],
		[
			15,
			29
		],
		[
			18,
			12
		],
		[
			10,
			13
		],
		[
			-9,
			18
		],
		[
			-7,
			23
		],
		[
			11,
			33
		],
		[
			5,
			4
		],
		[
			13,
			-1
		],
		[
			5,
			-10
		],
		[
			14,
			-6
		],
		[
			13,
			-3
		],
		[
			16,
			16
		],
		[
			14,
			24
		],
		[
			6,
			-3
		],
		[
			23,
			5
		],
		[
			15,
			18
		],
		[
			-1,
			7
		],
		[
			11,
			24
		],
		[
			6,
			3
		],
		[
			15,
			-1
		],
		[
			1,
			13
		],
		[
			9,
			-4
		],
		[
			16,
			12
		],
		[
			12,
			-3
		],
		[
			3,
			5
		],
		[
			14,
			-8
		],
		[
			11,
			-1
		],
		[
			5,
			6
		],
		[
			-4,
			23
		],
		[
			-18,
			25
		],
		[
			0,
			6
		],
		[
			-10,
			7
		],
		[
			-6,
			11
		],
		[
			-10,
			5
		],
		[
			-12,
			-3
		]
	],
	[
		[
			8270,
			7946
		],
		[
			-7,
			-13
		]
	],
	[
		[
			8263,
			7933
		],
		[
			-5,
			-6
		],
		[
			-13,
			13
		],
		[
			-17,
			-1
		],
		[
			-11,
			-9
		],
		[
			-7,
			10
		],
		[
			-2,
			13
		],
		[
			8,
			8
		],
		[
			-1,
			12
		],
		[
			25,
			79
		]
	],
	[
		[
			8240,
			8052
		],
		[
			16,
			-12
		],
		[
			14,
			-6
		],
		[
			12,
			9
		],
		[
			13,
			17
		],
		[
			12,
			1
		],
		[
			7,
			6
		],
		[
			1,
			14
		],
		[
			-4,
			6
		],
		[
			8,
			27
		],
		[
			7,
			10
		],
		[
			1,
			11
		],
		[
			8,
			23
		],
		[
			16,
			14
		],
		[
			3,
			17
		],
		[
			-4,
			7
		],
		[
			3,
			13
		],
		[
			-8,
			5
		],
		[
			-12,
			-1
		],
		[
			22,
			37
		],
		[
			12,
			1
		],
		[
			26,
			11
		],
		[
			19,
			0
		],
		[
			11,
			6
		],
		[
			28,
			-11
		],
		[
			4,
			-9
		],
		[
			20,
			-1
		],
		[
			17,
			-13
		],
		[
			23,
			-49
		],
		[
			-3,
			-10
		],
		[
			6,
			-23
		],
		[
			6,
			-9
		],
		[
			1,
			-20
		],
		[
			10,
			-19
		],
		[
			1,
			-23
		],
		[
			7,
			-6
		],
		[
			-2,
			-23
		],
		[
			5,
			-9
		],
		[
			11,
			-7
		],
		[
			20,
			2
		],
		[
			7,
			-14
		],
		[
			13,
			-3
		],
		[
			9,
			-7
		],
		[
			11,
			-17
		],
		[
			12,
			0
		],
		[
			-4,
			-13
		],
		[
			6,
			-8
		],
		[
			2,
			-13
		],
		[
			-4,
			-13
		],
		[
			7,
			-20
		],
		[
			15,
			2
		],
		[
			13,
			-5
		],
		[
			17,
			3
		],
		[
			3,
			9
		],
		[
			12,
			14
		],
		[
			12,
			-1
		],
		[
			6,
			9
		],
		[
			18,
			8
		],
		[
			9,
			-7
		],
		[
			-4,
			-13
		],
		[
			6,
			-17
		],
		[
			-8,
			-19
		],
		[
			-9,
			-6
		],
		[
			-4,
			-38
		],
		[
			-5,
			-13
		],
		[
			2,
			-9
		],
		[
			-11,
			-22
		],
		[
			-1,
			-15
		],
		[
			-8,
			-8
		],
		[
			-2,
			-21
		],
		[
			-8,
			-3
		]
	],
	[
		[
			4913,
			5477
		],
		[
			0,
			-1
		]
	],
	[
		[
			4913,
			5476
		],
		[
			0,
			1
		]
	],
	[
		[
			4925,
			5729
		],
		[
			-2,
			-26
		],
		[
			3,
			-1
		],
		[
			4,
			-47
		],
		[
			-8,
			-15
		],
		[
			-6,
			-39
		],
		[
			-7,
			-28
		],
		[
			2,
			-31
		],
		[
			2,
			-4
		],
		[
			4,
			-31
		],
		[
			5,
			-1
		],
		[
			2,
			-13
		],
		[
			-3,
			-14
		]
	],
	[
		[
			4921,
			5479
		],
		[
			-10,
			3
		],
		[
			-3,
			-4
		],
		[
			-15,
			4
		],
		[
			-5,
			4
		],
		[
			-18,
			3
		],
		[
			-3,
			-9
		],
		[
			16,
			7
		],
		[
			6,
			-3
		],
		[
			-22,
			-5
		],
		[
			-22,
			-3
		],
		[
			-38,
			-25
		],
		[
			-5,
			-8
		],
		[
			-12,
			-10
		]
	],
	[
		[
			4790,
			5433
		],
		[
			-1,
			2
		],
		[
			0,
			41
		],
		[
			5,
			10
		],
		[
			-1,
			33
		],
		[
			-10,
			7
		],
		[
			-1,
			13
		],
		[
			-6,
			7
		],
		[
			-10,
			3
		],
		[
			-6,
			8
		],
		[
			8,
			15
		],
		[
			1,
			23
		],
		[
			-5,
			23
		]
	],
	[
		[
			4764,
			5618
		],
		[
			7,
			-1
		],
		[
			3,
			10
		],
		[
			3,
			27
		],
		[
			-7,
			4
		],
		[
			2,
			14
		],
		[
			7,
			0
		],
		[
			5,
			-7
		],
		[
			2,
			15
		],
		[
			-8,
			9
		],
		[
			1,
			12
		],
		[
			5,
			5
		],
		[
			-5,
			6
		],
		[
			2,
			13
		],
		[
			-5,
			-2
		],
		[
			-3,
			7
		],
		[
			1,
			32
		],
		[
			4,
			6
		]
	],
	[
		[
			4778,
			5768
		],
		[
			4,
			2
		],
		[
			5,
			14
		],
		[
			5,
			1
		],
		[
			3,
			-12
		],
		[
			9,
			-6
		],
		[
			2,
			12
		],
		[
			7,
			-1
		],
		[
			1,
			18
		],
		[
			8,
			-5
		],
		[
			-1,
			8
		],
		[
			5,
			2
		],
		[
			2,
			-15
		],
		[
			-2,
			-13
		],
		[
			6,
			-3
		],
		[
			3,
			9
		],
		[
			11,
			4
		]
	],
	[
		[
			5402,
			5930
		],
		[
			2,
			-13
		],
		[
			7,
			-8
		],
		[
			3,
			-17
		],
		[
			-1,
			-10
		],
		[
			5,
			-3
		],
		[
			2,
			-34
		],
		[
			-2,
			-3
		],
		[
			-1,
			-26
		],
		[
			3,
			-28
		],
		[
			9,
			-22
		],
		[
			6,
			-8
		],
		[
			-7,
			-3
		],
		[
			-9,
			3
		],
		[
			-10,
			-4
		],
		[
			-15,
			3
		],
		[
			-7,
			-19
		],
		[
			11,
			-27
		],
		[
			17,
			-29
		],
		[
			3,
			-1
		],
		[
			8,
			-30
		],
		[
			2,
			-17
		],
		[
			4,
			-2
		],
		[
			-3,
			-16
		]
	],
	[
		[
			5449,
			5312
		],
		[
			-3,
			-5
		],
		[
			2,
			-25
		],
		[
			-18,
			15
		],
		[
			-7,
			3
		],
		[
			-10,
			-2
		],
		[
			-8,
			12
		],
		[
			-9,
			-3
		],
		[
			-27,
			0
		]
	],
	[
		[
			5369,
			5307
		],
		[
			-6,
			5
		],
		[
			-48,
			3
		],
		[
			-1,
			-7
		]
	],
	[
		[
			5314,
			5308
		],
		[
			-38,
			0
		],
		[
			-4,
			10
		]
	],
	[
		[
			5272,
			5318
		],
		[
			0,
			12
		],
		[
			4,
			27
		],
		[
			-1,
			12
		],
		[
			-8,
			18
		],
		[
			-2,
			13
		],
		[
			6,
			11
		],
		[
			-2,
			8
		],
		[
			-10,
			-11
		],
		[
			-10,
			10
		],
		[
			-2,
			29
		],
		[
			-11,
			-4
		],
		[
			2,
			17
		]
	],
	[
		[
			5238,
			5460
		],
		[
			6,
			19
		],
		[
			1,
			41
		],
		[
			4,
			2
		],
		[
			10,
			24
		],
		[
			10,
			13
		],
		[
			2,
			14
		],
		[
			10,
			13
		],
		[
			3,
			-8
		],
		[
			7,
			1
		],
		[
			1,
			9
		],
		[
			8,
			-5
		],
		[
			7,
			-14
		],
		[
			1,
			-16
		],
		[
			7,
			1
		],
		[
			6,
			15
		],
		[
			-1,
			8
		],
		[
			10,
			15
		],
		[
			-2,
			17
		],
		[
			5,
			9
		],
		[
			0,
			9
		],
		[
			5,
			14
		],
		[
			1,
			25
		],
		[
			16,
			23
		],
		[
			2,
			34
		],
		[
			9,
			9
		],
		[
			2,
			17
		],
		[
			-1,
			14
		],
		[
			6,
			5
		],
		[
			3,
			30
		],
		[
			12,
			34
		],
		[
			6,
			-1
		],
		[
			11,
			14
		],
		[
			1,
			37
		],
		[
			-3,
			10
		],
		[
			-10,
			4
		],
		[
			-3,
			40
		]
	],
	[
		[
			5390,
			5936
		],
		[
			7,
			0
		]
	],
	[
		[
			5397,
			5936
		],
		[
			-1,
			-11
		],
		[
			6,
			5
		]
	],
	[
		[
			5398,
			5936
		],
		[
			1,
			0
		]
	],
	[
		[
			5399,
			5936
		],
		[
			-1,
			0
		]
	],
	[
		[
			5944,
			7202
		],
		[
			0,
			0
		]
	],
	[
		[
			5944,
			7202
		],
		[
			-3,
			0
		]
	],
	[
		[
			5941,
			7202
		],
		[
			0,
			0
		]
	],
	[
		[
			5941,
			7202
		],
		[
			3,
			0
		]
	],
	[
		[
			5905,
			7208
		],
		[
			0,
			1
		]
	],
	[
		[
			5905,
			7209
		],
		[
			1,
			0
		]
	],
	[
		[
			5906,
			7209
		],
		[
			1,
			0
		]
	],
	[
		[
			5907,
			7209
		],
		[
			-2,
			-1
		]
	],
	[
		[
			5935,
			7200
		],
		[
			1,
			-2
		]
	],
	[
		[
			5936,
			7198
		],
		[
			-7,
			-1
		],
		[
			-1,
			11
		],
		[
			-17,
			-6
		],
		[
			-3,
			7
		]
	],
	[
		[
			5908,
			7209
		],
		[
			0,
			0
		]
	],
	[
		[
			5908,
			7209
		],
		[
			3,
			-5
		],
		[
			17,
			6
		],
		[
			1,
			-10
		],
		[
			6,
			0
		]
	],
	[
		[
			5807,
			5072
		],
		[
			0,
			-19
		],
		[
			-2,
			6
		],
		[
			2,
			13
		]
	],
	[
		[
			5762,
			5475
		],
		[
			2,
			-10
		],
		[
			7,
			-8
		],
		[
			0,
			-10
		],
		[
			16,
			-18
		],
		[
			12,
			12
		],
		[
			6,
			1
		],
		[
			5,
			-9
		],
		[
			7,
			12
		],
		[
			0,
			6
		],
		[
			10,
			-5
		],
		[
			0,
			-12
		],
		[
			4,
			-3
		],
		[
			7,
			-21
		],
		[
			10,
			-6
		],
		[
			0,
			-14
		],
		[
			6,
			4
		],
		[
			2,
			-10
		]
	],
	[
		[
			5856,
			5384
		],
		[
			2,
			-7
		],
		[
			-5,
			-19
		],
		[
			3,
			-15
		],
		[
			-4,
			-19
		],
		[
			8,
			-3
		],
		[
			8,
			-13
		]
	],
	[
		[
			5868,
			5308
		],
		[
			-10,
			-15
		],
		[
			-12,
			-24
		],
		[
			0,
			-15
		]
	],
	[
		[
			5846,
			5254
		],
		[
			-7,
			-6
		],
		[
			-2,
			-13
		],
		[
			-6,
			-5
		],
		[
			0,
			-21
		],
		[
			-3,
			-7
		],
		[
			-4,
			-25
		]
	],
	[
		[
			5824,
			5177
		],
		[
			-7,
			-9
		],
		[
			-3,
			-12
		],
		[
			1,
			-13
		],
		[
			8,
			12
		]
	],
	[
		[
			5823,
			5155
		],
		[
			-1,
			-6
		],
		[
			-1,
			-46
		]
	],
	[
		[
			5821,
			5103
		],
		[
			-7,
			-8
		],
		[
			-3,
			-9
		]
	],
	[
		[
			5811,
			5086
		],
		[
			-3,
			1
		],
		[
			-7,
			-28
		],
		[
			3,
			-9
		],
		[
			-3,
			-10
		]
	],
	[
		[
			5801,
			5040
		],
		[
			4,
			-14
		]
	],
	[
		[
			5811,
			4991
		],
		[
			-2,
			-3
		],
		[
			-1,
			-49
		],
		[
			4,
			11
		],
		[
			-1,
			-27
		],
		[
			-3,
			-5
		],
		[
			0,
			-30
		],
		[
			7,
			-28
		],
		[
			-1,
			-13
		],
		[
			-4,
			-5
		],
		[
			10,
			-49
		],
		[
			6,
			-14
		],
		[
			6,
			-6
		],
		[
			6,
			-13
		],
		[
			2,
			-29
		],
		[
			7,
			-10
		],
		[
			2,
			-12
		]
	],
	[
		[
			5849,
			4709
		],
		[
			-28,
			-8
		],
		[
			-19,
			-7
		]
	],
	[
		[
			5802,
			4694
		],
		[
			-16,
			-35
		],
		[
			0,
			-23
		],
		[
			4,
			-2
		],
		[
			2,
			9
		]
	],
	[
		[
			5792,
			4643
		],
		[
			4,
			-21
		],
		[
			-1,
			-21
		],
		[
			1,
			-34
		],
		[
			-5,
			-16
		],
		[
			0,
			-10
		],
		[
			-4,
			-17
		],
		[
			4,
			-25
		],
		[
			9,
			-11
		],
		[
			6,
			-17
		],
		[
			14,
			-4
		],
		[
			-2,
			11
		],
		[
			9,
			5
		],
		[
			0,
			-75
		],
		[
			-5,
			1
		],
		[
			-1,
			12
		],
		[
			-10,
			-10
		],
		[
			-7,
			1
		],
		[
			-2,
			14
		],
		[
			-6,
			17
		],
		[
			-4,
			-2
		],
		[
			-1,
			13
		],
		[
			-5,
			13
		],
		[
			-16,
			7
		],
		[
			-6,
			6
		],
		[
			-3,
			16
		],
		[
			-5,
			7
		],
		[
			-1,
			12
		],
		[
			-5,
			0
		],
		[
			-1,
			-16
		],
		[
			-7,
			-8
		],
		[
			-10,
			6
		],
		[
			-11,
			0
		],
		[
			-4,
			7
		],
		[
			-14,
			8
		],
		[
			0,
			26
		],
		[
			-17,
			-7
		],
		[
			-8,
			-8
		],
		[
			-4,
			5
		],
		[
			3,
			14
		],
		[
			-8,
			6
		],
		[
			-4,
			9
		]
	],
	[
		[
			5366,
			4846
		],
		[
			-9,
			2
		],
		[
			-4,
			-10
		],
		[
			-7,
			-3
		],
		[
			-7,
			16
		]
	],
	[
		[
			5363,
			4916
		],
		[
			8,
			-9
		],
		[
			0,
			-6
		],
		[
			8,
			11
		],
		[
			1,
			14
		],
		[
			7,
			-2
		],
		[
			12,
			12
		],
		[
			2,
			-8
		],
		[
			-3,
			-7
		],
		[
			1,
			-20
		],
		[
			9,
			0
		],
		[
			4,
			6
		],
		[
			10,
			27
		],
		[
			8,
			8
		],
		[
			1,
			8
		],
		[
			9,
			4
		],
		[
			10,
			35
		],
		[
			-1,
			29
		],
		[
			1,
			13
		],
		[
			-1,
			26
		],
		[
			12,
			25
		],
		[
			0,
			7
		],
		[
			11,
			30
		],
		[
			8,
			5
		],
		[
			12,
			27
		],
		[
			0,
			21
		],
		[
			3,
			25
		],
		[
			3,
			7
		],
		[
			-2,
			14
		],
		[
			1,
			28
		],
		[
			5,
			27
		],
		[
			-1,
			34
		],
		[
			16,
			57
		],
		[
			0,
			19
		]
	],
	[
		[
			5333,
			4894
		],
		[
			-5,
			13
		],
		[
			0,
			10
		],
		[
			-15,
			33
		],
		[
			-5,
			6
		]
	],
	[
		[
			5308,
			4956
		],
		[
			2,
			12
		],
		[
			8,
			13
		],
		[
			5,
			-10
		],
		[
			5,
			-2
		],
		[
			4,
			22
		],
		[
			-8,
			9
		],
		[
			3,
			10
		],
		[
			-7,
			12
		],
		[
			2,
			7
		],
		[
			-1,
			20
		],
		[
			4,
			-5
		],
		[
			6,
			5
		],
		[
			4,
			-5
		],
		[
			11,
			5
		],
		[
			-1,
			24
		],
		[
			5,
			5
		],
		[
			5,
			-5
		],
		[
			5,
			-26
		],
		[
			11,
			-4
		],
		[
			9,
			13
		],
		[
			1,
			6
		],
		[
			9,
			-22
		],
		[
			5,
			9
		],
		[
			0,
			20
		],
		[
			5,
			5
		],
		[
			1,
			41
		],
		[
			-2,
			10
		],
		[
			3,
			23
		],
		[
			-9,
			9
		],
		[
			-3,
			11
		],
		[
			-5,
			0
		],
		[
			0,
			27
		],
		[
			5,
			19
		],
		[
			5,
			0
		],
		[
			6,
			16
		],
		[
			-5,
			18
		],
		[
			0,
			11
		],
		[
			-14,
			6
		],
		[
			-7,
			-9
		],
		[
			-7,
			-3
		],
		[
			-4,
			22
		],
		[
			2,
			23
		],
		[
			3,
			9
		]
	],
	[
		[
			3018,
			5865
		],
		[
			-19,
			-13
		],
		[
			-7,
			-27
		],
		[
			-6,
			-1
		],
		[
			-7,
			-26
		],
		[
			-5,
			-13
		],
		[
			-2,
			-37
		],
		[
			-11,
			-37
		],
		[
			11,
			7
		],
		[
			1,
			-11
		],
		[
			4,
			2
		],
		[
			4,
			-28
		],
		[
			8,
			-16
		],
		[
			1,
			-19
		],
		[
			-4,
			-7
		],
		[
			1,
			-28
		],
		[
			7,
			-3
		],
		[
			3,
			-18
		],
		[
			7,
			-5
		],
		[
			5,
			4
		],
		[
			18,
			-4
		],
		[
			9,
			7
		],
		[
			10,
			-10
		],
		[
			7,
			-1
		],
		[
			18,
			-46
		],
		[
			5,
			-2
		],
		[
			7,
			8
		],
		[
			11,
			-5
		],
		[
			29,
			8
		],
		[
			4,
			-18
		],
		[
			-6,
			-10
		],
		[
			0,
			-17
		],
		[
			-5,
			-6
		],
		[
			0,
			-66
		],
		[
			5,
			-28
		],
		[
			4,
			-2
		],
		[
			5,
			-17
		],
		[
			-15,
			-35
		],
		[
			7,
			-6
		],
		[
			11,
			-18
		],
		[
			0,
			-12
		],
		[
			4,
			-17
		],
		[
			5,
			-39
		]
	],
	[
		[
			3056,
			4939
		],
		[
			-8,
			22
		],
		[
			-6,
			-2
		],
		[
			-7,
			6
		],
		[
			18,
			59
		],
		[
			0,
			7
		],
		[
			-26,
			25
		],
		[
			-10,
			-10
		],
		[
			-2,
			7
		],
		[
			-8,
			7
		],
		[
			-6,
			-11
		],
		[
			-10,
			-7
		],
		[
			-8,
			6
		],
		[
			-9,
			-5
		],
		[
			-7,
			8
		],
		[
			2,
			12
		],
		[
			-2,
			17
		],
		[
			-10,
			6
		],
		[
			1,
			12
		],
		[
			-4,
			13
		],
		[
			-7,
			3
		],
		[
			-5,
			10
		],
		[
			-5,
			2
		],
		[
			-4,
			26
		],
		[
			-6,
			11
		],
		[
			-5,
			2
		],
		[
			-8,
			14
		],
		[
			-5,
			-2
		]
	],
	[
		[
			2909,
			5177
		],
		[
			-11,
			11
		],
		[
			-3,
			-1
		],
		[
			-7,
			15
		],
		[
			-8,
			7
		],
		[
			-3,
			-12
		],
		[
			-9,
			-1
		],
		[
			-19,
			10
		],
		[
			-1,
			14
		],
		[
			-7,
			11
		],
		[
			-11,
			5
		],
		[
			-13,
			16
		],
		[
			-7,
			13
		]
	],
	[
		[
			2810,
			5265
		],
		[
			-5,
			10
		],
		[
			5,
			13
		],
		[
			7,
			-2
		],
		[
			-3,
			14
		],
		[
			0,
			13
		],
		[
			7,
			19
		],
		[
			10,
			-5
		],
		[
			0,
			9
		],
		[
			9,
			-4
		],
		[
			1,
			22
		],
		[
			12,
			29
		],
		[
			0,
			6
		],
		[
			7,
			20
		],
		[
			-6,
			-5
		],
		[
			-4,
			5
		],
		[
			-1,
			15
		],
		[
			3,
			16
		],
		[
			-2,
			57
		],
		[
			-5,
			2
		],
		[
			9,
			12
		],
		[
			0,
			7
		],
		[
			-7,
			20
		],
		[
			3,
			5
		],
		[
			1,
			19
		],
		[
			-5,
			6
		],
		[
			-3,
			17
		],
		[
			-7,
			14
		]
	],
	[
		[
			2836,
			5599
		],
		[
			2,
			14
		],
		[
			13,
			12
		],
		[
			1,
			13
		],
		[
			4,
			2
		],
		[
			-6,
			28
		],
		[
			-3,
			3
		],
		[
			3,
			11
		]
	],
	[
		[
			2850,
			5682
		],
		[
			12,
			-31
		],
		[
			1,
			-12
		],
		[
			5,
			0
		],
		[
			-1,
			29
		],
		[
			-4,
			10
		],
		[
			7,
			5
		],
		[
			10,
			15
		],
		[
			6,
			23
		],
		[
			12,
			4
		],
		[
			2,
			15
		],
		[
			-3,
			1
		],
		[
			3,
			13
		],
		[
			-1,
			20
		],
		[
			3,
			2
		],
		[
			0,
			16
		],
		[
			8,
			14
		],
		[
			11,
			14
		],
		[
			9,
			-5
		],
		[
			-3,
			-8
		],
		[
			7,
			-4
		],
		[
			4,
			18
		],
		[
			1,
			14
		],
		[
			10,
			-3
		],
		[
			15,
			1
		],
		[
			6,
			12
		],
		[
			10,
			13
		],
		[
			13,
			10
		],
		[
			3,
			11
		],
		[
			-1,
			9
		],
		[
			6,
			1
		],
		[
			12,
			10
		],
		[
			8,
			-6
		],
		[
			3,
			-18
		],
		[
			-6,
			-10
		]
	],
	[
		[
			6235,
			4487
		],
		[
			1,
			-17
		],
		[
			-4,
			8
		],
		[
			3,
			9
		]
	],
	[
		[
			6207,
			4496
		],
		[
			-7,
			9
		],
		[
			1,
			21
		],
		[
			4,
			1
		],
		[
			-1,
			-12
		],
		[
			3,
			-19
		]
	],
	[
		[
			4324,
			6037
		],
		[
			-5,
			9
		],
		[
			5,
			2
		],
		[
			0,
			-11
		]
	],
	[
		[
			4340,
			6065
		],
		[
			8,
			-16
		],
		[
			-5,
			-7
		],
		[
			-4,
			7
		],
		[
			1,
			16
		]
	],
	[
		[
			4365,
			6116
		],
		[
			5,
			-8
		],
		[
			-8,
			-3
		],
		[
			3,
			11
		]
	],
	[
		[
			4303,
			6173
		],
		[
			3,
			-6
		],
		[
			-7,
			-10
		],
		[
			-3,
			11
		],
		[
			7,
			5
		]
	],
	[
		[
			2676,
			5812
		],
		[
			7,
			-32
		],
		[
			16,
			-36
		],
		[
			7,
			-10
		]
	],
	[
		[
			2706,
			5734
		],
		[
			-3,
			-5
		],
		[
			-5,
			7
		],
		[
			-2,
			-8
		],
		[
			0,
			-23
		],
		[
			6,
			-10
		],
		[
			-5,
			-4
		],
		[
			2,
			-19
		],
		[
			-6,
			-11
		],
		[
			4,
			-16
		]
	],
	[
		[
			2697,
			5645
		],
		[
			-2,
			11
		],
		[
			-5,
			9
		],
		[
			0,
			15
		],
		[
			-9,
			5
		],
		[
			5,
			-10
		],
		[
			0,
			-10
		],
		[
			-12,
			12
		],
		[
			3,
			27
		],
		[
			-8,
			14
		],
		[
			-10,
			11
		],
		[
			-11,
			8
		],
		[
			1,
			10
		],
		[
			-12,
			21
		],
		[
			-4,
			-7
		],
		[
			9,
			-12
		],
		[
			-6,
			-16
		],
		[
			-6,
			15
		],
		[
			-10,
			5
		],
		[
			-5,
			19
		],
		[
			1,
			16
		],
		[
			3,
			2
		],
		[
			1,
			15
		],
		[
			-8,
			5
		],
		[
			7,
			2
		],
		[
			0,
			9
		]
	],
	[
		[
			2619,
			5821
		],
		[
			2,
			7
		],
		[
			21,
			-15
		],
		[
			5,
			7
		],
		[
			13,
			-10
		],
		[
			0,
			-5
		],
		[
			8,
			-5
		],
		[
			8,
			5
		],
		[
			0,
			7
		]
	],
	[
		[
			2698,
			6446
		],
		[
			5,
			-3
		],
		[
			4,
			-17
		],
		[
			-10,
			-9
		],
		[
			-8,
			8
		],
		[
			7,
			1
		],
		[
			-4,
			15
		],
		[
			6,
			5
		]
	],
	[
		[
			2836,
			6454
		],
		[
			6,
			-1
		],
		[
			-1,
			-7
		],
		[
			-5,
			8
		]
	],
	[
		[
			2823,
			6481
		],
		[
			-2,
			-7
		],
		[
			-7,
			5
		],
		[
			9,
			2
		]
	],
	[
		[
			2914,
			6329
		],
		[
			-1,
			4
		]
	],
	[
		[
			2913,
			6333
		],
		[
			-1,
			0
		]
	],
	[
		[
			2912,
			6333
		],
		[
			-2,
			-4
		]
	],
	[
		[
			2910,
			6329
		],
		[
			-10,
			-1
		],
		[
			-15,
			6
		],
		[
			-21,
			-3
		],
		[
			-2,
			-3
		],
		[
			-21,
			-3
		],
		[
			6,
			17
		],
		[
			9,
			10
		],
		[
			3,
			9
		],
		[
			-8,
			15
		],
		[
			-19,
			-1
		],
		[
			-13,
			20
		],
		[
			-1,
			18
		],
		[
			-6,
			16
		],
		[
			-14,
			-5
		],
		[
			-10,
			8
		],
		[
			-8,
			0
		],
		[
			-10,
			11
		],
		[
			-5,
			10
		],
		[
			-13,
			-1
		],
		[
			-13,
			8
		],
		[
			-13,
			4
		],
		[
			-7,
			11
		],
		[
			12,
			1
		],
		[
			1,
			7
		],
		[
			-7,
			6
		],
		[
			-25,
			1
		],
		[
			-10,
			-21
		],
		[
			-7,
			-9
		],
		[
			-15,
			0
		],
		[
			-2,
			-15
		],
		[
			-3,
			2
		],
		[
			-11,
			-11
		],
		[
			1,
			10
		],
		[
			-11,
			-3
		],
		[
			10,
			9
		],
		[
			5,
			0
		],
		[
			-2,
			15
		],
		[
			3,
			11
		],
		[
			12,
			15
		],
		[
			14,
			8
		],
		[
			3,
			6
		],
		[
			19,
			3
		],
		[
			9,
			8
		],
		[
			27,
			-2
		],
		[
			3,
			-6
		],
		[
			15,
			2
		],
		[
			6,
			-8
		],
		[
			10,
			1
		],
		[
			11,
			-12
		],
		[
			9,
			-20
		],
		[
			15,
			-1
		],
		[
			13,
			-13
		],
		[
			5,
			-1
		],
		[
			7,
			-16
		],
		[
			12,
			-5
		],
		[
			-3,
			9
		],
		[
			12,
			-16
		],
		[
			5,
			-11
		],
		[
			23,
			-17
		],
		[
			0,
			-5
		],
		[
			12,
			2
		],
		[
			3,
			-6
		],
		[
			-5,
			-10
		],
		[
			2,
			-9
		],
		[
			20,
			1
		],
		[
			7,
			-5
		],
		[
			9,
			-19
		],
		[
			5,
			2
		],
		[
			2,
			-9
		],
		[
			-3,
			-6
		],
		[
			-13,
			0
		],
		[
			-10,
			-9
		]
	],
	[
		[
			3089,
			5876
		],
		[
			-11,
			16
		],
		[
			3,
			2
		],
		[
			8,
			-18
		]
	],
	[
		[
			5905,
			7209
		],
		[
			1,
			0
		]
	],
	[
		[
			5941,
			7202
		],
		[
			-6,
			-2
		]
	],
	[
		[
			5908,
			7209
		],
		[
			6,
			1
		],
		[
			0,
			11
		],
		[
			14,
			-4
		],
		[
			17,
			8
		],
		[
			15,
			13
		],
		[
			0,
			-3
		],
		[
			-19,
			-22
		],
		[
			3,
			-11
		]
	],
	[
		[
			5938,
			7197
		],
		[
			0,
			0
		]
	],
	[
		[
			5938,
			7197
		],
		[
			0,
			0
		]
	],
	[
		[
			5937,
			7198
		],
		[
			0,
			0
		]
	],
	[
		[
			5944,
			7202
		],
		[
			-3,
			-6
		]
	],
	[
		[
			5941,
			7196
		],
		[
			0,
			6
		]
	],
	[
		[
			5936,
			7198
		],
		[
			0,
			-1
		]
	],
	[
		[
			5936,
			7197
		],
		[
			-3,
			-9
		],
		[
			-16,
			-11
		]
	],
	[
		[
			5917,
			7177
		],
		[
			-8,
			1
		]
	],
	[
		[
			5909,
			7178
		],
		[
			-7,
			3
		],
		[
			-5,
			11
		],
		[
			1,
			9
		],
		[
			7,
			7
		]
	],
	[
		[
			5907,
			7209
		],
		[
			1,
			0
		]
	],
	[
		[
			5411,
			8112
		],
		[
			4,
			8
		],
		[
			9,
			-9
		],
		[
			14,
			-7
		],
		[
			6,
			-6
		],
		[
			12,
			-3
		],
		[
			-7,
			-8
		],
		[
			13,
			-20
		],
		[
			10,
			7
		],
		[
			-4,
			12
		],
		[
			9,
			-2
		],
		[
			19,
			-24
		],
		[
			4,
			4
		],
		[
			7,
			-7
		],
		[
			8,
			0
		],
		[
			8,
			-23
		]
	],
	[
		[
			5523,
			8034
		],
		[
			-8,
			-1
		],
		[
			-12,
			-15
		],
		[
			-1,
			-11
		],
		[
			-15,
			-14
		],
		[
			-9,
			4
		],
		[
			-8,
			-15
		]
	],
	[
		[
			5383,
			7990
		],
		[
			-10,
			11
		],
		[
			-13,
			20
		],
		[
			-10,
			9
		],
		[
			-7,
			17
		],
		[
			3,
			13
		],
		[
			-5,
			11
		],
		[
			6,
			13
		],
		[
			26,
			11
		],
		[
			3,
			8
		],
		[
			9,
			1
		],
		[
			13,
			9
		],
		[
			-2,
			8
		],
		[
			15,
			-9
		]
	],
	[
		[
			5255,
			7927
		],
		[
			0,
			0
		]
	],
	[
		[
			5394,
			8289
		],
		[
			0,
			-4
		]
	],
	[
		[
			5394,
			8285
		],
		[
			0,
			4
		]
	],
	[
		[
			5371,
			8330
		],
		[
			6,
			-3
		],
		[
			4,
			-14
		],
		[
			-11,
			-5
		],
		[
			-6,
			4
		],
		[
			1,
			12
		],
		[
			6,
			6
		]
	],
	[
		[
			5262,
			8339
		],
		[
			4,
			3
		],
		[
			12,
			-11
		],
		[
			5,
			-15
		],
		[
			13,
			-5
		],
		[
			11,
			2
		],
		[
			1,
			-9
		],
		[
			-10,
			-8
		],
		[
			12,
			-2
		],
		[
			8,
			-7
		],
		[
			5,
			14
		],
		[
			11,
			2
		],
		[
			14,
			11
		],
		[
			13,
			4
		],
		[
			3,
			-10
		],
		[
			10,
			-8
		],
		[
			6,
			2
		],
		[
			3,
			-17
		],
		[
			13,
			-10
		]
	],
	[
		[
			5396,
			8275
		],
		[
			3,
			-23
		],
		[
			-5,
			-27
		],
		[
			12,
			-14
		],
		[
			-3,
			-9
		],
		[
			7,
			-21
		],
		[
			-4,
			-20
		],
		[
			2,
			-11
		],
		[
			7,
			-4
		],
		[
			2,
			-14
		],
		[
			-6,
			-20
		]
	],
	[
		[
			5269,
			7921
		],
		[
			-15,
			12
		],
		[
			1,
			-6
		]
	],
	[
		[
			5210,
			7923
		],
		[
			-2,
			4
		],
		[
			8,
			55
		],
		[
			9,
			11
		],
		[
			2,
			10
		],
		[
			-16,
			4
		],
		[
			-4,
			7
		],
		[
			-18,
			-1
		],
		[
			-13,
			17
		]
	],
	[
		[
			5176,
			8030
		],
		[
			4,
			20
		],
		[
			-6,
			3
		],
		[
			-5,
			16
		]
	],
	[
		[
			5166,
			8104
		],
		[
			-3,
			14
		],
		[
			9,
			22
		],
		[
			0,
			9
		],
		[
			-8,
			12
		],
		[
			5,
			10
		],
		[
			8,
			-4
		],
		[
			10,
			5
		],
		[
			8,
			28
		],
		[
			-10,
			5
		],
		[
			2,
			9
		],
		[
			8,
			1
		],
		[
			4,
			18
		],
		[
			0,
			16
		]
	],
	[
		[
			5199,
			8249
		],
		[
			-3,
			19
		],
		[
			6,
			6
		],
		[
			21,
			2
		],
		[
			6,
			-18
		],
		[
			0,
			12
		],
		[
			8,
			-4
		],
		[
			2,
			20
		],
		[
			9,
			1
		],
		[
			-8,
			29
		],
		[
			10,
			6
		],
		[
			-9,
			13
		],
		[
			-1,
			9
		]
	],
	[
		[
			5240,
			8344
		],
		[
			22,
			-5
		]
	],
	[
		[
			6201,
			5844
		],
		[
			-9,
			-28
		]
	],
	[
		[
			6192,
			5816
		],
		[
			-6,
			4
		],
		[
			-22,
			-7
		],
		[
			-4,
			8
		]
	],
	[
		[
			6160,
			5821
		],
		[
			0,
			12
		]
	],
	[
		[
			6160,
			5833
		],
		[
			0,
			24
		],
		[
			10,
			22
		],
		[
			7,
			22
		]
	],
	[
		[
			6177,
			5901
		],
		[
			8,
			-6
		],
		[
			3,
			9
		],
		[
			9,
			11
		]
	],
	[
		[
			6197,
			5915
		],
		[
			6,
			-14
		],
		[
			2,
			-25
		],
		[
			-10,
			-14
		],
		[
			-7,
			-3
		],
		[
			-3,
			-11
		],
		[
			13,
			3
		],
		[
			3,
			-7
		]
	],
	[
		[
			3294,
			6081
		],
		[
			4,
			-5
		],
		[
			0,
			-15
		],
		[
			-3,
			-3
		],
		[
			-3,
			16
		],
		[
			2,
			7
		]
	],
	[
		[
			5312,
			8347
		],
		[
			17,
			-10
		],
		[
			-1,
			-7
		],
		[
			-10,
			-1
		],
		[
			-8,
			6
		],
		[
			2,
			12
		]
	],
	[
		[
			5348,
			8350
		],
		[
			-12,
			-5
		],
		[
			4,
			7
		],
		[
			8,
			-2
		]
	],
	[
		[
			5272,
			8355
		],
		[
			7,
			-12
		],
		[
			-8,
			2
		],
		[
			1,
			10
		]
	],
	[
		[
			5413,
			8363
		],
		[
			6,
			-13
		],
		[
			-9,
			3
		],
		[
			3,
			10
		]
	],
	[
		[
			5287,
			8385
		],
		[
			7,
			0
		],
		[
			6,
			-15
		],
		[
			-2,
			-16
		],
		[
			-19,
			1
		],
		[
			-11,
			24
		],
		[
			19,
			6
		]
	],
	[
		[
			5342,
			8415
		],
		[
			7,
			-3
		],
		[
			0,
			-22
		],
		[
			-11,
			-12
		],
		[
			8,
			-11
		],
		[
			-13,
			-8
		],
		[
			5,
			-3
		],
		[
			-8,
			-10
		],
		[
			8,
			-5
		],
		[
			-9,
			-11
		],
		[
			-4,
			32
		],
		[
			-13,
			0
		],
		[
			-2,
			28
		],
		[
			13,
			12
		],
		[
			5,
			-13
		],
		[
			14,
			26
		]
	],
	[
		[
			5247,
			8463
		],
		[
			-2,
			-13
		],
		[
			-9,
			0
		],
		[
			11,
			13
		]
	],
	[
		[
			5240,
			8344
		],
		[
			-2,
			32
		],
		[
			-14,
			7
		],
		[
			3,
			14
		],
		[
			6,
			5
		],
		[
			-4,
			11
		],
		[
			-4,
			-6
		],
		[
			0,
			34
		],
		[
			16,
			1
		],
		[
			7,
			12
		],
		[
			9,
			-10
		],
		[
			-3,
			15
		],
		[
			18,
			12
		],
		[
			-32,
			-9
		],
		[
			-5,
			-13
		],
		[
			-7,
			3
		],
		[
			11,
			20
		],
		[
			17,
			1
		],
		[
			9,
			6
		],
		[
			10,
			19
		],
		[
			20,
			10
		],
		[
			-6,
			-10
		],
		[
			3,
			-20
		],
		[
			-7,
			-15
		],
		[
			2,
			-23
		],
		[
			12,
			-1
		],
		[
			5,
			-6
		],
		[
			-6,
			-16
		],
		[
			-11,
			2
		],
		[
			-4,
			-20
		],
		[
			-20,
			-21
		],
		[
			6,
			-16
		],
		[
			-7,
			-5
		],
		[
			8,
			-8
		],
		[
			-8,
			-10
		]
	],
	[
		[
			3006,
			6222
		],
		[
			2,
			16
		],
		[
			-6,
			10
		]
	],
	[
		[
			3002,
			6248
		],
		[
			0,
			0
		]
	],
	[
		[
			3002,
			6248
		],
		[
			-1,
			2
		]
	],
	[
		[
			3001,
			6250
		],
		[
			-1,
			4
		]
	],
	[
		[
			3000,
			6254
		],
		[
			8,
			11
		],
		[
			-2,
			9
		],
		[
			4,
			12
		],
		[
			-4,
			32
		]
	],
	[
		[
			3006,
			6318
		],
		[
			3,
			11
		],
		[
			14,
			-4
		],
		[
			4,
			6
		],
		[
			11,
			-10
		],
		[
			5,
			1
		],
		[
			4,
			-8
		],
		[
			11,
			0
		],
		[
			4,
			-20
		],
		[
			6,
			2
		],
		[
			11,
			-3
		],
		[
			-2,
			-5
		],
		[
			-11,
			2
		],
		[
			0,
			-8
		],
		[
			24,
			-7
		],
		[
			12,
			-20
		],
		[
			-9,
			-23
		],
		[
			-8,
			11
		],
		[
			-17,
			0
		],
		[
			-9,
			4
		],
		[
			-8,
			-14
		],
		[
			-9,
			-2
		],
		[
			-3,
			12
		],
		[
			-9,
			-8
		],
		[
			-5,
			2
		],
		[
			1,
			-9
		],
		[
			-10,
			-31
		],
		[
			-6,
			8
		],
		[
			-4,
			17
		]
	],
	[
		[
			5238,
			7310
		],
		[
			2,
			-6
		],
		[
			-7,
			-4
		],
		[
			1,
			-6
		],
		[
			-8,
			-8
		],
		[
			6,
			-5
		],
		[
			-4,
			-35
		],
		[
			3,
			-10
		],
		[
			-1,
			-19
		],
		[
			4,
			-5
		],
		[
			-4,
			-8
		],
		[
			-3,
			-30
		],
		[
			-11,
			-11
		],
		[
			-1,
			-9
		],
		[
			-7,
			-8
		],
		[
			-1,
			-14
		],
		[
			7,
			-25
		],
		[
			0,
			-11
		],
		[
			10,
			-7
		],
		[
			6,
			-15
		],
		[
			2,
			-20
		],
		[
			19,
			-24
		],
		[
			7,
			-62
		],
		[
			6,
			-44
		]
	],
	[
		[
			5264,
			6924
		],
		[
			-7,
			-7
		],
		[
			11,
			-29
		],
		[
			5,
			-37
		],
		[
			-2,
			-44
		],
		[
			4,
			-19
		],
		[
			-5,
			-34
		],
		[
			2,
			-21
		],
		[
			3,
			-4
		],
		[
			-2,
			-20
		],
		[
			-10,
			-9
		],
		[
			-3,
			-10
		],
		[
			18,
			-52
		],
		[
			0,
			-25
		],
		[
			5,
			-5
		],
		[
			1,
			-10
		],
		[
			6,
			-6
		],
		[
			7,
			5
		],
		[
			21,
			-13
		],
		[
			3,
			-4
		],
		[
			11,
			-43
		]
	],
	[
		[
			5332,
			6537
		],
		[
			-28,
			-35
		],
		[
			-99,
			-122
		],
		[
			-24,
			-40
		],
		[
			-17,
			-32
		],
		[
			-8,
			-8
		],
		[
			-39,
			-15
		]
	],
	[
		[
			5117,
			6285
		],
		[
			-26,
			-9
		],
		[
			-5,
			7
		],
		[
			4,
			15
		],
		[
			-2,
			11
		],
		[
			1,
			14
		],
		[
			-8,
			8
		],
		[
			-12,
			4
		],
		[
			-9,
			16
		],
		[
			-2,
			-4
		],
		[
			-9,
			5
		],
		[
			-4,
			14
		],
		[
			-14,
			12
		],
		[
			1,
			19
		],
		[
			-14,
			18
		],
		[
			-28,
			40
		],
		[
			-8,
			9
		],
		[
			-36,
			49
		],
		[
			-21,
			30
		],
		[
			-8,
			9
		],
		[
			-51,
			70
		]
	],
	[
		[
			4866,
			6622
		],
		[
			-64,
			78
		],
		[
			-16,
			21
		],
		[
			-28,
			33
		]
	],
	[
		[
			4758,
			6754
		],
		[
			0,
			22
		]
	],
	[
		[
			4758,
			6776
		],
		[
			0,
			59
		],
		[
			12,
			18
		],
		[
			18,
			22
		],
		[
			7,
			0
		],
		[
			8,
			8
		],
		[
			10,
			0
		],
		[
			27,
			5
		],
		[
			6,
			-5
		],
		[
			7,
			21
		],
		[
			11,
			17
		],
		[
			11,
			11
		],
		[
			6,
			11
		],
		[
			17,
			8
		],
		[
			3,
			14
		],
		[
			-8,
			21
		],
		[
			4,
			4
		],
		[
			1,
			15
		],
		[
			23,
			9
		],
		[
			-3,
			14
		],
		[
			12,
			5
		],
		[
			35,
			-3
		],
		[
			0,
			17
		],
		[
			6,
			7
		],
		[
			-11,
			14
		],
		[
			-4,
			11
		],
		[
			2,
			8
		],
		[
			-5,
			10
		],
		[
			2,
			18
		],
		[
			-4,
			8
		],
		[
			2,
			24
		],
		[
			-4,
			15
		],
		[
			3,
			6
		],
		[
			-4,
			7
		],
		[
			2,
			9
		],
		[
			-12,
			19
		]
	],
	[
		[
			4938,
			7203
		],
		[
			8,
			0
		],
		[
			18,
			16
		],
		[
			2,
			12
		],
		[
			11,
			12
		],
		[
			8,
			0
		],
		[
			1,
			7
		],
		[
			6,
			-5
		],
		[
			8,
			2
		],
		[
			5,
			15
		],
		[
			24,
			22
		],
		[
			25,
			4
		],
		[
			10,
			4
		],
		[
			8,
			-2
		],
		[
			11,
			13
		],
		[
			3,
			-4
		],
		[
			12,
			2
		],
		[
			9,
			8
		],
		[
			21,
			-1
		],
		[
			13,
			-7
		],
		[
			8,
			-8
		],
		[
			10,
			11
		],
		[
			14,
			5
		],
		[
			6,
			10
		],
		[
			12,
			-12
		],
		[
			8,
			2
		],
		[
			0,
			9
		],
		[
			9,
			-1
		],
		[
			7,
			-10
		],
		[
			13,
			4
		],
		[
			10,
			-1
		]
	],
	[
		[
			2774,
			5010
		],
		[
			-4,
			-1
		],
		[
			0,
			11
		],
		[
			5,
			9
		],
		[
			5,
			-3
		],
		[
			-6,
			-16
		]
	],
	[
		[
			2519,
			5143
		],
		[
			-4,
			-14
		],
		[
			-5,
			0
		],
		[
			9,
			14
		]
	],
	[
		[
			2493,
			5154
		],
		[
			0,
			-14
		],
		[
			-8,
			2
		],
		[
			1,
			11
		],
		[
			7,
			1
		]
	],
	[
		[
			2459,
			5168
		],
		[
			2,
			-12
		],
		[
			-7,
			2
		],
		[
			-1,
			8
		],
		[
			6,
			2
		]
	],
	[
		[
			2478,
			5174
		],
		[
			6,
			-6
		],
		[
			-5,
			-6
		],
		[
			-4,
			5
		],
		[
			3,
			7
		]
	],
	[
		[
			2463,
			5192
		],
		[
			4,
			-22
		],
		[
			6,
			-11
		],
		[
			-1,
			-9
		],
		[
			6,
			-10
		],
		[
			-4,
			-13
		],
		[
			-13,
			-3
		],
		[
			-3,
			10
		],
		[
			12,
			14
		],
		[
			-9,
			21
		],
		[
			-3,
			18
		],
		[
			5,
			5
		]
	],
	[
		[
			2909,
			5177
		],
		[
			-10,
			0
		],
		[
			6,
			-20
		],
		[
			4,
			-4
		],
		[
			-1,
			-13
		],
		[
			2,
			-13
		],
		[
			-5,
			0
		],
		[
			-4,
			-27
		],
		[
			-15,
			-40
		],
		[
			-16,
			-25
		],
		[
			-33,
			-24
		],
		[
			-9,
			-21
		],
		[
			1,
			-7
		],
		[
			-6,
			5
		],
		[
			-1,
			-22
		],
		[
			-8,
			-31
		],
		[
			-1,
			-17
		],
		[
			-4,
			-3
		],
		[
			-1,
			-12
		],
		[
			-4,
			-7
		],
		[
			-8,
			2
		],
		[
			-5,
			16
		],
		[
			0,
			9
		],
		[
			-8,
			2
		],
		[
			-9,
			11
		],
		[
			-8,
			-11
		],
		[
			-2,
			5
		],
		[
			4,
			10
		],
		[
			-5,
			9
		],
		[
			10,
			10
		],
		[
			-2,
			22
		],
		[
			-3,
			6
		]
	],
	[
		[
			2768,
			4987
		],
		[
			11,
			12
		],
		[
			6,
			40
		],
		[
			-3,
			5
		],
		[
			-4,
			-11
		],
		[
			-1,
			15
		],
		[
			-7,
			-22
		],
		[
			-11,
			18
		],
		[
			-7,
			5
		],
		[
			5,
			13
		],
		[
			-1,
			22
		],
		[
			-2,
			5
		],
		[
			2,
			15
		],
		[
			-4,
			19
		],
		[
			10,
			7
		],
		[
			3,
			21
		],
		[
			-1,
			11
		],
		[
			12,
			24
		],
		[
			1,
			31
		],
		[
			-2,
			13
		],
		[
			12,
			11
		],
		[
			19,
			9
		],
		[
			4,
			15
		]
	],
	[
		[
			5949,
			6986
		],
		[
			2,
			-6
		]
	],
	[
		[
			5951,
			6980
		],
		[
			17,
			-99
		]
	],
	[
		[
			5968,
			6881
		],
		[
			-4,
			-12
		],
		[
			-3,
			-33
		],
		[
			-5,
			-16
		],
		[
			0,
			-26
		],
		[
			-5,
			-14
		],
		[
			-13,
			15
		],
		[
			-6,
			17
		],
		[
			-10,
			16
		],
		[
			-1,
			26
		],
		[
			-8,
			12
		],
		[
			-5,
			14
		],
		[
			-2,
			23
		],
		[
			-4,
			-1
		],
		[
			-4,
			-16
		],
		[
			6,
			-10
		],
		[
			3,
			-16
		],
		[
			0,
			-14
		],
		[
			4,
			-6
		],
		[
			14,
			-42
		],
		[
			5,
			-5
		],
		[
			5,
			-36
		],
		[
			4,
			-4
		],
		[
			5,
			-25
		],
		[
			0,
			-11
		],
		[
			11,
			-43
		],
		[
			15,
			-51
		],
		[
			8,
			-35
		],
		[
			15,
			-29
		],
		[
			-8,
			3
		],
		[
			2,
			-41
		],
		[
			3,
			-16
		],
		[
			6,
			-13
		],
		[
			10,
			-6
		],
		[
			2,
			-8
		],
		[
			16,
			-29
		]
	],
	[
		[
			6024,
			6449
		],
		[
			-78,
			0
		],
		[
			-73,
			0
		],
		[
			0,
			14
		],
		[
			-6,
			-14
		],
		[
			-57,
			0
		],
		[
			-71,
			0
		],
		[
			-46,
			0
		]
	],
	[
		[
			5693,
			6449
		],
		[
			0,
			421
		],
		[
			-3,
			10
		],
		[
			-1,
			24
		],
		[
			-4,
			13
		],
		[
			6,
			20
		],
		[
			3,
			17
		],
		[
			-4,
			22
		],
		[
			0,
			14
		],
		[
			8,
			16
		]
	],
	[
		[
			5698,
			7006
		],
		[
			1,
			-7
		],
		[
			7,
			-2
		],
		[
			12,
			7
		],
		[
			14,
			-6
		],
		[
			27,
			-8
		],
		[
			1,
			-7
		],
		[
			8,
			-5
		],
		[
			5,
			4
		],
		[
			4,
			-9
		],
		[
			21,
			-6
		],
		[
			8,
			-9
		],
		[
			13,
			7
		],
		[
			16,
			22
		],
		[
			4,
			-4
		],
		[
			4,
			14
		],
		[
			3,
			-3
		],
		[
			11,
			6
		],
		[
			-9,
			-10
		],
		[
			9,
			2
		],
		[
			7,
			11
		],
		[
			13,
			-9
		],
		[
			8,
			5
		],
		[
			-3,
			-15
		],
		[
			7,
			-4
		],
		[
			1,
			-7
		],
		[
			6,
			2
		],
		[
			0,
			9
		],
		[
			6,
			-10
		],
		[
			7,
			-4
		],
		[
			31,
			7
		],
		[
			9,
			9
		]
	],
	[
		[
			6111,
			6097
		],
		[
			3,
			-11
		],
		[
			8,
			-6
		],
		[
			-12,
			2
		],
		[
			-2,
			8
		],
		[
			3,
			7
		]
	],
	[
		[
			6177,
			5901
		],
		[
			-6,
			15
		],
		[
			-8,
			12
		],
		[
			-5,
			18
		],
		[
			-14,
			19
		],
		[
			-7,
			23
		],
		[
			-5,
			10
		],
		[
			-10,
			7
		],
		[
			-5,
			9
		],
		[
			-9,
			-1
		],
		[
			-10,
			9
		],
		[
			-10,
			-6
		],
		[
			-5,
			10
		],
		[
			-3,
			-8
		],
		[
			-13,
			-5
		],
		[
			-6,
			16
		],
		[
			-3,
			-1
		],
		[
			-6,
			12
		],
		[
			-9,
			-45
		],
		[
			-6,
			19
		],
		[
			-5,
			1
		],
		[
			-2,
			-8
		],
		[
			-10,
			1
		],
		[
			-6,
			-4
		]
	],
	[
		[
			6014,
			6004
		],
		[
			-3,
			51
		],
		[
			6,
			17
		],
		[
			1,
			18
		],
		[
			3,
			5
		],
		[
			5,
			24
		],
		[
			-2,
			23
		],
		[
			3,
			6
		],
		[
			-1,
			17
		],
		[
			12,
			-2
		],
		[
			3,
			17
		],
		[
			21,
			13
		],
		[
			5,
			18
		],
		[
			5,
			9
		]
	],
	[
		[
			6072,
			6220
		],
		[
			9,
			-35
		],
		[
			0,
			-9
		],
		[
			6,
			-31
		],
		[
			1,
			-24
		],
		[
			3,
			-23
		],
		[
			4,
			-4
		],
		[
			0,
			-17
		],
		[
			5,
			-2
		],
		[
			2,
			-22
		],
		[
			4,
			-1
		],
		[
			-2,
			18
		],
		[
			3,
			4
		],
		[
			6,
			-7
		],
		[
			0,
			-17
		],
		[
			6,
			-8
		],
		[
			3,
			5
		],
		[
			6,
			-3
		],
		[
			3,
			-12
		],
		[
			12,
			-6
		],
		[
			12,
			-31
		],
		[
			2,
			-9
		],
		[
			9,
			-6
		],
		[
			3,
			-12
		],
		[
			3,
			1
		],
		[
			4,
			-13
		],
		[
			1,
			-13
		],
		[
			4,
			2
		],
		[
			6,
			-13
		],
		[
			0,
			-8
		],
		[
			10,
			-9
		]
	],
	[
		[
			5941,
			7196
		],
		[
			-3,
			1
		]
	],
	[
		[
			5938,
			7197
		],
		[
			-2,
			0
		]
	],
	[
		[
			4503,
			6784
		],
		[
			-3,
			-9
		],
		[
			-5,
			3
		],
		[
			8,
			6
		]
	],
	[
		[
			4571,
			6803
		],
		[
			1,
			-17
		],
		[
			-5,
			-6
		],
		[
			-6,
			6
		],
		[
			2,
			19
		],
		[
			8,
			-2
		]
	],
	[
		[
			4552,
			6828
		],
		[
			-7,
			-11
		],
		[
			-2,
			-14
		],
		[
			-7,
			-8
		],
		[
			-6,
			21
		],
		[
			12,
			4
		],
		[
			4,
			8
		],
		[
			6,
			0
		]
	],
	[
		[
			4604,
			6803
		],
		[
			7,
			35
		],
		[
			5,
			-4
		],
		[
			-4,
			-26
		],
		[
			-8,
			-5
		]
	],
	[
		[
			4503,
			6844
		],
		[
			4,
			-7
		],
		[
			-3,
			-16
		],
		[
			-4,
			14
		],
		[
			3,
			9
		]
	],
	[
		[
			4626,
			6861
		],
		[
			0,
			-6
		],
		[
			-9,
			-10
		],
		[
			-1,
			11
		],
		[
			10,
			5
		]
	],
	[
		[
			4919,
			7214
		],
		[
			-1,
			3
		]
	],
	[
		[
			4918,
			7217
		],
		[
			1,
			-3
		]
	],
	[
		[
			4851,
			7247
		],
		[
			-1,
			5
		]
	],
	[
		[
			4850,
			7252
		],
		[
			1,
			-5
		]
	],
	[
		[
			5043,
			7435
		],
		[
			2,
			-6
		],
		[
			-6,
			-9
		],
		[
			-6,
			2
		],
		[
			10,
			13
		]
	],
	[
		[
			5088,
			7483
		],
		[
			0,
			-11
		],
		[
			8,
			0
		],
		[
			-7,
			-23
		],
		[
			-4,
			-6
		],
		[
			-8,
			7
		],
		[
			-3,
			10
		],
		[
			-9,
			0
		],
		[
			9,
			14
		],
		[
			14,
			9
		]
	],
	[
		[
			5114,
			7490
		],
		[
			6,
			-11
		],
		[
			-3,
			-3
		],
		[
			-12,
			12
		],
		[
			9,
			2
		]
	],
	[
		[
			5055,
			7627
		],
		[
			0,
			0
		]
	],
	[
		[
			4950,
			7681
		],
		[
			11,
			-8
		],
		[
			1,
			-9
		],
		[
			16,
			-8
		],
		[
			6,
			-11
		],
		[
			6,
			3
		],
		[
			8,
			-7
		],
		[
			20,
			0
		],
		[
			0,
			9
		],
		[
			18,
			-7
		],
		[
			3,
			-7
		]
	],
	[
		[
			5047,
			7630
		],
		[
			8,
			-9
		],
		[
			8,
			4
		],
		[
			6,
			-5
		],
		[
			12,
			8
		],
		[
			7,
			-3
		]
	],
	[
		[
			5088,
			7625
		],
		[
			4,
			-5
		],
		[
			-6,
			-6
		],
		[
			3,
			-18
		],
		[
			-4,
			-6
		],
		[
			-23,
			-20
		],
		[
			-3,
			-10
		],
		[
			-17,
			-6
		],
		[
			-15,
			-8
		],
		[
			-8,
			-13
		],
		[
			5,
			-6
		],
		[
			-8,
			-7
		],
		[
			-7,
			-18
		],
		[
			-8,
			-14
		],
		[
			-11,
			-32
		],
		[
			3,
			-21
		],
		[
			6,
			-15
		],
		[
			7,
			-7
		],
		[
			-21,
			-22
		],
		[
			-9,
			-36
		],
		[
			4,
			-6
		],
		[
			-19,
			-4
		],
		[
			-12,
			-20
		],
		[
			-2,
			-15
		],
		[
			-7,
			-12
		],
		[
			-5,
			6
		],
		[
			-7,
			-1
		],
		[
			-3,
			-8
		],
		[
			-6,
			4
		],
		[
			-42,
			-1
		],
		[
			-7,
			-13
		],
		[
			-15,
			-5
		],
		[
			-4,
			-16
		]
	],
	[
		[
			4851,
			7264
		],
		[
			0,
			0
		]
	],
	[
		[
			4851,
			7264
		],
		[
			-6,
			-7
		],
		[
			-14,
			11
		],
		[
			-9,
			24
		],
		[
			-2,
			18
		],
		[
			-12,
			13
		],
		[
			-14,
			2
		]
	],
	[
		[
			4794,
			7325
		],
		[
			-3,
			18
		],
		[
			7,
			27
		],
		[
			6,
			2
		],
		[
			3,
			10
		],
		[
			-5,
			0
		],
		[
			-6,
			14
		],
		[
			1,
			17
		],
		[
			6,
			6
		],
		[
			3,
			12
		],
		[
			-5,
			3
		],
		[
			-5,
			22
		],
		[
			-6,
			12
		],
		[
			14,
			0
		],
		[
			4,
			14
		],
		[
			-4,
			17
		],
		[
			7,
			8
		],
		[
			-1,
			30
		],
		[
			-3,
			6
		],
		[
			8,
			16
		],
		[
			6,
			4
		],
		[
			6,
			14
		],
		[
			-10,
			6
		],
		[
			0,
			16
		],
		[
			-16,
			2
		],
		[
			-2,
			-7
		],
		[
			-11,
			-3
		],
		[
			-3,
			3
		],
		[
			-13,
			-3
		],
		[
			3,
			13
		],
		[
			-4,
			6
		],
		[
			-15,
			-10
		]
	],
	[
		[
			4756,
			7600
		],
		[
			-4,
			7
		],
		[
			8,
			12
		],
		[
			-7,
			6
		],
		[
			1,
			13
		],
		[
			-6,
			-4
		],
		[
			1,
			10
		],
		[
			-7,
			18
		],
		[
			12,
			17
		],
		[
			5,
			-3
		],
		[
			11,
			5
		],
		[
			-2,
			4
		],
		[
			13,
			17
		],
		[
			6,
			2
		],
		[
			13,
			-13
		],
		[
			36,
			2
		],
		[
			14,
			-2
		],
		[
			17,
			-9
		],
		[
			16,
			0
		],
		[
			17,
			6
		],
		[
			3,
			-6
		],
		[
			11,
			-2
		],
		[
			10,
			4
		],
		[
			16,
			-8
		],
		[
			10,
			5
		]
	],
	[
		[
			5628,
			8557
		],
		[
			8,
			2
		],
		[
			12,
			-10
		],
		[
			-17,
			-13
		],
		[
			-15,
			-4
		],
		[
			-10,
			7
		],
		[
			0,
			13
		],
		[
			22,
			5
		]
	],
	[
		[
			5631,
			8581
		],
		[
			8,
			-10
		],
		[
			-15,
			-8
		],
		[
			-3,
			11
		],
		[
			-9,
			4
		],
		[
			19,
			3
		]
	],
	[
		[
			5778,
			8608
		],
		[
			4,
			-7
		]
	],
	[
		[
			5782,
			8601
		],
		[
			-5,
			-1
		]
	],
	[
		[
			5777,
			8600
		],
		[
			3,
			-1
		]
	],
	[
		[
			5780,
			8599
		],
		[
			-7,
			-9
		]
	],
	[
		[
			5773,
			8590
		],
		[
			-4,
			-10
		]
	],
	[
		[
			5769,
			8580
		],
		[
			-12,
			1
		],
		[
			-9,
			-8
		],
		[
			13,
			-28
		],
		[
			6,
			-22
		]
	],
	[
		[
			5767,
			8523
		],
		[
			5,
			-8
		],
		[
			-7,
			-3
		],
		[
			-6,
			-16
		]
	],
	[
		[
			5759,
			8496
		],
		[
			-14,
			5
		],
		[
			-8,
			-6
		],
		[
			-15,
			19
		],
		[
			-26,
			13
		],
		[
			-21,
			-12
		]
	],
	[
		[
			5675,
			8515
		],
		[
			7,
			26
		],
		[
			-10,
			-3
		],
		[
			-13,
			5
		],
		[
			-6,
			13
		],
		[
			-3,
			20
		],
		[
			6,
			3
		],
		[
			-5,
			14
		],
		[
			18,
			5
		],
		[
			6,
			10
		],
		[
			30,
			1
		],
		[
			8,
			10
		],
		[
			35,
			-13
		],
		[
			27,
			-2
		],
		[
			3,
			4
		]
	],
	[
		[
			6160,
			5833
		],
		[
			0,
			-12
		]
	],
	[
		[
			6192,
			5816
		],
		[
			-8,
			-22
		],
		[
			5,
			-23
		],
		[
			5,
			-13
		],
		[
			6,
			-8
		],
		[
			1,
			-13
		],
		[
			4,
			-12
		],
		[
			5,
			-4
		],
		[
			12,
			-21
		],
		[
			51,
			-34
		],
		[
			31,
			-23
		],
		[
			28,
			0
		]
	],
	[
		[
			6332,
			5643
		],
		[
			-21,
			-43
		],
		[
			-31,
			-61
		],
		[
			-14,
			-31
		],
		[
			-14,
			-34
		],
		[
			-5,
			-9
		],
		[
			-27,
			3
		],
		[
			-20,
			-14
		],
		[
			-8,
			-12
		],
		[
			-1,
			-8
		],
		[
			-9,
			-7
		],
		[
			-12,
			-2
		],
		[
			-7,
			-13
		]
	],
	[
		[
			6163,
			5412
		],
		[
			-19,
			-3
		],
		[
			-3,
			2
		],
		[
			-9,
			19
		],
		[
			-26,
			-24
		],
		[
			-8,
			-27
		],
		[
			-25,
			12
		],
		[
			-15,
			0
		],
		[
			-7,
			11
		],
		[
			-28,
			36
		],
		[
			-23,
			1
		],
		[
			-3,
			10
		]
	],
	[
		[
			5997,
			5449
		],
		[
			-4,
			8
		],
		[
			0,
			27
		],
		[
			-2,
			9
		],
		[
			-11,
			-2
		],
		[
			-1,
			9
		],
		[
			-5,
			7
		],
		[
			-3,
			12
		],
		[
			0,
			13
		],
		[
			-4,
			11
		],
		[
			-3,
			24
		],
		[
			-6,
			5
		],
		[
			0,
			8
		],
		[
			-6,
			4
		],
		[
			-7,
			24
		],
		[
			-9,
			16
		],
		[
			-19,
			8
		],
		[
			-1,
			9
		],
		[
			5,
			9
		],
		[
			0,
			17
		],
		[
			12,
			3
		],
		[
			2,
			-5
		],
		[
			7,
			3
		],
		[
			5,
			9
		],
		[
			-1,
			50
		]
	],
	[
		[
			5946,
			5727
		],
		[
			4,
			33
		],
		[
			3,
			9
		],
		[
			-1,
			22
		],
		[
			7,
			18
		],
		[
			6,
			-7
		],
		[
			5,
			5
		],
		[
			0,
			25
		],
		[
			4,
			16
		],
		[
			-1,
			14
		],
		[
			6,
			8
		],
		[
			2,
			12
		],
		[
			11,
			31
		],
		[
			11,
			1
		],
		[
			0,
			19
		],
		[
			3,
			19
		],
		[
			6,
			24
		],
		[
			2,
			28
		]
	],
	[
		[
			5634,
			8649
		],
		[
			-3,
			-11
		],
		[
			-9,
			9
		],
		[
			12,
			2
		]
	],
	[
		[
			5804,
			9158
		],
		[
			-14,
			-7
		],
		[
			8,
			-9
		],
		[
			-8,
			-12
		],
		[
			7,
			-21
		],
		[
			18,
			-7
		],
		[
			18,
			-21
		],
		[
			-2,
			-10
		],
		[
			-23,
			-30
		],
		[
			-1,
			-9
		],
		[
			13,
			-20
		],
		[
			11,
			-25
		],
		[
			5,
			-23
		],
		[
			-10,
			-1
		],
		[
			2,
			-32
		],
		[
			-7,
			-6
		],
		[
			6,
			-11
		],
		[
			9,
			-1
		],
		[
			-2,
			-23
		],
		[
			14,
			-8
		],
		[
			1,
			-11
		],
		[
			-17,
			-18
		],
		[
			14,
			-16
		],
		[
			21,
			-15
		],
		[
			9,
			-17
		],
		[
			-9,
			-24
		],
		[
			-25,
			-28
		],
		[
			-15,
			-23
		],
		[
			-18,
			-22
		],
		[
			-10,
			-7
		],
		[
			-27,
			-31
		]
	],
	[
		[
			5772,
			8670
		],
		[
			-31,
			-8
		],
		[
			-19,
			-2
		],
		[
			-8,
			-8
		],
		[
			-15,
			0
		],
		[
			-6,
			-6
		],
		[
			-38,
			-11
		],
		[
			-10,
			-6
		],
		[
			-10,
			17
		],
		[
			3,
			10
		],
		[
			-12,
			-6
		],
		[
			2,
			10
		],
		[
			-10,
			0
		],
		[
			-12,
			14
		],
		[
			-5,
			-7
		],
		[
			-8,
			8
		],
		[
			-2,
			23
		],
		[
			5,
			3
		],
		[
			3,
			23
		],
		[
			-5,
			25
		],
		[
			-5,
			3
		],
		[
			3,
			22
		],
		[
			-6,
			2
		],
		[
			3,
			27
		],
		[
			13,
			9
		],
		[
			-5,
			12
		],
		[
			11,
			-3
		],
		[
			13,
			8
		],
		[
			-5,
			9
		],
		[
			17,
			9
		],
		[
			3,
			10
		],
		[
			13,
			6
		],
		[
			10,
			18
		],
		[
			17,
			18
		],
		[
			5,
			16
		],
		[
			25,
			8
		],
		[
			-4,
			14
		],
		[
			2,
			17
		],
		[
			-33,
			19
		]
	],
	[
		[
			5671,
			8973
		],
		[
			-15,
			37
		],
		[
			10,
			20
		],
		[
			-12,
			20
		],
		[
			5,
			16
		],
		[
			-7,
			26
		],
		[
			5,
			3
		],
		[
			-23,
			26
		],
		[
			-21,
			5
		],
		[
			-41,
			32
		]
	],
	[
		[
			5572,
			9158
		],
		[
			12,
			1
		],
		[
			7,
			14
		],
		[
			10,
			-2
		],
		[
			21,
			-31
		],
		[
			22,
			-6
		],
		[
			20,
			12
		],
		[
			27,
			-15
		],
		[
			7,
			13
		],
		[
			18,
			12
		],
		[
			-1,
			17
		],
		[
			6,
			22
		],
		[
			15,
			15
		],
		[
			16,
			-2
		],
		[
			22,
			10
		],
		[
			17,
			-16
		],
		[
			18,
			-7
		],
		[
			6,
			-12
		],
		[
			-14,
			-14
		],
		[
			3,
			-11
		]
	],
	[
		[
			9954,
			4093
		],
		[
			-5,
			-13
		],
		[
			-7,
			0
		],
		[
			12,
			13
		]
	],
	[
		[
			9951,
			4184
		],
		[
			0,
			-5
		],
		[
			9,
			-12
		],
		[
			2,
			-26
		],
		[
			-10,
			-2
		],
		[
			-3,
			-6
		],
		[
			-10,
			-2
		],
		[
			-15,
			11
		],
		[
			-1,
			12
		],
		[
			5,
			7
		],
		[
			-2,
			6
		],
		[
			7,
			12
		],
		[
			18,
			5
		]
	],
	[
		[
			0,
			4252
		],
		[
			9987,
			-23
		],
		[
			-2,
			-11
		],
		[
			4,
			2
		],
		[
			7,
			14
		],
		[
			0,
			-17
		],
		[
			-16,
			-2
		],
		[
			-1,
			7
		],
		[
			-11,
			-10
		],
		[
			-4,
			-9
		],
		[
			-7,
			15
		],
		[
			12,
			16
		],
		[
			13,
			4
		],
		[
			2,
			8
		],
		[
			-9984,
			6
		]
	],
	[
		[
			3351,
			2225
		],
		[
			4,
			-3
		],
		[
			-17,
			-28
		],
		[
			-11,
			-4
		],
		[
			-4,
			-11
		],
		[
			-8,
			-4
		],
		[
			-11,
			12
		],
		[
			16,
			3
		],
		[
			-4,
			17
		],
		[
			12,
			1
		],
		[
			-13,
			15
		],
		[
			11,
			-5
		],
		[
			9,
			6
		],
		[
			15,
			-3
		],
		[
			1,
			4
		]
	],
	[
		[
			3368,
			2227
		],
		[
			7,
			2
		],
		[
			4,
			-8
		],
		[
			12,
			3
		],
		[
			4,
			-18
		],
		[
			-17,
			-11
		],
		[
			-16,
			0
		],
		[
			8,
			-4
		],
		[
			-12,
			-6
		],
		[
			1,
			-10
		],
		[
			-11,
			5
		],
		[
			3,
			-11
		],
		[
			-9,
			12
		],
		[
			6,
			17
		],
		[
			13,
			11
		],
		[
			-3,
			14
		],
		[
			10,
			4
		]
	],
	[
		[
			6541,
			3981
		],
		[
			5,
			-2
		],
		[
			5,
			-13
		],
		[
			-1,
			-13
		],
		[
			-7,
			-1
		],
		[
			-6,
			6
		],
		[
			-4,
			14
		],
		[
			8,
			9
		]
	],
	[
		[
			6252,
			4454
		],
		[
			4,
			-5
		],
		[
			-1,
			-13
		],
		[
			-3,
			-1
		],
		[
			0,
			19
		]
	],
	[
		[
			3483,
			5317
		],
		[
			7,
			10
		],
		[
			4,
			16
		],
		[
			2,
			29
		],
		[
			4,
			19
		],
		[
			-10,
			24
		],
		[
			-3,
			26
		],
		[
			-1,
			25
		],
		[
			4,
			16
		],
		[
			5,
			9
		]
	],
	[
		[
			3495,
			5491
		],
		[
			3,
			5
		],
		[
			3,
			18
		],
		[
			12,
			-10
		],
		[
			11,
			-4
		],
		[
			6,
			-6
		],
		[
			10,
			-19
		],
		[
			22,
			-31
		],
		[
			3,
			-18
		],
		[
			-1,
			-11
		]
	],
	[
		[
			3306,
			6034
		],
		[
			4,
			-11
		],
		[
			-1,
			-7
		],
		[
			-9,
			13
		],
		[
			1,
			11
		],
		[
			5,
			-6
		]
	],
	[
		[
			3288,
			6120
		],
		[
			2,
			-14
		],
		[
			-4,
			-5
		],
		[
			-3,
			22
		],
		[
			5,
			-3
		]
	],
	[
		[
			3295,
			6124
		],
		[
			5,
			-5
		],
		[
			-9,
			-3
		],
		[
			1,
			18
		],
		[
			3,
			-10
		]
	],
	[
		[
			5262,
			7641
		],
		[
			2,
			-7
		],
		[
			1,
			-27
		],
		[
			-4,
			-7
		],
		[
			-2,
			-24
		],
		[
			-7,
			-9
		],
		[
			-8,
			9
		],
		[
			3,
			8
		],
		[
			-7,
			3
		],
		[
			2,
			19
		],
		[
			-5,
			15
		],
		[
			3,
			10
		],
		[
			13,
			13
		],
		[
			6,
			-1
		],
		[
			3,
			16
		],
		[
			0,
			-18
		]
	],
	[
		[
			5160,
			8036
		],
		[
			5,
			-6
		],
		[
			11,
			0
		]
	],
	[
		[
			5172,
			7849
		],
		[
			16,
			7
		]
	],
	[
		[
			5195,
			7827
		],
		[
			-7,
			-5
		],
		[
			5,
			-18
		],
		[
			5,
			-6
		],
		[
			-2,
			-11
		],
		[
			-13,
			-6
		],
		[
			3,
			-11
		],
		[
			8,
			-5
		],
		[
			1,
			-9
		],
		[
			-6,
			-11
		],
		[
			4,
			-14
		],
		[
			10,
			-7
		],
		[
			9,
			3
		],
		[
			-4,
			-22
		]
	],
	[
		[
			5208,
			7705
		],
		[
			-2,
			-3
		]
	],
	[
		[
			5206,
			7702
		],
		[
			-2,
			-1
		]
	],
	[
		[
			5204,
			7701
		],
		[
			-11,
			-10
		],
		[
			-9,
			-23
		],
		[
			-14,
			-6
		],
		[
			-22,
			9
		],
		[
			0,
			7
		],
		[
			-15,
			1
		],
		[
			-7,
			6
		],
		[
			-11,
			0
		],
		[
			-5,
			6
		],
		[
			-13,
			-17
		],
		[
			-10,
			-6
		],
		[
			-3,
			-9
		],
		[
			0,
			-26
		],
		[
			4,
			-8
		]
	],
	[
		[
			4950,
			7681
		],
		[
			9,
			13
		],
		[
			6,
			48
		],
		[
			-1,
			11
		],
		[
			4,
			49
		],
		[
			11,
			-11
		],
		[
			0,
			8
		],
		[
			-14,
			16
		],
		[
			3,
			6
		],
		[
			1,
			26
		],
		[
			-20,
			14
		],
		[
			-9,
			18
		],
		[
			4,
			14
		],
		[
			-5,
			12
		],
		[
			-8,
			1
		],
		[
			-3,
			15
		],
		[
			-6,
			-3
		],
		[
			-11,
			11
		],
		[
			-18,
			6
		],
		[
			-4,
			6
		],
		[
			-11,
			-5
		],
		[
			0,
			7
		],
		[
			-9,
			7
		],
		[
			12,
			5
		],
		[
			-14,
			12
		],
		[
			1,
			13
		],
		[
			10,
			6
		],
		[
			22,
			0
		],
		[
			2,
			9
		],
		[
			12,
			2
		],
		[
			10,
			-20
		],
		[
			12,
			9
		],
		[
			16,
			-4
		],
		[
			4,
			8
		],
		[
			-1,
			28
		],
		[
			-6,
			8
		],
		[
			0,
			18
		],
		[
			16,
			0
		],
		[
			-1,
			-11
		],
		[
			5,
			-6
		],
		[
			30,
			-4
		],
		[
			8,
			7
		],
		[
			-5,
			3
		],
		[
			2,
			11
		],
		[
			10,
			9
		],
		[
			18,
			7
		],
		[
			11,
			15
		],
		[
			0,
			37
		],
		[
			10,
			8
		],
		[
			17,
			4
		]
	],
	[
		[
			4800,
			8771
		],
		[
			13,
			-21
		],
		[
			-14,
			13
		],
		[
			1,
			8
		]
	],
	[
		[
			4808,
			8772
		],
		[
			9,
			-11
		],
		[
			-11,
			3
		],
		[
			2,
			8
		]
	],
	[
		[
			9394,
			5584
		],
		[
			3,
			-9
		],
		[
			-4,
			-1
		],
		[
			1,
			10
		]
	],
	[
		[
			5308,
			4956
		],
		[
			-3,
			13
		],
		[
			-10,
			15
		],
		[
			0,
			9
		],
		[
			-17,
			28
		],
		[
			-8,
			19
		],
		[
			7,
			-8
		],
		[
			5,
			3
		],
		[
			-8,
			8
		],
		[
			-7,
			1
		],
		[
			-2,
			13
		],
		[
			-9,
			21
		],
		[
			1,
			10
		],
		[
			8,
			2
		],
		[
			-2,
			7
		],
		[
			-4,
			-5
		],
		[
			-9,
			16
		],
		[
			-1,
			11
		],
		[
			-6,
			18
		],
		[
			5,
			6
		],
		[
			2,
			-7
		],
		[
			2,
			12
		],
		[
			6,
			13
		],
		[
			1,
			14
		],
		[
			-1,
			27
		],
		[
			2,
			-7
		],
		[
			11,
			-2
		],
		[
			-8,
			7
		],
		[
			-5,
			19
		],
		[
			9,
			-6
		],
		[
			-2,
			24
		],
		[
			3,
			7
		],
		[
			4,
			-4
		]
	],
	[
		[
			5272,
			5240
		],
		[
			6,
			1
		],
		[
			36,
			-1
		],
		[
			0,
			68
		]
	],
	[
		[
			4964,
			8107
		],
		[
			6,
			-6
		],
		[
			-7,
			-6
		],
		[
			-6,
			6
		],
		[
			7,
			6
		]
	],
	[
		[
			4883,
			8252
		],
		[
			-4,
			-10
		],
		[
			-6,
			16
		],
		[
			10,
			-6
		]
	],
	[
		[
			4825,
			8298
		],
		[
			-11,
			-2
		],
		[
			-8,
			20
		],
		[
			-10,
			-17
		],
		[
			-14,
			5
		],
		[
			-9,
			13
		],
		[
			11,
			10
		],
		[
			-5,
			6
		],
		[
			11,
			2
		],
		[
			8,
			19
		]
	],
	[
		[
			4798,
			8354
		],
		[
			20,
			10
		],
		[
			13,
			-2
		],
		[
			0,
			-8
		],
		[
			18,
			-35
		],
		[
			-7,
			-6
		],
		[
			-11,
			-19
		],
		[
			-6,
			4
		]
	],
	[
		[
			4857,
			8375
		],
		[
			-7,
			14
		],
		[
			7,
			-1
		],
		[
			0,
			-13
		]
	],
	[
		[
			4830,
			8398
		],
		[
			2,
			-9
		],
		[
			-7,
			-6
		],
		[
			-6,
			6
		],
		[
			1,
			10
		],
		[
			10,
			-1
		]
	],
	[
		[
			4839,
			8409
		],
		[
			-5,
			-13
		],
		[
			-4,
			6
		],
		[
			9,
			7
		]
	],
	[
		[
			4832,
			8443
		],
		[
			11,
			-10
		],
		[
			-2,
			-5
		],
		[
			-18,
			-4
		],
		[
			7,
			10
		],
		[
			-7,
			5
		],
		[
			9,
			4
		]
	],
	[
		[
			4795,
			8489
		],
		[
			3,
			-18
		],
		[
			-4,
			1
		],
		[
			1,
			17
		]
	],
	[
		[
			4800,
			8503
		],
		[
			1,
			-8
		],
		[
			-10,
			7
		],
		[
			9,
			1
		]
	],
	[
		[
			4824,
			8506
		],
		[
			5,
			-20
		],
		[
			14,
			-6
		],
		[
			-9,
			-6
		],
		[
			-10,
			1
		],
		[
			-13,
			15
		],
		[
			11,
			5
		],
		[
			2,
			11
		]
	],
	[
		[
			4827,
			8543
		],
		[
			-5,
			-20
		],
		[
			-16,
			-15
		],
		[
			3,
			11
		],
		[
			-7,
			3
		],
		[
			2,
			15
		],
		[
			23,
			15
		],
		[
			0,
			-9
		]
	],
	[
		[
			4907,
			8560
		],
		[
			9,
			0
		],
		[
			-6,
			-20
		],
		[
			-22,
			-20
		],
		[
			6,
			-7
		],
		[
			-8,
			-14
		],
		[
			22,
			8
		],
		[
			20,
			-3
		],
		[
			16,
			2
		],
		[
			7,
			-13
		],
		[
			-6,
			-9
		],
		[
			-6,
			-24
		],
		[
			-9,
			-18
		],
		[
			-10,
			-8
		],
		[
			8,
			-10
		],
		[
			-21,
			-15
		],
		[
			9,
			-4
		],
		[
			11,
			6
		],
		[
			13,
			-8
		],
		[
			14,
			-19
		],
		[
			4,
			-29
		],
		[
			8,
			-27
		],
		[
			19,
			-9
		],
		[
			4,
			-13
		],
		[
			8,
			-7
		],
		[
			-4,
			-5
		],
		[
			11,
			-24
		],
		[
			-7,
			1
		],
		[
			12,
			-23
		],
		[
			-7,
			-19
		],
		[
			8,
			-7
		],
		[
			5,
			11
		],
		[
			20,
			-2
		],
		[
			11,
			-10
		],
		[
			3,
			-16
		],
		[
			-5,
			-24
		],
		[
			-4,
			0
		],
		[
			-14,
			-26
		],
		[
			-11,
			-12
		],
		[
			12,
			-3
		],
		[
			13,
			1
		],
		[
			-3,
			-14
		],
		[
			-11,
			-13
		],
		[
			-5,
			1
		],
		[
			-14,
			-11
		],
		[
			-12,
			6
		],
		[
			-18,
			-6
		],
		[
			-3,
			7
		],
		[
			-18,
			-7
		],
		[
			-14,
			-1
		],
		[
			2,
			-8
		],
		[
			-27,
			9
		],
		[
			-13,
			-6
		],
		[
			-2,
			-17
		],
		[
			-8,
			-7
		],
		[
			-11,
			10
		],
		[
			-16,
			-3
		],
		[
			-12,
			-21
		],
		[
			-8,
			10
		],
		[
			19,
			25
		],
		[
			7,
			14
		],
		[
			1,
			12
		],
		[
			6,
			-1
		],
		[
			2,
			11
		],
		[
			12,
			3
		],
		[
			11,
			-4
		],
		[
			11,
			2
		],
		[
			8,
			20
		],
		[
			-23,
			-9
		],
		[
			-8,
			12
		],
		[
			-13,
			-3
		],
		[
			0,
			6
		],
		[
			-10,
			3
		],
		[
			-8,
			-7
		],
		[
			-10,
			18
		],
		[
			13,
			6
		],
		[
			20,
			18
		],
		[
			2,
			9
		],
		[
			-2,
			24
		],
		[
			-17,
			-4
		],
		[
			11,
			12
		],
		[
			5,
			11
		],
		[
			27,
			10
		],
		[
			8,
			19
		],
		[
			-4,
			11
		],
		[
			5,
			2
		],
		[
			-1,
			14
		],
		[
			-9,
			-6
		],
		[
			-11,
			23
		],
		[
			9,
			26
		],
		[
			-19,
			-10
		],
		[
			-11,
			5
		],
		[
			1,
			-10
		],
		[
			-13,
			10
		],
		[
			-5,
			-5
		],
		[
			-1,
			21
		],
		[
			11,
			19
		],
		[
			-15,
			29
		],
		[
			-8,
			-15
		],
		[
			-4,
			-23
		],
		[
			-5,
			-1
		],
		[
			3,
			22
		],
		[
			-1,
			18
		],
		[
			5,
			24
		],
		[
			8,
			18
		],
		[
			-12,
			-13
		],
		[
			-5,
			11
		],
		[
			0,
			17
		],
		[
			5,
			10
		],
		[
			-6,
			19
		],
		[
			7,
			25
		],
		[
			12,
			0
		],
		[
			-5,
			20
		],
		[
			11,
			21
		],
		[
			20,
			-6
		],
		[
			26,
			7
		]
	],
	[
		[
			4912,
			8589
		],
		[
			-2,
			-13
		],
		[
			-4,
			10
		],
		[
			6,
			3
		]
	],
	[
		[
			4964,
			8673
		],
		[
			4,
			-27
		],
		[
			-15,
			5
		],
		[
			9,
			7
		],
		[
			2,
			15
		]
	],
	[
		[
			6206,
			7550
		],
		[
			-23,
			27
		],
		[
			-5,
			-9
		],
		[
			-8,
			5
		],
		[
			-9,
			-5
		],
		[
			-8,
			5
		]
	],
	[
		[
			6153,
			7573
		],
		[
			7,
			17
		],
		[
			-8,
			51
		],
		[
			-10,
			6
		],
		[
			-3,
			11
		],
		[
			-21,
			13
		],
		[
			-8,
			10
		]
	],
	[
		[
			6110,
			7681
		],
		[
			2,
			9
		],
		[
			16,
			0
		],
		[
			27,
			-19
		],
		[
			21,
			2
		],
		[
			7,
			-6
		],
		[
			6,
			1
		],
		[
			10,
			-14
		],
		[
			17,
			-9
		],
		[
			-2,
			-8
		],
		[
			6,
			-4
		],
		[
			16,
			12
		],
		[
			7,
			-8
		],
		[
			4,
			8
		],
		[
			11,
			-14
		],
		[
			11,
			0
		],
		[
			-2,
			-18
		],
		[
			8,
			-10
		],
		[
			14,
			-9
		]
	],
	[
		[
			4995,
			5824
		],
		[
			5,
			-3
		],
		[
			-3,
			-26
		],
		[
			10,
			-13
		],
		[
			3,
			-27
		],
		[
			-4,
			-30
		],
		[
			8,
			0
		],
		[
			-2,
			-24
		],
		[
			2,
			-8
		],
		[
			-4,
			-8
		],
		[
			9,
			-19
		],
		[
			-3,
			-11
		],
		[
			0,
			-28
		],
		[
			-3,
			-15
		],
		[
			4,
			-3
		],
		[
			-1,
			-23
		],
		[
			-3,
			-2
		],
		[
			6,
			-28
		],
		[
			8,
			-9
		],
		[
			5,
			-13
		]
	],
	[
		[
			5032,
			5534
		],
		[
			-7,
			-19
		],
		[
			-15,
			1
		],
		[
			-21,
			-17
		],
		[
			-12,
			-16
		],
		[
			-6,
			0
		],
		[
			-6,
			-7
		],
		[
			-11,
			-5
		],
		[
			-10,
			-15
		],
		[
			-7,
			8
		],
		[
			-24,
			12
		]
	],
	[
		[
			4913,
			5477
		],
		[
			8,
			2
		]
	],
	[
		[
			4851,
			7264
		],
		[
			0,
			0
		]
	],
	[
		[
			4683,
			5897
		],
		[
			-3,
			-14
		],
		[
			6,
			-9
		],
		[
			6,
			11
		],
		[
			4,
			0
		],
		[
			8,
			-17
		],
		[
			4,
			13
		],
		[
			5,
			5
		],
		[
			16,
			-11
		],
		[
			2,
			7
		],
		[
			14,
			19
		],
		[
			5,
			-5
		],
		[
			2,
			-20
		],
		[
			3,
			-1
		],
		[
			-1,
			-21
		],
		[
			13,
			-17
		],
		[
			-9,
			-23
		],
		[
			5,
			5
		],
		[
			6,
			-3
		],
		[
			0,
			-28
		],
		[
			9,
			-12
		],
		[
			0,
			-8
		]
	],
	[
		[
			4764,
			5618
		],
		[
			-6,
			8
		],
		[
			-1,
			-12
		],
		[
			-11,
			-17
		],
		[
			-5,
			13
		],
		[
			-4,
			0
		],
		[
			3,
			19
		],
		[
			-5,
			25
		],
		[
			0,
			11
		],
		[
			-8,
			10
		],
		[
			-7,
			-7
		],
		[
			-6,
			3
		]
	],
	[
		[
			4714,
			5671
		],
		[
			-3,
			1
		],
		[
			-5,
			-11
		],
		[
			-3,
			4
		],
		[
			5,
			15
		],
		[
			-3,
			10
		],
		[
			0,
			15
		],
		[
			-4,
			1
		],
		[
			2,
			13
		],
		[
			-15,
			39
		],
		[
			-19,
			0
		],
		[
			-17,
			-7
		],
		[
			-5,
			-26
		],
		[
			-12,
			-21
		],
		[
			-5,
			-1
		]
	],
	[
		[
			4630,
			5703
		],
		[
			4,
			8
		],
		[
			-12,
			23
		],
		[
			0,
			12
		],
		[
			-4,
			-2
		],
		[
			-6,
			13
		],
		[
			-20,
			29
		],
		[
			4,
			20
		],
		[
			-5,
			-10
		],
		[
			-3,
			21
		],
		[
			-4,
			-14
		],
		[
			-2,
			11
		]
	],
	[
		[
			4582,
			5814
		],
		[
			8,
			30
		],
		[
			12,
			8
		],
		[
			16,
			4
		],
		[
			0,
			19
		],
		[
			-6,
			11
		],
		[
			7,
			3
		],
		[
			-1,
			24
		]
	],
	[
		[
			4618,
			5913
		],
		[
			19,
			-3
		],
		[
			-1,
			-8
		],
		[
			17,
			-6
		],
		[
			3,
			-5
		],
		[
			7,
			6
		],
		[
			20,
			0
		]
	],
	[
		[
			4534,
			5935
		],
		[
			-2,
			17
		],
		[
			4,
			7
		],
		[
			8,
			-14
		],
		[
			5,
			5
		],
		[
			-8,
			2
		],
		[
			-1,
			13
		]
	],
	[
		[
			4540,
			5965
		],
		[
			29,
			0
		],
		[
			4,
			12
		],
		[
			7,
			2
		],
		[
			8,
			-5
		],
		[
			2,
			-7
		],
		[
			6,
			1
		],
		[
			4,
			-10
		],
		[
			12,
			7
		],
		[
			3,
			-14
		],
		[
			-15,
			-6
		],
		[
			-5,
			7
		],
		[
			-11,
			6
		],
		[
			-6,
			7
		],
		[
			-1,
			-9
		],
		[
			-5,
			-4
		],
		[
			-12,
			-1
		],
		[
			0,
			-11
		],
		[
			-24,
			1
		],
		[
			-2,
			-6
		]
	],
	[
		[
			4553,
			5826
		],
		[
			1,
			-7
		],
		[
			-6,
			3
		],
		[
			5,
			4
		]
	],
	[
		[
			4582,
			5814
		],
		[
			-1,
			9
		],
		[
			-5,
			-7
		],
		[
			-7,
			20
		],
		[
			5,
			15
		],
		[
			8,
			-2
		],
		[
			-9,
			7
		],
		[
			-2,
			-8
		],
		[
			-3,
			8
		],
		[
			2,
			11
		],
		[
			8,
			-1
		],
		[
			-5,
			6
		],
		[
			-6,
			-7
		],
		[
			-11,
			-6
		],
		[
			3,
			14
		],
		[
			-7,
			-6
		],
		[
			-6,
			6
		],
		[
			1,
			13
		],
		[
			-5,
			-2
		],
		[
			-7,
			9
		]
	],
	[
		[
			4535,
			5893
		],
		[
			14,
			7
		],
		[
			15,
			-1
		],
		[
			13,
			14
		],
		[
			41,
			0
		]
	],
	[
		[
			5272,
			5240
		],
		[
			-3,
			6
		],
		[
			-10,
			3
		],
		[
			3,
			15
		],
		[
			10,
			28
		],
		[
			0,
			26
		]
	],
	[
		[
			5243,
			5399
		],
		[
			5,
			-8
		],
		[
			-8,
			-24
		],
		[
			-6,
			4
		],
		[
			0,
			10
		],
		[
			4,
			1
		],
		[
			1,
			11
		],
		[
			4,
			6
		]
	],
	[
		[
			5663,
			7229
		],
		[
			13,
			-11
		],
		[
			9,
			5
		],
		[
			22,
			-8
		],
		[
			8,
			3
		],
		[
			-1,
			-12
		],
		[
			9,
			6
		],
		[
			7,
			-7
		],
		[
			-2,
			-5
		],
		[
			-25,
			-2
		],
		[
			-16,
			-4
		],
		[
			0,
			9
		],
		[
			-10,
			6
		],
		[
			-24,
			5
		],
		[
			1,
			17
		],
		[
			4,
			5
		],
		[
			5,
			-7
		]
	],
	[
		[
			5756,
			7245
		],
		[
			-1,
			-17
		],
		[
			-3,
			-5
		],
		[
			4,
			22
		]
	],
	[
		[
			5640,
			7268
		],
		[
			-4,
			-2
		],
		[
			0,
			12
		],
		[
			4,
			-10
		]
	],
	[
		[
			5784,
			7281
		],
		[
			-5,
			-19
		],
		[
			-8,
			-12
		],
		[
			-2,
			13
		],
		[
			5,
			13
		],
		[
			10,
			5
		]
	],
	[
		[
			5710,
			7319
		],
		[
			-4,
			-10
		],
		[
			-2,
			10
		],
		[
			6,
			0
		]
	],
	[
		[
			5731,
			7350
		],
		[
			-10,
			-7
		],
		[
			2,
			7
		],
		[
			8,
			0
		]
	],
	[
		[
			5748,
			7357
		],
		[
			-5,
			-6
		],
		[
			-5,
			6
		],
		[
			10,
			0
		]
	],
	[
		[
			5576,
			7363
		],
		[
			5,
			-7
		],
		[
			-4,
			-5
		],
		[
			-5,
			10
		],
		[
			4,
			2
		]
	],
	[
		[
			5690,
			7366
		],
		[
			3,
			-13
		],
		[
			-8,
			16
		],
		[
			5,
			-3
		]
	],
	[
		[
			5571,
			7398
		],
		[
			6,
			-23
		],
		[
			-8,
			2
		],
		[
			-3,
			14
		],
		[
			5,
			7
		]
	],
	[
		[
			5723,
			7405
		],
		[
			3,
			-16
		],
		[
			-4,
			-9
		],
		[
			-5,
			25
		],
		[
			6,
			0
		]
	],
	[
		[
			5651,
			7423
		],
		[
			11,
			-14
		],
		[
			8,
			0
		],
		[
			5,
			-29
		],
		[
			7,
			0
		],
		[
			0,
			-10
		],
		[
			-7,
			1
		],
		[
			-8,
			23
		],
		[
			-11,
			0
		],
		[
			-1,
			9
		],
		[
			-12,
			17
		],
		[
			-9,
			-1
		],
		[
			13,
			12
		],
		[
			4,
			-8
		]
	],
	[
		[
			5733,
			7446
		],
		[
			6,
			-17
		],
		[
			-13,
			0
		],
		[
			4,
			10
		],
		[
			-10,
			-4
		],
		[
			-2,
			8
		],
		[
			13,
			8
		],
		[
			2,
			-5
		]
	],
	[
		[
			5553,
			7474
		],
		[
			-2,
			-18
		],
		[
			-5,
			18
		],
		[
			7,
			0
		]
	],
	[
		[
			5706,
			7488
		],
		[
			-2,
			-14
		],
		[
			-9,
			3
		],
		[
			0,
			9
		],
		[
			11,
			2
		]
	],
	[
		[
			5688,
			7522
		],
		[
			-8,
			1
		],
		[
			4,
			10
		],
		[
			4,
			-11
		]
	],
	[
		[
			5586,
			7536
		],
		[
			18,
			3
		],
		[
			4,
			11
		],
		[
			23,
			3
		],
		[
			5,
			10
		]
	],
	[
		[
			5731,
			7585
		],
		[
			7,
			-8
		],
		[
			1,
			-14
		],
		[
			-8,
			-6
		],
		[
			0,
			-15
		],
		[
			-8,
			-13
		]
	],
	[
		[
			5723,
			7529
		],
		[
			-3,
			5
		],
		[
			-11,
			2
		],
		[
			-11,
			8
		],
		[
			-12,
			-10
		],
		[
			-8,
			6
		],
		[
			-9,
			-12
		],
		[
			-11,
			1
		],
		[
			4,
			-19
		],
		[
			-4,
			-10
		],
		[
			8,
			-6
		],
		[
			-1,
			-11
		],
		[
			-9,
			17
		],
		[
			-8,
			0
		],
		[
			0,
			-6
		],
		[
			10,
			-14
		],
		[
			-9,
			6
		],
		[
			-2,
			14
		],
		[
			-12,
			9
		],
		[
			0,
			14
		],
		[
			-6,
			-6
		],
		[
			-3,
			-28
		],
		[
			8,
			-15
		],
		[
			2,
			-11
		],
		[
			5,
			-6
		],
		[
			7,
			-17
		],
		[
			-11,
			9
		],
		[
			-4,
			-7
		],
		[
			6,
			-16
		],
		[
			-9,
			-6
		],
		[
			17,
			-11
		],
		[
			0,
			-9
		],
		[
			8,
			-2
		],
		[
			13,
			-15
		],
		[
			-2,
			-5
		],
		[
			2,
			-25
		],
		[
			-3,
			-1
		],
		[
			-12,
			22
		],
		[
			-15,
			-11
		],
		[
			5,
			-3
		],
		[
			0,
			-11
		],
		[
			10,
			-10
		],
		[
			-11,
			-8
		],
		[
			-11,
			16
		],
		[
			0,
			-8
		],
		[
			7,
			-21
		],
		[
			3,
			-20
		],
		[
			0,
			-17
		],
		[
			-11,
			22
		],
		[
			-5,
			-6
		],
		[
			-4,
			-14
		],
		[
			0,
			13
		],
		[
			-6,
			19
		],
		[
			-6,
			-1
		],
		[
			0,
			-14
		],
		[
			-7,
			3
		],
		[
			-3,
			13
		],
		[
			3,
			14
		],
		[
			-3,
			15
		],
		[
			-13,
			17
		],
		[
			7,
			16
		],
		[
			7,
			2
		],
		[
			6,
			9
		],
		[
			19,
			-10
		],
		[
			10,
			-12
		],
		[
			9,
			10
		],
		[
			-5,
			6
		],
		[
			-17,
			14
		],
		[
			-1,
			-6
		],
		[
			-12,
			4
		],
		[
			-12,
			-7
		],
		[
			-4,
			8
		],
		[
			-8,
			-4
		],
		[
			-5,
			24
		],
		[
			-4,
			-1
		],
		[
			-1,
			16
		],
		[
			-13,
			20
		],
		[
			-2,
			14
		],
		[
			-5,
			4
		]
	],
	[
		[
			5583,
			7526
		],
		[
			0,
			0
		]
	],
	[
		[
			5582,
			7531
		],
		[
			4,
			5
		]
	],
	[
		[
			3288,
			5876
		],
		[
			-5,
			-2
		],
		[
			5,
			13
		],
		[
			0,
			-11
		]
	],
	[
		[
			3786,
			8632
		],
		[
			-12,
			-4
		],
		[
			4,
			9
		],
		[
			8,
			-5
		]
	],
	[
		[
			3787,
			8645
		],
		[
			3,
			-11
		],
		[
			-11,
			4
		],
		[
			-4,
			10
		],
		[
			12,
			-3
		]
	],
	[
		[
			3846,
			8835
		],
		[
			12,
			-11
		],
		[
			-9,
			0
		],
		[
			-12,
			15
		],
		[
			9,
			-4
		]
	],
	[
		[
			3579,
			8886
		],
		[
			3,
			14
		],
		[
			6,
			-4
		],
		[
			-9,
			-10
		]
	],
	[
		[
			3876,
			8910
		],
		[
			-1,
			-14
		],
		[
			-10,
			26
		],
		[
			11,
			-12
		]
	],
	[
		[
			3961,
			8973
		],
		[
			2,
			-9
		],
		[
			-18,
			-2
		],
		[
			0,
			10
		],
		[
			16,
			1
		]
	],
	[
		[
			3583,
			9209
		],
		[
			9,
			-5
		],
		[
			-9,
			-16
		],
		[
			-11,
			9
		],
		[
			11,
			12
		]
	],
	[
		[
			3535,
			9210
		],
		[
			20,
			-7
		],
		[
			5,
			-10
		],
		[
			-9,
			-9
		],
		[
			-40,
			-14
		],
		[
			-19,
			9
		],
		[
			8,
			9
		],
		[
			-21,
			2
		],
		[
			3,
			11
		],
		[
			-6,
			23
		],
		[
			14,
			9
		],
		[
			30,
			-7
		],
		[
			15,
			-16
		]
	],
	[
		[
			4292,
			9258
		],
		[
			5,
			-6
		],
		[
			-22,
			-8
		],
		[
			-56,
			-5
		],
		[
			5,
			12
		],
		[
			24,
			14
		],
		[
			11,
			0
		],
		[
			27,
			11
		],
		[
			6,
			-18
		]
	],
	[
		[
			3513,
			9274
		],
		[
			-13,
			6
		],
		[
			9,
			10
		],
		[
			4,
			-16
		]
	],
	[
		[
			3537,
			9281
		],
		[
			-14,
			10
		],
		[
			21,
			1
		],
		[
			-7,
			-11
		]
	],
	[
		[
			3472,
			9375
		],
		[
			-13,
			-11
		],
		[
			-4,
			9
		],
		[
			17,
			2
		]
	],
	[
		[
			4335,
			9380
		],
		[
			22,
			-3
		],
		[
			33,
			-25
		],
		[
			-20,
			4
		],
		[
			17,
			-11
		],
		[
			-5,
			-9
		],
		[
			-50,
			20
		],
		[
			-10,
			8
		],
		[
			0,
			15
		],
		[
			13,
			1
		]
	],
	[
		[
			4354,
			9391
		],
		[
			36,
			-8
		],
		[
			-3,
			-13
		],
		[
			-17,
			-1
		],
		[
			-14,
			11
		],
		[
			-38,
			1
		],
		[
			0,
			5
		],
		[
			36,
			5
		]
	],
	[
		[
			4333,
			9407
		],
		[
			21,
			-8
		],
		[
			-47,
			6
		],
		[
			55,
			-12
		],
		[
			-48,
			-4
		],
		[
			-29,
			9
		],
		[
			13,
			12
		],
		[
			35,
			-3
		]
	],
	[
		[
			4418,
			9469
		],
		[
			11,
			-1
		],
		[
			11,
			-14
		],
		[
			-32,
			-5
		],
		[
			-18,
			7
		],
		[
			3,
			8
		],
		[
			25,
			5
		]
	],
	[
		[
			4439,
			9496
		],
		[
			13,
			-2
		],
		[
			-12,
			-10
		],
		[
			-14,
			7
		],
		[
			13,
			5
		]
	],
	[
		[
			4505,
			9520
		],
		[
			-7,
			-8
		],
		[
			21,
			-2
		],
		[
			-15,
			-6
		],
		[
			-30,
			-2
		],
		[
			2,
			17
		],
		[
			29,
			1
		]
	],
	[
		[
			4481,
			9596
		],
		[
			3,
			-41
		],
		[
			-16,
			34
		],
		[
			13,
			7
		]
	],
	[
		[
			2994,
			9643
		],
		[
			23,
			-5
		],
		[
			-21,
			-3
		],
		[
			-2,
			8
		]
	],
	[
		[
			4445,
			9674
		],
		[
			18,
			-11
		],
		[
			-32,
			9
		],
		[
			14,
			2
		]
	],
	[
		[
			4519,
			9788
		],
		[
			-33,
			-16
		],
		[
			-26,
			9
		],
		[
			49,
			14
		],
		[
			10,
			-7
		]
	],
	[
		[
			3575,
			9904
		],
		[
			-53,
			7
		],
		[
			4,
			13
		],
		[
			49,
			-20
		]
	],
	[
		[
			3722,
			9942
		],
		[
			44,
			-15
		],
		[
			-28,
			-11
		],
		[
			-44,
			11
		],
		[
			-20,
			15
		],
		[
			48,
			0
		]
	],
	[
		[
			3880,
			9983
		],
		[
			38,
			-14
		],
		[
			-47,
			9
		],
		[
			9,
			5
		]
	],
	[
		[
			4105,
			9998
		],
		[
			43,
			-1
		],
		[
			139,
			-17
		],
		[
			-12,
			-6
		],
		[
			-116,
			-3
		],
		[
			-142,
			-14
		],
		[
			100,
			5
		],
		[
			47,
			8
		],
		[
			96,
			-4
		],
		[
			39,
			6
		],
		[
			2,
			-18
		],
		[
			34,
			4
		],
		[
			72,
			-17
		],
		[
			-31,
			-17
		],
		[
			-54,
			-4
		],
		[
			-152,
			-7
		],
		[
			-81,
			-17
		],
		[
			1,
			-9
		],
		[
			30,
			8
		],
		[
			107,
			13
		],
		[
			89,
			-4
		],
		[
			-3,
			-12
		],
		[
			-44,
			-9
		],
		[
			-2,
			-11
		],
		[
			85,
			20
		],
		[
			2,
			14
		],
		[
			51,
			4
		],
		[
			11,
			-19
		],
		[
			-7,
			-14
		],
		[
			-56,
			-36
		],
		[
			-16,
			-18
		],
		[
			53,
			26
		],
		[
			58,
			30
		],
		[
			75,
			-8
		],
		[
			37,
			24
		],
		[
			53,
			-1
		],
		[
			57,
			-12
		],
		[
			13,
			-8
		],
		[
			-64,
			-27
		],
		[
			-24,
			0
		],
		[
			7,
			-12
		],
		[
			-31,
			-8
		],
		[
			-46,
			1
		],
		[
			36,
			-15
		],
		[
			-18,
			-11
		],
		[
			-40,
			-3
		],
		[
			-44,
			6
		],
		[
			-25,
			-22
		],
		[
			11,
			-12
		],
		[
			20,
			3
		],
		[
			-9,
			-21
		],
		[
			17,
			-12
		],
		[
			-27,
			-8
		],
		[
			0,
			-11
		],
		[
			-28,
			-2
		],
		[
			-11,
			-42
		],
		[
			-18,
			-22
		],
		[
			18,
			0
		],
		[
			10,
			17
		],
		[
			51,
			-16
		],
		[
			-6,
			-10
		],
		[
			-19,
			10
		],
		[
			-22,
			-2
		],
		[
			38,
			-26
		],
		[
			10,
			6
		],
		[
			21,
			-5
		],
		[
			2,
			-18
		],
		[
			-10,
			-12
		],
		[
			-35,
			13
		],
		[
			-27,
			-3
		],
		[
			-24,
			-13
		],
		[
			-13,
			12
		],
		[
			-14,
			-8
		],
		[
			10,
			-12
		],
		[
			18,
			1
		],
		[
			0,
			-16
		],
		[
			19,
			4
		],
		[
			30,
			-4
		],
		[
			6,
			-11
		],
		[
			-15,
			-4
		],
		[
			21,
			-14
		],
		[
			3,
			-29
		],
		[
			-17,
			-4
		],
		[
			-4,
			9
		],
		[
			-16,
			-2
		],
		[
			-26,
			17
		],
		[
			8,
			-12
		],
		[
			24,
			-14
		],
		[
			-8,
			-27
		],
		[
			30,
			-5
		],
		[
			7,
			6
		],
		[
			13,
			-11
		],
		[
			-18,
			-15
		],
		[
			-16,
			2
		],
		[
			-7,
			11
		],
		[
			-36,
			-2
		],
		[
			-11,
			-18
		],
		[
			9,
			-27
		],
		[
			-2,
			21
		],
		[
			9,
			3
		],
		[
			36,
			-10
		],
		[
			-7,
			-26
		],
		[
			-28,
			3
		],
		[
			-18,
			-14
		],
		[
			-36,
			11
		],
		[
			-14,
			9
		],
		[
			-1,
			13
		],
		[
			-10,
			-16
		],
		[
			-25,
			-4
		],
		[
			-17,
			-16
		],
		[
			24,
			-7
		],
		[
			-16,
			-14
		],
		[
			22,
			-6
		],
		[
			6,
			-12
		],
		[
			-19,
			-7
		],
		[
			21,
			1
		],
		[
			23,
			-15
		],
		[
			33,
			-16
		],
		[
			-17,
			-14
		],
		[
			20,
			9
		],
		[
			14,
			-3
		],
		[
			-17,
			-11
		],
		[
			2,
			-17
		],
		[
			9,
			14
		],
		[
			10,
			-1
		],
		[
			0,
			-35
		],
		[
			8,
			-18
		],
		[
			-13,
			-10
		],
		[
			-11,
			3
		],
		[
			-7,
			22
		],
		[
			-2,
			-22
		],
		[
			-19,
			0
		],
		[
			-16,
			10
		],
		[
			-9,
			27
		],
		[
			-24,
			13
		],
		[
			-15,
			14
		],
		[
			-20,
			5
		],
		[
			-16,
			-3
		],
		[
			-26,
			23
		],
		[
			-16,
			-2
		],
		[
			31,
			-13
		],
		[
			-8,
			-6
		],
		[
			26,
			-8
		],
		[
			25,
			1
		],
		[
			11,
			-12
		],
		[
			-16,
			-13
		],
		[
			-24,
			-7
		],
		[
			-44,
			2
		],
		[
			14,
			-7
		],
		[
			-11,
			-17
		],
		[
			2,
			-11
		],
		[
			40,
			7
		],
		[
			13,
			-6
		],
		[
			-17,
			-3
		],
		[
			-27,
			-14
		],
		[
			-16,
			-3
		],
		[
			34,
			-3
		],
		[
			11,
			16
		],
		[
			15,
			-4
		],
		[
			29,
			13
		],
		[
			23,
			-11
		],
		[
			25,
			-7
		],
		[
			33,
			0
		],
		[
			0,
			-8
		],
		[
			-14,
			0
		],
		[
			-4,
			-12
		],
		[
			-19,
			-2
		],
		[
			1,
			-10
		],
		[
			-13,
			-8
		],
		[
			-17,
			-1
		],
		[
			2,
			-9
		],
		[
			-26,
			-21
		],
		[
			-31,
			-10
		],
		[
			-13,
			-9
		],
		[
			-23,
			1
		],
		[
			1,
			-6
		],
		[
			-24,
			-7
		],
		[
			-9,
			4
		],
		[
			-5,
			-11
		],
		[
			-18,
			10
		],
		[
			-1,
			-16
		],
		[
			-30,
			-3
		],
		[
			-30,
			17
		],
		[
			6,
			-17
		],
		[
			-4,
			-12
		],
		[
			-11,
			1
		],
		[
			-16,
			-12
		],
		[
			-12,
			-33
		],
		[
			-13,
			-5
		],
		[
			-1,
			-15
		],
		[
			-27,
			-26
		],
		[
			-15,
			-2
		],
		[
			-14,
			-18
		],
		[
			-13,
			3
		],
		[
			-20,
			-12
		],
		[
			-17,
			14
		],
		[
			15,
			16
		],
		[
			-12,
			0
		],
		[
			-7,
			-21
		],
		[
			-14,
			-1
		],
		[
			8,
			-16
		],
		[
			-17,
			1
		],
		[
			-7,
			-6
		],
		[
			-8,
			9
		],
		[
			-14,
			-12
		],
		[
			2,
			-15
		],
		[
			-14,
			-14
		],
		[
			-10,
			8
		],
		[
			-13,
			-3
		],
		[
			1,
			-12
		],
		[
			14,
			-11
		],
		[
			-1,
			-13
		],
		[
			-13,
			-9
		],
		[
			-12,
			1
		],
		[
			3,
			-8
		],
		[
			18,
			-1
		],
		[
			7,
			-27
		],
		[
			-13,
			0
		],
		[
			6,
			-7
		],
		[
			-18,
			-12
		],
		[
			-13,
			6
		],
		[
			12,
			-15
		],
		[
			-4,
			-15
		],
		[
			-21,
			-8
		],
		[
			-6,
			-11
		],
		[
			9,
			-15
		],
		[
			-21,
			9
		],
		[
			12,
			-11
		],
		[
			9,
			-1
		],
		[
			-8,
			-21
		],
		[
			11,
			5
		],
		[
			-6,
			-22
		],
		[
			-8,
			-6
		],
		[
			7,
			-7
		],
		[
			-17,
			-13
		],
		[
			9,
			-6
		],
		[
			-3,
			-17
		],
		[
			-20,
			3
		],
		[
			20,
			-7
		],
		[
			-12,
			-15
		],
		[
			-11,
			5
		],
		[
			14,
			-18
		],
		[
			0,
			-9
		],
		[
			-29,
			6
		],
		[
			-13,
			-12
		],
		[
			-12,
			10
		],
		[
			3,
			19
		],
		[
			-9,
			0
		],
		[
			6,
			10
		],
		[
			-15,
			-11
		],
		[
			-11,
			20
		],
		[
			6,
			8
		],
		[
			-3,
			10
		],
		[
			-10,
			-9
		],
		[
			-22,
			-8
		],
		[
			3,
			7
		],
		[
			-19,
			-8
		],
		[
			-17,
			0
		],
		[
			14,
			12
		],
		[
			-20,
			6
		],
		[
			-4,
			9
		],
		[
			7,
			5
		],
		[
			-20,
			5
		],
		[
			-1,
			9
		],
		[
			-10,
			13
		],
		[
			8,
			10
		],
		[
			-10,
			16
		],
		[
			-15,
			2
		],
		[
			-8,
			9
		],
		[
			5,
			28
		],
		[
			-12,
			7
		],
		[
			15,
			8
		],
		[
			-28,
			-3
		],
		[
			-2,
			19
		],
		[
			-11,
			10
		],
		[
			3,
			23
		],
		[
			-6,
			8
		],
		[
			14,
			-1
		],
		[
			13,
			13
		],
		[
			6,
			16
		],
		[
			9,
			-13
		],
		[
			-4,
			16
		],
		[
			-11,
			4
		],
		[
			-15,
			-12
		],
		[
			2,
			10
		],
		[
			-19,
			-33
		],
		[
			-9,
			0
		],
		[
			1,
			29
		],
		[
			22,
			16
		],
		[
			-10,
			2
		],
		[
			-8,
			-13
		],
		[
			-23,
			50
		],
		[
			-12,
			0
		],
		[
			-4,
			23
		],
		[
			19,
			15
		],
		[
			18,
			9
		],
		[
			21,
			21
		],
		[
			-21,
			-13
		],
		[
			-3,
			-7
		],
		[
			-33,
			-23
		],
		[
			-9,
			1
		],
		[
			1,
			22
		],
		[
			11,
			11
		],
		[
			16,
			-1
		],
		[
			5,
			10
		],
		[
			-34,
			3
		],
		[
			-6,
			14
		],
		[
			49,
			13
		],
		[
			17,
			-3
		],
		[
			12,
			6
		],
		[
			-28,
			-2
		],
		[
			-28,
			-7
		],
		[
			-21,
			-2
		],
		[
			2,
			10
		],
		[
			25,
			18
		],
		[
			15,
			2
		],
		[
			12,
			-7
		],
		[
			24,
			4
		],
		[
			-49,
			5
		],
		[
			-24,
			-17
		],
		[
			0,
			18
		],
		[
			22,
			10
		],
		[
			-5,
			12
		],
		[
			15,
			-1
		],
		[
			16,
			-8
		],
		[
			21,
			2
		],
		[
			-6,
			8
		],
		[
			7,
			12
		],
		[
			-13,
			0
		],
		[
			9,
			-8
		],
		[
			-31,
			-6
		],
		[
			-3,
			7
		],
		[
			-15,
			-1
		],
		[
			13,
			14
		],
		[
			18,
			4
		],
		[
			23,
			-2
		],
		[
			-5,
			11
		],
		[
			7,
			22
		],
		[
			16,
			-8
		],
		[
			0,
			19
		],
		[
			-17,
			-7
		],
		[
			10,
			18
		],
		[
			-2,
			11
		],
		[
			15,
			4
		],
		[
			-8,
			11
		],
		[
			-24,
			0
		],
		[
			-25,
			5
		],
		[
			-25,
			17
		],
		[
			-22,
			4
		],
		[
			-15,
			18
		],
		[
			11,
			6
		],
		[
			48,
			-8
		],
		[
			25,
			-15
		],
		[
			24,
			-6
		],
		[
			5,
			11
		],
		[
			-14,
			-6
		],
		[
			1,
			16
		],
		[
			-24,
			21
		],
		[
			17,
			-6
		],
		[
			-5,
			9
		],
		[
			-22,
			-1
		],
		[
			16,
			9
		],
		[
			-4,
			6
		],
		[
			-19,
			-12
		],
		[
			5,
			13
		],
		[
			24,
			4
		],
		[
			-8,
			4
		],
		[
			-21,
			-8
		],
		[
			-7,
			9
		],
		[
			25,
			4
		],
		[
			-41,
			6
		],
		[
			-4,
			7
		],
		[
			-14,
			-11
		],
		[
			0,
			-11
		],
		[
			-14,
			-5
		],
		[
			-24,
			1
		],
		[
			-17,
			17
		],
		[
			17,
			13
		],
		[
			-8,
			8
		],
		[
			19,
			13
		],
		[
			-21,
			11
		],
		[
			17,
			5
		],
		[
			10,
			12
		],
		[
			-3,
			15
		],
		[
			-18,
			4
		],
		[
			4,
			18
		],
		[
			-30,
			38
		],
		[
			7,
			13
		],
		[
			-16,
			5
		],
		[
			7,
			11
		],
		[
			-21,
			13
		],
		[
			4,
			8
		],
		[
			-31,
			10
		],
		[
			-14,
			17
		],
		[
			13,
			3
		],
		[
			-7,
			17
		],
		[
			-16,
			-2
		],
		[
			-4,
			10
		],
		[
			-26,
			9
		],
		[
			-17,
			-2
		],
		[
			-4,
			9
		],
		[
			-42,
			5
		],
		[
			-31,
			8
		],
		[
			-6,
			-11
		],
		[
			-27,
			5
		],
		[
			1,
			-9
		],
		[
			-35,
			-1
		],
		[
			7,
			10
		],
		[
			-15,
			1
		],
		[
			-6,
			-12
		],
		[
			-18,
			11
		],
		[
			-7,
			-6
		],
		[
			23,
			-12
		],
		[
			-58,
			9
		],
		[
			-30,
			15
		],
		[
			36,
			17
		],
		[
			-57,
			7
		],
		[
			-26,
			11
		],
		[
			12,
			12
		],
		[
			50,
			5
		],
		[
			21,
			6
		],
		[
			50,
			-3
		],
		[
			14,
			9
		],
		[
			-19,
			13
		],
		[
			-24,
			-11
		],
		[
			-45,
			-4
		],
		[
			-29,
			6
		],
		[
			21,
			8
		],
		[
			-33,
			-1
		],
		[
			13,
			9
		],
		[
			-30,
			-4
		],
		[
			-44,
			23
		],
		[
			8,
			21
		],
		[
			91,
			16
		],
		[
			8,
			10
		],
		[
			43,
			9
		],
		[
			42,
			-2
		],
		[
			31,
			23
		],
		[
			-5,
			30
		],
		[
			-56,
			2
		],
		[
			-12,
			15
		],
		[
			39,
			20
		],
		[
			28,
			7
		],
		[
			8,
			12
		],
		[
			46,
			13
		],
		[
			44,
			-9
		],
		[
			16,
			6
		],
		[
			6,
			19
		],
		[
			-19,
			15
		],
		[
			104,
			24
		],
		[
			90,
			11
		],
		[
			24,
			-14
		],
		[
			-6,
			-33
		],
		[
			24,
			17
		],
		[
			-1,
			11
		],
		[
			85,
			-18
		],
		[
			-31,
			13
		],
		[
			44,
			0
		],
		[
			-31,
			12
		],
		[
			-15,
			20
		],
		[
			65,
			-8
		],
		[
			77,
			-19
		],
		[
			22,
			-14
		],
		[
			25,
			1
		],
		[
			-8,
			28
		],
		[
			38,
			-1
		],
		[
			-68,
			26
		],
		[
			132,
			2
		],
		[
			-157,
			7
		],
		[
			28,
			14
		],
		[
			74,
			4
		],
		[
			6,
			5
		],
		[
			54,
			-17
		],
		[
			95,
			1
		],
		[
			-42,
			3
		],
		[
			53,
			5
		],
		[
			-49,
			3
		],
		[
			0,
			13
		],
		[
			180,
			11
		]
	],
	[
		[
			2530,
			6098
		],
		[
			8,
			-8
		],
		[
			4,
			5
		],
		[
			7,
			-7
		]
	],
	[
		[
			2549,
			6088
		],
		[
			-17,
			-28
		],
		[
			-9,
			-9
		],
		[
			-2,
			-15
		],
		[
			2,
			-14
		],
		[
			-6,
			-9
		]
	],
	[
		[
			2517,
			6013
		],
		[
			-6,
			-1
		],
		[
			2,
			-10
		],
		[
			-5,
			-3
		],
		[
			-10,
			-17
		],
		[
			-1,
			-9
		]
	],
	[
		[
			2497,
			5973
		],
		[
			-15,
			12
		],
		[
			-19,
			1
		],
		[
			-9,
			9
		],
		[
			-17,
			25
		]
	],
	[
		[
			2437,
			6020
		],
		[
			3,
			7
		],
		[
			-1,
			33
		],
		[
			1,
			10
		],
		[
			11,
			38
		],
		[
			36,
			0
		],
		[
			2,
			20
		],
		[
			-7,
			4
		],
		[
			-4,
			17
		],
		[
			-8,
			7
		],
		[
			-1,
			7
		],
		[
			-9,
			13
		],
		[
			12,
			0
		],
		[
			1,
			33
		],
		[
			50,
			0
		]
	],
	[
		[
			9022,
			5957
		],
		[
			-2,
			-11
		],
		[
			-3,
			10
		],
		[
			5,
			12
		],
		[
			4,
			-3
		],
		[
			-4,
			-8
		]
	],
	[
		[
			3409,
			5499
		],
		[
			-2,
			-9
		],
		[
			4,
			-10
		],
		[
			-2,
			-8
		],
		[
			-13,
			-2
		],
		[
			-5,
			-8
		],
		[
			2,
			-9
		],
		[
			-6,
			-39
		],
		[
			4,
			-7
		],
		[
			2,
			-13
		],
		[
			5,
			-8
		],
		[
			0,
			-8
		],
		[
			10,
			0
		],
		[
			2,
			-28
		],
		[
			6,
			-15
		],
		[
			0,
			-8
		],
		[
			9,
			-27
		],
		[
			6,
			-5
		]
	],
	[
		[
			3312,
			5482
		],
		[
			-18,
			43
		],
		[
			8,
			14
		],
		[
			-2,
			28
		],
		[
			9,
			7
		],
		[
			5,
			-2
		],
		[
			11,
			21
		],
		[
			-7,
			0
		],
		[
			-5,
			21
		],
		[
			5,
			19
		],
		[
			5,
			3
		],
		[
			15,
			22
		],
		[
			-6,
			18
		]
	],
	[
		[
			3332,
			5676
		],
		[
			4,
			-9
		],
		[
			7,
			-3
		],
		[
			15,
			-20
		],
		[
			17,
			-36
		],
		[
			1,
			-15
		],
		[
			-4,
			-18
		],
		[
			1,
			-10
		],
		[
			3,
			13
		],
		[
			4,
			2
		],
		[
			10,
			-8
		],
		[
			9,
			-18
		],
		[
			2,
			-9
		],
		[
			6,
			-1
		],
		[
			5,
			-11
		],
		[
			0,
			-27
		],
		[
			-3,
			-7
		]
	],
	[
		[
			8172,
			6482
		],
		[
			5,
			-7
		],
		[
			-5,
			-9
		],
		[
			-9,
			5
		],
		[
			5,
			9
		]
	],
	[
		[
			7037,
			2130
		],
		[
			10,
			-6
		],
		[
			-7,
			-4
		],
		[
			-3,
			10
		]
	],
	[
		[
			2691,
			6046
		],
		[
			-12,
			-1
		],
		[
			-4,
			-8
		],
		[
			-12,
			-4
		],
		[
			-8,
			-7
		],
		[
			-8,
			2
		],
		[
			-3,
			9
		],
		[
			-6,
			-6
		],
		[
			-4,
			-11
		],
		[
			0,
			-12
		],
		[
			-5,
			-3
		],
		[
			-5,
			-13
		],
		[
			-6,
			-5
		],
		[
			0,
			-7
		],
		[
			-8,
			9
		],
		[
			-8,
			-14
		],
		[
			-13,
			-2
		],
		[
			2,
			-26
		],
		[
			-6,
			-2
		],
		[
			0,
			-10
		],
		[
			-11,
			-5
		]
	],
	[
		[
			2574,
			5930
		],
		[
			-4,
			22
		],
		[
			-10,
			3
		]
	],
	[
		[
			2560,
			5955
		],
		[
			3,
			17
		],
		[
			-2,
			12
		],
		[
			-6,
			-1
		],
		[
			-3,
			6
		],
		[
			-10,
			-8
		],
		[
			0,
			7
		],
		[
			-7,
			3
		],
		[
			-8,
			17
		],
		[
			-10,
			5
		]
	],
	[
		[
			2549,
			6088
		],
		[
			8,
			9
		],
		[
			7,
			2
		],
		[
			7,
			-7
		],
		[
			2,
			4
		],
		[
			12,
			-6
		],
		[
			4,
			3
		],
		[
			12,
			-1
		],
		[
			13,
			11
		],
		[
			15,
			-6
		],
		[
			11,
			6
		],
		[
			18,
			-9
		],
		[
			13,
			-22
		],
		[
			-8,
			6
		],
		[
			10,
			-19
		],
		[
			8,
			0
		],
		[
			-7,
			9
		],
		[
			9,
			-6
		],
		[
			4,
			-13
		],
		[
			4,
			-3
		]
	],
	[
		[
			5512,
			7634
		],
		[
			1,
			-9
		]
	],
	[
		[
			5513,
			7625
		],
		[
			-8,
			12
		],
		[
			-27,
			21
		],
		[
			12,
			-5
		]
	],
	[
		[
			5466,
			7679
		],
		[
			-8,
			-5
		],
		[
			-2,
			8
		],
		[
			10,
			-3
		]
	],
	[
		[
			5412,
			7751
		],
		[
			11,
			-14
		],
		[
			-10,
			8
		],
		[
			-1,
			6
		]
	],
	[
		[
			5401,
			7772
		],
		[
			0,
			-20
		],
		[
			-5,
			27
		],
		[
			5,
			-7
		]
	],
	[
		[
			5404,
			7789
		],
		[
			3,
			-10
		],
		[
			-5,
			-3
		],
		[
			2,
			13
		]
	],
	[
		[
			5458,
			7861
		],
		[
			5,
			-3
		],
		[
			18,
			-29
		],
		[
			6,
			0
		],
		[
			9,
			-10
		],
		[
			17,
			0
		],
		[
			11,
			9
		]
	],
	[
		[
			5524,
			7828
		],
		[
			3,
			-33
		],
		[
			12,
			-10
		],
		[
			-10,
			-3
		],
		[
			-1,
			-17
		]
	],
	[
		[
			5488,
			7656
		],
		[
			-12,
			12
		],
		[
			-6,
			13
		],
		[
			-14,
			10
		],
		[
			-11,
			-4
		],
		[
			-2,
			10
		],
		[
			-14,
			14
		],
		[
			-9,
			17
		],
		[
			8,
			5
		],
		[
			-15,
			23
		],
		[
			-1,
			23
		],
		[
			-9,
			12
		],
		[
			-7,
			2
		],
		[
			-3,
			-20
		],
		[
			-8,
			-11
		],
		[
			-8,
			20
		],
		[
			0,
			20
		]
	],
	[
		[
			5377,
			7802
		],
		[
			9,
			-3
		],
		[
			13,
			3
		],
		[
			6,
			6
		],
		[
			20,
			-9
		],
		[
			-2,
			17
		],
		[
			12,
			6
		],
		[
			-2,
			20
		],
		[
			9,
			5
		],
		[
			8,
			12
		],
		[
			8,
			2
		]
	],
	[
		[
			3002,
			6248
		],
		[
			-1,
			2
		]
	],
	[
		[
			2977,
			6260
		],
		[
			-12,
			8
		],
		[
			1,
			7
		],
		[
			11,
			-10
		],
		[
			0,
			-5
		]
	],
	[
		[
			3000,
			6254
		],
		[
			2,
			-6
		]
	],
	[
		[
			3006,
			6222
		],
		[
			-8,
			11
		],
		[
			-24,
			-5
		],
		[
			-11,
			6
		],
		[
			-8,
			0
		],
		[
			-6,
			-5
		],
		[
			1,
			-8
		],
		[
			-12,
			16
		],
		[
			-7,
			4
		],
		[
			2,
			15
		],
		[
			6,
			2
		],
		[
			16,
			-10
		],
		[
			24,
			-4
		],
		[
			4,
			8
		],
		[
			7,
			-2
		],
		[
			0,
			7
		],
		[
			-13,
			23
		],
		[
			1,
			19
		],
		[
			3,
			2
		],
		[
			-9,
			11
		],
		[
			-11,
			1
		],
		[
			-2,
			6
		],
		[
			8,
			10
		],
		[
			11,
			2
		],
		[
			13,
			-11
		],
		[
			15,
			-2
		]
	],
	[
		[
			5614,
			7970
		],
		[
			21,
			-26
		]
	],
	[
		[
			5635,
			7944
		],
		[
			-8,
			-11
		],
		[
			-4,
			2
		],
		[
			-13,
			-17
		],
		[
			-4,
			-19
		],
		[
			-5,
			-6
		],
		[
			-4,
			-21
		],
		[
			-6,
			-5
		],
		[
			-1,
			-12
		],
		[
			-6,
			-10
		],
		[
			-7,
			2
		],
		[
			-5,
			-8
		],
		[
			-10,
			-1
		]
	],
	[
		[
			5562,
			7838
		],
		[
			-16,
			4
		],
		[
			-11,
			-11
		],
		[
			-11,
			-3
		]
	],
	[
		[
			5458,
			7861
		],
		[
			-7,
			21
		],
		[
			-4,
			-1
		]
	],
	[
		[
			5476,
			7947
		],
		[
			6,
			-1
		],
		[
			10,
			-13
		],
		[
			15,
			0
		],
		[
			14,
			3
		],
		[
			-1,
			10
		],
		[
			7,
			4
		],
		[
			14,
			3
		],
		[
			4,
			7
		],
		[
			8,
			-7
		],
		[
			12,
			11
		],
		[
			3,
			13
		],
		[
			9,
			3
		],
		[
			9,
			-5
		],
		[
			11,
			3
		],
		[
			5,
			-11
		],
		[
			12,
			3
		]
	],
	[
		[
			8426,
			4574
		],
		[
			2,
			-3
		],
		[
			-6,
			-11
		],
		[
			-11,
			-6
		],
		[
			0,
			8
		],
		[
			6,
			3
		],
		[
			10,
			17
		],
		[
			-1,
			-8
		]
	],
	[
		[
			8386,
			4582
		],
		[
			-1,
			-10
		],
		[
			-6,
			2
		],
		[
			7,
			8
		]
	],
	[
		[
			8333,
			4644
		],
		[
			9,
			-18
		],
		[
			4,
			2
		],
		[
			10,
			-24
		],
		[
			-10,
			-15
		],
		[
			-9,
			5
		],
		[
			-5,
			14
		],
		[
			-10,
			12
		],
		[
			-15,
			3
		],
		[
			-4,
			11
		],
		[
			10,
			10
		],
		[
			20,
			0
		]
	],
	[
		[
			8473,
			4637
		],
		[
			-2,
			-11
		],
		[
			-16,
			-29
		],
		[
			-8,
			0
		],
		[
			-2,
			-6
		],
		[
			-12,
			-5
		],
		[
			-3,
			9
		],
		[
			7,
			6
		],
		[
			-5,
			10
		],
		[
			2,
			16
		],
		[
			10,
			18
		]
	],
	[
		[
			8444,
			4645
		],
		[
			2,
			-5
		],
		[
			7,
			4
		],
		[
			3,
			10
		]
	],
	[
		[
			8456,
			4654
		],
		[
			13,
			13
		]
	],
	[
		[
			8469,
			4667
		],
		[
			7,
			-5
		],
		[
			0,
			-8
		],
		[
			-6,
			-2
		],
		[
			3,
			-15
		]
	],
	[
		[
			8318,
			4695
		],
		[
			-3,
			-16
		],
		[
			1,
			18
		],
		[
			2,
			-2
		]
	],
	[
		[
			8424,
			4708
		],
		[
			1,
			-8
		],
		[
			-8,
			-2
		],
		[
			4,
			11
		],
		[
			3,
			-1
		]
	],
	[
		[
			8242,
			4700
		],
		[
			-7,
			-24
		],
		[
			3,
			-4
		],
		[
			-11,
			-3
		],
		[
			-10,
			6
		],
		[
			6,
			6
		],
		[
			-1,
			15
		],
		[
			7,
			13
		],
		[
			8,
			-1
		],
		[
			5,
			-8
		]
	],
	[
		[
			8442,
			4708
		],
		[
			-5,
			-4
		],
		[
			-10,
			-16
		],
		[
			-5,
			4
		],
		[
			7,
			9
		],
		[
			-2,
			6
		],
		[
			12,
			4
		],
		[
			3,
			-3
		]
	],
	[
		[
			8450,
			4700
		],
		[
			-5,
			-10
		],
		[
			-4,
			6
		],
		[
			11,
			16
		],
		[
			-2,
			-12
		]
	],
	[
		[
			8858,
			4702
		],
		[
			-10,
			-1
		],
		[
			7,
			12
		],
		[
			3,
			-11
		]
	],
	[
		[
			8265,
			4700
		],
		[
			-2,
			12
		],
		[
			5,
			2
		],
		[
			-3,
			-14
		]
	],
	[
		[
			8459,
			4715
		],
		[
			2,
			-3
		],
		[
			13,
			1
		],
		[
			1,
			-11
		],
		[
			-22,
			-6
		],
		[
			3,
			18
		],
		[
			3,
			1
		]
	],
	[
		[
			8550,
			4716
		],
		[
			8,
			-3
		],
		[
			-2,
			-6
		],
		[
			-6,
			9
		]
	],
	[
		[
			8276,
			4716
		],
		[
			4,
			0
		],
		[
			5,
			-15
		],
		[
			6,
			7
		],
		[
			6,
			-6
		],
		[
			8,
			2
		],
		[
			1,
			-19
		],
		[
			-18,
			-12
		],
		[
			0,
			10
		],
		[
			-7,
			-11
		],
		[
			-12,
			-2
		],
		[
			-9,
			-9
		],
		[
			-7,
			-2
		],
		[
			-11,
			5
		],
		[
			2,
			11
		],
		[
			-1,
			13
		],
		[
			12,
			14
		],
		[
			6,
			-8
		],
		[
			4,
			5
		],
		[
			6,
			-18
		],
		[
			14,
			4
		],
		[
			-6,
			11
		],
		[
			-4,
			1
		],
		[
			-6,
			16
		],
		[
			7,
			3
		]
	],
	[
		[
			8415,
			4713
		],
		[
			2,
			-8
		],
		[
			-7,
			-8
		],
		[
			2,
			-8
		],
		[
			-13,
			-10
		],
		[
			-8,
			1
		],
		[
			-9,
			-9
		],
		[
			-11,
			5
		],
		[
			-1,
			-7
		],
		[
			-12,
			0
		],
		[
			-2,
			6
		],
		[
			-7,
			2
		],
		[
			-9,
			-3
		],
		[
			-13,
			4
		],
		[
			0,
			11
		],
		[
			13,
			18
		],
		[
			19,
			-4
		],
		[
			15,
			-16
		],
		[
			15,
			11
		],
		[
			6,
			-12
		],
		[
			6,
			1
		],
		[
			0,
			7
		],
		[
			12,
			12
		],
		[
			-4,
			4
		],
		[
			3,
			8
		],
		[
			3,
			-5
		]
	],
	[
		[
			8208,
			4712
		],
		[
			5,
			-15
		],
		[
			-14,
			-15
		],
		[
			-7,
			13
		],
		[
			-11,
			8
		],
		[
			-3,
			14
		],
		[
			12,
			-6
		],
		[
			8,
			8
		],
		[
			10,
			-7
		]
	],
	[
		[
			8604,
			4733
		],
		[
			0,
			-14
		],
		[
			-5,
			14
		],
		[
			5,
			0
		]
	],
	[
		[
			8519,
			4741
		],
		[
			-6,
			-15
		],
		[
			-15,
			2
		],
		[
			-5,
			-7
		],
		[
			5,
			21
		],
		[
			11,
			-2
		],
		[
			8,
			7
		],
		[
			2,
			-6
		]
	],
	[
		[
			8857,
			4720
		],
		[
			-12,
			-20
		],
		[
			-23,
			0
		],
		[
			5,
			24
		],
		[
			6,
			21
		],
		[
			6,
			8
		],
		[
			11,
			6
		],
		[
			5,
			-1
		],
		[
			7,
			-11
		],
		[
			-5,
			-27
		]
	],
	[
		[
			8656,
			4770
		],
		[
			0,
			-26
		],
		[
			-8,
			-16
		],
		[
			-7,
			-6
		],
		[
			3,
			28
		],
		[
			10,
			23
		],
		[
			2,
			-3
		]
	],
	[
		[
			8664,
			4774
		],
		[
			1,
			-9
		],
		[
			-7,
			7
		],
		[
			6,
			2
		]
	],
	[
		[
			8166,
			4787
		],
		[
			3,
			-6
		],
		[
			-12,
			-8
		],
		[
			-3,
			-6
		],
		[
			-12,
			-1
		],
		[
			-12,
			5
		],
		[
			4,
			15
		],
		[
			32,
			1
		]
	],
	[
		[
			8204,
			4789
		],
		[
			6,
			-5
		],
		[
			-10,
			-1
		],
		[
			4,
			6
		]
	],
	[
		[
			8738,
			4813
		],
		[
			-1,
			-5
		],
		[
			-6,
			7
		],
		[
			3,
			6
		],
		[
			4,
			-8
		]
	],
	[
		[
			8733,
			4812
		],
		[
			3,
			-8
		],
		[
			-6,
			-16
		],
		[
			-7,
			2
		],
		[
			2,
			30
		],
		[
			-1,
			7
		],
		[
			9,
			-15
		]
	],
	[
		[
			7948,
			4837
		],
		[
			3,
			4
		],
		[
			13,
			-9
		],
		[
			8,
			1
		],
		[
			0,
			9
		],
		[
			9,
			-3
		],
		[
			2,
			-10
		],
		[
			7,
			-5
		],
		[
			6,
			2
		],
		[
			5,
			-8
		],
		[
			8,
			5
		],
		[
			5,
			-14
		],
		[
			2,
			-16
		],
		[
			11,
			-1
		],
		[
			10,
			-5
		],
		[
			4,
			4
		],
		[
			11,
			-7
		],
		[
			7,
			4
		],
		[
			5,
			-7
		],
		[
			7,
			8
		],
		[
			2,
			19
		],
		[
			4,
			5
		],
		[
			7,
			-1
		],
		[
			3,
			-15
		],
		[
			12,
			3
		],
		[
			12,
			-14
		],
		[
			16,
			1
		],
		[
			0,
			-13
		],
		[
			6,
			-8
		],
		[
			-2,
			-17
		],
		[
			16,
			-15
		],
		[
			12,
			4
		],
		[
			7,
			6
		],
		[
			13,
			-11
		],
		[
			-3,
			-41
		],
		[
			7,
			-10
		],
		[
			-18,
			4
		],
		[
			-20,
			20
		],
		[
			-6,
			-1
		],
		[
			-10,
			-8
		],
		[
			-9,
			6
		],
		[
			-16,
			4
		],
		[
			-2,
			-6
		],
		[
			-9,
			6
		],
		[
			-11,
			0
		],
		[
			-13,
			8
		],
		[
			-14,
			14
		],
		[
			-18,
			10
		],
		[
			-23,
			1
		],
		[
			-2,
			-7
		],
		[
			-18,
			4
		],
		[
			-11,
			14
		],
		[
			-25,
			5
		],
		[
			-4,
			10
		],
		[
			4,
			15
		],
		[
			-7,
			-1
		],
		[
			-7,
			10
		],
		[
			-20,
			-2
		],
		[
			3,
			10
		],
		[
			2,
			-8
		],
		[
			4,
			17
		],
		[
			5,
			1
		],
		[
			1,
			18
		],
		[
			5,
			17
		],
		[
			4,
			-6
		]
	],
	[
		[
			8346,
			4810
		],
		[
			-1,
			39
		],
		[
			3,
			-8
		],
		[
			-2,
			-31
		]
	],
	[
		[
			8685,
			4859
		],
		[
			3,
			-16
		],
		[
			-4,
			0
		],
		[
			1,
			16
		]
	],
	[
		[
			8737,
			4870
		],
		[
			5,
			-12
		],
		[
			1,
			-27
		],
		[
			-5,
			-14
		],
		[
			-8,
			8
		],
		[
			-1,
			9
		],
		[
			2,
			19
		],
		[
			6,
			17
		]
	],
	[
		[
			7843,
			4868
		],
		[
			-9,
			8
		],
		[
			9,
			-3
		],
		[
			0,
			-5
		]
	],
	[
		[
			8386,
			4889
		],
		[
			2,
			1
		],
		[
			2,
			-20
		],
		[
			-3,
			-2
		],
		[
			-4,
			10
		],
		[
			3,
			11
		]
	],
	[
		[
			8410,
			4898
		],
		[
			-4,
			-6
		],
		[
			0,
			-18
		],
		[
			-10,
			-1
		],
		[
			3,
			23
		],
		[
			-2,
			8
		],
		[
			11,
			13
		],
		[
			2,
			-19
		]
	],
	[
		[
			8422,
			4913
		],
		[
			0,
			-9
		],
		[
			-5,
			6
		],
		[
			-2,
			-24
		],
		[
			7,
			-6
		],
		[
			-2,
			-7
		],
		[
			-8,
			-5
		],
		[
			0,
			-10
		],
		[
			-6,
			-1
		],
		[
			-2,
			9
		],
		[
			5,
			17
		],
		[
			3,
			22
		],
		[
			0,
			15
		],
		[
			4,
			10
		],
		[
			6,
			-17
		]
	],
	[
		[
			8418,
			4952
		],
		[
			5,
			-5
		],
		[
			-3,
			-8
		],
		[
			-5,
			6
		],
		[
			3,
			7
		]
	],
	[
		[
			8564,
			4977
		],
		[
			-2,
			-8
		],
		[
			-9,
			-3
		],
		[
			3,
			10
		],
		[
			8,
			1
		]
	],
	[
		[
			8225,
			4951
		],
		[
			-3,
			23
		],
		[
			3,
			18
		],
		[
			4,
			5
		],
		[
			1,
			-36
		],
		[
			-5,
			-10
		]
	],
	[
		[
			8523,
			5004
		],
		[
			7,
			-6
		],
		[
			-2,
			-7
		],
		[
			6,
			-2
		],
		[
			0,
			-14
		],
		[
			-15,
			-15
		],
		[
			-15,
			15
		],
		[
			-5,
			14
		],
		[
			1,
			12
		],
		[
			11,
			5
		],
		[
			12,
			-2
		]
	],
	[
		[
			8598,
			5023
		],
		[
			14,
			-13
		],
		[
			8,
			1
		],
		[
			7,
			-8
		],
		[
			1,
			-15
		],
		[
			7,
			-11
		],
		[
			-1,
			-17
		],
		[
			-24,
			23
		],
		[
			-3,
			8
		],
		[
			-9,
			2
		],
		[
			-2,
			-10
		],
		[
			-15,
			7
		],
		[
			-2,
			8
		],
		[
			-6,
			-10
		],
		[
			-7,
			-2
		],
		[
			-6,
			20
		],
		[
			-4,
			-17
		],
		[
			-6,
			11
		],
		[
			8,
			6
		],
		[
			1,
			12
		],
		[
			21,
			0
		],
		[
			5,
			-5
		],
		[
			13,
			10
		]
	],
	[
		[
			7789,
			5006
		],
		[
			0,
			-13
		],
		[
			-7,
			21
		],
		[
			0,
			8
		],
		[
			6,
			-7
		],
		[
			1,
			-9
		]
	],
	[
		[
			7994,
			5036
		],
		[
			13,
			-12
		],
		[
			-2,
			-21
		],
		[
			-6,
			-7
		],
		[
			-3,
			11
		],
		[
			-8,
			-10
		],
		[
			0,
			26
		],
		[
			2,
			12
		],
		[
			4,
			1
		]
	],
	[
		[
			7782,
			5024
		],
		[
			-5,
			-4
		],
		[
			0,
			20
		],
		[
			5,
			-16
		]
	],
	[
		[
			7769,
			5060
		],
		[
			4,
			-12
		],
		[
			-4,
			1
		],
		[
			-5,
			11
		],
		[
			5,
			0
		]
	],
	[
		[
			8501,
			5041
		],
		[
			-3,
			3
		],
		[
			-3,
			21
		],
		[
			4,
			3
		],
		[
			2,
			-27
		]
	],
	[
		[
			8483,
			5079
		],
		[
			15,
			1
		],
		[
			11,
			-2
		],
		[
			-2,
			-3
		],
		[
			-24,
			-4
		],
		[
			0,
			8
		]
	],
	[
		[
			8620,
			5085
		],
		[
			2,
			-15
		],
		[
			-6,
			-6
		],
		[
			-14,
			10
		],
		[
			10,
			9
		],
		[
			8,
			2
		]
	],
	[
		[
			8458,
			5089
		],
		[
			22,
			-6
		],
		[
			0,
			-9
		],
		[
			-8,
			-3
		],
		[
			-7,
			2
		],
		[
			-10,
			-6
		],
		[
			-1,
			20
		],
		[
			4,
			2
		]
	],
	[
		[
			8762,
			5091
		],
		[
			20,
			-3
		],
		[
			6,
			-5
		],
		[
			14,
			-4
		],
		[
			-11,
			-5
		],
		[
			-15,
			5
		],
		[
			-14,
			12
		]
	],
	[
		[
			7940,
			5097
		],
		[
			5,
			-5
		],
		[
			4,
			-17
		],
		[
			0,
			-18
		],
		[
			4,
			-16
		],
		[
			14,
			-6
		],
		[
			-5,
			-8
		],
		[
			-2,
			-12
		],
		[
			4,
			-10
		],
		[
			-22,
			15
		],
		[
			0,
			21
		],
		[
			-3,
			4
		],
		[
			-1,
			14
		],
		[
			-18,
			4
		],
		[
			0,
			8
		],
		[
			7,
			9
		],
		[
			-3,
			5
		],
		[
			9,
			9
		],
		[
			2,
			-13
		],
		[
			3,
			1
		],
		[
			-2,
			12
		],
		[
			4,
			3
		]
	],
	[
		[
			8550,
			5100
		],
		[
			9,
			-9
		],
		[
			-6,
			-5
		],
		[
			-11,
			-3
		],
		[
			-5,
			6
		],
		[
			1,
			9
		],
		[
			6,
			8
		],
		[
			6,
			-6
		]
	],
	[
		[
			8421,
			5116
		],
		[
			1,
			-14
		],
		[
			3,
			9
		],
		[
			6,
			-1
		],
		[
			0,
			-10
		],
		[
			-4,
			-5
		],
		[
			-3,
			6
		],
		[
			-1,
			-12
		],
		[
			-3,
			18
		],
		[
			-6,
			-15
		],
		[
			-4,
			10
		],
		[
			3,
			13
		],
		[
			8,
			1
		]
	],
	[
		[
			8044,
			5127
		],
		[
			4,
			-10
		],
		[
			-9,
			-8
		],
		[
			0,
			18
		],
		[
			5,
			0
		]
	],
	[
		[
			7746,
			5129
		],
		[
			7,
			-31
		],
		[
			4,
			-7
		],
		[
			-2,
			-11
		],
		[
			-9,
			6
		],
		[
			-9,
			29
		],
		[
			3,
			13
		],
		[
			6,
			1
		]
	],
	[
		[
			8636,
			5129
		],
		[
			4,
			-8
		],
		[
			-2,
			-16
		],
		[
			-7,
			6
		],
		[
			-3,
			15
		],
		[
			8,
			3
		]
	],
	[
		[
			8634,
			5139
		],
		[
			-7,
			-9
		],
		[
			-4,
			6
		],
		[
			11,
			3
		]
	],
	[
		[
			8761,
			5145
		],
		[
			12,
			-2
		],
		[
			9,
			-20
		],
		[
			6,
			-4
		],
		[
			-7,
			-7
		],
		[
			-7,
			2
		],
		[
			-4,
			22
		],
		[
			-3,
			-4
		],
		[
			-6,
			13
		]
	],
	[
		[
			8536,
			5138
		],
		[
			-5,
			0
		],
		[
			3,
			9
		],
		[
			2,
			-9
		]
	],
	[
		[
			8915,
			5033
		],
		[
			0,
			-218
		],
		[
			-3,
			-12
		],
		[
			3,
			-17
		],
		[
			0,
			-128
		]
	],
	[
		[
			8915,
			4658
		],
		[
			-10,
			18
		],
		[
			-4,
			12
		],
		[
			-15,
			28
		],
		[
			-17,
			-5
		],
		[
			-3,
			6
		],
		[
			-7,
			-8
		],
		[
			-1,
			19
		],
		[
			5,
			19
		],
		[
			-4,
			4
		],
		[
			-7,
			18
		],
		[
			13,
			-3
		],
		[
			-12,
			8
		],
		[
			-4,
			13
		],
		[
			10,
			2
		],
		[
			-8,
			7
		],
		[
			1,
			5
		],
		[
			-7,
			13
		],
		[
			-3,
			32
		],
		[
			-8,
			7
		],
		[
			0,
			12
		],
		[
			-4,
			8
		],
		[
			-15,
			20
		],
		[
			-21,
			12
		],
		[
			-18,
			18
		],
		[
			-14,
			4
		],
		[
			-7,
			-1
		],
		[
			-16,
			20
		],
		[
			1,
			11
		],
		[
			-4,
			-6
		],
		[
			-5,
			9
		],
		[
			-1,
			-9
		],
		[
			-5,
			7
		],
		[
			1,
			8
		],
		[
			-6,
			-4
		],
		[
			-4,
			14
		],
		[
			-3,
			-5
		],
		[
			0,
			28
		],
		[
			6,
			6
		],
		[
			-1,
			9
		],
		[
			-6,
			-11
		],
		[
			0,
			-14
		],
		[
			-7,
			-21
		],
		[
			1,
			-8
		],
		[
			-5,
			-11
		],
		[
			-7,
			-3
		],
		[
			-6,
			11
		],
		[
			-2,
			14
		],
		[
			6,
			8
		],
		[
			-9,
			15
		],
		[
			-3,
			12
		],
		[
			-6,
			8
		],
		[
			-6,
			-2
		],
		[
			-2,
			12
		],
		[
			5,
			5
		],
		[
			10,
			-2
		],
		[
			4,
			-6
		],
		[
			9,
			18
		],
		[
			7,
			5
		],
		[
			7,
			-10
		],
		[
			8,
			7
		],
		[
			4,
			12
		],
		[
			-1,
			9
		],
		[
			-7,
			-8
		],
		[
			-11,
			2
		],
		[
			-16,
			-6
		],
		[
			-4,
			7
		],
		[
			-6,
			-5
		],
		[
			-8,
			11
		],
		[
			-4,
			22
		],
		[
			-5,
			11
		],
		[
			-9,
			2
		],
		[
			-5,
			-3
		],
		[
			-7,
			4
		],
		[
			3,
			13
		],
		[
			5,
			6
		],
		[
			0,
			18
		],
		[
			7,
			5
		],
		[
			8,
			0
		],
		[
			10,
			17
		],
		[
			8,
			5
		],
		[
			8,
			-1
		],
		[
			12,
			-10
		],
		[
			6,
			-11
		],
		[
			17,
			0
		],
		[
			5,
			-8
		],
		[
			-4,
			-5
		],
		[
			7,
			-22
		],
		[
			-1,
			-12
		],
		[
			-4,
			-7
		],
		[
			2,
			-39
		],
		[
			5,
			-10
		],
		[
			3,
			-17
		],
		[
			1,
			17
		],
		[
			5,
			-3
		],
		[
			1,
			-23
		],
		[
			5,
			-17
		],
		[
			6,
			-6
		],
		[
			11,
			0
		],
		[
			2,
			7
		],
		[
			10,
			16
		],
		[
			1,
			11
		],
		[
			9,
			14
		],
		[
			3,
			18
		],
		[
			9,
			-2
		],
		[
			14,
			10
		],
		[
			-3,
			16
		],
		[
			19,
			18
		],
		[
			4,
			0
		],
		[
			11,
			-13
		],
		[
			9,
			-4
		],
		[
			5,
			-10
		],
		[
			7,
			-3
		],
		[
			20,
			-21
		],
		[
			10,
			3
		],
		[
			16,
			-10
		],
		[
			-2,
			-6
		],
		[
			8,
			0
		]
	],
	[
		[
			7903,
			5160
		],
		[
			0,
			-12
		],
		[
			-8,
			7
		],
		[
			6,
			9
		],
		[
			2,
			-4
		]
	],
	[
		[
			8544,
			5159
		],
		[
			1,
			-17
		],
		[
			6,
			0
		],
		[
			-1,
			-9
		],
		[
			-5,
			6
		],
		[
			-5,
			-3
		],
		[
			0,
			10
		],
		[
			-5,
			11
		],
		[
			6,
			9
		],
		[
			3,
			-7
		]
	],
	[
		[
			8533,
			5168
		],
		[
			1,
			-14
		],
		[
			-4,
			-1
		],
		[
			0,
			14
		],
		[
			3,
			1
		]
	],
	[
		[
			7735,
			5153
		],
		[
			-4,
			0
		],
		[
			3,
			16
		],
		[
			1,
			-16
		]
	],
	[
		[
			7881,
			5163
		],
		[
			-8,
			-1
		],
		[
			3,
			8
		],
		[
			5,
			-7
		]
	],
	[
		[
			8633,
			5183
		],
		[
			14,
			-10
		],
		[
			-2,
			-13
		],
		[
			-6,
			2
		],
		[
			-11,
			13
		],
		[
			8,
			-16
		],
		[
			-6,
			-1
		],
		[
			-1,
			8
		],
		[
			-9,
			2
		],
		[
			-2,
			9
		],
		[
			15,
			6
		]
	],
	[
		[
			7737,
			5167
		],
		[
			-5,
			8
		],
		[
			0,
			8
		],
		[
			5,
			-16
		]
	],
	[
		[
			7904,
			5183
		],
		[
			11,
			-16
		],
		[
			-7,
			4
		],
		[
			-8,
			-1
		],
		[
			4,
			13
		]
	],
	[
		[
			7850,
			5240
		],
		[
			4,
			0
		],
		[
			7,
			-11
		],
		[
			-14,
			-1
		],
		[
			-1,
			20
		],
		[
			4,
			-8
		]
	],
	[
		[
			7861,
			5243
		],
		[
			2,
			-12
		],
		[
			-8,
			11
		],
		[
			-5,
			-1
		],
		[
			5,
			9
		],
		[
			6,
			-7
		]
	],
	[
		[
			7892,
			5248
		],
		[
			-1,
			-8
		],
		[
			-5,
			3
		],
		[
			6,
			5
		]
	],
	[
		[
			7904,
			5252
		],
		[
			2,
			-10
		],
		[
			-2,
			-11
		],
		[
			-3,
			13
		],
		[
			-6,
			-3
		],
		[
			2,
			9
		],
		[
			7,
			2
		]
	],
	[
		[
			7845,
			5238
		],
		[
			-6,
			7
		],
		[
			-1,
			17
		],
		[
			3,
			2
		],
		[
			5,
			-9
		],
		[
			-1,
			-17
		]
	],
	[
		[
			7704,
			5270
		],
		[
			3,
			-2
		],
		[
			6,
			-18
		],
		[
			6,
			-7
		],
		[
			-2,
			-28
		],
		[
			-4,
			1
		],
		[
			-3,
			14
		],
		[
			-5,
			7
		],
		[
			-8,
			26
		],
		[
			7,
			7
		]
	],
	[
		[
			7839,
			5273
		],
		[
			7,
			-4
		],
		[
			0,
			-13
		],
		[
			-10,
			11
		],
		[
			-2,
			10
		],
		[
			5,
			-4
		]
	],
	[
		[
			8473,
			5279
		],
		[
			5,
			-11
		],
		[
			-3,
			-3
		],
		[
			-6,
			-26
		],
		[
			-5,
			-5
		],
		[
			-7,
			-25
		],
		[
			-24,
			-11
		],
		[
			-11,
			3
		],
		[
			-4,
			10
		],
		[
			-24,
			0
		],
		[
			-12,
			-4
		],
		[
			-6,
			6
		],
		[
			-13,
			-7
		],
		[
			-11,
			7
		],
		[
			-10,
			-4
		],
		[
			-7,
			-19
		],
		[
			-3,
			-19
		],
		[
			3,
			-26
		],
		[
			4,
			-13
		],
		[
			5,
			-1
		],
		[
			5,
			-12
		],
		[
			2,
			-17
		],
		[
			13,
			1
		],
		[
			2,
			12
		],
		[
			8,
			18
		],
		[
			5,
			-3
		],
		[
			13,
			0
		],
		[
			1,
			9
		],
		[
			15,
			-2
		],
		[
			7,
			4
		],
		[
			-7,
			4
		],
		[
			10,
			6
		],
		[
			9,
			-5
		],
		[
			0,
			-20
		],
		[
			-3,
			-4
		],
		[
			-4,
			11
		],
		[
			-9,
			-3
		],
		[
			-8,
			-23
		],
		[
			-9,
			-17
		],
		[
			-12,
			-6
		],
		[
			-3,
			-12
		],
		[
			-10,
			8
		],
		[
			0,
			-8
		],
		[
			8,
			-15
		],
		[
			5,
			-3
		],
		[
			11,
			-32
		],
		[
			7,
			-26
		],
		[
			-5,
			-8
		],
		[
			-1,
			-14
		],
		[
			13,
			-17
		],
		[
			-1,
			-9
		],
		[
			7,
			-3
		],
		[
			0,
			-15
		],
		[
			-4,
			-6
		],
		[
			-4,
			6
		],
		[
			-14,
			-7
		],
		[
			-2,
			-7
		],
		[
			2,
			-12
		],
		[
			-12,
			1
		],
		[
			-5,
			9
		],
		[
			1,
			25
		],
		[
			3,
			8
		],
		[
			-8,
			7
		],
		[
			-13,
			25
		],
		[
			0,
			9
		],
		[
			5,
			10
		],
		[
			1,
			26
		],
		[
			-8,
			8
		],
		[
			-17,
			-20
		],
		[
			6,
			-16
		],
		[
			0,
			-25
		],
		[
			-2,
			-12
		],
		[
			1,
			-36
		],
		[
			2,
			-7
		],
		[
			-4,
			-14
		],
		[
			-1,
			-14
		],
		[
			5,
			-24
		],
		[
			-15,
			-2
		],
		[
			-4,
			-8
		],
		[
			-11,
			16
		],
		[
			0,
			14
		],
		[
			3,
			7
		],
		[
			0,
			18
		],
		[
			4,
			19
		],
		[
			0,
			23
		],
		[
			-5,
			19
		],
		[
			2,
			12
		],
		[
			-6,
			3
		],
		[
			-10,
			-8
		],
		[
			-3,
			14
		],
		[
			2,
			27
		],
		[
			-4,
			0
		],
		[
			1,
			13
		],
		[
			3,
			-1
		],
		[
			7,
			11
		],
		[
			-1,
			15
		],
		[
			3,
			13
		],
		[
			4,
			2
		],
		[
			-2,
			14
		],
		[
			0,
			26
		],
		[
			5,
			11
		],
		[
			1,
			11
		],
		[
			7,
			11
		],
		[
			1,
			50
		],
		[
			3,
			16
		],
		[
			4,
			4
		],
		[
			-1,
			10
		],
		[
			9,
			8
		],
		[
			7,
			-3
		],
		[
			6,
			14
		],
		[
			0,
			15
		],
		[
			3,
			3
		],
		[
			10,
			-7
		],
		[
			5,
			3
		],
		[
			0,
			-9
		],
		[
			5,
			-4
		],
		[
			8,
			2
		],
		[
			8,
			-5
		],
		[
			7,
			1
		],
		[
			10,
			-12
		],
		[
			4,
			8
		],
		[
			19,
			-6
		],
		[
			8,
			1
		],
		[
			10,
			8
		],
		[
			9,
			23
		],
		[
			10,
			19
		],
		[
			2,
			-4
		]
	],
	[
		[
			7825,
			5301
		],
		[
			0,
			-16
		],
		[
			-7,
			-2
		],
		[
			-2,
			18
		],
		[
			9,
			0
		]
	],
	[
		[
			8556,
			5309
		],
		[
			-6,
			-20
		],
		[
			5,
			-6
		],
		[
			0,
			-25
		],
		[
			-11,
			-20
		],
		[
			3,
			-8
		],
		[
			6,
			3
		],
		[
			0,
			8
		],
		[
			7,
			8
		],
		[
			-3,
			5
		],
		[
			3,
			9
		],
		[
			11,
			11
		],
		[
			4,
			-1
		],
		[
			-1,
			-29
		],
		[
			-11,
			-9
		],
		[
			0,
			-14
		],
		[
			11,
			-6
		],
		[
			0,
			-13
		],
		[
			-20,
			8
		],
		[
			-3,
			-10
		],
		[
			1,
			-20
		],
		[
			5,
			-25
		],
		[
			10,
			-24
		],
		[
			-11,
			11
		],
		[
			-5,
			20
		],
		[
			-5,
			6
		],
		[
			1,
			34
		],
		[
			-4,
			4
		],
		[
			-2,
			38
		],
		[
			-3,
			10
		],
		[
			4,
			12
		],
		[
			0,
			12
		],
		[
			4,
			16
		],
		[
			10,
			15
		]
	],
	[
		[
			8571,
			5333
		],
		[
			3,
			-7
		],
		[
			-3,
			-21
		],
		[
			-8,
			-7
		],
		[
			-3,
			16
		],
		[
			5,
			13
		],
		[
			6,
			6
		]
	],
	[
		[
			7663,
			5350
		],
		[
			2,
			-7
		],
		[
			14,
			-20
		],
		[
			-5,
			0
		],
		[
			-14,
			13
		],
		[
			-4,
			9
		],
		[
			7,
			5
		]
	],
	[
		[
			8268,
			5370
		],
		[
			-4,
			6
		],
		[
			4,
			4
		],
		[
			0,
			-10
		]
	],
	[
		[
			8489,
			5385
		],
		[
			-4,
			-3
		],
		[
			0,
			16
		],
		[
			4,
			-13
		]
	],
	[
		[
			8269,
			5423
		],
		[
			5,
			-1
		]
	],
	[
		[
			8274,
			5422
		],
		[
			-2,
			-7
		],
		[
			-3,
			8
		]
	],
	[
		[
			8008,
			5418
		],
		[
			2,
			-16
		],
		[
			-2,
			-7
		],
		[
			-8,
			11
		],
		[
			-1,
			9
		],
		[
			7,
			11
		],
		[
			2,
			-8
		]
	],
	[
		[
			8265,
			5422
		],
		[
			-5,
			1
		],
		[
			11,
			-21
		],
		[
			-1,
			-10
		],
		[
			-15,
			-1
		],
		[
			7,
			-13
		],
		[
			-5,
			-10
		],
		[
			11,
			-13
		],
		[
			-4,
			-4
		],
		[
			16,
			-37
		],
		[
			-8,
			-15
		],
		[
			1,
			-8
		],
		[
			7,
			-13
		],
		[
			9,
			-10
		],
		[
			10,
			-16
		],
		[
			6,
			-14
		],
		[
			-7,
			-9
		],
		[
			-16,
			4
		],
		[
			-8,
			12
		],
		[
			4,
			-17
		],
		[
			-6,
			2
		],
		[
			-6,
			-18
		],
		[
			-4,
			-26
		],
		[
			2,
			-2
		],
		[
			-3,
			-17
		],
		[
			1,
			-14
		],
		[
			4,
			4
		],
		[
			-3,
			-14
		],
		[
			4,
			-4
		],
		[
			-9,
			-8
		],
		[
			-1,
			5
		],
		[
			-7,
			-22
		],
		[
			-14,
			-16
		],
		[
			1,
			-8
		],
		[
			-9,
			-10
		],
		[
			6,
			1
		],
		[
			-2,
			-24
		],
		[
			6,
			0
		],
		[
			-2,
			-19
		],
		[
			-4,
			-2
		],
		[
			0,
			-18
		],
		[
			-5,
			-7
		],
		[
			-6,
			-36
		],
		[
			-38,
			-32
		],
		[
			0,
			28
		],
		[
			-14,
			23
		],
		[
			-6,
			-9
		],
		[
			-9,
			3
		],
		[
			0,
			12
		],
		[
			-6,
			-6
		],
		[
			-9,
			20
		],
		[
			-3,
			-10
		],
		[
			3,
			-3
		],
		[
			-14,
			-16
		],
		[
			-9,
			6
		],
		[
			-7,
			-11
		],
		[
			-4,
			-1
		],
		[
			1,
			27
		],
		[
			-4,
			17
		],
		[
			0,
			-10
		],
		[
			-4,
			-4
		],
		[
			-7,
			5
		],
		[
			-9,
			-9
		],
		[
			-7,
			6
		],
		[
			-2,
			-5
		],
		[
			-3,
			12
		],
		[
			-7,
			-8
		],
		[
			-6,
			62
		],
		[
			-5,
			8
		],
		[
			3,
			3
		],
		[
			2,
			20
		],
		[
			-4,
			16
		],
		[
			-7,
			11
		],
		[
			-7,
			4
		],
		[
			-2,
			-4
		],
		[
			-7,
			21
		],
		[
			0,
			34
		],
		[
			5,
			-2
		],
		[
			-5,
			14
		],
		[
			-5,
			4
		],
		[
			0,
			20
		],
		[
			3,
			50
		],
		[
			7,
			9
		],
		[
			1,
			14
		],
		[
			9,
			9
		]
	],
	[
		[
			8045,
			5303
		],
		[
			-3,
			-16
		],
		[
			3,
			-12
		],
		[
			17,
			-35
		],
		[
			7,
			-8
		],
		[
			8,
			3
		],
		[
			2,
			6
		],
		[
			10,
			4
		],
		[
			7,
			-6
		],
		[
			9,
			2
		],
		[
			8,
			7
		],
		[
			2,
			18
		],
		[
			8,
			7
		],
		[
			15,
			0
		],
		[
			-2,
			-8
		],
		[
			9,
			-3
		],
		[
			11,
			-8
		],
		[
			7,
			12
		],
		[
			16,
			-1
		],
		[
			5,
			12
		],
		[
			1,
			13
		],
		[
			3,
			2
		],
		[
			-1,
			20
		],
		[
			12,
			14
		],
		[
			-4,
			12
		],
		[
			1,
			10
		],
		[
			5,
			10
		],
		[
			6,
			-1
		],
		[
			4,
			65
		],
		[
			5,
			11
		],
		[
			6,
			-4
		],
		[
			3,
			5
		],
		[
			7,
			-4
		],
		[
			10,
			4
		],
		[
			13,
			0
		],
		[
			10,
			-12
		]
	],
	[
		[
			8523,
			5442
		],
		[
			2,
			-13
		],
		[
			-3,
			-14
		],
		[
			-4,
			-2
		],
		[
			2,
			32
		],
		[
			3,
			-3
		]
	],
	[
		[
			7652,
			5506
		],
		[
			11,
			-6
		],
		[
			4,
			-11
		],
		[
			10,
			-6
		],
		[
			12,
			4
		],
		[
			10,
			-8
		],
		[
			9,
			6
		],
		[
			11,
			-21
		],
		[
			3,
			-16
		],
		[
			6,
			-9
		],
		[
			0,
			-16
		],
		[
			13,
			-17
		],
		[
			3,
			-9
		],
		[
			6,
			-5
		],
		[
			20,
			-26
		],
		[
			7,
			-15
		],
		[
			-1,
			-13
		],
		[
			3,
			-5
		],
		[
			3,
			6
		],
		[
			6,
			-23
		],
		[
			14,
			-21
		],
		[
			-2,
			19
		],
		[
			6,
			1
		],
		[
			8,
			-16
		],
		[
			1,
			-14
		],
		[
			10,
			-6
		],
		[
			12,
			-18
		],
		[
			1,
			-19
		],
		[
			7,
			-15
		],
		[
			13,
			-3
		],
		[
			5,
			-14
		],
		[
			-13,
			-13
		],
		[
			8,
			1
		],
		[
			12,
			15
		],
		[
			11,
			-13
		],
		[
			2,
			-18
		],
		[
			-7,
			0
		],
		[
			-6,
			-21
		],
		[
			7,
			-4
		],
		[
			-5,
			-5
		],
		[
			1,
			-12
		],
		[
			4,
			-12
		],
		[
			9,
			-1
		],
		[
			7,
			-6
		],
		[
			6,
			2
		],
		[
			2,
			-16
		],
		[
			1,
			-28
		],
		[
			4,
			-14
		],
		[
			7,
			-5
		],
		[
			-1,
			-9
		],
		[
			8,
			-5
		],
		[
			13,
			-1
		],
		[
			0,
			-13
		],
		[
			5,
			-6
		],
		[
			0,
			-10
		],
		[
			6,
			-4
		],
		[
			2,
			-14
		],
		[
			-6,
			-14
		],
		[
			-1,
			-15
		],
		[
			3,
			-5
		],
		[
			-4,
			-25
		],
		[
			2,
			-13
		],
		[
			0,
			-26
		],
		[
			-2,
			-53
		],
		[
			-7,
			2
		],
		[
			-7,
			19
		],
		[
			-3,
			-6
		],
		[
			0,
			-12
		],
		[
			-8,
			6
		],
		[
			-9,
			11
		],
		[
			-1,
			-4
		],
		[
			5,
			-19
		],
		[
			-4,
			-3
		],
		[
			-3,
			11
		],
		[
			-10,
			17
		],
		[
			-5,
			19
		],
		[
			-7,
			10
		],
		[
			-11,
			12
		],
		[
			-28,
			46
		],
		[
			-1,
			17
		],
		[
			-17,
			23
		],
		[
			-8,
			29
		],
		[
			-9,
			16
		],
		[
			-5,
			17
		],
		[
			2,
			7
		],
		[
			-9,
			34
		],
		[
			0,
			8
		],
		[
			-5,
			3
		],
		[
			1,
			11
		],
		[
			-9,
			30
		],
		[
			-9,
			14
		],
		[
			0,
			13
		],
		[
			-4,
			9
		],
		[
			-9,
			10
		],
		[
			-5,
			1
		],
		[
			-1,
			21
		],
		[
			-9,
			45
		],
		[
			0,
			20
		],
		[
			-3,
			0
		],
		[
			-7,
			14
		],
		[
			-5,
			2
		],
		[
			-9,
			14
		],
		[
			-7,
			6
		],
		[
			-2,
			27
		],
		[
			-5,
			5
		],
		[
			-4,
			14
		],
		[
			-3,
			5
		],
		[
			-8,
			23
		],
		[
			-11,
			6
		],
		[
			-8,
			21
		],
		[
			-6,
			5
		],
		[
			-13,
			28
		],
		[
			-5,
			27
		],
		[
			-3,
			6
		],
		[
			0,
			17
		],
		[
			8,
			2
		]
	],
	[
		[
			4872,
			8298
		],
		[
			-4,
			5
		],
		[
			8,
			13
		],
		[
			4,
			-7
		],
		[
			-8,
			-11
		]
	],
	[
		[
			7606,
			5598
		],
		[
			2,
			-16
		],
		[
			-2,
			-11
		],
		[
			-5,
			16
		],
		[
			0,
			9
		],
		[
			5,
			2
		]
	],
	[
		[
			7571,
			5804
		],
		[
			0,
			-12
		],
		[
			-5,
			0
		],
		[
			-1,
			12
		],
		[
			6,
			0
		]
	],
	[
		[
			7583,
			5964
		],
		[
			1,
			-29
		],
		[
			-3,
			1
		],
		[
			1,
			-36
		],
		[
			-3,
			-2
		],
		[
			1,
			-13
		],
		[
			-5,
			-6
		],
		[
			2,
			-9
		],
		[
			-2,
			-25
		],
		[
			-5,
			13
		],
		[
			5,
			34
		],
		[
			0,
			29
		],
		[
			2,
			1
		],
		[
			0,
			26
		],
		[
			6,
			16
		]
	],
	[
		[
			7448,
			6428
		],
		[
			-4,
			1
		],
		[
			4,
			13
		],
		[
			0,
			-14
		]
	],
	[
		[
			7248,
			6922
		],
		[
			-16,
			-24
		],
		[
			0,
			-12
		],
		[
			-5,
			-9
		],
		[
			1,
			-17
		],
		[
			-7,
			-14
		],
		[
			9,
			-14
		],
		[
			9,
			-1
		],
		[
			7,
			-10
		],
		[
			9,
			-6
		],
		[
			2,
			-11
		],
		[
			15,
			-17
		],
		[
			6,
			3
		],
		[
			11,
			-14
		],
		[
			7,
			2
		],
		[
			1,
			-11
		],
		[
			12,
			-4
		],
		[
			18,
			0
		],
		[
			8,
			4
		],
		[
			6,
			-8
		],
		[
			8,
			-2
		],
		[
			1,
			-18
		],
		[
			8,
			-3
		],
		[
			10,
			-14
		],
		[
			9,
			7
		],
		[
			7,
			-16
		],
		[
			4,
			5
		],
		[
			9,
			-3
		],
		[
			11,
			-11
		],
		[
			7,
			7
		],
		[
			9,
			-11
		],
		[
			13,
			6
		],
		[
			7,
			-5
		],
		[
			4,
			17
		],
		[
			0,
			13
		],
		[
			-6,
			11
		],
		[
			2,
			24
		],
		[
			3,
			21
		]
	],
	[
		[
			7703,
			6808
		],
		[
			0,
			-19
		],
		[
			-13,
			-15
		],
		[
			0,
			-11
		],
		[
			7,
			-21
		],
		[
			-7,
			6
		],
		[
			-4,
			10
		],
		[
			-21,
			-9
		],
		[
			-2,
			-10
		],
		[
			-14,
			-19
		],
		[
			-9,
			-5
		],
		[
			-2,
			-21
		],
		[
			4,
			-12
		],
		[
			-4,
			-6
		],
		[
			0,
			-10
		],
		[
			-10,
			-18
		],
		[
			-2,
			-16
		],
		[
			3,
			-3
		],
		[
			-2,
			-22
		],
		[
			-3,
			-2
		],
		[
			-6,
			-22
		],
		[
			-5,
			-27
		],
		[
			-11,
			9
		],
		[
			-11,
			-2
		],
		[
			4,
			-18
		],
		[
			-2,
			-30
		],
		[
			-9,
			-21
		],
		[
			2,
			-34
		],
		[
			-3,
			1
		],
		[
			-1,
			-12
		],
		[
			-8,
			9
		],
		[
			-3,
			-10
		]
	],
	[
		[
			7473,
			6457
		],
		[
			-4,
			-11
		],
		[
			5,
			-18
		],
		[
			-6,
			2
		],
		[
			-4,
			-6
		],
		[
			-2,
			22
		],
		[
			-5,
			-3
		],
		[
			-1,
			-16
		],
		[
			-7,
			0
		],
		[
			-1,
			26
		],
		[
			-8,
			-18
		],
		[
			-21,
			-14
		],
		[
			-8,
			-19
		],
		[
			6,
			-28
		],
		[
			-7,
			-10
		],
		[
			-4,
			-16
		],
		[
			-4,
			-3
		],
		[
			-6,
			-16
		],
		[
			-19,
			-10
		],
		[
			-5,
			9
		],
		[
			-5,
			-13
		],
		[
			5,
			1
		],
		[
			-15,
			-26
		],
		[
			-9,
			-26
		],
		[
			-13,
			-29
		],
		[
			-9,
			-8
		],
		[
			-6,
			-10
		],
		[
			-9,
			-22
		],
		[
			-21,
			-21
		],
		[
			-6,
			-16
		],
		[
			3,
			-5
		],
		[
			-1,
			-14
		],
		[
			-6,
			-9
		],
		[
			-11,
			-8
		],
		[
			-10,
			4
		],
		[
			-4,
			-3
		],
		[
			-1,
			-20
		],
		[
			-10,
			-15
		],
		[
			-1,
			10
		],
		[
			-6,
			-1
		],
		[
			-9,
			-10
		],
		[
			-3,
			-17
		],
		[
			-2,
			-18
		],
		[
			3,
			-24
		],
		[
			-1,
			-30
		],
		[
			3,
			-29
		],
		[
			-5,
			-4
		],
		[
			7,
			-9
		],
		[
			0,
			-14
		],
		[
			-3,
			-37
		],
		[
			-8,
			-24
		],
		[
			-4,
			-26
		],
		[
			2,
			-16
		],
		[
			0,
			-46
		],
		[
			1,
			-17
		],
		[
			-15,
			0
		],
		[
			-2,
			-15
		],
		[
			-8,
			-21
		],
		[
			-2,
			-13
		],
		[
			5,
			-9
		],
		[
			-20,
			-12
		],
		[
			-5,
			-12
		],
		[
			-2,
			-22
		],
		[
			-2,
			-8
		],
		[
			-16,
			-16
		],
		[
			-7,
			6
		],
		[
			-11,
			22
		],
		[
			-7,
			19
		],
		[
			-6,
			25
		],
		[
			-3,
			32
		],
		[
			4,
			-10
		],
		[
			0,
			11
		],
		[
			-6,
			7
		],
		[
			-2,
			18
		],
		[
			-6,
			30
		],
		[
			-1,
			14
		],
		[
			-9,
			36
		],
		[
			-9,
			17
		],
		[
			-6,
			25
		],
		[
			-6,
			34
		],
		[
			-2,
			33
		],
		[
			-8,
			39
		],
		[
			-1,
			14
		],
		[
			-7,
			14
		],
		[
			-2,
			12
		],
		[
			-4,
			5
		],
		[
			0,
			15
		],
		[
			-3,
			4
		],
		[
			-4,
			24
		],
		[
			-4,
			8
		],
		[
			-5,
			29
		],
		[
			-1,
			37
		],
		[
			-5,
			30
		],
		[
			-6,
			45
		],
		[
			1,
			7
		],
		[
			-3,
			22
		],
		[
			-1,
			23
		],
		[
			-3,
			24
		],
		[
			2,
			33
		],
		[
			4,
			12
		],
		[
			-2,
			36
		],
		[
			-3,
			-4
		],
		[
			-3,
			11
		],
		[
			2,
			16
		],
		[
			12,
			11
		],
		[
			-16,
			-3
		],
		[
			2,
			14
		],
		[
			-2,
			14
		],
		[
			9,
			5
		],
		[
			-13,
			4
		],
		[
			-2,
			-15
		],
		[
			-8,
			-7
		],
		[
			8,
			-18
		],
		[
			-6,
			-25
		],
		[
			-17,
			-17
		],
		[
			-14,
			-11
		],
		[
			-5,
			0
		],
		[
			-10,
			9
		],
		[
			-11,
			17
		],
		[
			-15,
			33
		],
		[
			-15,
			29
		],
		[
			0,
			10
		],
		[
			7,
			1
		],
		[
			0,
			-9
		],
		[
			14,
			12
		],
		[
			3,
			-3
		],
		[
			9,
			7
		],
		[
			7,
			23
		],
		[
			-10,
			-1
		],
		[
			-9,
			-10
		],
		[
			-13,
			5
		],
		[
			-11,
			10
		],
		[
			-9,
			15
		],
		[
			-4,
			19
		],
		[
			-6,
			14
		]
	],
	[
		[
			6893,
			6556
		],
		[
			5,
			7
		],
		[
			10,
			0
		],
		[
			0,
			19
		],
		[
			13,
			-3
		],
		[
			11,
			2
		],
		[
			5,
			-7
		],
		[
			6,
			0
		],
		[
			3,
			8
		],
		[
			13,
			7
		],
		[
			0,
			-8
		],
		[
			6,
			-3
		],
		[
			9,
			10
		],
		[
			-4,
			12
		],
		[
			3,
			3
		],
		[
			-5,
			27
		],
		[
			-6,
			14
		],
		[
			0,
			17
		],
		[
			-10,
			1
		],
		[
			-6,
			14
		],
		[
			2,
			35
		],
		[
			-9,
			2
		],
		[
			-10,
			11
		],
		[
			1,
			17
		],
		[
			10,
			20
		],
		[
			6,
			22
		],
		[
			7,
			12
		],
		[
			6,
			1
		],
		[
			4,
			-16
		],
		[
			4,
			-2
		],
		[
			9,
			7
		],
		[
			20,
			8
		],
		[
			0,
			9
		],
		[
			8,
			16
		],
		[
			5,
			21
		],
		[
			16,
			16
		],
		[
			9,
			29
		],
		[
			3,
			22
		],
		[
			12,
			8
		],
		[
			4,
			7
		],
		[
			-2,
			10
		],
		[
			6,
			11
		],
		[
			6,
			19
		],
		[
			10,
			12
		],
		[
			-4,
			2
		],
		[
			3,
			17
		],
		[
			-2,
			24
		],
		[
			7,
			10
		],
		[
			14,
			8
		],
		[
			1,
			10
		],
		[
			-8,
			8
		],
		[
			-11,
			2
		],
		[
			0,
			14
		],
		[
			-9,
			2
		],
		[
			0,
			13
		],
		[
			-9,
			10
		],
		[
			4,
			22
		],
		[
			-5,
			5
		],
		[
			1,
			10
		],
		[
			7,
			10
		],
		[
			-9,
			1
		],
		[
			1,
			16
		],
		[
			-5,
			3
		],
		[
			4,
			19
		],
		[
			13,
			6
		],
		[
			7,
			-5
		],
		[
			16,
			-2
		],
		[
			11,
			-9
		],
		[
			11,
			11
		],
		[
			17,
			3
		],
		[
			3,
			10
		],
		[
			5,
			1
		],
		[
			4,
			11
		]
	],
	[
		[
			7140,
			7205
		],
		[
			20,
			22
		]
	],
	[
		[
			4825,
			8298
		],
		[
			2,
			-37
		],
		[
			6,
			-29
		],
		[
			-6,
			-16
		],
		[
			-4,
			-28
		],
		[
			-10,
			1
		],
		[
			-8,
			-4
		],
		[
			-12,
			0
		],
		[
			-5,
			-10
		],
		[
			-7,
			0
		],
		[
			-4,
			-8
		],
		[
			-7,
			-1
		],
		[
			-12,
			-14
		],
		[
			-20,
			0
		],
		[
			-11,
			-8
		],
		[
			10,
			14
		],
		[
			-20,
			-4
		],
		[
			12,
			13
		],
		[
			-11,
			-6
		],
		[
			-7,
			10
		],
		[
			13,
			14
		],
		[
			-15,
			-2
		],
		[
			5,
			10
		],
		[
			13,
			-2
		],
		[
			-1,
			11
		],
		[
			8,
			12
		],
		[
			-10,
			-5
		],
		[
			12,
			12
		],
		[
			5,
			21
		],
		[
			10,
			8
		],
		[
			-16,
			-2
		],
		[
			-14,
			9
		],
		[
			-3,
			9
		],
		[
			6,
			13
		],
		[
			0,
			24
		],
		[
			-5,
			4
		],
		[
			22,
			4
		],
		[
			23,
			-3
		],
		[
			-5,
			4
		],
		[
			12,
			9
		],
		[
			3,
			8
		],
		[
			-15,
			-1
		],
		[
			-2,
			7
		],
		[
			10,
			6
		],
		[
			2,
			18
		],
		[
			15,
			2
		],
		[
			6,
			-6
		],
		[
			4,
			17
		],
		[
			13,
			-9
		],
		[
			-9,
			-9
		]
	],
	[
		[
			6560,
			6732
		],
		[
			-4,
			-9
		],
		[
			-5,
			0
		],
		[
			-16,
			-12
		],
		[
			0,
			7
		],
		[
			13,
			7
		],
		[
			13,
			13
		],
		[
			-1,
			-6
		]
	],
	[
		[
			6357,
			7396
		],
		[
			3,
			-38
		],
		[
			4,
			-9
		],
		[
			9,
			-7
		],
		[
			13,
			-2
		],
		[
			9,
			-5
		],
		[
			2,
			-13
		],
		[
			21,
			-24
		],
		[
			23,
			-9
		],
		[
			43,
			18
		],
		[
			16,
			-4
		],
		[
			-3,
			30
		]
	],
	[
		[
			6497,
			7333
		],
		[
			8,
			-1
		],
		[
			16,
			11
		],
		[
			1,
			13
		],
		[
			9,
			13
		],
		[
			9,
			7
		],
		[
			24,
			0
		],
		[
			3,
			10
		],
		[
			17,
			-4
		],
		[
			5,
			4
		],
		[
			3,
			-17
		],
		[
			23,
			-10
		],
		[
			8,
			-9
		],
		[
			10,
			3
		],
		[
			11,
			-10
		],
		[
			10,
			-21
		],
		[
			13,
			-7
		],
		[
			8,
			-22
		],
		[
			23,
			0
		],
		[
			2,
			-31
		],
		[
			-3,
			-8
		],
		[
			4,
			-5
		],
		[
			0,
			-15
		]
	],
	[
		[
			6689,
			6902
		],
		[
			14,
			-27
		],
		[
			0,
			-8
		],
		[
			6,
			-21
		],
		[
			10,
			-20
		],
		[
			14,
			-8
		],
		[
			5,
			-10
		],
		[
			5,
			-1
		],
		[
			-1,
			-12
		],
		[
			2,
			-18
		],
		[
			-1,
			-26
		],
		[
			11,
			2
		],
		[
			4,
			-8
		],
		[
			-4,
			-17
		],
		[
			0,
			-11
		],
		[
			-12,
			0
		],
		[
			-12,
			-7
		],
		[
			-2,
			-10
		],
		[
			-11,
			-7
		],
		[
			-7,
			-59
		]
	],
	[
		[
			6710,
			6634
		],
		[
			-5,
			-8
		],
		[
			-10,
			9
		],
		[
			-12,
			4
		],
		[
			-1,
			9
		],
		[
			-5,
			-6
		],
		[
			-24,
			3
		],
		[
			-2,
			4
		],
		[
			-12,
			-4
		],
		[
			-6,
			10
		],
		[
			-7,
			2
		],
		[
			-14,
			-2
		],
		[
			-4,
			8
		],
		[
			-17,
			5
		],
		[
			-4,
			19
		],
		[
			-4,
			42
		],
		[
			-6,
			17
		],
		[
			-11,
			3
		],
		[
			-8,
			-2
		],
		[
			-5,
			-8
		],
		[
			-9,
			-4
		],
		[
			-3,
			-11
		],
		[
			-6,
			2
		],
		[
			-13,
			-17
		],
		[
			-11,
			5
		],
		[
			-3,
			7
		],
		[
			-17,
			0
		],
		[
			-8,
			16
		],
		[
			-10,
			6
		],
		[
			-13,
			16
		],
		[
			-4,
			16
		],
		[
			-12,
			11
		],
		[
			-9,
			-1
		],
		[
			-8,
			6
		],
		[
			-9,
			35
		],
		[
			0,
			12
		],
		[
			-8,
			13
		],
		[
			2,
			10
		],
		[
			-6,
			0
		],
		[
			1,
			16
		],
		[
			-15,
			30
		],
		[
			0,
			10
		],
		[
			-5,
			6
		],
		[
			-11,
			-12
		],
		[
			-2,
			9
		],
		[
			-7,
			-1
		],
		[
			-9,
			13
		],
		[
			8,
			-1
		],
		[
			0,
			9
		],
		[
			-9,
			-8
		],
		[
			1,
			-20
		],
		[
			-11,
			-4
		]
	],
	[
		[
			6347,
			6908
		],
		[
			-3,
			15
		],
		[
			-11,
			14
		],
		[
			0,
			31
		],
		[
			-9,
			0
		],
		[
			0,
			23
		],
		[
			4,
			21
		],
		[
			-9,
			22
		],
		[
			-5,
			19
		],
		[
			-6,
			-1
		],
		[
			-14,
			21
		],
		[
			-16,
			15
		],
		[
			4,
			5
		],
		[
			-4,
			15
		],
		[
			-11,
			15
		],
		[
			-5,
			22
		],
		[
			3,
			14
		],
		[
			-4,
			8
		],
		[
			2,
			8
		],
		[
			6,
			-3
		],
		[
			-2,
			9
		],
		[
			7,
			21
		],
		[
			7,
			2
		],
		[
			1,
			7
		],
		[
			-6,
			16
		],
		[
			1,
			10
		],
		[
			6,
			2
		],
		[
			-4,
			9
		],
		[
			-6,
			-3
		],
		[
			-14,
			14
		],
		[
			-3,
			21
		],
		[
			-5,
			0
		],
		[
			-1,
			18
		],
		[
			-6,
			5
		],
		[
			2,
			12
		],
		[
			-3,
			7
		]
	],
	[
		[
			6243,
			7322
		],
		[
			0,
			10
		],
		[
			-6,
			6
		],
		[
			1,
			17
		],
		[
			-10,
			17
		],
		[
			6,
			20
		],
		[
			-4,
			0
		],
		[
			-3,
			45
		],
		[
			-5,
			13
		],
		[
			11,
			4
		],
		[
			4,
			19
		],
		[
			7,
			-7
		]
	],
	[
		[
			6347,
			6908
		],
		[
			-13,
			5
		],
		[
			-3,
			-3
		]
	],
	[
		[
			6331,
			6910
		],
		[
			-7,
			6
		],
		[
			-9,
			0
		],
		[
			-6,
			-5
		],
		[
			-8,
			-33
		],
		[
			-9,
			-20
		]
	],
	[
		[
			6292,
			6858
		],
		[
			-5,
			-2
		],
		[
			-46,
			8
		],
		[
			-62,
			91
		],
		[
			-11,
			18
		],
		[
			-47,
			49
		],
		[
			-34,
			10
		]
	],
	[
		[
			6087,
			7032
		],
		[
			4,
			8
		],
		[
			-7,
			3
		],
		[
			0,
			11
		],
		[
			-8,
			51
		]
	],
	[
		[
			6076,
			7105
		],
		[
			4,
			3
		],
		[
			43,
			44
		],
		[
			14,
			11
		],
		[
			7,
			22
		],
		[
			1,
			40
		],
		[
			3,
			8
		],
		[
			-2,
			23
		]
	],
	[
		[
			6146,
			7256
		],
		[
			0,
			0
		]
	],
	[
		[
			6146,
			7256
		],
		[
			0,
			20
		],
		[
			3,
			10
		],
		[
			13,
			5
		],
		[
			15,
			26
		],
		[
			-1,
			3
		]
	],
	[
		[
			6176,
			7320
		],
		[
			6,
			2
		],
		[
			6,
			13
		],
		[
			9,
			0
		],
		[
			10,
			-7
		],
		[
			12,
			-2
		],
		[
			8,
			4
		],
		[
			1,
			-18
		],
		[
			11,
			12
		],
		[
			4,
			-2
		]
	],
	[
		[
			4554,
			9014
		],
		[
			7,
			-14
		],
		[
			12,
			-7
		],
		[
			12,
			13
		],
		[
			-4,
			-20
		],
		[
			10,
			2
		],
		[
			-2,
			-20
		],
		[
			12,
			4
		],
		[
			0,
			-8
		],
		[
			21,
			-10
		],
		[
			-4,
			-10
		],
		[
			6,
			-8
		],
		[
			-13,
			-25
		],
		[
			-13,
			-4
		],
		[
			-2,
			-15
		],
		[
			-24,
			-8
		],
		[
			-39,
			-26
		],
		[
			-31,
			-6
		],
		[
			-1,
			-11
		],
		[
			-23,
			-7
		],
		[
			-27,
			8
		],
		[
			-12,
			0
		],
		[
			-28,
			20
		],
		[
			-42,
			-4
		],
		[
			4,
			9
		],
		[
			14,
			4
		],
		[
			10,
			10
		],
		[
			2,
			11
		],
		[
			-13,
			-6
		],
		[
			-9,
			29
		],
		[
			-32,
			1
		],
		[
			-11,
			-4
		],
		[
			-3,
			8
		],
		[
			23,
			2
		],
		[
			15,
			8
		],
		[
			25,
			-2
		],
		[
			-21,
			7
		],
		[
			22,
			16
		],
		[
			-39,
			7
		],
		[
			-20,
			-9
		],
		[
			-18,
			6
		],
		[
			7,
			8
		],
		[
			12,
			-7
		],
		[
			-8,
			15
		],
		[
			17,
			-5
		],
		[
			-9,
			12
		],
		[
			10,
			17
		],
		[
			20,
			-8
		],
		[
			-5,
			7
		],
		[
			9,
			16
		],
		[
			11,
			-11
		],
		[
			25,
			-14
		],
		[
			-2,
			-19
		],
		[
			9,
			-29
		],
		[
			0,
			13
		],
		[
			9,
			15
		],
		[
			9,
			-10
		],
		[
			5,
			13
		],
		[
			-5,
			20
		],
		[
			9,
			3
		],
		[
			13,
			-22
		],
		[
			6,
			-1
		],
		[
			-1,
			19
		],
		[
			22,
			6
		],
		[
			16,
			-26
		],
		[
			-6,
			27
		],
		[
			10,
			-1
		],
		[
			10,
			-11
		],
		[
			12,
			14
		],
		[
			6,
			-6
		],
		[
			13,
			3
		],
		[
			-3,
			19
		],
		[
			15,
			2
		]
	],
	[
		[
			5993,
			7068
		],
		[
			-6,
			-5
		],
		[
			0,
			-15
		]
	],
	[
		[
			5987,
			7048
		],
		[
			-10,
			8
		],
		[
			-6,
			-14
		],
		[
			0,
			-19
		],
		[
			6,
			-9
		],
		[
			-7,
			-11
		],
		[
			-2,
			-14
		],
		[
			10,
			1
		],
		[
			5,
			6
		]
	],
	[
		[
			5983,
			6996
		],
		[
			0,
			-9
		]
	],
	[
		[
			5983,
			6987
		],
		[
			0,
			-6
		]
	],
	[
		[
			5983,
			6981
		],
		[
			1,
			-8
		]
	],
	[
		[
			5984,
			6973
		],
		[
			-8,
			-34
		],
		[
			0,
			-21
		],
		[
			-6,
			-33
		]
	],
	[
		[
			5970,
			6885
		],
		[
			-2,
			-4
		]
	],
	[
		[
			5951,
			6980
		],
		[
			8,
			18
		],
		[
			-2,
			4
		]
	],
	[
		[
			5957,
			7002
		],
		[
			7,
			21
		],
		[
			6,
			44
		],
		[
			5,
			21
		]
	],
	[
		[
			5975,
			7088
		],
		[
			10,
			0
		],
		[
			1,
			9
		],
		[
			8,
			10
		]
	],
	[
		[
			5994,
			7107
		],
		[
			-1,
			-9
		],
		[
			3,
			-19
		],
		[
			-3,
			-11
		]
	],
	[
		[
			5434,
			7386
		],
		[
			-12,
			-29
		],
		[
			-3,
			-25
		],
		[
			6,
			-18
		],
		[
			-6,
			-11
		],
		[
			1,
			-8
		],
		[
			-10,
			1
		],
		[
			-8,
			6
		],
		[
			-3,
			10
		],
		[
			-7,
			8
		],
		[
			-7,
			-1
		],
		[
			-25,
			27
		],
		[
			-10,
			1
		],
		[
			-4,
			6
		],
		[
			0,
			19
		],
		[
			7,
			6
		],
		[
			6,
			-6
		],
		[
			4,
			10
		],
		[
			7,
			1
		],
		[
			10,
			-13
		],
		[
			9,
			4
		],
		[
			9,
			-2
		],
		[
			17,
			10
		],
		[
			4,
			-4
		],
		[
			12,
			11
		],
		[
			3,
			-3
		]
	],
	[
		[
			5256,
			7557
		],
		[
			8,
			-6
		],
		[
			8,
			-34
		],
		[
			-5,
			-14
		],
		[
			3,
			-13
		],
		[
			-2,
			-30
		],
		[
			-6,
			-24
		],
		[
			-10,
			6
		],
		[
			-5,
			-19
		],
		[
			-8,
			0
		],
		[
			-7,
			17
		],
		[
			5,
			39
		],
		[
			-4,
			1
		],
		[
			2,
			23
		],
		[
			-5,
			17
		],
		[
			-4,
			0
		],
		[
			2,
			16
		],
		[
			8,
			-2
		],
		[
			9,
			6
		],
		[
			11,
			17
		]
	],
	[
		[
			5380,
			7862
		],
		[
			-9,
			-16
		],
		[
			7,
			-7
		],
		[
			-4,
			-8
		],
		[
			3,
			-12
		],
		[
			8,
			-10
		],
		[
			-5,
			-1
		]
	],
	[
		[
			5380,
			7808
		],
		[
			1,
			7
		],
		[
			-18,
			1
		],
		[
			-3,
			-5
		],
		[
			-16,
			-12
		],
		[
			-4,
			2
		],
		[
			-1,
			-16
		],
		[
			9,
			-13
		],
		[
			-6,
			-7
		],
		[
			-2,
			-13
		],
		[
			2,
			-18
		],
		[
			8,
			-16
		],
		[
			9,
			-7
		],
		[
			19,
			-21
		],
		[
			12,
			-54
		],
		[
			18,
			-28
		],
		[
			12,
			-11
		],
		[
			25,
			0
		],
		[
			4,
			-9
		],
		[
			-8,
			-15
		],
		[
			19,
			-17
		],
		[
			13,
			-7
		],
		[
			14,
			-18
		],
		[
			13,
			-8
		],
		[
			0,
			-6
		],
		[
			12,
			-15
		],
		[
			2,
			-10
		],
		[
			-4,
			-18
		],
		[
			-9,
			6
		],
		[
			-5,
			23
		],
		[
			-11,
			0
		],
		[
			-14,
			11
		],
		[
			-11,
			-25
		],
		[
			-2,
			-21
		],
		[
			9,
			-5
		],
		[
			9,
			-11
		],
		[
			-1,
			-29
		],
		[
			-11,
			-1
		],
		[
			-5,
			-8
		],
		[
			1,
			-18
		],
		[
			-8,
			-10
		],
		[
			-8,
			-20
		],
		[
			-10,
			4
		],
		[
			0,
			15
		],
		[
			5,
			3
		],
		[
			3,
			12
		],
		[
			-3,
			8
		],
		[
			9,
			5
		],
		[
			2,
			12
		],
		[
			-4,
			8
		],
		[
			-2,
			21
		],
		[
			-4,
			6
		],
		[
			-2,
			20
		],
		[
			-7,
			11
		],
		[
			-5,
			-5
		],
		[
			-12,
			13
		],
		[
			2,
			8
		],
		[
			-6,
			18
		],
		[
			-8,
			1
		],
		[
			-5,
			8
		],
		[
			-7,
			3
		],
		[
			-10,
			22
		],
		[
			-10,
			1
		],
		[
			-8,
			-3
		],
		[
			-5,
			11
		],
		[
			-7,
			2
		],
		[
			-12,
			24
		],
		[
			-10,
			10
		],
		[
			-8,
			18
		],
		[
			-10,
			5
		],
		[
			-3,
			12
		],
		[
			-9,
			9
		],
		[
			1,
			6
		],
		[
			-8,
			2
		],
		[
			1,
			18
		],
		[
			-7,
			17
		],
		[
			0,
			14
		],
		[
			-5,
			13
		],
		[
			-7,
			1
		],
		[
			-16,
			17
		],
		[
			-15,
			5
		],
		[
			-14,
			-19
		],
		[
			-3,
			-11
		],
		[
			-17,
			-6
		]
	],
	[
		[
			5344,
			7711
		],
		[
			0,
			0
		]
	],
	[
		[
			5345,
			7596
		],
		[
			0,
			0
		]
	],
	[
		[
			2849,
			6246
		],
		[
			15,
			-3
		],
		[
			3,
			-8
		],
		[
			12,
			-7
		],
		[
			4,
			-14
		],
		[
			-9,
			-3
		],
		[
			-10,
			6
		],
		[
			-1,
			-7
		],
		[
			-6,
			3
		],
		[
			-1,
			-11
		],
		[
			-7,
			10
		],
		[
			-8,
			-1
		],
		[
			-7,
			10
		],
		[
			-3,
			10
		],
		[
			-8,
			2
		],
		[
			5,
			12
		],
		[
			10,
			5
		],
		[
			11,
			-4
		]
	],
	[
		[
			6087,
			7032
		],
		[
			-4,
			-6
		],
		[
			-57,
			-30
		],
		[
			15,
			-28
		],
		[
			13,
			-29
		],
		[
			-9,
			-10
		],
		[
			-4,
			-18
		],
		[
			-21,
			-8
		],
		[
			-7,
			-22
		],
		[
			-12,
			-17
		],
		[
			-31,
			9
		]
	],
	[
		[
			5970,
			6873
		],
		[
			0,
			12
		]
	],
	[
		[
			5984,
			6973
		],
		[
			-1,
			8
		]
	],
	[
		[
			5983,
			6987
		],
		[
			4,
			0
		],
		[
			0,
			25
		]
	],
	[
		[
			5987,
			7012
		],
		[
			0,
			36
		]
	],
	[
		[
			5993,
			7068
		],
		[
			7,
			-5
		],
		[
			10,
			-16
		],
		[
			12,
			-3
		],
		[
			54,
			61
		]
	],
	[
		[
			8563,
			6721
		],
		[
			-5,
			-10
		],
		[
			-7,
			-5
		],
		[
			-4,
			-21
		],
		[
			0,
			20
		],
		[
			7,
			8
		],
		[
			-3,
			7
		],
		[
			7,
			-1
		],
		[
			4,
			12
		],
		[
			1,
			-10
		]
	],
	[
		[
			8603,
			6820
		],
		[
			-13,
			-15
		],
		[
			0,
			9
		],
		[
			11,
			11
		],
		[
			2,
			-5
		]
	],
	[
		[
			8624,
			6937
		],
		[
			5,
			-5
		],
		[
			-7,
			-8
		],
		[
			2,
			13
		]
	],
	[
		[
			8639,
			6942
		],
		[
			-5,
			-5
		],
		[
			6,
			22
		],
		[
			-1,
			-17
		]
	],
	[
		[
			8616,
			7056
		],
		[
			0,
			-12
		],
		[
			-6,
			-7
		],
		[
			1,
			18
		],
		[
			5,
			1
		]
	],
	[
		[
			8578,
			7069
		],
		[
			-1,
			-10
		],
		[
			-6,
			2
		],
		[
			7,
			8
		]
	],
	[
		[
			8638,
			7135
		],
		[
			3,
			-16
		],
		[
			7,
			-3
		],
		[
			9,
			6
		],
		[
			1,
			-15
		],
		[
			-5,
			-9
		],
		[
			10,
			1
		],
		[
			0,
			-17
		],
		[
			5,
			-2
		],
		[
			-11,
			-22
		],
		[
			-6,
			-38
		],
		[
			0,
			-16
		],
		[
			-3,
			-14
		],
		[
			-7,
			5
		],
		[
			1,
			-11
		],
		[
			-12,
			-13
		],
		[
			2,
			20
		],
		[
			-5,
			12
		],
		[
			-2,
			-4
		],
		[
			0,
			-22
		],
		[
			-9,
			5
		],
		[
			4,
			18
		],
		[
			-5,
			12
		],
		[
			1,
			21
		],
		[
			2,
			-2
		],
		[
			8,
			19
		],
		[
			-2,
			11
		],
		[
			3,
			12
		],
		[
			-5,
			15
		],
		[
			-8,
			2
		],
		[
			7,
			-19
		],
		[
			-6,
			-11
		],
		[
			1,
			11
		],
		[
			-10,
			-10
		],
		[
			-6,
			18
		],
		[
			1,
			10
		],
		[
			4,
			-14
		],
		[
			5,
			-1
		],
		[
			-1,
			10
		],
		[
			-11,
			11
		],
		[
			1,
			10
		],
		[
			6,
			-2
		],
		[
			18,
			22
		],
		[
			2,
			9
		],
		[
			6,
			4
		],
		[
			7,
			-3
		]
	],
	[
		[
			8726,
			7162
		],
		[
			8,
			-9
		],
		[
			5,
			1
		],
		[
			-1,
			-13
		],
		[
			4,
			-10
		],
		[
			-10,
			-11
		],
		[
			-5,
			-23
		],
		[
			-8,
			15
		],
		[
			-5,
			2
		],
		[
			-13,
			-11
		],
		[
			0,
			-7
		],
		[
			-7,
			-11
		],
		[
			-1,
			-16
		],
		[
			-10,
			0
		],
		[
			3,
			9
		],
		[
			-6,
			1
		],
		[
			-6,
			31
		],
		[
			11,
			14
		],
		[
			2,
			17
		],
		[
			6,
			6
		],
		[
			5,
			-10
		],
		[
			10,
			2
		],
		[
			3,
			14
		],
		[
			8,
			9
		],
		[
			7,
			0
		]
	],
	[
		[
			8747,
			7160
		],
		[
			-3,
			-8
		],
		[
			-3,
			8
		],
		[
			8,
			15
		],
		[
			-2,
			-15
		]
	],
	[
		[
			8595,
			7181
		],
		[
			-2,
			-23
		],
		[
			-3,
			4
		],
		[
			1,
			16
		],
		[
			4,
			3
		]
	],
	[
		[
			8845,
			7375
		],
		[
			1,
			-10
		],
		[
			-6,
			-6
		],
		[
			-1,
			17
		],
		[
			8,
			13
		],
		[
			-2,
			-14
		]
	],
	[
		[
			8923,
			7564
		],
		[
			5,
			3
		],
		[
			-1,
			-34
		],
		[
			2,
			-14
		],
		[
			8,
			-11
		],
		[
			5,
			-22
		],
		[
			4,
			-26
		],
		[
			-5,
			-14
		],
		[
			0,
			-12
		],
		[
			-7,
			-6
		],
		[
			-5,
			-25
		],
		[
			1,
			-17
		],
		[
			-6,
			9
		],
		[
			-7,
			-6
		],
		[
			-3,
			-24
		],
		[
			3,
			-14
		],
		[
			-2,
			-39
		],
		[
			-5,
			-8
		],
		[
			-5,
			-19
		],
		[
			-1,
			-20
		],
		[
			8,
			-27
		],
		[
			-11,
			-7
		],
		[
			-2,
			-21
		],
		[
			-16,
			-17
		],
		[
			2,
			30
		],
		[
			5,
			11
		],
		[
			-8,
			0
		],
		[
			-4,
			-12
		],
		[
			1,
			-16
		],
		[
			-7,
			11
		],
		[
			-8,
			-5
		],
		[
			0,
			-21
		],
		[
			-9,
			-16
		],
		[
			-1,
			25
		],
		[
			-6,
			4
		],
		[
			-6,
			-11
		],
		[
			-4,
			-18
		],
		[
			-17,
			5
		],
		[
			-15,
			-6
		],
		[
			7,
			9
		],
		[
			-13,
			1
		],
		[
			0,
			16
		],
		[
			-5,
			-3
		],
		[
			-3,
			-22
		],
		[
			9,
			-9
		],
		[
			1,
			-10
		],
		[
			-7,
			3
		],
		[
			-10,
			-9
		],
		[
			0,
			-10
		],
		[
			-6,
			-8
		],
		[
			-3,
			-15
		],
		[
			-5,
			-7
		],
		[
			-10,
			5
		],
		[
			-1,
			8
		],
		[
			-9,
			11
		],
		[
			3,
			8
		],
		[
			-3,
			14
		],
		[
			10,
			17
		],
		[
			-2,
			9
		],
		[
			-11,
			-4
		],
		[
			-6,
			7
		],
		[
			-7,
			0
		],
		[
			-20,
			-18
		],
		[
			-10,
			1
		],
		[
			-3,
			-9
		],
		[
			-6,
			2
		],
		[
			-15,
			-9
		],
		[
			-1,
			9
		],
		[
			-8,
			-6
		],
		[
			-2,
			-24
		],
		[
			-11,
			13
		],
		[
			-16,
			-7
		],
		[
			-4,
			7
		],
		[
			-3,
			-8
		],
		[
			-1,
			25
		],
		[
			3,
			5
		],
		[
			12,
			-1
		],
		[
			3,
			10
		],
		[
			7,
			5
		],
		[
			17,
			28
		],
		[
			7,
			7
		],
		[
			-1,
			9
		],
		[
			17,
			8
		],
		[
			5,
			-8
		],
		[
			24,
			6
		],
		[
			7,
			7
		],
		[
			11,
			-2
		],
		[
			8,
			7
		],
		[
			-1,
			-12
		],
		[
			13,
			-4
		],
		[
			12,
			10
		],
		[
			-3,
			18
		],
		[
			5,
			16
		],
		[
			7,
			8
		],
		[
			10,
			28
		],
		[
			-1,
			26
		],
		[
			11,
			10
		],
		[
			6,
			1
		],
		[
			-3,
			-13
		],
		[
			-9,
			-5
		],
		[
			4,
			-6
		],
		[
			-2,
			-13
		],
		[
			10,
			-6
		],
		[
			3,
			10
		],
		[
			21,
			13
		],
		[
			10,
			12
		],
		[
			10,
			29
		],
		[
			14,
			15
		],
		[
			1,
			16
		],
		[
			9,
			23
		],
		[
			3,
			24
		],
		[
			4,
			10
		],
		[
			1,
			17
		],
		[
			-4,
			11
		],
		[
			-5,
			-3
		],
		[
			7,
			19
		],
		[
			1,
			11
		],
		[
			-5,
			13
		],
		[
			5,
			10
		],
		[
			7,
			3
		],
		[
			1,
			26
		],
		[
			9,
			-5
		],
		[
			3,
			-20
		],
		[
			3,
			9
		],
		[
			8,
			-6
		],
		[
			3,
			19
		],
		[
			-13,
			-5
		],
		[
			3,
			23
		],
		[
			10,
			-10
		]
	],
	[
		[
			8944,
			7799
		],
		[
			15,
			-24
		],
		[
			4,
			-13
		],
		[
			19,
			-27
		],
		[
			11,
			-7
		],
		[
			0,
			-6
		],
		[
			12,
			0
		],
		[
			3,
			-7
		],
		[
			13,
			-4
		],
		[
			15,
			25
		],
		[
			1,
			-8
		],
		[
			-7,
			-17
		],
		[
			-1,
			-9
		],
		[
			8,
			-28
		],
		[
			8,
			6
		],
		[
			-4,
			-12
		],
		[
			-6,
			0
		],
		[
			-8,
			-10
		],
		[
			-27,
			-4
		],
		[
			-11,
			-14
		],
		[
			-8,
			-20
		],
		[
			-3,
			-23
		],
		[
			-8,
			11
		],
		[
			-14,
			9
		],
		[
			-8,
			11
		],
		[
			-12,
			9
		],
		[
			-8,
			-3
		],
		[
			-12,
			-15
		],
		[
			-9,
			15
		],
		[
			-5,
			0
		],
		[
			-6,
			-18
		],
		[
			12,
			-8
		],
		[
			13,
			-20
		],
		[
			-13,
			-1
		],
		[
			-8,
			-7
		],
		[
			-6,
			-13
		],
		[
			-7,
			10
		],
		[
			5,
			14
		],
		[
			-3,
			17
		],
		[
			-7,
			6
		],
		[
			3,
			26
		],
		[
			12,
			7
		],
		[
			5,
			11
		],
		[
			-5,
			13
		],
		[
			6,
			8
		],
		[
			8,
			-9
		],
		[
			10,
			-3
		],
		[
			7,
			10
		],
		[
			-3,
			22
		],
		[
			9,
			14
		],
		[
			0,
			22
		],
		[
			3,
			6
		],
		[
			1,
			20
		],
		[
			-6,
			23
		],
		[
			3,
			12
		],
		[
			9,
			3
		]
	],
	[
		[
			6762,
			7807
		],
		[
			-15,
			8
		],
		[
			-3,
			11
		],
		[
			1,
			13
		],
		[
			12,
			14
		],
		[
			11,
			-3
		],
		[
			7,
			-11
		],
		[
			1,
			-13
		],
		[
			-4,
			-11
		],
		[
			-10,
			-8
		]
	],
	[
		[
			7140,
			7205
		],
		[
			-9,
			31
		]
	],
	[
		[
			6651,
			7782
		],
		[
			-20,
			19
		]
	],
	[
		[
			6631,
			7801
		],
		[
			12,
			18
		],
		[
			8,
			-37
		]
	],
	[
		[
			7227,
			7611
		],
		[
			-6,
			13
		],
		[
			-15,
			4
		],
		[
			-12,
			17
		],
		[
			-14,
			6
		],
		[
			-14,
			0
		],
		[
			-19,
			2
		],
		[
			-14,
			5
		],
		[
			-13,
			-5
		],
		[
			-16,
			1
		],
		[
			-3,
			-6
		],
		[
			-13,
			2
		],
		[
			-12,
			8
		],
		[
			-12,
			13
		],
		[
			-21,
			-10
		],
		[
			-5,
			-27
		],
		[
			3,
			-9
		],
		[
			-22,
			14
		],
		[
			-27,
			9
		],
		[
			-10,
			-1
		],
		[
			-10,
			-13
		],
		[
			-5,
			-15
		],
		[
			3,
			-3
		]
	],
	[
		[
			6970,
			7616
		],
		[
			-6,
			-3
		],
		[
			-4,
			-11
		],
		[
			-4,
			5
		],
		[
			-9,
			-16
		],
		[
			-20,
			-15
		],
		[
			0,
			-5
		],
		[
			-10,
			-5
		],
		[
			0,
			-10
		],
		[
			-13,
			-17
		],
		[
			1,
			-19
		],
		[
			-4,
			0
		],
		[
			-13,
			13
		],
		[
			4,
			14
		],
		[
			-5,
			7
		],
		[
			-33,
			-3
		],
		[
			-5,
			20
		],
		[
			-2,
			30
		],
		[
			-14,
			0
		],
		[
			2,
			57
		],
		[
			-8,
			-7
		],
		[
			-8,
			26
		],
		[
			-7,
			5
		],
		[
			-10,
			19
		],
		[
			-12,
			-10
		],
		[
			-37,
			4
		],
		[
			-32,
			-8
		],
		[
			-23,
			38
		],
		[
			-2,
			12
		],
		[
			-28,
			28
		]
	],
	[
		[
			6668,
			7765
		],
		[
			0,
			34
		],
		[
			-2,
			9
		],
		[
			-7,
			-1
		],
		[
			3,
			20
		],
		[
			17,
			-5
		],
		[
			8,
			16
		],
		[
			12,
			7
		],
		[
			2,
			14
		],
		[
			-11,
			2
		],
		[
			-3,
			9
		],
		[
			-13,
			3
		],
		[
			-8,
			-7
		],
		[
			4,
			-13
		],
		[
			17,
			0
		],
		[
			2,
			-11
		],
		[
			-4,
			-6
		],
		[
			-24,
			2
		],
		[
			-2,
			12
		],
		[
			-7,
			0
		],
		[
			7,
			-14
		],
		[
			-3,
			-17
		],
		[
			-8,
			-6
		],
		[
			-4,
			5
		],
		[
			4,
			13
		],
		[
			-15,
			-3
		],
		[
			-6,
			-23
		]
	],
	[
		[
			6627,
			7805
		],
		[
			-73,
			-31
		],
		[
			0,
			-212
		]
	],
	[
		[
			6554,
			7562
		],
		[
			-14,
			-3
		],
		[
			-15,
			32
		],
		[
			0,
			6
		],
		[
			-20,
			23
		],
		[
			-20,
			-3
		],
		[
			-14,
			-9
		],
		[
			-15,
			-21
		]
	],
	[
		[
			6456,
			7587
		],
		[
			-1,
			20
		],
		[
			6,
			15
		],
		[
			3,
			22
		],
		[
			-15,
			9
		],
		[
			-8,
			-3
		],
		[
			-6,
			18
		],
		[
			-12,
			0
		],
		[
			1,
			23
		],
		[
			-4,
			4
		],
		[
			-8,
			33
		],
		[
			-17,
			9
		],
		[
			1,
			17
		],
		[
			16,
			-1
		],
		[
			4,
			-6
		],
		[
			16,
			-2
		],
		[
			-17,
			20
		],
		[
			12,
			28
		],
		[
			9,
			5
		],
		[
			22,
			0
		],
		[
			11,
			-6
		],
		[
			10,
			2
		],
		[
			-15,
			10
		],
		[
			0,
			6
		],
		[
			9,
			18
		],
		[
			4,
			40
		],
		[
			-8,
			19
		],
		[
			-13,
			2
		],
		[
			-10,
			-10
		],
		[
			-16,
			14
		],
		[
			-9,
			3
		],
		[
			-12,
			-11
		],
		[
			-9,
			-2
		],
		[
			-18,
			-21
		],
		[
			-13,
			2
		],
		[
			-2,
			-14
		]
	],
	[
		[
			6367,
			7850
		],
		[
			-9,
			9
		],
		[
			-10,
			5
		],
		[
			0,
			12
		],
		[
			6,
			-6
		],
		[
			7,
			6
		],
		[
			-9,
			19
		],
		[
			-4,
			15
		],
		[
			-14,
			23
		],
		[
			-11,
			0
		],
		[
			-7,
			5
		],
		[
			-1,
			-9
		],
		[
			-7,
			7
		],
		[
			0,
			26
		],
		[
			-18,
			8
		],
		[
			8,
			30
		],
		[
			8,
			10
		],
		[
			-7,
			14
		],
		[
			3,
			28
		],
		[
			12,
			12
		],
		[
			-1,
			14
		],
		[
			9,
			9
		],
		[
			22,
			-37
		],
		[
			13,
			11
		],
		[
			-5,
			20
		],
		[
			0,
			13
		],
		[
			20,
			17
		],
		[
			0,
			15
		],
		[
			11,
			0
		],
		[
			15,
			12
		],
		[
			6,
			17
		],
		[
			5,
			6
		],
		[
			14,
			-3
		],
		[
			1,
			-11
		],
		[
			11,
			-1
		],
		[
			6,
			12
		],
		[
			11,
			6
		],
		[
			5,
			-16
		],
		[
			23,
			0
		],
		[
			9,
			-7
		],
		[
			1,
			-9
		],
		[
			7,
			-1
		],
		[
			6,
			-13
		],
		[
			10,
			-7
		],
		[
			-3,
			-16
		],
		[
			8,
			2
		],
		[
			1,
			24
		],
		[
			10,
			-13
		],
		[
			16,
			-15
		],
		[
			13,
			11
		],
		[
			11,
			20
		],
		[
			18,
			0
		],
		[
			5,
			-11
		],
		[
			11,
			1
		],
		[
			1,
			13
		],
		[
			22,
			-4
		],
		[
			0,
			-11
		],
		[
			10,
			-11
		],
		[
			16,
			-3
		],
		[
			1,
			-9
		],
		[
			7,
			4
		],
		[
			5,
			18
		],
		[
			9,
			-10
		],
		[
			15,
			-1
		],
		[
			17,
			10
		],
		[
			2,
			19
		],
		[
			4,
			6
		],
		[
			-7,
			11
		],
		[
			-10,
			1
		],
		[
			-3,
			8
		],
		[
			-16,
			3
		],
		[
			3,
			8
		],
		[
			-12,
			4
		],
		[
			11,
			15
		],
		[
			7,
			1
		],
		[
			10,
			11
		],
		[
			-10,
			23
		],
		[
			22,
			16
		],
		[
			17,
			-3
		],
		[
			1,
			7
		],
		[
			-13,
			9
		],
		[
			-14,
			3
		],
		[
			2,
			12
		],
		[
			-6,
			8
		],
		[
			5,
			11
		],
		[
			-6,
			3
		],
		[
			12,
			10
		],
		[
			4,
			-6
		],
		[
			43,
			7
		],
		[
			25,
			14
		],
		[
			25,
			5
		],
		[
			9,
			-4
		],
		[
			-1,
			10
		],
		[
			7,
			7
		],
		[
			15,
			-1
		],
		[
			15,
			6
		],
		[
			33,
			8
		],
		[
			13,
			6
		],
		[
			2,
			13
		],
		[
			10,
			0
		],
		[
			2,
			9
		],
		[
			8,
			-4
		],
		[
			-1,
			9
		],
		[
			8,
			-6
		],
		[
			13,
			0
		],
		[
			14,
			-11
		],
		[
			8,
			9
		],
		[
			14,
			-12
		],
		[
			1,
			-18
		],
		[
			6,
			-3
		],
		[
			-1,
			-23
		],
		[
			-6,
			0
		],
		[
			6,
			-13
		],
		[
			3,
			6
		],
		[
			11,
			-4
		],
		[
			10,
			5
		],
		[
			3,
			9
		],
		[
			9,
			-14
		],
		[
			-3,
			-13
		],
		[
			9,
			3
		],
		[
			-4,
			10
		],
		[
			11,
			-1
		],
		[
			3,
			-8
		],
		[
			11,
			-2
		],
		[
			8,
			7
		],
		[
			-3,
			-12
		],
		[
			-6,
			1
		],
		[
			-6,
			-17
		],
		[
			6,
			-8
		],
		[
			13,
			12
		],
		[
			14,
			-10
		],
		[
			1,
			12
		],
		[
			9,
			9
		],
		[
			7,
			-2
		],
		[
			12,
			11
		],
		[
			-2,
			4
		],
		[
			31,
			15
		],
		[
			12,
			8
		],
		[
			-7,
			-19
		],
		[
			-8,
			1
		],
		[
			3,
			-9
		],
		[
			34,
			-36
		],
		[
			7,
			-11
		],
		[
			42,
			-97
		],
		[
			12,
			-38
		],
		[
			15,
			7
		],
		[
			-1,
			14
		],
		[
			6,
			6
		],
		[
			15,
			-7
		],
		[
			-3,
			-15
		],
		[
			9,
			2
		],
		[
			2,
			-13
		],
		[
			11,
			3
		],
		[
			6,
			-4
		],
		[
			17,
			5
		],
		[
			18,
			12
		],
		[
			13,
			-7
		],
		[
			11,
			-20
		],
		[
			0,
			-15
		],
		[
			23,
			-14
		],
		[
			-2,
			-7
		],
		[
			9,
			-19
		],
		[
			19,
			-1
		],
		[
			6,
			-7
		],
		[
			12,
			20
		],
		[
			0,
			-10
		],
		[
			12,
			-22
		],
		[
			7,
			-9
		]
	],
	[
		[
			6163,
			5412
		],
		[
			-17,
			-50
		],
		[
			-9,
			-17
		],
		[
			0,
			-175
		],
		[
			1,
			-39
		],
		[
			15,
			-39
		],
		[
			0,
			-7
		]
	],
	[
		[
			6153,
			5085
		],
		[
			-6,
			-15
		],
		[
			-9,
			-4
		],
		[
			-4,
			-20
		],
		[
			-5,
			-9
		],
		[
			-5,
			0
		],
		[
			-9,
			-13
		],
		[
			2,
			-12
		],
		[
			-3,
			-18
		],
		[
			-6,
			-12
		],
		[
			-3,
			-25
		],
		[
			-4,
			-11
		],
		[
			-7,
			-30
		],
		[
			-6,
			-3
		]
	],
	[
		[
			6088,
			4913
		],
		[
			-21,
			33
		],
		[
			-19,
			27
		],
		[
			-5,
			13
		],
		[
			4,
			6
		],
		[
			-1,
			14
		],
		[
			-100,
			116
		]
	],
	[
		[
			5946,
			5122
		],
		[
			3,
			12
		],
		[
			-4,
			7
		],
		[
			0,
			10
		],
		[
			4,
			7
		],
		[
			9,
			-1
		],
		[
			-2,
			6
		],
		[
			11,
			4
		],
		[
			-4,
			11
		],
		[
			-10,
			-6
		],
		[
			2,
			-6
		],
		[
			-9,
			7
		],
		[
			-3,
			12
		],
		[
			1,
			12
		]
	],
	[
		[
			5944,
			5197
		],
		[
			4,
			21
		],
		[
			7,
			12
		],
		[
			2,
			15
		],
		[
			9,
			9
		],
		[
			2,
			18
		],
		[
			3,
			6
		],
		[
			0,
			26
		],
		[
			-3,
			18
		],
		[
			2,
			3
		],
		[
			-14,
			40
		],
		[
			-2,
			17
		],
		[
			2,
			13
		],
		[
			-8,
			5
		],
		[
			-3,
			24
		],
		[
			-2,
			2
		]
	],
	[
		[
			5943,
			5426
		],
		[
			11,
			23
		],
		[
			15,
			14
		],
		[
			14,
			9
		],
		[
			4,
			-7
		],
		[
			2,
			-16
		],
		[
			8,
			0
		]
	],
	[
		[
			7045,
			7454
		],
		[
			-13,
			-5
		],
		[
			-15,
			2
		],
		[
			-9,
			-5
		],
		[
			-2,
			-6
		],
		[
			-5,
			10
		],
		[
			-7,
			-7
		],
		[
			-2,
			12
		],
		[
			-8,
			8
		],
		[
			-12,
			-11
		],
		[
			-8,
			-1
		],
		[
			-4,
			11
		],
		[
			-36,
			-5
		],
		[
			-2,
			14
		],
		[
			7,
			20
		],
		[
			14,
			6
		],
		[
			18,
			-12
		],
		[
			1,
			7
		],
		[
			8,
			8
		]
	],
	[
		[
			6970,
			7500
		],
		[
			12,
			3
		],
		[
			11,
			-7
		],
		[
			9,
			15
		],
		[
			8,
			-3
		],
		[
			0,
			14
		],
		[
			7,
			-6
		],
		[
			4,
			9
		],
		[
			10,
			8
		],
		[
			-13,
			3
		],
		[
			-5,
			9
		],
		[
			-9,
			-1
		],
		[
			0,
			10
		],
		[
			-8,
			0
		],
		[
			-6,
			22
		],
		[
			-1,
			-10
		],
		[
			-6,
			-2
		],
		[
			0,
			-13
		],
		[
			-6,
			-1
		],
		[
			-12,
			7
		],
		[
			-4,
			14
		],
		[
			-4,
			-4
		],
		[
			-9,
			10
		],
		[
			8,
			7
		],
		[
			22,
			29
		],
		[
			-8,
			3
		]
	],
	[
		[
			6976,
			7489
		],
		[
			-6,
			4
		],
		[
			2,
			-14
		],
		[
			4,
			10
		]
	],
	[
		[
			6993,
			7480
		],
		[
			0,
			0
		]
	],
	[
		[
			6961,
			7477
		],
		[
			0,
			0
		]
	],
	[
		[
			7901,
			5783
		],
		[
			-6,
			7
		],
		[
			-11,
			2
		],
		[
			-7,
			-4
		],
		[
			-3,
			5
		],
		[
			5,
			13
		],
		[
			0,
			15
		],
		[
			-4,
			5
		],
		[
			-3,
			-16
		],
		[
			-9,
			2
		],
		[
			-2,
			38
		],
		[
			-3,
			3
		]
	],
	[
		[
			7858,
			5853
		],
		[
			0,
			7
		],
		[
			-6,
			22
		],
		[
			0,
			22
		],
		[
			-6,
			7
		],
		[
			0,
			21
		],
		[
			-3,
			7
		],
		[
			-2,
			25
		],
		[
			6,
			0
		],
		[
			10,
			26
		],
		[
			1,
			11
		],
		[
			9,
			8
		],
		[
			12,
			5
		],
		[
			9,
			-5
		],
		[
			5,
			3
		],
		[
			11,
			-2
		],
		[
			5,
			4
		],
		[
			6,
			-3
		],
		[
			2,
			-10
		],
		[
			4,
			8
		]
	],
	[
		[
			7921,
			6009
		],
		[
			3,
			-14
		],
		[
			13,
			-1
		],
		[
			3,
			-9
		],
		[
			6,
			-1
		],
		[
			2,
			7
		],
		[
			-6,
			19
		],
		[
			7,
			7
		],
		[
			6,
			-2
		],
		[
			3,
			6
		],
		[
			8,
			-14
		],
		[
			4,
			0
		],
		[
			8,
			11
		],
		[
			5,
			2
		],
		[
			2,
			10
		]
	],
	[
		[
			7985,
			6030
		],
		[
			0,
			-14
		],
		[
			-3,
			-2
		],
		[
			-2,
			-19
		],
		[
			3,
			-10
		],
		[
			0,
			-10
		],
		[
			5,
			-22
		],
		[
			-5,
			-20
		],
		[
			4,
			-24
		],
		[
			-2,
			-15
		],
		[
			-2,
			-6
		],
		[
			-4,
			5
		],
		[
			-8,
			-14
		],
		[
			-8,
			-7
		],
		[
			-8,
			-1
		],
		[
			0,
			-17
		],
		[
			-11,
			7
		],
		[
			-4,
			-13
		],
		[
			-1,
			-15
		],
		[
			9,
			-13
		],
		[
			1,
			-17
		],
		[
			-9,
			3
		],
		[
			-3,
			10
		],
		[
			-10,
			-2
		],
		[
			-3,
			-7
		],
		[
			-7,
			6
		],
		[
			1,
			-11
		],
		[
			-6,
			-13
		],
		[
			-9,
			0
		],
		[
			-2,
			-6
		]
	],
	[
		[
			627,
			5299
		],
		[
			5,
			-18
		],
		[
			-8,
			8
		],
		[
			3,
			10
		]
	],
	[
		[
			8522,
			7115
		],
		[
			1,
			-14
		],
		[
			-17,
			-6
		],
		[
			-2,
			8
		],
		[
			5,
			8
		],
		[
			13,
			4
		]
	],
	[
		[
			8508,
			7172
		],
		[
			1,
			-8
		],
		[
			-7,
			2
		],
		[
			6,
			6
		]
	],
	[
		[
			8575,
			7196
		],
		[
			-1,
			-14
		],
		[
			-5,
			11
		],
		[
			6,
			3
		]
	],
	[
		[
			8518,
			7361
		],
		[
			8,
			22
		],
		[
			5,
			6
		],
		[
			27,
			0
		],
		[
			7,
			17
		]
	],
	[
		[
			8565,
			7406
		],
		[
			7,
			-27
		],
		[
			14,
			-31
		],
		[
			6,
			-25
		],
		[
			4,
			-25
		],
		[
			-2,
			-7
		],
		[
			-1,
			-33
		],
		[
			4,
			-6
		],
		[
			-2,
			-25
		],
		[
			-9,
			-23
		],
		[
			-18,
			0
		],
		[
			-1,
			-15
		],
		[
			-3,
			6
		],
		[
			-17,
			1
		],
		[
			-2,
			-20
		],
		[
			-4,
			14
		],
		[
			0,
			-13
		],
		[
			-5,
			-9
		],
		[
			-3,
			13
		],
		[
			-6,
			-5
		],
		[
			-3,
			-11
		],
		[
			-4,
			3
		],
		[
			-4,
			-10
		],
		[
			-2,
			15
		],
		[
			-7,
			2
		],
		[
			0,
			9
		],
		[
			6,
			-7
		],
		[
			2,
			11
		],
		[
			-4,
			1
		],
		[
			-2,
			18
		],
		[
			2,
			17
		],
		[
			6,
			9
		],
		[
			-4,
			4
		],
		[
			8,
			7
		],
		[
			-7,
			10
		],
		[
			5,
			1
		],
		[
			-5,
			11
		],
		[
			-1,
			31
		],
		[
			-3,
			8
		],
		[
			3,
			12
		],
		[
			7,
			-1
		],
		[
			-6,
			42
		],
		[
			4,
			3
		]
	],
	[
		[
			5598,
			7616
		],
		[
			-9,
			-9
		],
		[
			-3,
			6
		],
		[
			-10,
			-8
		],
		[
			0,
			-11
		],
		[
			-5,
			0
		]
	],
	[
		[
			5557,
			7633
		],
		[
			8,
			15
		]
	],
	[
		[
			5565,
			7648
		],
		[
			9,
			17
		],
		[
			-2,
			6
		],
		[
			14,
			-7
		],
		[
			8,
			-19
		],
		[
			10,
			-5
		],
		[
			-6,
			-24
		]
	],
	[
		[
			6338,
			6909
		],
		[
			5,
			-15
		],
		[
			-4,
			-7
		],
		[
			-5,
			12
		],
		[
			4,
			10
		]
	],
	[
		[
			6345,
			6826
		],
		[
			-22,
			0
		],
		[
			-6,
			27
		],
		[
			-25,
			5
		]
	],
	[
		[
			6331,
			6910
		],
		[
			7,
			-26
		],
		[
			-6,
			2
		],
		[
			-7,
			-12
		],
		[
			10,
			-1
		],
		[
			2,
			-19
		],
		[
			8,
			-28
		]
	],
	[
		[
			7836,
			6473
		],
		[
			2,
			-9
		],
		[
			8,
			-12
		],
		[
			6,
			-22
		],
		[
			2,
			9
		],
		[
			5,
			-5
		],
		[
			0,
			-9
		],
		[
			-2,
			-23
		],
		[
			7,
			-19
		],
		[
			15,
			-11
		],
		[
			2,
			8
		],
		[
			9,
			10
		],
		[
			5,
			-4
		],
		[
			9,
			-13
		],
		[
			-1,
			-9
		],
		[
			-6,
			-3
		],
		[
			9,
			-6
		],
		[
			0,
			-8
		],
		[
			7,
			-2
		],
		[
			0,
			-11
		],
		[
			-2,
			-10
		],
		[
			-9,
			-12
		],
		[
			-8,
			6
		],
		[
			-4,
			-15
		],
		[
			-6,
			-7
		],
		[
			18,
			-21
		],
		[
			4,
			-8
		],
		[
			9,
			-5
		],
		[
			5,
			-6
		],
		[
			-2,
			-12
		],
		[
			6,
			-14
		],
		[
			5,
			0
		],
		[
			7,
			-30
		],
		[
			13,
			-24
		],
		[
			9,
			-17
		],
		[
			0,
			-18
		],
		[
			4,
			-11
		],
		[
			5,
			5
		],
		[
			4,
			-14
		],
		[
			8,
			-12
		],
		[
			4,
			-1
		],
		[
			-1,
			-8
		],
		[
			-6,
			-5
		],
		[
			2,
			-12
		],
		[
			7,
			-8
		],
		[
			5,
			-12
		],
		[
			-5,
			-33
		]
	],
	[
		[
			7921,
			6009
		],
		[
			9,
			11
		],
		[
			0,
			20
		],
		[
			1,
			5
		],
		[
			-3,
			11
		],
		[
			3,
			6
		],
		[
			2,
			24
		],
		[
			-5,
			5
		],
		[
			0,
			13
		],
		[
			-11,
			7
		],
		[
			0,
			8
		],
		[
			-8,
			15
		],
		[
			0,
			29
		],
		[
			2,
			20
		],
		[
			-3,
			9
		],
		[
			-7,
			7
		],
		[
			-6,
			14
		],
		[
			-7,
			24
		],
		[
			-18,
			8
		],
		[
			-2,
			-10
		],
		[
			-9,
			-15
		],
		[
			-9,
			-6
		],
		[
			-16,
			16
		],
		[
			-4,
			-9
		],
		[
			-19,
			-26
		],
		[
			-4,
			-7
		],
		[
			-5,
			6
		],
		[
			3,
			19
		],
		[
			4,
			9
		],
		[
			0,
			17
		],
		[
			-3,
			3
		],
		[
			5,
			14
		],
		[
			0,
			15
		],
		[
			3,
			7
		],
		[
			-3,
			6
		],
		[
			-1,
			19
		],
		[
			2,
			7
		],
		[
			-12,
			2
		],
		[
			-2,
			-7
		],
		[
			-7,
			0
		],
		[
			-3,
			9
		],
		[
			3,
			29
		],
		[
			-5,
			15
		],
		[
			-6,
			-5
		]
	],
	[
		[
			7780,
			6353
		],
		[
			0,
			15
		],
		[
			7,
			14
		],
		[
			4,
			-1
		],
		[
			0,
			13
		],
		[
			6,
			16
		],
		[
			3,
			0
		],
		[
			9,
			14
		]
	],
	[
		[
			5975,
			7088
		],
		[
			14,
			52
		],
		[
			1,
			19
		],
		[
			9,
			12
		],
		[
			0,
			7
		]
	],
	[
		[
			5999,
			7178
		],
		[
			13,
			-3
		],
		[
			4,
			-23
		],
		[
			-9,
			-14
		],
		[
			2,
			-8
		],
		[
			-6,
			2
		],
		[
			-6,
			-12
		],
		[
			3,
			-5
		],
		[
			-6,
			-8
		]
	],
	[
		[
			4790,
			5433
		],
		[
			-19,
			13
		],
		[
			-21,
			22
		],
		[
			-9,
			12
		],
		[
			-21,
			40
		],
		[
			-9,
			19
		],
		[
			-12,
			7
		],
		[
			-1,
			10
		],
		[
			-14,
			13
		],
		[
			-3,
			12
		]
	],
	[
		[
			4681,
			5581
		],
		[
			3,
			14
		],
		[
			6,
			12
		],
		[
			15,
			23
		],
		[
			0,
			16
		],
		[
			8,
			8
		],
		[
			1,
			17
		]
	],
	[
		[
			5693,
			6449
		],
		[
			0,
			-115
		],
		[
			-27,
			0
		],
		[
			0,
			-28
		]
	],
	[
		[
			5666,
			6306
		],
		[
			-66,
			66
		],
		[
			-3,
			4
		],
		[
			-45,
			45
		],
		[
			-34,
			36
		],
		[
			-45,
			45
		],
		[
			-30,
			31
		],
		[
			-27,
			-26
		]
	],
	[
		[
			5416,
			6507
		],
		[
			-22,
			-22
		],
		[
			-20,
			33
		],
		[
			-42,
			19
		]
	],
	[
		[
			5264,
			6924
		],
		[
			10,
			7
		],
		[
			11,
			30
		],
		[
			-5,
			31
		],
		[
			6,
			17
		],
		[
			5,
			1
		],
		[
			10,
			22
		],
		[
			19,
			18
		],
		[
			-2,
			10
		],
		[
			1,
			34
		]
	],
	[
		[
			5319,
			7094
		],
		[
			10,
			-6
		],
		[
			12,
			-14
		],
		[
			15,
			-2
		],
		[
			14,
			6
		],
		[
			6,
			-6
		],
		[
			17,
			-5
		],
		[
			8,
			-12
		],
		[
			20,
			-6
		],
		[
			5,
			-13
		],
		[
			0,
			-14
		],
		[
			7,
			-25
		],
		[
			4,
			-7
		],
		[
			17,
			-9
		],
		[
			10,
			0
		],
		[
			18,
			-8
		],
		[
			23,
			-18
		],
		[
			3,
			-7
		],
		[
			18,
			-22
		],
		[
			8,
			0
		],
		[
			14,
			14
		],
		[
			10,
			24
		],
		[
			1,
			18
		],
		[
			-6,
			24
		],
		[
			0,
			16
		],
		[
			3,
			12
		],
		[
			15,
			24
		],
		[
			14,
			13
		],
		[
			10,
			1
		],
		[
			5,
			7
		],
		[
			21,
			-3
		],
		[
			21,
			-14
		],
		[
			-1,
			-18
		],
		[
			6,
			-6
		],
		[
			19,
			-7
		],
		[
			2,
			-5
		],
		[
			25,
			-2
		],
		[
			5,
			-18
		]
	],
	[
		[
			3307,
			5973
		],
		[
			-4,
			11
		],
		[
			5,
			10
		],
		[
			-1,
			-21
		]
	],
	[
		[
			7235,
			5735
		],
		[
			7,
			-13
		],
		[
			17,
			-49
		],
		[
			5,
			-36
		],
		[
			5,
			-8
		],
		[
			4,
			-24
		],
		[
			0,
			-20
		],
		[
			-2,
			-22
		],
		[
			-12,
			-22
		],
		[
			-22,
			-17
		],
		[
			-9,
			5
		],
		[
			-4,
			7
		],
		[
			-7,
			43
		],
		[
			-1,
			50
		],
		[
			1,
			40
		],
		[
			2,
			10
		],
		[
			0,
			17
		],
		[
			6,
			17
		],
		[
			-2,
			7
		],
		[
			4,
			10
		],
		[
			6,
			1
		],
		[
			-14,
			10
		],
		[
			2,
			7
		],
		[
			7,
			-3
		],
		[
			7,
			-10
		]
	],
	[
		[
			5798,
			3530
		],
		[
			6,
			-12
		],
		[
			10,
			-10
		],
		[
			3,
			-14
		],
		[
			-4,
			-17
		],
		[
			-5,
			-7
		],
		[
			1,
			-10
		],
		[
			-8,
			-9
		],
		[
			-13,
			-4
		],
		[
			-5,
			-7
		],
		[
			-4,
			-22
		],
		[
			-8,
			2
		],
		[
			-16,
			35
		],
		[
			-5,
			22
		],
		[
			8,
			6
		],
		[
			12,
			35
		],
		[
			8,
			2
		],
		[
			4,
			10
		],
		[
			13,
			8
		],
		[
			3,
			-8
		]
	],
	[
		[
			5582,
			8366
		],
		[
			-1,
			0
		]
	],
	[
		[
			5581,
			8366
		],
		[
			1,
			0
		]
	],
	[
		[
			5652,
			8289
		],
		[
			0,
			9
		],
		[
			-14,
			16
		],
		[
			-6,
			-1
		]
	],
	[
		[
			5632,
			8313
		],
		[
			-3,
			6
		],
		[
			5,
			24
		],
		[
			-8,
			11
		],
		[
			-15,
			1
		],
		[
			-21,
			9
		]
	],
	[
		[
			5590,
			8364
		],
		[
			-6,
			32
		],
		[
			0,
			16
		]
	],
	[
		[
			5584,
			8412
		],
		[
			8,
			9
		],
		[
			22,
			11
		],
		[
			15,
			-4
		],
		[
			8,
			3
		],
		[
			29,
			-5
		],
		[
			4,
			-4
		],
		[
			22,
			8
		],
		[
			5,
			-12
		],
		[
			15,
			-2
		],
		[
			26,
			-28
		]
	],
	[
		[
			5759,
			8496
		],
		[
			14,
			-14
		],
		[
			-6,
			-26
		],
		[
			14,
			-17
		],
		[
			0,
			-23
		]
	],
	[
		[
			5584,
			8412
		],
		[
			-2,
			19
		],
		[
			2,
			24
		],
		[
			10,
			12
		],
		[
			0,
			15
		],
		[
			8,
			15
		],
		[
			22,
			11
		],
		[
			18,
			-21
		],
		[
			4,
			-17
		],
		[
			12,
			-7
		],
		[
			19,
			15
		],
		[
			-2,
			37
		]
	],
	[
		[
			3249,
			6221
		],
		[
			-2,
			2
		]
	],
	[
		[
			3247,
			6223
		],
		[
			2,
			-2
		]
	],
	[
		[
			4851,
			7247
		],
		[
			2,
			-14
		],
		[
			14,
			-21
		],
		[
			11,
			-5
		],
		[
			19,
			8
		],
		[
			6,
			-5
		],
		[
			15,
			7
		]
	],
	[
		[
			4919,
			7214
		],
		[
			2,
			-9
		],
		[
			17,
			-2
		]
	],
	[
		[
			4758,
			6776
		],
		[
			-3,
			0
		],
		[
			1,
			-30
		],
		[
			-18,
			-3
		],
		[
			-7,
			-11
		],
		[
			-16,
			-2
		],
		[
			-9,
			7
		],
		[
			-10,
			1
		],
		[
			-13,
			-7
		],
		[
			2,
			-15
		],
		[
			-4,
			-6
		],
		[
			-8,
			-25
		],
		[
			-8,
			-3
		],
		[
			-4,
			-23
		],
		[
			-3,
			-30
		],
		[
			-3,
			-13
		],
		[
			-6,
			-12
		],
		[
			-12,
			-16
		],
		[
			-6,
			-22
		],
		[
			-16,
			-16
		],
		[
			-4,
			-13
		],
		[
			-6,
			-53
		],
		[
			0,
			-16
		],
		[
			-12,
			-26
		],
		[
			1,
			-7
		],
		[
			-4,
			-14
		],
		[
			-11,
			-4
		],
		[
			-22,
			4
		],
		[
			-18,
			-1
		],
		[
			-12,
			-4
		]
	],
	[
		[
			4527,
			6416
		],
		[
			1,
			21
		],
		[
			4,
			20
		],
		[
			10,
			13
		],
		[
			4,
			26
		],
		[
			5,
			11
		],
		[
			-2,
			5
		],
		[
			13,
			42
		],
		[
			-4,
			0
		],
		[
			8,
			12
		],
		[
			11,
			26
		],
		[
			5,
			4
		],
		[
			5,
			17
		],
		[
			0,
			22
		],
		[
			10,
			45
		],
		[
			0,
			9
		],
		[
			9,
			16
		],
		[
			7,
			4
		],
		[
			10,
			14
		],
		[
			10,
			53
		],
		[
			7,
			16
		],
		[
			24,
			8
		],
		[
			16,
			14
		],
		[
			11,
			23
		],
		[
			15,
			15
		],
		[
			21,
			49
		],
		[
			5,
			19
		],
		[
			1,
			14
		],
		[
			-7,
			13
		],
		[
			0,
			26
		],
		[
			2,
			26
		],
		[
			3,
			11
		],
		[
			9,
			18
		],
		[
			3,
			24
		],
		[
			-1,
			7
		],
		[
			11,
			17
		],
		[
			10,
			23
		],
		[
			26,
			19
		],
		[
			21,
			25
		],
		[
			15,
			48
		],
		[
			2,
			15
		],
		[
			9,
			39
		],
		[
			14,
			7
		]
	],
	[
		[
			5206,
			7702
		],
		[
			-2,
			-1
		]
	],
	[
		[
			5783,
			7801
		],
		[
			-3,
			21
		],
		[
			1,
			26
		],
		[
			3,
			22
		],
		[
			-4,
			18
		],
		[
			-6,
			5
		],
		[
			-17,
			36
		],
		[
			-10,
			30
		],
		[
			-8,
			3
		]
	],
	[
		[
			5739,
			7962
		],
		[
			20,
			10
		],
		[
			14,
			-2
		],
		[
			6,
			-9
		],
		[
			21,
			-8
		],
		[
			10,
			-13
		],
		[
			-1,
			-25
		],
		[
			7,
			-10
		],
		[
			5,
			2
		],
		[
			0,
			-20
		],
		[
			10,
			-9
		],
		[
			-1,
			-16
		],
		[
			6,
			-9
		],
		[
			-15,
			0
		],
		[
			-3,
			6
		],
		[
			-7,
			-6
		],
		[
			-1,
			9
		],
		[
			-7,
			-4
		],
		[
			1,
			-26
		],
		[
			-13,
			-19
		],
		[
			0,
			-11
		],
		[
			-8,
			-1
		]
	],
	[
		[
			6384,
			4200
		],
		[
			0,
			8
		],
		[
			5,
			14
		],
		[
			-5,
			-22
		]
	],
	[
		[
			6370,
			4487
		],
		[
			-2,
			-11
		],
		[
			7,
			-4
		],
		[
			1,
			-18
		],
		[
			7,
			-8
		],
		[
			4,
			-13
		],
		[
			-1,
			-9
		],
		[
			5,
			-25
		],
		[
			3,
			-37
		],
		[
			0,
			-29
		],
		[
			8,
			-27
		],
		[
			-4,
			-34
		],
		[
			-3,
			-9
		],
		[
			-6,
			7
		],
		[
			-3,
			25
		],
		[
			-8,
			-7
		],
		[
			3,
			-23
		],
		[
			-2,
			-5
		],
		[
			5,
			-11
		],
		[
			-1,
			-25
		],
		[
			-5,
			-13
		],
		[
			-6,
			-24
		],
		[
			2,
			-29
		],
		[
			-4,
			-39
		],
		[
			-3,
			-11
		],
		[
			-10,
			-59
		],
		[
			-2,
			-19
		],
		[
			-7,
			-32
		],
		[
			-3,
			-29
		],
		[
			-10,
			-57
		],
		[
			-4,
			-16
		],
		[
			-2,
			-24
		],
		[
			-7,
			-48
		],
		[
			-1,
			-16
		],
		[
			-4,
			-13
		],
		[
			-8,
			-47
		],
		[
			-14,
			-15
		],
		[
			-11,
			-2
		],
		[
			-13,
			-11
		],
		[
			-6,
			-9
		],
		[
			-12,
			-2
		],
		[
			-11,
			17
		],
		[
			-10,
			2
		],
		[
			-10,
			15
		],
		[
			-2,
			20
		],
		[
			-7,
			14
		],
		[
			-1,
			45
		],
		[
			3,
			10
		],
		[
			-4,
			6
		],
		[
			-1,
			16
		],
		[
			-6,
			12
		],
		[
			-4,
			36
		],
		[
			3,
			27
		],
		[
			4,
			6
		],
		[
			0,
			17
		],
		[
			7,
			4
		],
		[
			11,
			46
		],
		[
			4,
			7
		],
		[
			6,
			29
		],
		[
			-3,
			4
		],
		[
			2,
			24
		],
		[
			-6,
			18
		],
		[
			1,
			16
		],
		[
			-6,
			22
		],
		[
			-1,
			35
		],
		[
			-3,
			15
		],
		[
			15,
			49
		],
		[
			0,
			30
		],
		[
			12,
			-1
		],
		[
			11,
			16
		],
		[
			10,
			-2
		],
		[
			0,
			7
		],
		[
			8,
			4
		],
		[
			4,
			-6
		],
		[
			1,
			9
		],
		[
			6,
			5
		],
		[
			18,
			25
		],
		[
			3,
			-7
		],
		[
			-3,
			-10
		],
		[
			7,
			2
		],
		[
			-4,
			18
		],
		[
			4,
			5
		],
		[
			2,
			12
		],
		[
			6,
			8
		],
		[
			-3,
			-22
		],
		[
			11,
			28
		],
		[
			-3,
			11
		],
		[
			3,
			11
		],
		[
			4,
			-2
		],
		[
			3,
			11
		],
		[
			-4,
			9
		],
		[
			0,
			19
		],
		[
			7,
			-1
		],
		[
			1,
			-10
		],
		[
			4,
			-1
		],
		[
			0,
			14
		],
		[
			5,
			1
		],
		[
			-1,
			9
		],
		[
			6,
			-4
		],
		[
			3,
			5
		],
		[
			1,
			16
		],
		[
			3,
			8
		],
		[
			-2,
			22
		],
		[
			3,
			13
		],
		[
			5,
			4
		],
		[
			3,
			18
		],
		[
			2,
			-8
		]
	],
	[
		[
			2590,
			6367
		],
		[
			-7,
			-17
		],
		[
			2,
			17
		],
		[
			5,
			0
		]
	],
	[
		[
			1889,
			6595
		],
		[
			7,
			-4
		],
		[
			1,
			-9
		],
		[
			-8,
			13
		]
	],
	[
		[
			1800,
			6801
		],
		[
			-5,
			-1
		],
		[
			5,
			12
		],
		[
			0,
			-11
		]
	],
	[
		[
			1880,
			6866
		],
		[
			3,
			-12
		],
		[
			-3,
			-16
		],
		[
			-7,
			7
		],
		[
			2,
			17
		],
		[
			5,
			4
		]
	],
	[
		[
			1847,
			6884
		],
		[
			4,
			-14
		],
		[
			5,
			-1
		],
		[
			2,
			-17
		],
		[
			-11,
			17
		],
		[
			-3,
			9
		],
		[
			3,
			6
		]
	],
	[
		[
			2186,
			6889
		],
		[
			0,
			-8
		],
		[
			7,
			-2
		]
	],
	[
		[
			2193,
			6879
		],
		[
			11,
			-20
		],
		[
			1,
			-12
		],
		[
			9,
			-31
		],
		[
			6,
			-12
		],
		[
			9,
			-27
		],
		[
			7,
			-6
		],
		[
			-1,
			-15
		],
		[
			2,
			-15
		]
	],
	[
		[
			2237,
			6741
		],
		[
			3,
			-16
		],
		[
			3,
			2
		],
		[
			2,
			-14
		]
	],
	[
		[
			2245,
			6713
		],
		[
			2,
			-9
		],
		[
			20,
			-12
		],
		[
			4,
			-8
		],
		[
			16,
			-2
		],
		[
			9,
			-10
		],
		[
			5,
			6
		]
	],
	[
		[
			2301,
			6678
		],
		[
			0,
			-14
		],
		[
			-8,
			-31
		],
		[
			-6,
			-38
		],
		[
			-2,
			-30
		],
		[
			-1,
			-43
		],
		[
			1,
			-16
		],
		[
			-4,
			-22
		],
		[
			3,
			-29
		],
		[
			5,
			-34
		],
		[
			15,
			-57
		],
		[
			9,
			-17
		],
		[
			9,
			-27
		],
		[
			3,
			-25
		],
		[
			5,
			-5
		],
		[
			1,
			-9
		],
		[
			7,
			-19
		],
		[
			7,
			-4
		],
		[
			11,
			2
		],
		[
			5,
			-9
		],
		[
			6,
			-2
		],
		[
			8,
			-21
		],
		[
			10,
			3
		],
		[
			16,
			11
		],
		[
			17,
			3
		],
		[
			15,
			13
		],
		[
			10,
			2
		],
		[
			6,
			-12
		],
		[
			10,
			-3
		],
		[
			6,
			17
		],
		[
			-5,
			8
		],
		[
			14,
			16
		],
		[
			5,
			11
		],
		[
			1,
			21
		],
		[
			7,
			14
		],
		[
			-1,
			6
		],
		[
			1,
			39
		],
		[
			3,
			15
		],
		[
			16,
			17
		],
		[
			19,
			4
		],
		[
			17,
			12
		],
		[
			14,
			2
		],
		[
			20,
			-9
		],
		[
			6,
			9
		],
		[
			6,
			-10
		],
		[
			2,
			-17
		],
		[
			-3,
			-16
		],
		[
			-9,
			-18
		],
		[
			-7,
			-19
		],
		[
			-1,
			-19
		],
		[
			-8,
			-16
		],
		[
			9,
			-8
		],
		[
			-6,
			-40
		],
		[
			-3,
			-10
		],
		[
			-2,
			-23
		],
		[
			-3,
			14
		],
		[
			-4,
			3
		],
		[
			2,
			18
		],
		[
			-5,
			-4
		],
		[
			-3,
			-15
		]
	],
	[
		[
			2437,
			6020
		],
		[
			-20,
			42
		],
		[
			-19,
			33
		],
		[
			-11,
			16
		],
		[
			-10,
			10
		],
		[
			-1,
			-6
		],
		[
			-8,
			1
		],
		[
			-4,
			13
		],
		[
			-5,
			-9
		],
		[
			9,
			-4
		],
		[
			-11,
			-1
		],
		[
			-8,
			-12
		],
		[
			-15,
			-9
		],
		[
			-7,
			-8
		],
		[
			-8,
			-2
		],
		[
			-15,
			10
		],
		[
			-4,
			6
		],
		[
			-17,
			3
		],
		[
			-8,
			13
		],
		[
			-13,
			6
		],
		[
			-6,
			14
		],
		[
			-5,
			0
		],
		[
			-15,
			8
		],
		[
			-5,
			0
		],
		[
			-5,
			9
		],
		[
			-31,
			22
		],
		[
			-6,
			11
		],
		[
			-13,
			14
		],
		[
			-4,
			13
		],
		[
			-7,
			6
		],
		[
			-5,
			-4
		],
		[
			-32,
			20
		],
		[
			-8,
			21
		],
		[
			-9,
			14
		],
		[
			-12,
			13
		],
		[
			-15,
			12
		],
		[
			-3,
			14
		],
		[
			-5,
			6
		],
		[
			-8,
			22
		],
		[
			0,
			10
		],
		[
			-4,
			8
		],
		[
			3,
			8
		],
		[
			10,
			6
		],
		[
			-7,
			15
		],
		[
			7,
			12
		],
		[
			1,
			22
		],
		[
			-6,
			8
		],
		[
			-7,
			23
		],
		[
			-2,
			32
		],
		[
			-9,
			17
		],
		[
			-15,
			34
		],
		[
			-12,
			32
		],
		[
			-21,
			28
		],
		[
			7,
			-7
		],
		[
			0,
			9
		],
		[
			-5,
			-1
		],
		[
			-9,
			13
		],
		[
			-6,
			18
		],
		[
			7,
			0
		],
		[
			-22,
			24
		],
		[
			0,
			5
		],
		[
			-9,
			-3
		],
		[
			6,
			9
		],
		[
			-7,
			-1
		],
		[
			-8,
			9
		],
		[
			0,
			14
		],
		[
			4,
			9
		],
		[
			0,
			19
		],
		[
			-4,
			9
		],
		[
			-10,
			3
		],
		[
			-5,
			23
		],
		[
			-9,
			2
		],
		[
			-7,
			13
		],
		[
			-2,
			26
		],
		[
			2,
			3
		],
		[
			-14,
			4
		],
		[
			-8,
			12
		],
		[
			-5,
			13
		],
		[
			-5,
			5
		],
		[
			-13,
			29
		],
		[
			-2,
			20
		],
		[
			-5,
			2
		],
		[
			1,
			9
		],
		[
			-11,
			23
		],
		[
			0,
			16
		],
		[
			-10,
			36
		],
		[
			3,
			20
		],
		[
			-16,
			10
		],
		[
			-1,
			10
		],
		[
			-7,
			6
		],
		[
			-9,
			-6
		],
		[
			-10,
			15
		],
		[
			-8,
			2
		],
		[
			0,
			-41
		],
		[
			4,
			-8
		],
		[
			3,
			-27
		],
		[
			-1,
			-19
		],
		[
			7,
			-21
		],
		[
			4,
			-1
		],
		[
			17,
			-27
		],
		[
			3,
			-23
		],
		[
			7,
			-3
		],
		[
			11,
			-32
		],
		[
			3,
			-25
		],
		[
			4,
			-12
		],
		[
			8,
			-6
		],
		[
			4,
			-20
		],
		[
			6,
			-7
		],
		[
			-1,
			-6
		],
		[
			8,
			-25
		],
		[
			-3,
			20
		],
		[
			8,
			-10
		],
		[
			0,
			-9
		],
		[
			5,
			-13
		],
		[
			1,
			-29
		],
		[
			9,
			-25
		],
		[
			10,
			-36
		],
		[
			-2,
			-15
		],
		[
			3,
			-15
		],
		[
			8,
			-8
		],
		[
			0,
			13
		],
		[
			14,
			-16
		],
		[
			4,
			-23
		],
		[
			7,
			-10
		],
		[
			0,
			-14
		],
		[
			-11,
			-19
		],
		[
			-7,
			0
		],
		[
			-6,
			36
		],
		[
			-8,
			9
		],
		[
			-12,
			22
		],
		[
			-14,
			16
		],
		[
			-5,
			14
		],
		[
			-4,
			-3
		],
		[
			-4,
			14
		],
		[
			-3,
			-1
		],
		[
			-2,
			25
		],
		[
			3,
			3
		],
		[
			0,
			27
		],
		[
			-9,
			30
		],
		[
			-3,
			0
		],
		[
			-17,
			21
		],
		[
			-1,
			21
		],
		[
			-4,
			-13
		],
		[
			-10,
			-1
		],
		[
			-5,
			13
		],
		[
			-8,
			9
		],
		[
			-10,
			6
		],
		[
			0,
			9
		],
		[
			-16,
			20
		],
		[
			-1,
			8
		],
		[
			15,
			-5
		],
		[
			7,
			6
		],
		[
			5,
			-13
		],
		[
			-1,
			17
		],
		[
			2,
			28
		],
		[
			-9,
			26
		],
		[
			-4,
			3
		],
		[
			-12,
			26
		],
		[
			-6,
			2
		],
		[
			-14,
			19
		],
		[
			-4,
			12
		],
		[
			0,
			19
		],
		[
			-5,
			4
		],
		[
			-1,
			26
		],
		[
			-7,
			9
		],
		[
			0,
			11
		],
		[
			-10,
			22
		],
		[
			1,
			15
		],
		[
			-8,
			14
		],
		[
			-6,
			28
		]
	],
	[
		[
			1746,
			7056
		],
		[
			66,
			10
		],
		[
			-1,
			-12
		],
		[
			46,
			-30
		],
		[
			58,
			-37
		],
		[
			79,
			0
		],
		[
			0,
			26
		],
		[
			46,
			0
		],
		[
			11,
			-20
		],
		[
			8,
			-8
		],
		[
			14,
			-26
		],
		[
			6,
			-4
		],
		[
			7,
			-12
		],
		[
			6,
			-21
		],
		[
			-1,
			-10
		],
		[
			5,
			-21
		],
		[
			14,
			-20
		],
		[
			25,
			-19
		],
		[
			8,
			14
		],
		[
			4,
			30
		],
		[
			8,
			2
		],
		[
			3,
			6
		],
		[
			5,
			-5
		],
		[
			20,
			-2
		],
		[
			3,
			-8
		]
	],
	[
		[
			2290,
			6649
		],
		[
			-4,
			-5
		],
		[
			0,
			-32
		],
		[
			-2,
			-53
		],
		[
			6,
			67
		],
		[
			4,
			13
		],
		[
			-4,
			10
		]
	],
	[
		[
			5582,
			7536
		],
		[
			0,
			0
		]
	],
	[
		[
			5586,
			7536
		],
		[
			-4,
			1
		]
	],
	[
		[
			5581,
			7537
		],
		[
			0,
			0
		]
	],
	[
		[
			5575,
			7539
		],
		[
			-2,
			10
		]
	],
	[
		[
			5598,
			7616
		],
		[
			20,
			7
		],
		[
			2,
			-4
		]
	],
	[
		[
			5117,
			6285
		],
		[
			0,
			-124
		],
		[
			-1,
			-33
		],
		[
			-4,
			-7
		],
		[
			-4,
			-29
		],
		[
			-11,
			-17
		],
		[
			0,
			-8
		],
		[
			-14,
			4
		],
		[
			0,
			-5
		],
		[
			-47,
			-3
		],
		[
			-9,
			-17
		],
		[
			-9,
			-3
		],
		[
			-13,
			3
		],
		[
			1,
			-5
		]
	],
	[
		[
			4683,
			5897
		],
		[
			-1,
			36
		],
		[
			-6,
			21
		],
		[
			-5,
			-5
		],
		[
			-8,
			23
		],
		[
			4,
			5
		],
		[
			-2,
			28
		],
		[
			-5,
			6
		],
		[
			1,
			18
		],
		[
			-2,
			5
		]
	],
	[
		[
			4659,
			6034
		],
		[
			5,
			-2
		],
		[
			7,
			8
		],
		[
			0,
			24
		],
		[
			3,
			11
		],
		[
			6,
			7
		],
		[
			14,
			-22
		],
		[
			3,
			-2
		],
		[
			4,
			13
		],
		[
			12,
			1
		],
		[
			14,
			-4
		],
		[
			13,
			7
		],
		[
			65,
			0
		],
		[
			41,
			0
		],
		[
			5,
			45
		],
		[
			-8,
			15
		],
		[
			-1,
			33
		],
		[
			-2,
			21
		],
		[
			-1,
			36
		],
		[
			-2,
			22
		],
		[
			-6,
			109
		],
		[
			0,
			17
		],
		[
			-3,
			39
		],
		[
			-6,
			104
		],
		[
			0,
			14
		],
		[
			-3,
			39
		],
		[
			0,
			16
		],
		[
			-3,
			37
		],
		[
			50,
			0
		]
	],
	[
		[
			7737,
			5862
		],
		[
			0,
			-11
		],
		[
			-4,
			-2
		],
		[
			-1,
			13
		],
		[
			5,
			0
		]
	],
	[
		[
			7733,
			5907
		],
		[
			-2,
			-14
		],
		[
			-1,
			20
		],
		[
			3,
			-6
		]
	],
	[
		[
			7622,
			6095
		],
		[
			-2,
			9
		],
		[
			7,
			13
		],
		[
			2,
			-6
		],
		[
			-7,
			-16
		]
	],
	[
		[
			7710,
			6117
		],
		[
			-4,
			12
		],
		[
			2,
			5
		],
		[
			2,
			-17
		]
	],
	[
		[
			7602,
			6269
		],
		[
			-2,
			-10
		],
		[
			-5,
			9
		],
		[
			7,
			1
		]
	],
	[
		[
			7604,
			6305
		],
		[
			6,
			-6
		],
		[
			-6,
			-6
		],
		[
			-3,
			10
		],
		[
			3,
			2
		]
	],
	[
		[
			7780,
			6353
		],
		[
			-9,
			6
		],
		[
			0,
			-6
		],
		[
			-10,
			2
		],
		[
			3,
			-11
		],
		[
			-6,
			-6
		],
		[
			-8,
			1
		],
		[
			-1,
			-17
		],
		[
			-21,
			-7
		],
		[
			-6,
			8
		],
		[
			0,
			-9
		],
		[
			-5,
			-4
		],
		[
			-2,
			-10
		],
		[
			1,
			-18
		],
		[
			-4,
			-10
		],
		[
			3,
			-19
		],
		[
			-10,
			-8
		],
		[
			5,
			-6
		],
		[
			5,
			-22
		],
		[
			-2,
			-10
		],
		[
			11,
			-23
		],
		[
			4,
			-17
		],
		[
			7,
			-8
		],
		[
			-1,
			-11
		],
		[
			6,
			-28
		],
		[
			6,
			5
		],
		[
			-2,
			-15
		],
		[
			-7,
			-3
		],
		[
			0,
			-40
		],
		[
			-9,
			-4
		],
		[
			-2,
			-12
		],
		[
			2,
			-16
		],
		[
			6,
			-13
		],
		[
			3,
			-15
		],
		[
			11,
			-14
		],
		[
			4,
			-11
		],
		[
			3,
			-67
		],
		[
			6,
			-9
		],
		[
			1,
			-25
		],
		[
			2,
			1
		],
		[
			3,
			-19
		],
		[
			-6,
			-12
		],
		[
			-1,
			-12
		],
		[
			-5,
			-17
		],
		[
			-6,
			-8
		],
		[
			0,
			-8
		],
		[
			-5,
			-4
		],
		[
			-2,
			-23
		]
	],
	[
		[
			7742,
			5779
		],
		[
			-7,
			-20
		],
		[
			0,
			24
		],
		[
			-1,
			18
		],
		[
			7,
			10
		],
		[
			1,
			45
		],
		[
			-5,
			2
		],
		[
			4,
			20
		],
		[
			-6,
			11
		],
		[
			5,
			21
		],
		[
			-3,
			32
		],
		[
			-9,
			31
		],
		[
			-4,
			-1
		],
		[
			0,
			27
		],
		[
			-3,
			9
		],
		[
			-5,
			30
		],
		[
			0,
			32
		],
		[
			-2,
			26
		],
		[
			-4,
			14
		],
		[
			2,
			25
		],
		[
			-8,
			-2
		],
		[
			-5,
			13
		],
		[
			0,
			18
		],
		[
			-3,
			12
		],
		[
			-6,
			8
		],
		[
			0,
			-23
		],
		[
			-2,
			-16
		],
		[
			-5,
			-11
		],
		[
			-11,
			3
		],
		[
			2,
			-12
		],
		[
			-16,
			-8
		],
		[
			-2,
			-16
		],
		[
			-7,
			-13
		],
		[
			-9,
			8
		],
		[
			-6,
			-4
		],
		[
			0,
			12
		],
		[
			-5,
			-9
		],
		[
			-3,
			5
		],
		[
			3,
			21
		],
		[
			-12,
			-19
		],
		[
			-1,
			11
		],
		[
			4,
			22
		],
		[
			2,
			38
		],
		[
			4,
			9
		],
		[
			0,
			22
		],
		[
			-2,
			3
		],
		[
			-2,
			30
		],
		[
			-6,
			24
		],
		[
			-5,
			8
		],
		[
			0,
			20
		],
		[
			-2,
			-4
		],
		[
			-1,
			-16
		],
		[
			-7,
			9
		],
		[
			-6,
			22
		],
		[
			9,
			-10
		],
		[
			6,
			14
		],
		[
			-11,
			14
		],
		[
			3,
			13
		],
		[
			-4,
			-3
		],
		[
			-6,
			11
		],
		[
			-10,
			-1
		],
		[
			2,
			16
		],
		[
			-4,
			-12
		],
		[
			-5,
			6
		],
		[
			5,
			4
		],
		[
			-5,
			9
		],
		[
			0,
			-11
		],
		[
			-7,
			22
		],
		[
			-3,
			3
		],
		[
			-3,
			21
		]
	],
	[
		[
			5533,
			7690
		],
		[
			8,
			-17
		],
		[
			11,
			-8
		],
		[
			13,
			-12
		],
		[
			0,
			-5
		]
	],
	[
		[
			5538,
			7620
		],
		[
			0,
			-3
		]
	],
	[
		[
			5537,
			7617
		],
		[
			-6,
			0
		],
		[
			7,
			-10
		]
	],
	[
		[
			5537,
			7593
		],
		[
			-14,
			24
		],
		[
			-10,
			8
		]
	],
	[
		[
			8263,
			7933
		],
		[
			2,
			-6
		],
		[
			9,
			9
		],
		[
			-4,
			10
		]
	],
	[
		[
			7439,
			8014
		],
		[
			9,
			6
		],
		[
			1,
			10
		],
		[
			19,
			0
		],
		[
			8,
			3
		],
		[
			15,
			13
		],
		[
			-2,
			11
		],
		[
			25,
			18
		],
		[
			5,
			0
		],
		[
			8,
			12
		],
		[
			11,
			0
		],
		[
			12,
			16
		],
		[
			9,
			-2
		],
		[
			7,
			10
		],
		[
			7,
			-10
		],
		[
			9,
			6
		],
		[
			2,
			-10
		],
		[
			33,
			-2
		],
		[
			3,
			-22
		],
		[
			8,
			-10
		],
		[
			8,
			1
		],
		[
			15,
			-8
		],
		[
			9,
			7
		],
		[
			21,
			-9
		],
		[
			11,
			2
		],
		[
			9,
			-10
		],
		[
			7,
			11
		],
		[
			15,
			6
		],
		[
			5,
			15
		],
		[
			2,
			14
		],
		[
			-8,
			6
		],
		[
			-6,
			22
		],
		[
			7,
			27
		],
		[
			5,
			0
		],
		[
			3,
			14
		],
		[
			8,
			4
		],
		[
			7,
			20
		],
		[
			11,
			-11
		],
		[
			11,
			-3
		],
		[
			9,
			-10
		],
		[
			14,
			0
		],
		[
			23,
			-15
		],
		[
			7,
			1
		],
		[
			17,
			-9
		],
		[
			2,
			-43
		],
		[
			17,
			-15
		],
		[
			11,
			-7
		],
		[
			20,
			-3
		],
		[
			13,
			10
		],
		[
			19,
			4
		],
		[
			4,
			6
		],
		[
			21,
			-6
		],
		[
			4,
			-6
		],
		[
			13,
			3
		],
		[
			14,
			-20
		],
		[
			22,
			-3
		],
		[
			-1,
			-15
		],
		[
			17,
			-20
		],
		[
			16,
			1
		],
		[
			31,
			-10
		],
		[
			3,
			4
		],
		[
			9,
			-6
		],
		[
			20,
			14
		],
		[
			18,
			1
		],
		[
			11,
			8
		],
		[
			10,
			-2
		],
		[
			8,
			5
		],
		[
			3,
			12
		],
		[
			27,
			27
		],
		[
			17,
			-1
		],
		[
			17,
			-20
		],
		[
			9,
			-1
		],
		[
			12,
			8
		],
		[
			12,
			-5
		],
		[
			3,
			-6
		]
	],
	[
		[
			5913,
			3637
		],
		[
			-22,
			0
		]
	],
	[
		[
			5891,
			3637
		],
		[
			1,
			15
		],
		[
			-3,
			17
		],
		[
			1,
			16
		],
		[
			-3,
			3
		]
	],
	[
		[
			5887,
			3688
		],
		[
			1,
			16
		],
		[
			0,
			71
		],
		[
			-4,
			30
		],
		[
			-3,
			5
		],
		[
			-6,
			24
		],
		[
			1,
			14
		],
		[
			-7,
			44
		]
	],
	[
		[
			5869,
			3892
		],
		[
			31,
			64
		],
		[
			-2,
			10
		],
		[
			4,
			10
		],
		[
			-1,
			17
		],
		[
			6,
			7
		],
		[
			9,
			29
		],
		[
			1,
			14
		],
		[
			-6,
			6
		],
		[
			1,
			36
		],
		[
			-5,
			2
		],
		[
			0,
			11
		],
		[
			6,
			3
		],
		[
			-1,
			14
		],
		[
			4,
			4
		],
		[
			-2,
			36
		],
		[
			3,
			14
		],
		[
			-1,
			17
		],
		[
			-5,
			22
		],
		[
			4,
			14
		],
		[
			-7,
			-1
		],
		[
			-1,
			6
		],
		[
			-13,
			9
		],
		[
			-9,
			1
		],
		[
			-5,
			12
		],
		[
			-5,
			1
		],
		[
			-7,
			10
		],
		[
			-9,
			-2
		],
		[
			-2,
			4
		],
		[
			-13,
			-1
		],
		[
			0,
			21
		]
	],
	[
		[
			5844,
			4282
		],
		[
			-1,
			18
		],
		[
			-4,
			20
		],
		[
			19,
			14
		],
		[
			14,
			6
		],
		[
			19,
			16
		],
		[
			4,
			1
		],
		[
			27,
			19
		]
	],
	[
		[
			5922,
			4376
		],
		[
			6,
			-21
		],
		[
			7,
			-13
		],
		[
			1,
			6
		],
		[
			17,
			6
		],
		[
			5,
			-11
		],
		[
			2,
			-41
		],
		[
			-5,
			-11
		],
		[
			0,
			-9
		],
		[
			-5,
			-10
		],
		[
			5,
			-13
		],
		[
			1,
			-14
		],
		[
			9,
			-15
		],
		[
			5,
			-13
		],
		[
			5,
			-4
		],
		[
			0,
			-17
		],
		[
			5,
			0
		],
		[
			-2,
			38
		],
		[
			4,
			19
		],
		[
			9,
			2
		],
		[
			3,
			5
		],
		[
			1,
			35
		],
		[
			-1,
			16
		],
		[
			3,
			15
		],
		[
			-2,
			14
		],
		[
			-21,
			54
		],
		[
			-6,
			11
		]
	],
	[
		[
			5968,
			4405
		],
		[
			-2,
			10
		],
		[
			-1,
			28
		],
		[
			2,
			8
		],
		[
			-4,
			14
		],
		[
			0,
			16
		],
		[
			6,
			10
		],
		[
			2,
			25
		]
	],
	[
		[
			5971,
			4516
		],
		[
			19,
			0
		],
		[
			5,
			10
		],
		[
			9,
			-10
		],
		[
			1,
			-7
		],
		[
			15,
			1
		],
		[
			7,
			6
		],
		[
			12,
			-8
		],
		[
			11,
			10
		],
		[
			1,
			13
		],
		[
			7,
			4
		],
		[
			11,
			-8
		],
		[
			11,
			13
		],
		[
			11,
			0
		],
		[
			5,
			9
		],
		[
			9,
			4
		],
		[
			18,
			27
		]
	],
	[
		[
			6123,
			4580
		],
		[
			6,
			-13
		],
		[
			-7,
			-32
		],
		[
			0,
			-23
		],
		[
			3,
			-18
		],
		[
			0,
			-28
		],
		[
			3,
			-20
		],
		[
			-6,
			-8
		],
		[
			5,
			-1
		],
		[
			-2,
			-39
		],
		[
			4,
			-23
		],
		[
			-4,
			-8
		],
		[
			6,
			-2
		],
		[
			-3,
			-8
		],
		[
			6,
			-5
		],
		[
			0,
			-22
		],
		[
			-5,
			-7
		],
		[
			1,
			-8
		],
		[
			-3,
			-24
		],
		[
			-13,
			-26
		],
		[
			-3,
			-14
		],
		[
			-7,
			-7
		],
		[
			3,
			-7
		],
		[
			-21,
			-26
		],
		[
			-1,
			-7
		],
		[
			-11,
			-2
		],
		[
			-16,
			-16
		],
		[
			-6,
			-3
		],
		[
			-20,
			-22
		],
		[
			-11,
			-32
		],
		[
			-8,
			-15
		],
		[
			-2,
			-13
		],
		[
			-5,
			5
		],
		[
			1,
			-12
		],
		[
			-4,
			6
		],
		[
			-13,
			-18
		],
		[
			-6,
			-17
		],
		[
			-16,
			-26
		],
		[
			-3,
			4
		],
		[
			0,
			-25
		],
		[
			-3,
			-12
		],
		[
			6,
			-15
		],
		[
			3,
			0
		],
		[
			4,
			-39
		],
		[
			4,
			-16
		],
		[
			2,
			-20
		],
		[
			-1,
			-24
		],
		[
			5,
			16
		],
		[
			2,
			-16
		],
		[
			-2,
			-10
		],
		[
			3,
			-20
		],
		[
			-7,
			-50
		],
		[
			6,
			-4
		],
		[
			-3,
			-17
		],
		[
			-9,
			-26
		],
		[
			-13,
			-11
		],
		[
			-26,
			-17
		],
		[
			-11,
			-10
		],
		[
			-12,
			-16
		],
		[
			-5,
			-18
		],
		[
			-4,
			-6
		],
		[
			3,
			-12
		],
		[
			7,
			-5
		],
		[
			-1,
			-33
		]
	],
	[
		[
			4659,
			6034
		],
		[
			-6,
			12
		],
		[
			-12,
			16
		],
		[
			-1,
			13
		],
		[
			-8,
			8
		],
		[
			-2,
			17
		],
		[
			-5,
			13
		],
		[
			-10,
			-2
		],
		[
			-6,
			16
		],
		[
			-8,
			14
		],
		[
			-16,
			0
		],
		[
			-20,
			-9
		],
		[
			-19,
			1
		],
		[
			-1,
			-15
		],
		[
			-3,
			-3
		],
		[
			-2,
			-22
		]
	],
	[
		[
			4540,
			6093
		],
		[
			0,
			30
		],
		[
			2,
			18
		],
		[
			8,
			33
		],
		[
			4,
			26
		],
		[
			0,
			28
		],
		[
			-3,
			40
		],
		[
			-5,
			20
		],
		[
			-6,
			11
		],
		[
			9,
			24
		],
		[
			0,
			28
		],
		[
			-9,
			26
		],
		[
			0,
			-9
		],
		[
			-5,
			11
		],
		[
			-4,
			19
		],
		[
			-4,
			-3
		],
		[
			-1,
			-16
		]
	],
	[
		[
			4526,
			6379
		],
		[
			-1,
			6
		],
		[
			3,
			26
		],
		[
			55,
			0
		],
		[
			55,
			0
		],
		[
			0,
			15
		],
		[
			-4,
			71
		],
		[
			3,
			10
		],
		[
			12,
			16
		],
		[
			17,
			11
		],
		[
			0,
			146
		],
		[
			56,
			0
		],
		[
			36,
			0
		],
		[
			0,
			74
		]
	],
	[
		[
			6603,
			4026
		],
		[
			2,
			-11
		],
		[
			-3,
			-12
		],
		[
			-9,
			-1
		],
		[
			0,
			15
		],
		[
			4,
			13
		],
		[
			6,
			-4
		]
	],
	[
		[
			5969,
			4525
		],
		[
			0,
			2
		]
	],
	[
		[
			5969,
			4527
		],
		[
			0,
			-2
		]
	],
	[
		[
			5964,
			4534
		],
		[
			0,
			2
		]
	],
	[
		[
			5964,
			4536
		],
		[
			0,
			-2
		]
	],
	[
		[
			5952,
			4624
		],
		[
			-3,
			6
		]
	],
	[
		[
			5949,
			4630
		],
		[
			3,
			-6
		]
	],
	[
		[
			5946,
			4634
		],
		[
			0,
			1
		]
	],
	[
		[
			5946,
			4635
		],
		[
			0,
			-1
		]
	],
	[
		[
			5941,
			4623
		],
		[
			2,
			-16
		],
		[
			8,
			-22
		],
		[
			-1,
			-51
		],
		[
			3,
			-25
		],
		[
			-8,
			-21
		],
		[
			0,
			-15
		],
		[
			4,
			-4
		],
		[
			0,
			-16
		],
		[
			4,
			-12
		],
		[
			-1,
			-26
		],
		[
			2,
			-9
		],
		[
			7,
			-10
		],
		[
			-2,
			-24
		],
		[
			7,
			-10
		],
		[
			2,
			11
		],
		[
			8,
			-16
		],
		[
			4,
			0
		],
		[
			-6,
			34
		],
		[
			-6,
			2
		],
		[
			0,
			12
		]
	],
	[
		[
			5922,
			4376
		],
		[
			-7,
			-1
		],
		[
			-2,
			12
		],
		[
			-6,
			14
		],
		[
			6,
			8
		],
		[
			4,
			49
		],
		[
			9,
			3
		],
		[
			5,
			11
		],
		[
			-4,
			0
		],
		[
			-4,
			11
		],
		[
			2,
			15
		],
		[
			-3,
			27
		],
		[
			5,
			15
		],
		[
			-4,
			17
		],
		[
			7,
			6
		],
		[
			5,
			11
		],
		[
			-4,
			20
		],
		[
			-6,
			8
		],
		[
			1,
			15
		],
		[
			-4,
			12
		],
		[
			-7,
			1
		],
		[
			-1,
			11
		]
	],
	[
		[
			5914,
			4641
		],
		[
			10,
			-5
		],
		[
			4,
			-7
		],
		[
			9,
			1
		],
		[
			4,
			-7
		]
	],
	[
		[
			8093,
			5320
		],
		[
			-2,
			3
		],
		[
			0,
			20
		],
		[
			2,
			-2
		],
		[
			0,
			-21
		]
	],
	[
		[
			8269,
			5423
		],
		[
			5,
			-1
		]
	],
	[
		[
			7786,
			5497
		],
		[
			-1,
			-11
		],
		[
			-3,
			11
		],
		[
			4,
			0
		]
	],
	[
		[
			7773,
			5553
		],
		[
			-3,
			-8
		],
		[
			-3,
			8
		],
		[
			6,
			0
		]
	],
	[
		[
			7834,
			5543
		],
		[
			9,
			-7
		],
		[
			3,
			-14
		],
		[
			18,
			-29
		],
		[
			9,
			-33
		],
		[
			1,
			-32
		],
		[
			-4,
			-8
		],
		[
			0,
			-23
		],
		[
			4,
			-12
		],
		[
			-2,
			-6
		],
		[
			1,
			-32
		],
		[
			10,
			-15
		],
		[
			3,
			-23
		],
		[
			8,
			-23
		],
		[
			1,
			-24
		],
		[
			-16,
			4
		],
		[
			-4,
			-10
		],
		[
			-5,
			15
		],
		[
			-15,
			19
		],
		[
			-7,
			11
		],
		[
			-10,
			9
		],
		[
			-11,
			21
		],
		[
			-14,
			15
		],
		[
			2,
			9
		],
		[
			-2,
			17
		],
		[
			-6,
			17
		],
		[
			-11,
			19
		],
		[
			2,
			9
		],
		[
			-4,
			6
		],
		[
			1,
			21
		],
		[
			-2,
			19
		],
		[
			-6,
			11
		],
		[
			2,
			6
		],
		[
			-2,
			23
		],
		[
			0,
			26
		],
		[
			-7,
			25
		]
	],
	[
		[
			7780,
			5554
		],
		[
			2,
			15
		],
		[
			4,
			-9
		],
		[
			12,
			-7
		],
		[
			2,
			-11
		],
		[
			7,
			1
		],
		[
			0,
			-19
		],
		[
			-3,
			-9
		],
		[
			3,
			-8
		],
		[
			5,
			9
		],
		[
			9,
			7
		],
		[
			6,
			-10
		],
		[
			7,
			30
		]
	],
	[
		[
			8045,
			5303
		],
		[
			0,
			-10
		],
		[
			8,
			-13
		],
		[
			9,
			1
		],
		[
			16,
			-8
		],
		[
			6,
			-6
		],
		[
			0,
			16
		],
		[
			5,
			22
		],
		[
			0,
			18
		],
		[
			4,
			0
		],
		[
			2,
			16
		],
		[
			5,
			8
		],
		[
			11,
			2
		],
		[
			20,
			10
		],
		[
			9,
			9
		],
		[
			12,
			33
		],
		[
			7,
			12
		],
		[
			6,
			19
		],
		[
			1,
			16
		]
	],
	[
		[
			8193,
			5464
		],
		[
			1,
			-4
		]
	],
	[
		[
			8198,
			5465
		],
		[
			6,
			1
		],
		[
			6,
			15
		],
		[
			-6,
			9
		],
		[
			6,
			11
		],
		[
			6,
			0
		],
		[
			3,
			14
		],
		[
			4,
			4
		],
		[
			1,
			17
		],
		[
			6,
			6
		],
		[
			1,
			8
		],
		[
			8,
			18
		],
		[
			3,
			19
		],
		[
			3,
			-3
		],
		[
			-2,
			-22
		],
		[
			6,
			8
		],
		[
			3,
			15
		],
		[
			4,
			-2
		],
		[
			1,
			-18
		],
		[
			7,
			-3
		],
		[
			6,
			-10
		],
		[
			-4,
			-13
		],
		[
			5,
			-16
		],
		[
			6,
			9
		],
		[
			3,
			-14
		],
		[
			8,
			-1
		],
		[
			9,
			-15
		],
		[
			15,
			-10
		],
		[
			0,
			-11
		],
		[
			-15,
			-13
		],
		[
			-7,
			-1
		],
		[
			-2,
			6
		],
		[
			-7,
			-8
		],
		[
			5,
			-14
		],
		[
			9,
			-13
		],
		[
			-18,
			-12
		],
		[
			-11,
			10
		],
		[
			-1,
			-14
		]
	],
	[
		[
			8256,
			5598
		],
		[
			-5,
			-6
		],
		[
			0,
			10
		],
		[
			6,
			4
		],
		[
			-1,
			-8
		]
	],
	[
		[
			5649,
			4167
		],
		[
			22,
			9
		],
		[
			17,
			-1
		],
		[
			7,
			-5
		],
		[
			6,
			-12
		]
	],
	[
		[
			5554,
			3757
		],
		[
			1,
			-13
		],
		[
			0,
			-196
		],
		[
			-12,
			-8
		],
		[
			-2,
			-9
		],
		[
			-7,
			-5
		],
		[
			-3,
			-11
		],
		[
			-11,
			7
		],
		[
			-16,
			-4
		],
		[
			-16,
			13
		],
		[
			-5,
			-1
		],
		[
			-2,
			28
		],
		[
			-4,
			0
		],
		[
			-3,
			11
		],
		[
			-5,
			-2
		],
		[
			-4,
			-12
		],
		[
			0,
			-11
		],
		[
			-8,
			-7
		]
	],
	[
		[
			5457,
			3537
		],
		[
			-5,
			4
		],
		[
			-15,
			27
		],
		[
			-12,
			41
		],
		[
			-2,
			21
		],
		[
			-5,
			18
		],
		[
			2,
			11
		],
		[
			-5,
			7
		],
		[
			0,
			21
		],
		[
			-3,
			11
		],
		[
			-1,
			23
		],
		[
			1,
			20
		],
		[
			-11,
			53
		],
		[
			1,
			33
		],
		[
			-2,
			25
		],
		[
			3,
			10
		],
		[
			-1,
			27
		],
		[
			-14,
			39
		],
		[
			-4,
			18
		],
		[
			-13,
			37
		],
		[
			-5,
			37
		],
		[
			-3,
			3
		],
		[
			-4,
			20
		],
		[
			-7,
			22
		],
		[
			-3,
			18
		],
		[
			-8,
			23
		],
		[
			-8,
			14
		],
		[
			-5,
			21
		],
		[
			-3,
			36
		],
		[
			1,
			12
		]
	],
	[
		[
			9665,
			3952
		],
		[
			5,
			-3
		],
		[
			-1,
			-13
		],
		[
			-7,
			3
		],
		[
			-2,
			12
		],
		[
			5,
			1
		]
	],
	[
		[
			9646,
			3990
		],
		[
			4,
			-27
		],
		[
			-9,
			7
		],
		[
			-1,
			8
		],
		[
			6,
			12
		]
	],
	[
		[
			9555,
			4026
		],
		[
			7,
			-13
		],
		[
			6,
			0
		],
		[
			16,
			-24
		],
		[
			5,
			-3
		],
		[
			11,
			-30
		],
		[
			7,
			-3
		],
		[
			15,
			-20
		],
		[
			4,
			-10
		],
		[
			11,
			-14
		],
		[
			2,
			-10
		],
		[
			-3,
			-5
		],
		[
			-12,
			8
		],
		[
			-2,
			-4
		],
		[
			-6,
			8
		],
		[
			-2,
			13
		],
		[
			-4,
			-1
		],
		[
			-7,
			14
		],
		[
			-13,
			7
		],
		[
			-4,
			13
		],
		[
			-12,
			16
		],
		[
			-1,
			8
		],
		[
			-6,
			6
		],
		[
			-12,
			44
		]
	],
	[
		[
			5416,
			6507
		],
		[
			4,
			-53
		],
		[
			1,
			-34
		],
		[
			12,
			-31
		],
		[
			-1,
			-12
		],
		[
			11,
			-21
		],
		[
			-7,
			-29
		],
		[
			0,
			-21
		],
		[
			-6,
			-142
		],
		[
			-1,
			-9
		],
		[
			-22,
			-46
		],
		[
			-12,
			-29
		],
		[
			-13,
			-39
		],
		[
			0,
			-11
		],
		[
			-9,
			-19
		],
		[
			4,
			-39
		]
	],
	[
		[
			5377,
			5972
		],
		[
			-6,
			1
		],
		[
			-4,
			-10
		],
		[
			-5,
			0
		],
		[
			-14,
			-18
		],
		[
			-2,
			-10
		],
		[
			-10,
			2
		],
		[
			-7,
			9
		],
		[
			-12,
			6
		],
		[
			-22,
			1
		],
		[
			-13,
			-6
		],
		[
			-7,
			-7
		],
		[
			-8,
			-20
		],
		[
			-18,
			2
		],
		[
			-10,
			7
		],
		[
			-15,
			20
		],
		[
			-9,
			1
		],
		[
			-10,
			-12
		],
		[
			-6,
			0
		],
		[
			-3,
			-7
		],
		[
			-7,
			4
		],
		[
			-4,
			15
		],
		[
			-12,
			21
		],
		[
			-3,
			-3
		],
		[
			-16,
			14
		],
		[
			-8,
			-8
		],
		[
			-12,
			2
		],
		[
			-11,
			-6
		],
		[
			-9,
			-11
		],
		[
			-1,
			-28
		],
		[
			-4,
			-14
		],
		[
			-8,
			-13
		],
		[
			-1,
			-25
		],
		[
			1,
			-21
		],
		[
			-2,
			-2
		]
	],
	[
		[
			5377,
			5972
		],
		[
			13,
			-36
		]
	],
	[
		[
			5238,
			5460
		],
		[
			-5,
			-4
		],
		[
			-6,
			14
		],
		[
			5,
			-21
		],
		[
			-2,
			-4
		],
		[
			-17,
			-3
		],
		[
			-14,
			10
		],
		[
			0,
			-10
		],
		[
			-4,
			-4
		],
		[
			0,
			13
		],
		[
			-4,
			2
		],
		[
			3,
			-18
		],
		[
			-25,
			-6
		],
		[
			-7,
			6
		],
		[
			-8,
			17
		],
		[
			-3,
			12
		],
		[
			-3,
			27
		],
		[
			-4,
			8
		],
		[
			-3,
			17
		],
		[
			-6,
			13
		],
		[
			-13,
			20
		],
		[
			-15,
			4
		],
		[
			-12,
			-1
		],
		[
			4,
			6
		],
		[
			-5,
			2
		],
		[
			0,
			-9
		],
		[
			-19,
			-1
		]
	],
	[
		[
			2691,
			6046
		],
		[
			-6,
			-4
		],
		[
			4,
			-35
		],
		[
			-7,
			-20
		],
		[
			-4,
			-40
		],
		[
			2,
			-21
		],
		[
			-1,
			-19
		],
		[
			2,
			-10
		],
		[
			-4,
			-2
		],
		[
			1,
			15
		],
		[
			-5,
			-4
		],
		[
			4,
			-12
		],
		[
			-5,
			-31
		],
		[
			3,
			2
		],
		[
			1,
			-14
		],
		[
			-6,
			-11
		],
		[
			1,
			-16
		],
		[
			5,
			-12
		]
	],
	[
		[
			2619,
			5821
		],
		[
			-6,
			13
		],
		[
			-12,
			18
		],
		[
			-7,
			15
		],
		[
			-4,
			17
		],
		[
			-26,
			41
		],
		[
			4,
			10
		],
		[
			6,
			-5
		]
	],
	[
		[
			5093,
			8141
		],
		[
			24,
			0
		]
	],
	[
		[
			5162,
			8210
		],
		[
			-10,
			-17
		],
		[
			-10,
			7
		],
		[
			15,
			13
		],
		[
			5,
			-3
		]
	],
	[
		[
			5118,
			8141
		],
		[
			-21,
			6
		],
		[
			1,
			7
		],
		[
			9,
			1
		],
		[
			7,
			-11
		],
		[
			-3,
			33
		],
		[
			8,
			7
		],
		[
			6,
			13
		],
		[
			6,
			36
		],
		[
			10,
			-1
		],
		[
			14,
			21
		],
		[
			11,
			5
		],
		[
			24,
			3
		],
		[
			9,
			-12
		]
	],
	[
		[
			5140,
			8230
		],
		[
			7,
			-10
		],
		[
			-8,
			-8
		],
		[
			0,
			-15
		],
		[
			12,
			-5
		],
		[
			12,
			14
		],
		[
			-12,
			20
		],
		[
			-2,
			13
		],
		[
			-9,
			-9
		]
	],
	[
		[
			5157,
			8665
		],
		[
			-10,
			4
		],
		[
			10,
			9
		],
		[
			0,
			-13
		]
	],
	[
		[
			5249,
			8849
		],
		[
			3,
			-8
		],
		[
			-16,
			-5
		],
		[
			-3,
			7
		],
		[
			16,
			6
		]
	],
	[
		[
			5244,
			8857
		],
		[
			-2,
			-7
		],
		[
			-13,
			0
		],
		[
			15,
			7
		]
	],
	[
		[
			5344,
			8955
		],
		[
			3,
			-6
		],
		[
			-12,
			-11
		],
		[
			9,
			17
		]
	],
	[
		[
			5387,
			9114
		],
		[
			3,
			-5
		],
		[
			-17,
			-6
		],
		[
			5,
			13
		],
		[
			9,
			-2
		]
	],
	[
		[
			5420,
			9124
		],
		[
			-11,
			-11
		],
		[
			-15,
			-6
		],
		[
			9,
			15
		],
		[
			17,
			2
		]
	],
	[
		[
			5441,
			9154
		],
		[
			2,
			-15
		],
		[
			8,
			12
		],
		[
			8,
			-5
		],
		[
			-1,
			-15
		],
		[
			-21,
			-8
		],
		[
			-4,
			-7
		],
		[
			-17,
			-3
		],
		[
			6,
			18
		],
		[
			6,
			0
		],
		[
			6,
			23
		],
		[
			7,
			0
		]
	],
	[
		[
			5421,
			9152
		],
		[
			6,
			-15
		],
		[
			-9,
			-5
		],
		[
			-18,
			7
		],
		[
			21,
			13
		]
	],
	[
		[
			5439,
			9158
		],
		[
			-11,
			-3
		],
		[
			20,
			19
		],
		[
			-9,
			-16
		]
	],
	[
		[
			5492,
			9188
		],
		[
			10,
			-7
		],
		[
			-3,
			-14
		],
		[
			-32,
			-8
		],
		[
			9,
			12
		],
		[
			-6,
			8
		],
		[
			22,
			9
		]
	],
	[
		[
			5523,
			9207
		],
		[
			6,
			-7
		],
		[
			-8,
			-11
		],
		[
			-17,
			-2
		],
		[
			5,
			15
		],
		[
			14,
			5
		]
	],
	[
		[
			5533,
			9218
		],
		[
			12,
			-6
		],
		[
			-15,
			-10
		],
		[
			-9,
			7
		],
		[
			12,
			9
		]
	],
	[
		[
			5652,
			9249
		],
		[
			5,
			-8
		],
		[
			-16,
			-11
		],
		[
			-6,
			7
		],
		[
			17,
			12
		]
	],
	[
		[
			5649,
			9262
		],
		[
			-11,
			-16
		],
		[
			-24,
			-4
		],
		[
			7,
			13
		],
		[
			17,
			-3
		],
		[
			11,
			10
		]
	],
	[
		[
			5856,
			9203
		],
		[
			2,
			-15
		],
		[
			-17,
			4
		],
		[
			-10,
			-15
		],
		[
			-16,
			-3
		],
		[
			-11,
			-16
		]
	],
	[
		[
			5572,
			9158
		],
		[
			-14,
			0
		],
		[
			7,
			-8
		],
		[
			-11,
			-20
		],
		[
			0,
			-11
		],
		[
			-42,
			13
		],
		[
			-8,
			-3
		],
		[
			1,
			-19
		],
		[
			-8,
			-13
		],
		[
			-16,
			8
		],
		[
			-15,
			-11
		],
		[
			-5,
			-16
		],
		[
			-14,
			-13
		],
		[
			9,
			-12
		],
		[
			-1,
			-10
		],
		[
			-27,
			-31
		],
		[
			2,
			-13
		],
		[
			-12,
			-7
		],
		[
			-15,
			-1
		],
		[
			3,
			-17
		],
		[
			-3,
			-30
		],
		[
			-5,
			-12
		],
		[
			-20,
			-30
		],
		[
			14,
			-8
		],
		[
			1,
			-15
		],
		[
			-5,
			-10
		],
		[
			-21,
			5
		],
		[
			-15,
			-8
		],
		[
			-14,
			-21
		],
		[
			-5,
			-18
		],
		[
			6,
			-16
		],
		[
			-4,
			-24
		],
		[
			7,
			-20
		],
		[
			-5,
			-30
		],
		[
			20,
			-20
		],
		[
			-4,
			-18
		],
		[
			-13,
			-4
		],
		[
			10,
			-29
		],
		[
			-3,
			-21
		],
		[
			-10,
			-13
		],
		[
			-7,
			0
		],
		[
			-6,
			-16
		],
		[
			4,
			-21
		],
		[
			-6,
			-21
		],
		[
			-5,
			6
		]
	],
	[
		[
			5317,
			8580
		],
		[
			-2,
			7
		],
		[
			-16,
			4
		],
		[
			-5,
			22
		],
		[
			-5,
			-3
		],
		[
			1,
			-15
		],
		[
			-5,
			-12
		],
		[
			-15,
			-2
		],
		[
			-28,
			-36
		],
		[
			-16,
			-16
		],
		[
			-15,
			-5
		],
		[
			-30,
			5
		],
		[
			4,
			7
		],
		[
			-19,
			9
		],
		[
			-10,
			9
		],
		[
			-4,
			11
		],
		[
			2,
			18
		],
		[
			14,
			-10
		],
		[
			-5,
			13
		],
		[
			9,
			14
		],
		[
			-12,
			11
		],
		[
			2,
			-11
		],
		[
			-10,
			-4
		],
		[
			-8,
			9
		],
		[
			8,
			18
		],
		[
			11,
			0
		],
		[
			-5,
			7
		],
		[
			7,
			5
		],
		[
			5,
			15
		],
		[
			10,
			13
		],
		[
			-13,
			-9
		],
		[
			-6,
			-16
		],
		[
			-6,
			16
		],
		[
			-6,
			-8
		],
		[
			-6,
			8
		],
		[
			3,
			14
		],
		[
			12,
			-3
		],
		[
			-1,
			14
		],
		[
			-10,
			-9
		],
		[
			-10,
			14
		],
		[
			3,
			16
		],
		[
			10,
			0
		],
		[
			-13,
			10
		],
		[
			0,
			10
		],
		[
			11,
			7
		],
		[
			-11,
			5
		],
		[
			11,
			16
		],
		[
			33,
			-6
		],
		[
			-31,
			8
		],
		[
			-7,
			-3
		],
		[
			7,
			17
		],
		[
			13,
			1
		],
		[
			25,
			16
		],
		[
			-12,
			-3
		],
		[
			12,
			13
		],
		[
			22,
			-8
		],
		[
			-1,
			10
		],
		[
			-16,
			2
		],
		[
			-2,
			12
		],
		[
			10,
			5
		],
		[
			7,
			-6
		],
		[
			16,
			2
		],
		[
			4,
			11
		],
		[
			12,
			-2
		],
		[
			-5,
			11
		],
		[
			34,
			19
		],
		[
			7,
			-14
		],
		[
			24,
			5
		],
		[
			-2,
			8
		],
		[
			19,
			14
		],
		[
			2,
			9
		],
		[
			-18,
			-7
		],
		[
			2,
			-9
		],
		[
			-26,
			-14
		],
		[
			-12,
			16
		],
		[
			15,
			11
		],
		[
			-3,
			9
		],
		[
			14,
			10
		],
		[
			12,
			17
		],
		[
			13,
			-11
		],
		[
			0,
			17
		],
		[
			11,
			5
		],
		[
			4,
			17
		],
		[
			19,
			3
		],
		[
			-10,
			6
		],
		[
			10,
			12
		],
		[
			-8,
			12
		],
		[
			27,
			33
		],
		[
			-8,
			8
		],
		[
			9,
			16
		],
		[
			12,
			10
		],
		[
			-7,
			6
		],
		[
			20,
			4
		],
		[
			10,
			13
		],
		[
			22,
			-3
		],
		[
			0,
			5
		],
		[
			-28,
			1
		],
		[
			28,
			31
		],
		[
			-15,
			-9
		],
		[
			4,
			15
		],
		[
			30,
			7
		],
		[
			-22,
			1
		],
		[
			23,
			8
		],
		[
			5,
			-17
		],
		[
			6,
			8
		],
		[
			-11,
			14
		],
		[
			17,
			8
		],
		[
			32,
			-1
		],
		[
			-9,
			8
		],
		[
			-29,
			-5
		],
		[
			2,
			11
		],
		[
			24,
			6
		],
		[
			6,
			22
		],
		[
			10,
			6
		],
		[
			4,
			14
		],
		[
			19,
			5
		],
		[
			11,
			13
		],
		[
			26,
			10
		],
		[
			8,
			-11
		],
		[
			15,
			2
		],
		[
			11,
			14
		],
		[
			19,
			-17
		],
		[
			-5,
			14
		],
		[
			-18,
			15
		],
		[
			28,
			3
		],
		[
			20,
			-6
		],
		[
			5,
			-14
		],
		[
			11,
			25
		],
		[
			29,
			23
		],
		[
			0,
			11
		],
		[
			37,
			-7
		],
		[
			-19,
			-17
		],
		[
			-9,
			-26
		],
		[
			8,
			-1
		],
		[
			6,
			15
		],
		[
			33,
			35
		],
		[
			-3,
			-34
		],
		[
			17,
			22
		],
		[
			11,
			6
		],
		[
			-8,
			10
		],
		[
			28,
			3
		],
		[
			8,
			-5
		],
		[
			-19,
			-29
		],
		[
			14,
			2
		],
		[
			11,
			20
		],
		[
			9,
			1
		],
		[
			21,
			-14
		],
		[
			8,
			4
		],
		[
			27,
			-25
		],
		[
			-16,
			-2
		],
		[
			-10,
			-10
		],
		[
			-39,
			6
		],
		[
			-3,
			-4
		],
		[
			29,
			-8
		],
		[
			-2,
			-12
		],
		[
			34,
			3
		]
	],
	[
		[
			5713,
			9281
		],
		[
			11,
			-11
		],
		[
			-15,
			-3
		],
		[
			-6,
			9
		],
		[
			10,
			5
		]
	],
	[
		[
			4778,
			9282
		],
		[
			-1,
			-9
		],
		[
			-15,
			-2
		],
		[
			16,
			11
		]
	],
	[
		[
			5647,
			9686
		],
		[
			-7,
			-11
		],
		[
			38,
			-10
		],
		[
			-33,
			-33
		],
		[
			-23,
			0
		],
		[
			10,
			17
		],
		[
			-53,
			-6
		],
		[
			22,
			27
		],
		[
			-22,
			9
		],
		[
			23,
			8
		],
		[
			45,
			-1
		]
	],
	[
		[
			5596,
			9708
		],
		[
			21,
			-5
		],
		[
			1,
			-13
		],
		[
			-43,
			-4
		],
		[
			-15,
			17
		],
		[
			36,
			5
		]
	],
	[
		[
			5313,
			9706
		],
		[
			24,
			-18
		],
		[
			-29,
			12
		],
		[
			-16,
			19
		],
		[
			13,
			4
		],
		[
			8,
			-17
		]
	],
	[
		[
			5467,
			9783
		],
		[
			4,
			5
		],
		[
			53,
			-31
		],
		[
			2,
			-16
		],
		[
			23,
			1
		],
		[
			8,
			-9
		],
		[
			40,
			-9
		],
		[
			-5,
			-12
		],
		[
			-44,
			-1
		],
		[
			-22,
			-10
		],
		[
			3,
			-21
		],
		[
			-18,
			-4
		],
		[
			-5,
			-31
		],
		[
			-14,
			1
		],
		[
			-11,
			-30
		],
		[
			-12,
			-11
		],
		[
			3,
			-11
		],
		[
			-20,
			6
		],
		[
			-35,
			25
		],
		[
			-18,
			3
		],
		[
			-9,
			22
		],
		[
			50,
			-2
		],
		[
			-31,
			7
		],
		[
			59,
			9
		],
		[
			-36,
			4
		],
		[
			-50,
			-9
		],
		[
			-5,
			19
		],
		[
			40,
			3
		],
		[
			17,
			12
		],
		[
			27,
			1
		],
		[
			-3,
			22
		],
		[
			-14,
			-14
		],
		[
			-16,
			-1
		],
		[
			-1,
			23
		],
		[
			-28,
			-21
		],
		[
			10,
			-6
		],
		[
			-25,
			-10
		],
		[
			-23,
			-1
		],
		[
			-17,
			20
		],
		[
			-20,
			10
		],
		[
			21,
			16
		],
		[
			-19,
			4
		],
		[
			10,
			14
		],
		[
			-23,
			-12
		],
		[
			-16,
			26
		],
		[
			31,
			17
		],
		[
			9,
			-10
		],
		[
			47,
			12
		],
		[
			-3,
			-10
		],
		[
			-33,
			-9
		],
		[
			37,
			-1
		],
		[
			19,
			16
		],
		[
			20,
			-12
		],
		[
			5,
			-15
		],
		[
			28,
			-25
		],
		[
			-14,
			23
		],
		[
			-7,
			33
		],
		[
			24,
			9
		],
		[
			7,
			-9
		]
	],
	[
		[
			5642,
			9812
		],
		[
			113,
			-16
		],
		[
			-1,
			-15
		],
		[
			-37,
			-13
		],
		[
			-5,
			-13
		],
		[
			-38,
			-5
		],
		[
			-6,
			-7
		],
		[
			-32,
			2
		],
		[
			-1,
			11
		],
		[
			-57,
			-2
		],
		[
			-32,
			10
		],
		[
			22,
			8
		],
		[
			39,
			1
		],
		[
			0,
			7
		],
		[
			-66,
			-7
		],
		[
			-28,
			4
		],
		[
			-12,
			23
		],
		[
			33,
			-5
		],
		[
			33,
			19
		],
		[
			53,
			-25
		],
		[
			3,
			26
		],
		[
			19,
			-3
		]
	],
	[
		[
			9617,
			2273
		],
		[
			0,
			-19
		],
		[
			-6,
			6
		],
		[
			6,
			13
		]
	],
	[
		[
			9665,
			2494
		],
		[
			6,
			-10
		],
		[
			0,
			-14
		],
		[
			-12,
			-2
		],
		[
			-5,
			-8
		],
		[
			1,
			13
		],
		[
			5,
			6
		],
		[
			-1,
			14
		],
		[
			6,
			1
		]
	],
	[
		[
			96,
			2665
		],
		[
			10,
			-1
		],
		[
			-9,
			-6
		],
		[
			6,
			-11
		],
		[
			-9,
			-5
		],
		[
			3,
			13
		],
		[
			-9,
			8
		],
		[
			8,
			2
		]
	],
	[
		[
			9802,
			2850
		],
		[
			-4,
			0
		],
		[
			-2,
			-14
		],
		[
			9,
			-2
		],
		[
			1,
			-21
		],
		[
			4,
			-9
		],
		[
			10,
			14
		],
		[
			6,
			3
		],
		[
			3,
			-10
		],
		[
			3,
			13
		],
		[
			9,
			-2
		],
		[
			-4,
			-7
		],
		[
			3,
			-10
		],
		[
			-6,
			-8
		],
		[
			6,
			-18
		],
		[
			-8,
			-17
		],
		[
			-3,
			-13
		],
		[
			-9,
			-13
		],
		[
			-6,
			-23
		],
		[
			-15,
			-16
		],
		[
			-1,
			-24
		],
		[
			9,
			-5
		],
		[
			1,
			-9
		],
		[
			-7,
			-4
		],
		[
			-10,
			10
		],
		[
			-7,
			-9
		],
		[
			-25,
			-22
		],
		[
			-4,
			-20
		],
		[
			0,
			-17
		],
		[
			-7,
			-15
		],
		[
			-5,
			-25
		],
		[
			0,
			-16
		],
		[
			-8,
			-3
		],
		[
			-17,
			-24
		],
		[
			-4,
			-11
		],
		[
			-13,
			-7
		],
		[
			-11,
			0
		],
		[
			-1,
			6
		],
		[
			-13,
			-4
		],
		[
			-5,
			16
		],
		[
			-11,
			-2
		],
		[
			-2,
			10
		],
		[
			-8,
			3
		],
		[
			-3,
			-7
		],
		[
			-16,
			3
		],
		[
			1,
			13
		],
		[
			-9,
			0
		],
		[
			0,
			10
		],
		[
			9,
			6
		],
		[
			-2,
			8
		],
		[
			4,
			17
		],
		[
			8,
			-7
		],
		[
			-4,
			16
		],
		[
			36,
			56
		],
		[
			2,
			7
		],
		[
			10,
			1
		],
		[
			19,
			21
		],
		[
			8,
			4
		],
		[
			16,
			27
		],
		[
			14,
			12
		],
		[
			13,
			29
		],
		[
			6,
			37
		],
		[
			9,
			4
		],
		[
			8,
			16
		],
		[
			1,
			31
		],
		[
			15,
			21
		],
		[
			7,
			0
		]
	],
	[
		[
			9872,
			3102
		],
		[
			4,
			-10
		],
		[
			-7,
			5
		],
		[
			3,
			5
		]
	],
	[
		[
			9807,
			3201
		],
		[
			-1,
			-14
		],
		[
			3,
			-11
		],
		[
			8,
			-8
		],
		[
			8,
			2
		],
		[
			10,
			-9
		],
		[
			2,
			-9
		],
		[
			5,
			4
		],
		[
			1,
			-13
		],
		[
			5,
			-10
		],
		[
			-2,
			-23
		],
		[
			9,
			-16
		],
		[
			-3,
			-21
		],
		[
			7,
			-17
		],
		[
			8,
			0
		],
		[
			4,
			-17
		],
		[
			5,
			3
		],
		[
			-4,
			18
		],
		[
			3,
			20
		],
		[
			3,
			-14
		],
		[
			7,
			-9
		],
		[
			1,
			-35
		],
		[
			2,
			-7
		],
		[
			14,
			-7
		],
		[
			19,
			-13
		],
		[
			10,
			4
		],
		[
			5,
			14
		],
		[
			8,
			7
		],
		[
			8,
			0
		],
		[
			7,
			-10
		],
		[
			-6,
			-15
		],
		[
			-1,
			-32
		],
		[
			-10,
			-9
		],
		[
			-2,
			-34
		],
		[
			-1,
			12
		],
		[
			-12,
			1
		],
		[
			-10,
			-8
		],
		[
			-4,
			-10
		],
		[
			1,
			-13
		],
		[
			4,
			-3
		],
		[
			-5,
			-25
		],
		[
			-8,
			-21
		],
		[
			-6,
			-9
		],
		[
			-9,
			-30
		],
		[
			-8,
			-14
		],
		[
			-13,
			-14
		],
		[
			-3,
			11
		],
		[
			-9,
			-1
		],
		[
			-8,
			12
		],
		[
			4,
			4
		],
		[
			10,
			24
		],
		[
			4,
			27
		],
		[
			-5,
			17
		],
		[
			-15,
			10
		],
		[
			-6,
			12
		],
		[
			-9,
			4
		],
		[
			-6,
			8
		],
		[
			1,
			14
		],
		[
			22,
			19
		],
		[
			3,
			41
		],
		[
			4,
			20
		],
		[
			-3,
			30
		],
		[
			4,
			10
		],
		[
			-3,
			8
		],
		[
			-8,
			-6
		],
		[
			-2,
			16
		],
		[
			-6,
			19
		],
		[
			7,
			-12
		],
		[
			-2,
			22
		],
		[
			-11,
			8
		],
		[
			1,
			-9
		],
		[
			-26,
			61
		],
		[
			2,
			16
		],
		[
			-12,
			29
		],
		[
			10,
			1
		]
	],
	[
		[
			6629,
			6344
		],
		[
			-1,
			12
		],
		[
			8,
			19
		],
		[
			-7,
			-31
		]
	],
	[
		[
			6474,
			6141
		],
		[
			-8,
			37
		],
		[
			-2,
			0
		],
		[
			-11,
			55
		],
		[
			-10,
			44
		]
	],
	[
		[
			6443,
			6277
		],
		[
			13,
			8
		],
		[
			52,
			37
		],
		[
			19,
			12
		],
		[
			9,
			56
		],
		[
			9,
			61
		],
		[
			-13,
			39
		]
	],
	[
		[
			6566,
			6621
		],
		[
			6,
			-28
		],
		[
			6,
			-15
		],
		[
			10,
			-17
		],
		[
			31,
			-18
		],
		[
			8,
			2
		],
		[
			6,
			-11
		],
		[
			13,
			-39
		],
		[
			7,
			-13
		],
		[
			8,
			-2
		],
		[
			0,
			-17
		],
		[
			-9,
			-27
		],
		[
			-4,
			-19
		],
		[
			-12,
			-17
		],
		[
			-11,
			-42
		],
		[
			-8,
			1
		],
		[
			1,
			11
		],
		[
			-5,
			-3
		],
		[
			-3,
			-13
		],
		[
			-4,
			-4
		],
		[
			-1,
			-20
		],
		[
			-3,
			-10
		],
		[
			2,
			-31
		],
		[
			2,
			-11
		],
		[
			-3,
			-4
		],
		[
			-15,
			-2
		],
		[
			-8,
			-6
		],
		[
			-7,
			-12
		],
		[
			-3,
			-28
		],
		[
			-5,
			-10
		],
		[
			-5,
			1
		],
		[
			-21,
			-7
		],
		[
			-6,
			-19
		],
		[
			2,
			-9
		],
		[
			-7,
			-20
		],
		[
			-8,
			-3
		],
		[
			-4,
			5
		],
		[
			-16,
			-3
		],
		[
			-12,
			-14
		],
		[
			-7,
			0
		],
		[
			-7,
			-6
		]
	],
	[
		[
			6557,
			6684
		],
		[
			2,
			8
		],
		[
			9,
			-6
		],
		[
			-5,
			-27
		]
	],
	[
		[
			6893,
			6556
		],
		[
			-1,
			-9
		],
		[
			-8,
			10
		],
		[
			-6,
			-3
		],
		[
			-8,
			15
		],
		[
			-5,
			42
		],
		[
			-13,
			5
		],
		[
			1,
			20
		],
		[
			-5,
			7
		],
		[
			-3,
			13
		],
		[
			-7,
			1
		],
		[
			2,
			-7
		],
		[
			-16,
			-8
		],
		[
			-13,
			2
		],
		[
			-1,
			-4
		],
		[
			-23,
			-1
		],
		[
			-19,
			6
		],
		[
			-4,
			-11
		],
		[
			-28,
			4
		],
		[
			-5,
			-6
		],
		[
			-17,
			-8
		],
		[
			1,
			8
		],
		[
			-5,
			2
		]
	],
	[
		[
			2729,
			5623
		],
		[
			3,
			-19
		],
		[
			-7,
			12
		],
		[
			4,
			7
		]
	],
	[
		[
			2836,
			5599
		],
		[
			-8,
			16
		],
		[
			-7,
			31
		],
		[
			5,
			4
		],
		[
			0,
			10
		],
		[
			5,
			8
		],
		[
			-5,
			3
		],
		[
			-4,
			-7
		],
		[
			-3,
			16
		],
		[
			-10,
			15
		],
		[
			-6,
			5
		],
		[
			-10,
			2
		],
		[
			-9,
			-12
		],
		[
			0,
			-13
		],
		[
			-8,
			-11
		],
		[
			-12,
			-10
		],
		[
			0,
			-8
		],
		[
			10,
			-19
		],
		[
			4,
			-14
		],
		[
			-10,
			-6
		],
		[
			-2,
			-9
		],
		[
			-13,
			-2
		],
		[
			0,
			7
		],
		[
			-8,
			30
		],
		[
			-1,
			-14
		],
		[
			-10,
			8
		],
		[
			-3,
			19
		],
		[
			-9,
			8
		],
		[
			-6,
			-1
		],
		[
			0,
			8
		],
		[
			-8,
			-4
		],
		[
			-9,
			2
		],
		[
			-2,
			-16
		]
	],
	[
		[
			2706,
			5734
		],
		[
			6,
			-10
		],
		[
			3,
			-23
		],
		[
			13,
			-4
		],
		[
			-4,
			11
		],
		[
			5,
			-3
		],
		[
			6,
			-15
		],
		[
			10,
			-1
		],
		[
			9,
			5
		],
		[
			7,
			12
		],
		[
			14,
			8
		],
		[
			14,
			22
		],
		[
			10,
			-4
		],
		[
			7,
			2
		],
		[
			-2,
			-7
		],
		[
			16,
			-2
		],
		[
			17,
			-19
		],
		[
			3,
			-9
		],
		[
			10,
			-15
		]
	],
	[
		[
			3073,
			4289
		],
		[
			-8,
			13
		],
		[
			-7,
			0
		],
		[
			2,
			-20
		],
		[
			-3,
			4
		],
		[
			-3,
			-15
		],
		[
			17,
			-10
		],
		[
			-2,
			-8
		],
		[
			7,
			-8
		],
		[
			4,
			3
		]
	],
	[
		[
			3084,
			4249
		],
		[
			-2,
			-19
		]
	],
	[
		[
			3044,
			4127
		],
		[
			-14,
			19
		],
		[
			0,
			3
		],
		[
			-13,
			15
		],
		[
			0,
			13
		],
		[
			-3,
			10
		],
		[
			-18,
			16
		],
		[
			-6,
			15
		],
		[
			-10,
			5
		],
		[
			-17,
			20
		],
		[
			-17,
			13
		],
		[
			-3,
			8
		],
		[
			-32,
			34
		],
		[
			-1,
			9
		],
		[
			-9,
			19
		],
		[
			-10,
			12
		],
		[
			-6,
			25
		],
		[
			-4,
			2
		],
		[
			0,
			15
		],
		[
			3,
			23
		],
		[
			-10,
			34
		],
		[
			0,
			7
		],
		[
			-8,
			20
		],
		[
			1,
			6
		],
		[
			-7,
			9
		],
		[
			-3,
			11
		],
		[
			-2,
			23
		],
		[
			-4,
			10
		],
		[
			-8,
			9
		],
		[
			1,
			11
		],
		[
			-4,
			20
		],
		[
			-12,
			36
		],
		[
			-1,
			20
		],
		[
			-4,
			9
		],
		[
			-2,
			18
		],
		[
			-5,
			8
		],
		[
			-4,
			33
		],
		[
			-6,
			23
		],
		[
			-14,
			29
		],
		[
			-6,
			35
		],
		[
			-7,
			12
		],
		[
			-6,
			16
		],
		[
			-16,
			16
		],
		[
			-11,
			17
		],
		[
			0,
			11
		],
		[
			8,
			6
		],
		[
			-2,
			16
		],
		[
			-7,
			11
		],
		[
			3,
			15
		],
		[
			-8,
			19
		],
		[
			2,
			25
		],
		[
			12,
			23
		],
		[
			0,
			5
		],
		[
			14,
			21
		]
	],
	[
		[
			8339,
			5486
		],
		[
			-9,
			-12
		],
		[
			-3,
			4
		],
		[
			12,
			8
		]
	],
	[
		[
			8361,
			5534
		],
		[
			5,
			-6
		],
		[
			-8,
			-6
		],
		[
			3,
			12
		]
	],
	[
		[
			8390,
			5552
		],
		[
			-3,
			0
		],
		[
			-4,
			14
		],
		[
			7,
			5
		],
		[
			7,
			-7
		],
		[
			-7,
			-12
		]
	],
	[
		[
			8493,
			5581
		],
		[
			-3,
			9
		],
		[
			3,
			5
		],
		[
			0,
			-14
		]
	],
	[
		[
			8251,
			5645
		],
		[
			-2,
			-13
		],
		[
			-1,
			14
		],
		[
			3,
			-1
		]
	],
	[
		[
			8489,
			5736
		],
		[
			9,
			-8
		],
		[
			3,
			-13
		],
		[
			4,
			4
		],
		[
			-1,
			-13
		],
		[
			4,
			-7
		],
		[
			0,
			-10
		],
		[
			-6,
			-9
		],
		[
			8,
			-6
		],
		[
			-1,
			-20
		],
		[
			3,
			3
		],
		[
			-2,
			-23
		],
		[
			5,
			-6
		],
		[
			1,
			-27
		],
		[
			-4,
			-16
		],
		[
			-6,
			-12
		],
		[
			-1,
			-28
		],
		[
			-4,
			20
		],
		[
			1,
			8
		],
		[
			-6,
			19
		],
		[
			-1,
			14
		],
		[
			-5,
			-4
		],
		[
			0,
			-9
		],
		[
			-5,
			-8
		],
		[
			-3,
			-22
		],
		[
			6,
			-6
		],
		[
			3,
			-20
		],
		[
			-1,
			-12
		],
		[
			-7,
			-21
		],
		[
			-7,
			13
		],
		[
			3,
			8
		],
		[
			-3,
			9
		],
		[
			-3,
			-14
		],
		[
			-10,
			5
		],
		[
			-13,
			14
		],
		[
			-5,
			15
		],
		[
			0,
			20
		],
		[
			-2,
			0
		],
		[
			1,
			19
		],
		[
			6,
			8
		],
		[
			0,
			9
		],
		[
			-5,
			11
		],
		[
			-15,
			13
		],
		[
			-3,
			-12
		],
		[
			1,
			-15
		],
		[
			-4,
			9
		],
		[
			-4,
			-1
		],
		[
			0,
			12
		],
		[
			-4,
			-14
		],
		[
			-6,
			0
		],
		[
			1,
			16
		],
		[
			-9,
			-3
		],
		[
			-7,
			-26
		],
		[
			-2,
			-17
		],
		[
			-3,
			-3
		],
		[
			-5,
			9
		],
		[
			7,
			30
		],
		[
			-1,
			11
		],
		[
			7,
			16
		],
		[
			16,
			6
		],
		[
			3,
			21
		],
		[
			8,
			1
		],
		[
			2,
			11
		],
		[
			3,
			-6
		],
		[
			6,
			1
		],
		[
			4,
			-13
		],
		[
			0,
			-15
		],
		[
			11,
			6
		],
		[
			2,
			17
		],
		[
			3,
			4
		],
		[
			6,
			-8
		],
		[
			3,
			5
		],
		[
			0,
			23
		],
		[
			4,
			1
		],
		[
			5,
			-9
		],
		[
			5,
			10
		],
		[
			7,
			1
		],
		[
			0,
			17
		],
		[
			-4,
			21
		],
		[
			2,
			8
		],
		[
			5,
			-12
		]
	],
	[
		[
			8503,
			5750
		],
		[
			-4,
			-2
		],
		[
			2,
			14
		],
		[
			2,
			-12
		]
	],
	[
		[
			8453,
			5767
		],
		[
			7,
			-6
		],
		[
			-1,
			-12
		],
		[
			-7,
			-13
		],
		[
			-12,
			2
		],
		[
			-2,
			9
		],
		[
			7,
			10
		],
		[
			3,
			10
		],
		[
			5,
			0
		]
	],
	[
		[
			8479,
			5754
		],
		[
			-4,
			9
		],
		[
			3,
			3
		],
		[
			1,
			-12
		]
	],
	[
		[
			8490,
			5782
		],
		[
			1,
			-31
		],
		[
			-5,
			11
		],
		[
			0,
			15
		],
		[
			4,
			5
		]
	],
	[
		[
			8332,
			5791
		],
		[
			-6,
			-5
		],
		[
			2,
			10
		],
		[
			4,
			-5
		]
	],
	[
		[
			8408,
			5792
		],
		[
			-5,
			-9
		],
		[
			0,
			11
		],
		[
			4,
			7
		],
		[
			1,
			-9
		]
	],
	[
		[
			8423,
			5815
		],
		[
			8,
			-4
		],
		[
			1,
			-7
		],
		[
			-7,
			-25
		],
		[
			-1,
			-15
		],
		[
			-4,
			-13
		],
		[
			0,
			-19
		],
		[
			5,
			-11
		],
		[
			-2,
			-12
		],
		[
			-7,
			-5
		],
		[
			-3,
			15
		],
		[
			-9,
			8
		],
		[
			-5,
			15
		],
		[
			2,
			15
		],
		[
			11,
			6
		],
		[
			-1,
			23
		],
		[
			4,
			23
		],
		[
			8,
			6
		]
	],
	[
		[
			8444,
			5821
		],
		[
			1,
			-35
		],
		[
			-2,
			-9
		],
		[
			-9,
			-14
		],
		[
			0,
			-7
		],
		[
			-6,
			-27
		],
		[
			-3,
			-4
		],
		[
			2,
			34
		],
		[
			9,
			27
		],
		[
			5,
			33
		],
		[
			3,
			2
		]
	],
	[
		[
			8319,
			5836
		],
		[
			0,
			-30
		],
		[
			6,
			-17
		],
		[
			-10,
			-11
		],
		[
			-4,
			-14
		],
		[
			-13,
			-9
		],
		[
			1,
			-12
		],
		[
			-9,
			-26
		],
		[
			-10,
			-10
		],
		[
			-1,
			-9
		],
		[
			-8,
			-14
		],
		[
			-6,
			-2
		],
		[
			-1,
			-9
		],
		[
			-9,
			0
		],
		[
			19,
			43
		],
		[
			4,
			0
		],
		[
			9,
			23
		],
		[
			7,
			11
		],
		[
			6,
			20
		],
		[
			12,
			17
		],
		[
			4,
			32
		],
		[
			0,
			14
		],
		[
			3,
			3
		]
	],
	[
		[
			8456,
			5842
		],
		[
			7,
			-8
		],
		[
			4,
			7
		],
		[
			6,
			-10
		],
		[
			-1,
			-30
		],
		[
			5,
			-8
		],
		[
			2,
			-19
		],
		[
			-8,
			-4
		],
		[
			2,
			-10
		],
		[
			-8,
			7
		],
		[
			-1,
			14
		],
		[
			2,
			19
		],
		[
			-2,
			11
		],
		[
			-5,
			5
		],
		[
			-4,
			-4
		],
		[
			1,
			30
		]
	],
	[
		[
			8456,
			5856
		],
		[
			5,
			-12
		],
		[
			-5,
			0
		],
		[
			0,
			12
		]
	],
	[
		[
			8396,
			5860
		],
		[
			10,
			-14
		],
		[
			4,
			6
		],
		[
			3,
			-11
		],
		[
			7,
			8
		],
		[
			-1,
			-24
		],
		[
			-9,
			-10
		],
		[
			-1,
			-11
		],
		[
			-6,
			-6
		],
		[
			-9,
			-2
		],
		[
			-6,
			-13
		],
		[
			-2,
			20
		],
		[
			4,
			17
		],
		[
			0,
			39
		],
		[
			-6,
			1
		],
		[
			3,
			10
		],
		[
			9,
			-10
		]
	],
	[
		[
			8332,
			5870
		],
		[
			2,
			-13
		],
		[
			-3,
			-2
		],
		[
			-2,
			15
		],
		[
			3,
			0
		]
	],
	[
		[
			8331,
			5890
		],
		[
			11,
			-11
		],
		[
			0,
			-5
		],
		[
			-10,
			1
		],
		[
			-1,
			15
		]
	],
	[
		[
			8405,
			5890
		],
		[
			-5,
			12
		],
		[
			6,
			0
		],
		[
			-1,
			-12
		]
	],
	[
		[
			8469,
			5906
		],
		[
			10,
			-3
		],
		[
			2,
			-13
		],
		[
			5,
			-4
		],
		[
			-2,
			-6
		],
		[
			1,
			-33
		],
		[
			6,
			-24
		],
		[
			-14,
			0
		],
		[
			-2,
			10
		],
		[
			-4,
			0
		],
		[
			-4,
			10
		],
		[
			6,
			17
		],
		[
			-5,
			0
		],
		[
			-6,
			16
		],
		[
			-8,
			11
		],
		[
			-3,
			20
		],
		[
			7,
			-3
		],
		[
			11,
			2
		]
	],
	[
		[
			8426,
			5905
		],
		[
			6,
			-6
		],
		[
			5,
			-13
		],
		[
			4,
			-1
		],
		[
			4,
			-15
		],
		[
			0,
			-12
		],
		[
			-17,
			28
		],
		[
			-8,
			-17
		],
		[
			3,
			13
		],
		[
			-1,
			26
		],
		[
			4,
			-3
		]
	],
	[
		[
			8392,
			5910
		],
		[
			-3,
			-30
		],
		[
			-3,
			11
		],
		[
			2,
			17
		],
		[
			4,
			2
		]
	],
	[
		[
			8434,
			5912
		],
		[
			3,
			-18
		],
		[
			-5,
			16
		],
		[
			2,
			2
		]
	],
	[
		[
			8421,
			5926
		],
		[
			-7,
			8
		],
		[
			2,
			6
		],
		[
			5,
			-14
		]
	],
	[
		[
			8360,
			5962
		],
		[
			15,
			-22
		],
		[
			-1,
			-23
		],
		[
			-3,
			-26
		],
		[
			-4,
			-5
		],
		[
			-9,
			17
		],
		[
			-4,
			15
		],
		[
			0,
			14
		],
		[
			-7,
			12
		],
		[
			-4,
			18
		],
		[
			10,
			-4
		],
		[
			7,
			4
		]
	],
	[
		[
			8385,
			5963
		],
		[
			7,
			-9
		],
		[
			-4,
			-11
		],
		[
			-5,
			8
		],
		[
			2,
			12
		]
	],
	[
		[
			8450,
			5993
		],
		[
			5,
			-11
		],
		[
			0,
			-12
		],
		[
			-7,
			-8
		],
		[
			-4,
			7
		],
		[
			3,
			5
		],
		[
			0,
			20
		],
		[
			3,
			-1
		]
	],
	[
		[
			8387,
			6049
		],
		[
			2,
			-18
		],
		[
			-3,
			-5
		],
		[
			-3,
			23
		],
		[
			4,
			0
		]
	],
	[
		[
			8358,
			6252
		],
		[
			7,
			4
		],
		[
			10,
			-14
		],
		[
			13,
			-6
		],
		[
			4,
			13
		],
		[
			3,
			0
		],
		[
			2,
			-15
		],
		[
			-4,
			-8
		],
		[
			-1,
			-29
		],
		[
			3,
			-15
		],
		[
			4,
			0
		],
		[
			2,
			-28
		],
		[
			-8,
			-32
		],
		[
			1,
			-4
		],
		[
			-18,
			-18
		],
		[
			2,
			-10
		],
		[
			-7,
			-28
		],
		[
			9,
			-32
		],
		[
			-3,
			-1
		],
		[
			4,
			-30
		],
		[
			5,
			-10
		],
		[
			10,
			-2
		],
		[
			-3,
			13
		],
		[
			8,
			9
		],
		[
			8,
			-1
		],
		[
			9,
			-20
		],
		[
			-1,
			-12
		],
		[
			5,
			-3
		],
		[
			3,
			17
		],
		[
			17,
			-13
		],
		[
			1,
			-4
		],
		[
			-12,
			-1
		],
		[
			0,
			-8
		],
		[
			5,
			-8
		],
		[
			4,
			-16
		],
		[
			6,
			-8
		],
		[
			2,
			-12
		],
		[
			-2,
			-14
		],
		[
			-6,
			5
		],
		[
			-1,
			13
		],
		[
			-7,
			1
		],
		[
			-8,
			7
		],
		[
			0,
			14
		],
		[
			-3,
			11
		],
		[
			-7,
			6
		],
		[
			-5,
			16
		],
		[
			-9,
			7
		],
		[
			2,
			-18
		],
		[
			5,
			-15
		],
		[
			-3,
			-12
		],
		[
			-7,
			25
		],
		[
			-17,
			19
		],
		[
			-8,
			-8
		],
		[
			1,
			-6
		],
		[
			-11,
			-4
		],
		[
			-4,
			16
		],
		[
			-6,
			2
		],
		[
			-2,
			-7
		],
		[
			-1,
			24
		],
		[
			11,
			17
		],
		[
			-4,
			14
		],
		[
			-9,
			-4
		],
		[
			2,
			-13
		],
		[
			-4,
			-3
		],
		[
			-4,
			23
		],
		[
			-7,
			4
		],
		[
			-1,
			23
		],
		[
			-4,
			8
		],
		[
			1,
			26
		],
		[
			-4,
			3
		],
		[
			0,
			23
		],
		[
			9,
			-15
		],
		[
			9,
			5
		],
		[
			-3,
			17
		],
		[
			0,
			21
		],
		[
			4,
			10
		],
		[
			-1,
			11
		],
		[
			0,
			43
		],
		[
			5,
			23
		],
		[
			-1,
			10
		],
		[
			10,
			4
		]
	],
	[
		[
			8740,
			5620
		],
		[
			-2,
			-13
		],
		[
			-3,
			3
		],
		[
			5,
			10
		]
	],
	[
		[
			9256,
			4529
		],
		[
			13,
			-10
		],
		[
			0,
			-5
		],
		[
			-10,
			3
		],
		[
			-3,
			12
		]
	],
	[
		[
			9195,
			4611
		],
		[
			7,
			-2
		],
		[
			-2,
			-10
		],
		[
			-8,
			2
		],
		[
			-5,
			23
		],
		[
			8,
			-13
		]
	],
	[
		[
			9184,
			4640
		],
		[
			3,
			2
		],
		[
			5,
			-15
		],
		[
			-14,
			1
		],
		[
			0,
			16
		],
		[
			6,
			-4
		]
	],
	[
		[
			9176,
			4644
		],
		[
			-1,
			-9
		],
		[
			-5,
			5
		],
		[
			-1,
			9
		],
		[
			6,
			1
		],
		[
			1,
			-6
		]
	],
	[
		[
			9234,
			4667
		],
		[
			10,
			-3
		],
		[
			5,
			-11
		],
		[
			-10,
			2
		],
		[
			-5,
			12
		]
	],
	[
		[
			8989,
			4680
		],
		[
			-11,
			16
		],
		[
			11,
			-11
		],
		[
			0,
			-5
		]
	],
	[
		[
			8981,
			4701
		],
		[
			6,
			0
		],
		[
			1,
			-7
		],
		[
			-7,
			7
		]
	],
	[
		[
			9105,
			4867
		],
		[
			7,
			-7
		],
		[
			-1,
			-11
		],
		[
			-7,
			10
		],
		[
			1,
			8
		]
	],
	[
		[
			9299,
			4867
		],
		[
			8,
			-4
		],
		[
			3,
			-17
		],
		[
			6,
			-8
		],
		[
			1,
			-9
		],
		[
			5,
			-4
		],
		[
			8,
			-16
		],
		[
			2,
			-14
		],
		[
			-7,
			-8
		],
		[
			-5,
			1
		],
		[
			-10,
			17
		],
		[
			1,
			14
		],
		[
			-14,
			25
		],
		[
			0,
			19
		],
		[
			2,
			4
		]
	],
	[
		[
			9089,
			4870
		],
		[
			-4,
			0
		],
		[
			-2,
			11
		],
		[
			3,
			3
		],
		[
			3,
			-14
		]
	],
	[
		[
			9296,
			4889
		],
		[
			-2,
			-21
		],
		[
			-1,
			25
		],
		[
			3,
			-4
		]
	],
	[
		[
			9228,
			4941
		],
		[
			-2,
			-6
		],
		[
			7,
			-2
		],
		[
			0,
			-17
		],
		[
			-5,
			-20
		],
		[
			-8,
			-1
		],
		[
			5,
			-25
		],
		[
			-8,
			-9
		],
		[
			-11,
			3
		],
		[
			2,
			-8
		],
		[
			-14,
			-21
		],
		[
			-15,
			-13
		],
		[
			-24,
			-2
		],
		[
			-3,
			10
		],
		[
			-6,
			4
		],
		[
			-6,
			-5
		],
		[
			-2,
			7
		],
		[
			-10,
			12
		],
		[
			-9,
			7
		],
		[
			4,
			14
		],
		[
			11,
			-5
		],
		[
			3,
			4
		],
		[
			7,
			-8
		],
		[
			20,
			6
		],
		[
			2,
			24
		],
		[
			4,
			-27
		],
		[
			8,
			6
		],
		[
			8,
			-5
		],
		[
			8,
			6
		],
		[
			0,
			10
		],
		[
			10,
			20
		],
		[
			7,
			-3
		],
		[
			2,
			5
		],
		[
			-2,
			23
		],
		[
			-3,
			16
		],
		[
			7,
			0
		],
		[
			5,
			-8
		],
		[
			2,
			8
		],
		[
			6,
			0
		]
	],
	[
		[
			8915,
			5033
		],
		[
			7,
			-1
		],
		[
			25,
			-25
		],
		[
			25,
			-17
		],
		[
			13,
			-4
		],
		[
			9,
			-11
		],
		[
			5,
			-11
		],
		[
			15,
			-2
		],
		[
			0,
			-8
		],
		[
			9,
			-6
		],
		[
			5,
			-15
		],
		[
			8,
			-3
		],
		[
			13,
			-25
		],
		[
			-1,
			-38
		],
		[
			14,
			-4
		],
		[
			18,
			-16
		],
		[
			5,
			-7
		],
		[
			12,
			-3
		],
		[
			9,
			-22
		],
		[
			0,
			-18
		],
		[
			-25,
			-3
		],
		[
			0,
			-12
		],
		[
			5,
			-13
		],
		[
			1,
			-15
		],
		[
			7,
			-6
		],
		[
			8,
			-21
		],
		[
			12,
			-8
		],
		[
			3,
			-30
		],
		[
			7,
			-9
		],
		[
			2,
			-19
		],
		[
			21,
			3
		],
		[
			-4,
			-19
		],
		[
			1,
			-9
		],
		[
			7,
			-6
		],
		[
			15,
			-2
		],
		[
			1,
			-5
		],
		[
			-9,
			-5
		],
		[
			8,
			-16
		],
		[
			10,
			-7
		],
		[
			12,
			-3
		],
		[
			-4,
			-5
		],
		[
			-9,
			-1
		],
		[
			10,
			-10
		],
		[
			-7,
			-9
		],
		[
			-13,
			6
		],
		[
			2,
			7
		],
		[
			-9,
			8
		],
		[
			-7,
			-1
		],
		[
			-8,
			6
		],
		[
			-12,
			0
		],
		[
			1,
			5
		],
		[
			-11,
			-3
		],
		[
			-2,
			5
		],
		[
			-17,
			1
		],
		[
			-11,
			33
		],
		[
			-5,
			2
		],
		[
			-7,
			22
		],
		[
			-8,
			6
		],
		[
			-4,
			23
		],
		[
			-10,
			30
		],
		[
			-13,
			9
		],
		[
			-5,
			-1
		],
		[
			-7,
			8
		],
		[
			-9,
			2
		],
		[
			-6,
			12
		],
		[
			-6,
			-1
		],
		[
			2,
			-13
		],
		[
			-7,
			10
		],
		[
			1,
			-8
		],
		[
			-13,
			8
		],
		[
			4,
			-19
		],
		[
			-11,
			-4
		],
		[
			1,
			-12
		],
		[
			-18,
			-5
		],
		[
			-6,
			1
		],
		[
			11,
			-10
		],
		[
			7,
			-15
		],
		[
			1,
			-11
		],
		[
			-22,
			-23
		],
		[
			-11,
			10
		],
		[
			-20,
			-3
		],
		[
			-6,
			4
		],
		[
			-3,
			-5
		],
		[
			-6,
			7
		]
	],
	[
		[
			9195,
			5027
		],
		[
			10,
			-11
		],
		[
			11,
			-17
		],
		[
			7,
			-3
		],
		[
			14,
			-33
		],
		[
			11,
			-10
		],
		[
			5,
			-22
		],
		[
			-2,
			-14
		],
		[
			-5,
			-10
		],
		[
			-6,
			14
		],
		[
			1,
			21
		],
		[
			-5,
			19
		],
		[
			-10,
			21
		],
		[
			-6,
			2
		],
		[
			-9,
			16
		],
		[
			-5,
			4
		],
		[
			-9,
			15
		],
		[
			-10,
			7
		],
		[
			8,
			1
		]
	],
	[
		[
			9172,
			5046
		],
		[
			6,
			-5
		],
		[
			0,
			-12
		],
		[
			-8,
			0
		],
		[
			-3,
			9
		],
		[
			5,
			8
		]
	],
	[
		[
			9079,
			5070
		],
		[
			12,
			-5
		],
		[
			-3,
			-8
		],
		[
			-17,
			0
		],
		[
			0,
			11
		],
		[
			8,
			2
		]
	],
	[
		[
			9154,
			5105
		],
		[
			6,
			-13
		],
		[
			-6,
			5
		],
		[
			0,
			8
		]
	],
	[
		[
			5544,
			8319
		],
		[
			0,
			-1
		]
	],
	[
		[
			5544,
			8318
		],
		[
			4,
			-1
		]
	],
	[
		[
			5548,
			8317
		],
		[
			63,
			-4
		],
		[
			21,
			0
		]
	],
	[
		[
			5655,
			8150
		],
		[
			1,
			-13
		],
		[
			14,
			-27
		],
		[
			-5,
			0
		],
		[
			4,
			-18
		],
		[
			-10,
			-8
		],
		[
			-18,
			-24
		],
		[
			-13,
			-25
		],
		[
			4,
			-28
		],
		[
			-6,
			2
		]
	],
	[
		[
			5626,
			8009
		],
		[
			-15,
			8
		],
		[
			-11,
			12
		],
		[
			-16,
			-2
		],
		[
			-4,
			-6
		],
		[
			-6,
			6
		],
		[
			-10,
			0
		],
		[
			-14,
			-12
		],
		[
			-1,
			12
		],
		[
			-10,
			11
		],
		[
			-7,
			-11
		],
		[
			-9,
			7
		]
	],
	[
		[
			5396,
			8275
		],
		[
			8,
			-3
		],
		[
			0,
			13
		],
		[
			-10,
			0
		]
	],
	[
		[
			5394,
			8289
		],
		[
			54,
			20
		],
		[
			12,
			16
		],
		[
			10,
			2
		],
		[
			11,
			9
		],
		[
			27,
			5
		],
		[
			7,
			-23
		],
		[
			12,
			-6
		],
		[
			17,
			7
		]
	],
	[
		[
			3138,
			6248
		],
		[
			29,
			-2
		],
		[
			9,
			-6
		],
		[
			2,
			-7
		],
		[
			-7,
			-13
		],
		[
			-9,
			-5
		],
		[
			-17,
			3
		],
		[
			-12,
			-1
		],
		[
			1,
			15
		],
		[
			-3,
			7
		],
		[
			3,
			10
		],
		[
			4,
			-1
		]
	],
	[
		[
			8625,
			7631
		],
		[
			5,
			-14
		]
	],
	[
		[
			8630,
			7617
		],
		[
			-7,
			4
		],
		[
			-11,
			-15
		],
		[
			-11,
			-27
		],
		[
			4,
			-15
		],
		[
			-3,
			-11
		],
		[
			1,
			-19
		],
		[
			-11,
			-5
		],
		[
			-7,
			-16
		],
		[
			-13,
			-11
		],
		[
			-8,
			-14
		],
		[
			-9,
			1
		],
		[
			-4,
			-9
		],
		[
			-10,
			-8
		],
		[
			2,
			-9
		],
		[
			-6,
			-13
		],
		[
			2,
			-13
		],
		[
			9,
			-2
		],
		[
			17,
			-29
		]
	],
	[
		[
			8518,
			7361
		],
		[
			-8,
			4
		],
		[
			-8,
			-9
		],
		[
			-8,
			15
		],
		[
			-7,
			1
		],
		[
			2,
			-14
		],
		[
			-10,
			9
		],
		[
			-7,
			-2
		],
		[
			3,
			9
		],
		[
			-13,
			4
		],
		[
			9,
			5
		],
		[
			-3,
			9
		],
		[
			10,
			20
		],
		[
			-3,
			4
		],
		[
			4,
			21
		],
		[
			5,
			14
		],
		[
			-4,
			8
		],
		[
			-16,
			7
		],
		[
			-11,
			14
		],
		[
			1,
			12
		]
	],
	[
		[
			4525,
			7072
		],
		[
			11,
			-2
		],
		[
			-3,
			-7
		],
		[
			-10,
			3
		],
		[
			2,
			6
		]
	],
	[
		[
			4286,
			7362
		],
		[
			15,
			1
		],
		[
			0,
			-6
		],
		[
			-10,
			-3
		],
		[
			-5,
			8
		]
	],
	[
		[
			4220,
			7396
		],
		[
			-11,
			-2
		],
		[
			-2,
			9
		],
		[
			13,
			-7
		]
	],
	[
		[
			4248,
			7409
		],
		[
			-8,
			0
		],
		[
			0,
			8
		],
		[
			6,
			0
		],
		[
			2,
			-8
		]
	],
	[
		[
			4794,
			7325
		],
		[
			-12,
			-12
		],
		[
			-21,
			8
		],
		[
			-10,
			-7
		],
		[
			4,
			24
		],
		[
			1,
			44
		],
		[
			-4,
			18
		],
		[
			-8,
			-2
		],
		[
			-1,
			11
		],
		[
			8,
			6
		],
		[
			-2,
			7
		],
		[
			-4,
			-11
		],
		[
			-9,
			1
		],
		[
			4,
			38
		],
		[
			6,
			7
		],
		[
			7,
			36
		],
		[
			-1,
			3
		],
		[
			7,
			47
		],
		[
			-6,
			50
		],
		[
			3,
			7
		]
	],
	[
		[
			3492,
			3797
		],
		[
			-1,
			-17
		],
		[
			-4,
			-23
		],
		[
			-1,
			-22
		],
		[
			-3,
			-17
		]
	],
	[
		[
			5949,
			6986
		],
		[
			8,
			16
		]
	],
	[
		[
			5987,
			7012
		],
		[
			-4,
			-16
		]
	],
	[
		[
			853,
			4163
		],
		[
			-9,
			-2
		],
		[
			-1,
			11
		],
		[
			5,
			3
		],
		[
			5,
			-12
		]
	],
	[
		[
			6422,
			6601
		],
		[
			-8,
			-2
		],
		[
			-3,
			9
		]
	],
	[
		[
			6411,
			6608
		],
		[
			1,
			10
		],
		[
			-3,
			15
		],
		[
			1,
			20
		],
		[
			3,
			6
		],
		[
			4,
			24
		],
		[
			6,
			6
		],
		[
			4,
			-12
		],
		[
			5,
			-2
		],
		[
			1,
			-9
		],
		[
			-4,
			-14
		],
		[
			4,
			-14
		],
		[
			0,
			-15
		],
		[
			-4,
			-17
		],
		[
			-7,
			-5
		]
	],
	[
		[
			5783,
			7801
		],
		[
			3,
			-8
		],
		[
			11,
			-6
		],
		[
			14,
			12
		],
		[
			10,
			-3
		],
		[
			2,
			-9
		]
	],
	[
		[
			5823,
			7787
		],
		[
			-1,
			-22
		],
		[
			-14,
			-4
		],
		[
			-3,
			13
		],
		[
			-4,
			-3
		],
		[
			-6,
			-35
		],
		[
			1,
			-21
		],
		[
			-3,
			-13
		]
	],
	[
		[
			5630,
			7730
		],
		[
			-6,
			15
		],
		[
			8,
			5
		],
		[
			-10,
			9
		],
		[
			-6,
			-14
		],
		[
			-5,
			9
		],
		[
			-10,
			2
		],
		[
			-9,
			9
		],
		[
			5,
			16
		],
		[
			-15,
			12
		],
		[
			-6,
			9
		],
		[
			1,
			16
		],
		[
			-13,
			13
		],
		[
			-2,
			7
		]
	],
	[
		[
			5635,
			7944
		],
		[
			10,
			8
		],
		[
			7,
			-5
		],
		[
			20,
			-6
		],
		[
			10,
			3
		],
		[
			9,
			-14
		],
		[
			10,
			11
		],
		[
			26,
			6
		],
		[
			3,
			12
		],
		[
			9,
			3
		]
	],
	[
		[
			9064,
			7741
		],
		[
			7,
			1
		],
		[
			-12,
			-10
		],
		[
			-16,
			-24
		],
		[
			15,
			37
		],
		[
			6,
			-4
		]
	],
	[
		[
			9133,
			7793
		],
		[
			-15,
			-6
		],
		[
			-10,
			-15
		],
		[
			-5,
			0
		],
		[
			-7,
			-11
		],
		[
			-18,
			-19
		],
		[
			10,
			17
		],
		[
			-3,
			3
		],
		[
			25,
			28
		],
		[
			9,
			0
		],
		[
			12,
			15
		],
		[
			2,
			-12
		]
	],
	[
		[
			9182,
			7845
		],
		[
			-21,
			-27
		],
		[
			-10,
			-9
		],
		[
			15,
			27
		],
		[
			16,
			9
		]
	],
	[
		[
			9227,
			7898
		],
		[
			-1,
			-8
		],
		[
			-10,
			-14
		],
		[
			11,
			22
		]
	],
	[
		[
			9301,
			8041
		],
		[
			-1,
			-17
		],
		[
			-6,
			3
		],
		[
			7,
			14
		]
	],
	[
		[
			9336,
			8091
		],
		[
			-7,
			-15
		],
		[
			-9,
			-4
		],
		[
			-5,
			-11
		],
		[
			-5,
			16
		],
		[
			15,
			9
		],
		[
			4,
			15
		],
		[
			7,
			3
		],
		[
			0,
			-13
		]
	],
	[
		[
			9344,
			8100
		],
		[
			-7,
			6
		],
		[
			7,
			7
		],
		[
			0,
			-13
		]
	],
	[
		[
			8967,
			8309
		],
		[
			5,
			-11
		],
		[
			-3,
			-7
		],
		[
			8,
			-35
		],
		[
			4,
			-38
		],
		[
			-6,
			-46
		],
		[
			5,
			-11
		],
		[
			-2,
			-12
		],
		[
			6,
			0
		],
		[
			9,
			-69
		],
		[
			10,
			-33
		],
		[
			0,
			-7
		],
		[
			8,
			-36
		],
		[
			-9,
			14
		],
		[
			-23,
			9
		],
		[
			3,
			-6
		],
		[
			-10,
			-7
		],
		[
			-2,
			-16
		],
		[
			-12,
			-57
		],
		[
			6,
			-26
		],
		[
			8,
			-11
		],
		[
			0,
			-11
		],
		[
			5,
			-21
		],
		[
			9,
			4
		],
		[
			1,
			-28
		],
		[
			-3,
			-6
		],
		[
			-2,
			22
		],
		[
			-17,
			3
		],
		[
			-2,
			6
		],
		[
			-7,
			-5
		],
		[
			-6,
			-32
		],
		[
			-5,
			-9
		],
		[
			-3,
			6
		],
		[
			-4,
			29
		],
		[
			7,
			30
		],
		[
			-3,
			31
		],
		[
			7,
			21
		],
		[
			-3,
			26
		],
		[
			-5,
			12
		],
		[
			7,
			55
		],
		[
			0,
			46
		],
		[
			-3,
			10
		],
		[
			1,
			17
		],
		[
			5,
			19
		],
		[
			-5,
			18
		],
		[
			-11,
			14
		],
		[
			-1,
			38
		],
		[
			4,
			5
		],
		[
			3,
			26
		],
		[
			-4,
			26
		],
		[
			13,
			9
		],
		[
			1,
			-9
		],
		[
			10,
			9
		],
		[
			-4,
			8
		],
		[
			9,
			2
		],
		[
			-2,
			12
		],
		[
			-10,
			21
		],
		[
			5,
			-2
		],
		[
			5,
			11
		],
		[
			3,
			-8
		]
	],
	[
		[
			9669,
			8321
		],
		[
			-19,
			19
		],
		[
			4,
			0
		],
		[
			15,
			-19
		]
	],
	[
		[
			8810,
			8355
		],
		[
			-14,
			-11
		],
		[
			8,
			11
		],
		[
			6,
			0
		]
	],
	[
		[
			8827,
			8358
		],
		[
			9,
			-8
		],
		[
			-12,
			-22
		],
		[
			-6,
			15
		],
		[
			-6,
			1
		],
		[
			8,
			17
		],
		[
			7,
			-3
		]
	],
	[
		[
			5548,
			8317
		],
		[
			18,
			15
		],
		[
			-10,
			2
		],
		[
			-12,
			-16
		]
	],
	[
		[
			5544,
			8319
		],
		[
			10,
			17
		],
		[
			0,
			12
		],
		[
			12,
			-1
		],
		[
			15,
			19
		]
	],
	[
		[
			5582,
			8366
		],
		[
			-12,
			-19
		],
		[
			12,
			-3
		],
		[
			7,
			5
		],
		[
			1,
			15
		]
	],
	[
		[
			9609,
			8371
		],
		[
			18,
			-27
		],
		[
			1,
			-11
		],
		[
			-13,
			14
		],
		[
			-4,
			13
		],
		[
			-7,
			6
		],
		[
			5,
			5
		]
	],
	[
		[
			9571,
			8591
		],
		[
			3,
			-16
		],
		[
			-8,
			-2
		],
		[
			-23,
			-18
		],
		[
			9,
			26
		],
		[
			19,
			10
		]
	],
	[
		[
			5777,
			8600
		],
		[
			3,
			-1
		]
	],
	[
		[
			6924,
			9029
		],
		[
			21,
			-5
		],
		[
			-5,
			-13
		],
		[
			-16,
			18
		]
	],
	[
		[
			6396,
			9167
		],
		[
			-24,
			-22
		],
		[
			-23,
			-4
		],
		[
			-10,
			9
		],
		[
			1,
			19
		],
		[
			15,
			16
		],
		[
			13,
			1
		],
		[
			28,
			-19
		]
	],
	[
		[
			9482,
			9188
		],
		[
			-3,
			-8
		],
		[
			6,
			-25
		],
		[
			-10,
			6
		],
		[
			-2,
			19
		],
		[
			9,
			8
		]
	],
	[
		[
			9705,
			9201
		],
		[
			-6,
			-12
		],
		[
			-29,
			7
		],
		[
			-11,
			8
		],
		[
			14,
			11
		],
		[
			32,
			-8
		],
		[
			0,
			-6
		]
	],
	[
		[
			6648,
			9234
		],
		[
			5,
			-8
		],
		[
			26,
			-17
		],
		[
			0,
			-11
		],
		[
			-25,
			-1
		],
		[
			-5,
			11
		],
		[
			-10,
			-2
		],
		[
			-13,
			12
		],
		[
			-1,
			15
		],
		[
			13,
			8
		],
		[
			10,
			-7
		]
	],
	[
		[
			6464,
			9295
		],
		[
			14,
			-14
		],
		[
			-6,
			-11
		],
		[
			-7,
			12
		],
		[
			-15,
			9
		],
		[
			14,
			4
		]
	],
	[
		[
			0,
			9271
		],
		[
			9990,
			-7
		],
		[
			-25,
			-4
		],
		[
			-4,
			14
		],
		[
			8,
			11
		],
		[
			30,
			17
		],
		[
			-9999,
			-31
		]
	],
	[
		[
			8829,
			9305
		],
		[
			-3,
			-9
		],
		[
			-20,
			5
		],
		[
			23,
			4
		]
	],
	[
		[
			0,
			9302
		],
		[
			26,
			4
		],
		[
			18,
			-3
		],
		[
			27,
			-17
		],
		[
			-12,
			-12
		],
		[
			-42,
			-8
		],
		[
			-17,
			5
		],
		[
			0,
			31
		]
	],
	[
		[
			7160,
			9347
		],
		[
			-27,
			1
		],
		[
			22,
			18
		],
		[
			21,
			-9
		],
		[
			-16,
			-10
		]
	],
	[
		[
			8580,
			9366
		],
		[
			-7,
			-7
		],
		[
			-15,
			7
		],
		[
			22,
			0
		]
	],
	[
		[
			8592,
			9374
		],
		[
			-28,
			2
		],
		[
			18,
			7
		],
		[
			10,
			-9
		]
	],
	[
		[
			7209,
			9382
		],
		[
			0,
			-11
		],
		[
			-19,
			1
		],
		[
			-8,
			7
		],
		[
			16,
			13
		],
		[
			11,
			-10
		]
	],
	[
		[
			7078,
			9392
		],
		[
			-5,
			-14
		],
		[
			-16,
			10
		],
		[
			21,
			4
		]
	],
	[
		[
			6536,
			9406
		],
		[
			31,
			-6
		],
		[
			-8,
			-26
		],
		[
			-15,
			-9
		],
		[
			-7,
			-32
		],
		[
			5,
			-18
		],
		[
			16,
			-29
		],
		[
			23,
			-20
		],
		[
			19,
			-10
		],
		[
			-49,
			-5
		],
		[
			-16,
			3
		],
		[
			-2,
			-8
		],
		[
			-14,
			12
		],
		[
			-18,
			-1
		],
		[
			-11,
			7
		],
		[
			-11,
			34
		],
		[
			-11,
			-4
		],
		[
			-10,
			10
		],
		[
			-19,
			-6
		],
		[
			-8,
			6
		],
		[
			-3,
			22
		],
		[
			11,
			12
		],
		[
			15,
			-5
		],
		[
			9,
			22
		],
		[
			11,
			9
		],
		[
			-20,
			7
		],
		[
			7,
			8
		],
		[
			21,
			1
		],
		[
			-7,
			12
		],
		[
			17,
			12
		],
		[
			13,
			-2
		],
		[
			20,
			9
		],
		[
			11,
			-5
		]
	],
	[
		[
			6970,
			9416
		],
		[
			1,
			-13
		],
		[
			11,
			-6
		],
		[
			-42,
			-7
		],
		[
			3,
			20
		],
		[
			27,
			6
		]
	],
	[
		[
			8951,
			9436
		],
		[
			32,
			-18
		],
		[
			0,
			-21
		],
		[
			-33,
			3
		],
		[
			-40,
			10
		],
		[
			-27,
			-4
		],
		[
			2,
			8
		],
		[
			17,
			1
		],
		[
			17,
			22
		],
		[
			32,
			-1
		]
	],
	[
		[
			8903,
			9439
		],
		[
			-10,
			16
		],
		[
			20,
			5
		],
		[
			2,
			-17
		],
		[
			-12,
			-4
		]
	],
	[
		[
			8148,
			9464
		],
		[
			-16,
			-15
		],
		[
			-37,
			13
		],
		[
			18,
			14
		],
		[
			34,
			-4
		],
		[
			1,
			-8
		]
	],
	[
		[
			7281,
			9528
		],
		[
			-4,
			-16
		],
		[
			-14,
			11
		],
		[
			18,
			5
		]
	],
	[
		[
			9075,
			9530
		],
		[
			47,
			-4
		],
		[
			5,
			-12
		],
		[
			15,
			3
		],
		[
			49,
			-6
		],
		[
			-8,
			-15
		],
		[
			-25,
			-8
		],
		[
			-43,
			2
		],
		[
			-58,
			24
		],
		[
			7,
			20
		],
		[
			11,
			-4
		]
	],
	[
		[
			8773,
			9524
		],
		[
			-11,
			-1
		],
		[
			6,
			29
		],
		[
			14,
			-16
		],
		[
			-9,
			-12
		]
	],
	[
		[
			8863,
			9565
		],
		[
			40,
			-20
		],
		[
			10,
			14
		],
		[
			19,
			1
		],
		[
			-8,
			10
		],
		[
			35,
			-19
		],
		[
			29,
			1
		],
		[
			50,
			-20
		],
		[
			-19,
			-5
		],
		[
			5,
			-8
		],
		[
			-16,
			-15
		],
		[
			-40,
			6
		],
		[
			-11,
			13
		],
		[
			15,
			13
		],
		[
			-3,
			8
		],
		[
			-25,
			-4
		],
		[
			5,
			-18
		],
		[
			12,
			-15
		],
		[
			30,
			-9
		],
		[
			-38,
			-6
		],
		[
			-14,
			10
		],
		[
			-49,
			-10
		],
		[
			-6,
			8
		],
		[
			-17,
			-18
		],
		[
			-33,
			8
		],
		[
			-25,
			20
		],
		[
			-2,
			34
		],
		[
			18,
			1
		],
		[
			-9,
			9
		],
		[
			42,
			18
		],
		[
			5,
			-7
		]
	],
	[
		[
			7674,
			9577
		],
		[
			3,
			-9
		],
		[
			-30,
			3
		],
		[
			27,
			6
		]
	],
	[
		[
			8125,
			9595
		],
		[
			2,
			-10
		],
		[
			-18,
			11
		],
		[
			16,
			-1
		]
	],
	[
		[
			9145,
			9596
		],
		[
			-23,
			0
		],
		[
			29,
			8
		],
		[
			-6,
			-8
		]
	],
	[
		[
			6893,
			9615
		],
		[
			24,
			-15
		],
		[
			-21,
			-24
		],
		[
			-51,
			-17
		],
		[
			-116,
			-32
		],
		[
			-47,
			-18
		],
		[
			0,
			-15
		],
		[
			-22,
			-8
		],
		[
			-2,
			-8
		],
		[
			-17,
			8
		],
		[
			1,
			-16
		],
		[
			-26,
			8
		],
		[
			15,
			-17
		],
		[
			-16,
			-8
		],
		[
			-16,
			-31
		],
		[
			-24,
			-20
		],
		[
			-36,
			4
		],
		[
			-11,
			6
		],
		[
			-20,
			-6
		],
		[
			-4,
			9
		],
		[
			24,
			12
		],
		[
			-30,
			-4
		],
		[
			-2,
			8
		],
		[
			26,
			12
		],
		[
			-3,
			6
		],
		[
			26,
			13
		],
		[
			-3,
			20
		],
		[
			24,
			4
		],
		[
			-14,
			7
		],
		[
			18,
			4
		],
		[
			-18,
			4
		],
		[
			-3,
			9
		],
		[
			21,
			-4
		],
		[
			14,
			19
		],
		[
			19,
			-4
		],
		[
			-5,
			11
		],
		[
			38,
			20
		],
		[
			23,
			3
		],
		[
			14,
			11
		],
		[
			23,
			-2
		],
		[
			0,
			12
		],
		[
			52,
			-5
		],
		[
			61,
			15
		],
		[
			49,
			28
		],
		[
			35,
			1
		]
	],
	[
		[
			7679,
			9622
		],
		[
			-33,
			-4
		],
		[
			35,
			11
		],
		[
			-2,
			-7
		]
	],
	[
		[
			8666,
			7787
		],
		[
			3,
			-13
		],
		[
			-2,
			-13
		],
		[
			9,
			-14
		],
		[
			7,
			9
		],
		[
			6,
			22
		]
	],
	[
		[
			6367,
			7850
		],
		[
			-12,
			-15
		],
		[
			-2,
			-14
		],
		[
			-4,
			9
		],
		[
			-10,
			-14
		],
		[
			-17,
			0
		],
		[
			-7,
			-31
		],
		[
			-8,
			-23
		],
		[
			-10,
			-8
		],
		[
			0,
			-13
		],
		[
			14,
			-11
		],
		[
			8,
			-28
		],
		[
			-2,
			-14
		],
		[
			6,
			19
		],
		[
			-5,
			-26
		],
		[
			0,
			-21
		],
		[
			7,
			-10
		],
		[
			4,
			-16
		],
		[
			12,
			-26
		],
		[
			2,
			-11
		],
		[
			6,
			-4
		]
	],
	[
		[
			6110,
			7681
		],
		[
			-15,
			21
		],
		[
			-1,
			6
		],
		[
			-18,
			24
		],
		[
			-15,
			7
		],
		[
			-11,
			15
		],
		[
			-9,
			1
		],
		[
			-8,
			19
		],
		[
			-17,
			11
		],
		[
			8,
			3
		],
		[
			-1,
			11
		],
		[
			8,
			-6
		],
		[
			11,
			2
		],
		[
			5,
			-4
		],
		[
			0,
			16
		],
		[
			-4,
			2
		],
		[
			8,
			10
		],
		[
			2,
			14
		],
		[
			4,
			-6
		],
		[
			2,
			11
		],
		[
			11,
			0
		],
		[
			-13,
			17
		],
		[
			-5,
			0
		],
		[
			-4,
			15
		],
		[
			6,
			-3
		],
		[
			13,
			14
		],
		[
			24,
			9
		],
		[
			0,
			13
		],
		[
			-30,
			-8
		]
	],
	[
		[
			6061,
			7895
		],
		[
			-1,
			12
		],
		[
			5,
			17
		],
		[
			11,
			5
		],
		[
			3,
			10
		],
		[
			25,
			-3
		],
		[
			0,
			13
		],
		[
			6,
			12
		],
		[
			-8,
			29
		],
		[
			10,
			5
		],
		[
			-8,
			3
		],
		[
			11,
			26
		],
		[
			-1,
			14
		],
		[
			-10,
			-2
		],
		[
			-5,
			10
		],
		[
			-7,
			0
		],
		[
			-5,
			9
		],
		[
			-6,
			-5
		],
		[
			-8,
			10
		],
		[
			-18,
			-4
		],
		[
			-8,
			11
		],
		[
			-8,
			20
		],
		[
			-16,
			-6
		],
		[
			-6,
			-7
		],
		[
			-10,
			4
		],
		[
			-5,
			8
		],
		[
			-13,
			-5
		],
		[
			-6,
			10
		],
		[
			2,
			10
		],
		[
			-4,
			19
		],
		[
			-7,
			12
		],
		[
			-11,
			-3
		],
		[
			-13,
			12
		],
		[
			-3,
			17
		],
		[
			8,
			9
		],
		[
			-8,
			8
		],
		[
			-1,
			10
		],
		[
			-11,
			13
		],
		[
			-13,
			1
		],
		[
			-9,
			-8
		],
		[
			-15,
			5
		],
		[
			-1,
			-11
		],
		[
			-12,
			-7
		],
		[
			-3,
			5
		]
	],
	[
		[
			5767,
			8523
		],
		[
			9,
			-9
		],
		[
			6,
			9
		],
		[
			-6,
			10
		],
		[
			-10,
			-2
		],
		[
			7,
			19
		],
		[
			-4,
			30
		]
	],
	[
		[
			5773,
			8590
		],
		[
			9,
			11
		]
	],
	[
		[
			5778,
			8608
		],
		[
			-1,
			16
		],
		[
			11,
			-5
		],
		[
			3,
			11
		],
		[
			10,
			-4
		],
		[
			7,
			12
		],
		[
			29,
			-8
		],
		[
			2,
			8
		],
		[
			-9,
			9
		],
		[
			-25,
			2
		],
		[
			-10,
			28
		],
		[
			-16,
			-9
		],
		[
			-7,
			2
		]
	],
	[
		[
			5856,
			9203
		],
		[
			15,
			-9
		],
		[
			19,
			18
		],
		[
			16,
			-11
		],
		[
			14,
			-3
		],
		[
			-7,
			-8
		],
		[
			-20,
			4
		],
		[
			6,
			-7
		],
		[
			19,
			-3
		],
		[
			-6,
			-7
		],
		[
			19,
			4
		],
		[
			5,
			-5
		],
		[
			35,
			-7
		],
		[
			23,
			-1
		],
		[
			52,
			-28
		],
		[
			21,
			-21
		],
		[
			14,
			-2
		],
		[
			16,
			-14
		],
		[
			13,
			-3
		],
		[
			30,
			-21
		],
		[
			1,
			-23
		],
		[
			7,
			-2
		],
		[
			-5,
			-24
		],
		[
			-21,
			-24
		],
		[
			-30,
			-15
		],
		[
			-22,
			-4
		],
		[
			-28,
			5
		],
		[
			-22,
			9
		],
		[
			-27,
			3
		],
		[
			-27,
			15
		],
		[
			-36,
			7
		],
		[
			-24,
			23
		],
		[
			-11,
			0
		],
		[
			8,
			-15
		],
		[
			18,
			-11
		],
		[
			3,
			-9
		],
		[
			13,
			-6
		],
		[
			-4,
			-7
		],
		[
			14,
			-3
		],
		[
			21,
			-20
		],
		[
			-4,
			-21
		],
		[
			-6,
			-7
		],
		[
			13,
			-46
		],
		[
			-6,
			-4
		],
		[
			16,
			-15
		],
		[
			15,
			2
		],
		[
			12,
			-18
		],
		[
			31,
			-13
		],
		[
			16,
			9
		],
		[
			1,
			21
		],
		[
			-25,
			5
		],
		[
			-16,
			19
		],
		[
			-3,
			12
		],
		[
			10,
			2
		],
		[
			7,
			12
		],
		[
			18,
			-9
		],
		[
			10,
			-13
		],
		[
			0,
			-9
		],
		[
			10,
			10
		],
		[
			31,
			-15
		],
		[
			9,
			7
		],
		[
			18,
			-7
		],
		[
			-4,
			22
		],
		[
			-19,
			30
		],
		[
			4,
			9
		],
		[
			18,
			12
		],
		[
			6,
			9
		],
		[
			18,
			5
		],
		[
			22,
			27
		],
		[
			11,
			-8
		],
		[
			20,
			3
		],
		[
			22,
			-21
		],
		[
			1,
			11
		],
		[
			11,
			23
		],
		[
			0,
			16
		],
		[
			-20,
			19
		],
		[
			10,
			28
		],
		[
			3,
			31
		],
		[
			-25,
			18
		],
		[
			18,
			-4
		],
		[
			37,
			0
		],
		[
			18,
			-6
		],
		[
			16,
			-18
		],
		[
			5,
			-18
		],
		[
			-38,
			-5
		],
		[
			-12,
			-22
		],
		[
			17,
			-9
		],
		[
			8,
			-17
		],
		[
			20,
			-5
		],
		[
			34,
			13
		],
		[
			5,
			22
		],
		[
			-3,
			11
		],
		[
			26,
			7
		],
		[
			1,
			6
		],
		[
			24,
			9
		],
		[
			31,
			22
		],
		[
			8,
			-1
		],
		[
			31,
			13
		],
		[
			-1,
			-12
		],
		[
			16,
			4
		],
		[
			-12,
			10
		],
		[
			32,
			18
		],
		[
			15,
			-3
		],
		[
			-7,
			-14
		],
		[
			6,
			-13
		],
		[
			-21,
			-8
		],
		[
			29,
			-3
		],
		[
			7,
			6
		],
		[
			11,
			-7
		],
		[
			1,
			12
		],
		[
			29,
			14
		],
		[
			38,
			-5
		],
		[
			18,
			17
		],
		[
			25,
			8
		],
		[
			15,
			-13
		],
		[
			-10,
			-8
		],
		[
			1,
			-13
		],
		[
			16,
			-4
		],
		[
			8,
			10
		],
		[
			-6,
			7
		],
		[
			20,
			5
		],
		[
			13,
			11
		],
		[
			0,
			10
		],
		[
			-22,
			28
		],
		[
			15,
			6
		],
		[
			2,
			10
		],
		[
			74,
			-10
		],
		[
			20,
			-7
		],
		[
			19,
			-15
		],
		[
			62,
			-29
		],
		[
			33,
			-25
		],
		[
			2,
			-9
		],
		[
			17,
			25
		],
		[
			7,
			19
		],
		[
			-21,
			2
		],
		[
			-10,
			16
		],
		[
			-1,
			12
		],
		[
			-35,
			14
		],
		[
			3,
			16
		],
		[
			12,
			3
		],
		[
			-6,
			9
		],
		[
			6,
			15
		],
		[
			-1,
			20
		],
		[
			-16,
			-3
		],
		[
			-2,
			17
		],
		[
			8,
			14
		],
		[
			28,
			12
		],
		[
			15,
			17
		],
		[
			14,
			51
		],
		[
			12,
			16
		],
		[
			5,
			-5
		],
		[
			52,
			1
		],
		[
			39,
			-11
		],
		[
			1,
			-25
		],
		[
			-16,
			-26
		],
		[
			1,
			-7
		],
		[
			-15,
			-11
		],
		[
			8,
			-13
		],
		[
			16,
			-10
		],
		[
			5,
			-15
		],
		[
			-2,
			-25
		],
		[
			-10,
			-9
		],
		[
			8,
			-25
		],
		[
			-5,
			-11
		],
		[
			3,
			-21
		],
		[
			-3,
			-16
		],
		[
			5,
			-8
		],
		[
			26,
			-20
		],
		[
			-15,
			-16
		],
		[
			3,
			-22
		],
		[
			-18,
			-13
		],
		[
			-9,
			-27
		],
		[
			-20,
			-14
		],
		[
			2,
			-15
		],
		[
			-15,
			-1
		],
		[
			-10,
			-7
		],
		[
			-22,
			21
		],
		[
			-22,
			-6
		],
		[
			8,
			-15
		],
		[
			27,
			-10
		],
		[
			22,
			2
		],
		[
			24,
			-8
		],
		[
			10,
			6
		],
		[
			2,
			16
		],
		[
			13,
			2
		],
		[
			26,
			20
		],
		[
			1,
			17
		],
		[
			24,
			24
		],
		[
			-1,
			25
		],
		[
			-11,
			15
		],
		[
			3,
			17
		],
		[
			29,
			12
		],
		[
			31,
			4
		],
		[
			1,
			-11
		],
		[
			19,
			-15
		],
		[
			-5,
			-15
		],
		[
			5,
			-20
		],
		[
			-7,
			-7
		],
		[
			18,
			-13
		],
		[
			18,
			-1
		],
		[
			-25,
			13
		],
		[
			0,
			18
		],
		[
			20,
			10
		],
		[
			-11,
			14
		],
		[
			-5,
			24
		],
		[
			-19,
			5
		],
		[
			-24,
			13
		],
		[
			-17,
			1
		],
		[
			-20,
			-10
		],
		[
			-27,
			5
		],
		[
			3,
			18
		],
		[
			-10,
			15
		],
		[
			6,
			25
		],
		[
			17,
			20
		],
		[
			-21,
			41
		],
		[
			-15,
			12
		],
		[
			14,
			22
		],
		[
			39,
			16
		],
		[
			5,
			17
		],
		[
			-4,
			28
		],
		[
			15,
			-7
		],
		[
			6,
			-30
		],
		[
			-13,
			-17
		],
		[
			7,
			-17
		],
		[
			-5,
			-18
		],
		[
			11,
			-4
		],
		[
			57,
			-7
		],
		[
			6,
			-11
		],
		[
			12,
			0
		],
		[
			-4,
			17
		],
		[
			-17,
			2
		],
		[
			-39,
			16
		],
		[
			-8,
			20
		],
		[
			27,
			8
		],
		[
			17,
			-13
		],
		[
			15,
			3
		],
		[
			-5,
			14
		],
		[
			-15,
			-2
		],
		[
			15,
			14
		],
		[
			16,
			5
		],
		[
			28,
			-3
		],
		[
			51,
			-35
		],
		[
			23,
			-3
		],
		[
			18,
			5
		],
		[
			14,
			-7
		],
		[
			-14,
			-16
		],
		[
			-16,
			-6
		],
		[
			-2,
			-17
		],
		[
			7,
			-12
		],
		[
			-10,
			-12
		],
		[
			11,
			2
		],
		[
			0,
			11
		],
		[
			10,
			11
		],
		[
			9,
			-6
		],
		[
			-4,
			-27
		],
		[
			-10,
			-9
		],
		[
			14,
			-10
		],
		[
			-7,
			14
		],
		[
			18,
			0
		],
		[
			6,
			8
		],
		[
			-17,
			44
		],
		[
			13,
			23
		],
		[
			-6,
			11
		],
		[
			-32,
			15
		],
		[
			-3,
			11
		],
		[
			-26,
			4
		],
		[
			-14,
			11
		],
		[
			4,
			23
		],
		[
			-11,
			9
		],
		[
			2,
			28
		],
		[
			39,
			5
		],
		[
			43,
			-1
		],
		[
			59,
			10
		],
		[
			40,
			3
		],
		[
			-23,
			-18
		],
		[
			25,
			2
		],
		[
			10,
			13
		],
		[
			-19,
			21
		],
		[
			-22,
			4
		],
		[
			14,
			18
		],
		[
			-21,
			4
		],
		[
			13,
			10
		],
		[
			16,
			-7
		],
		[
			68,
			47
		],
		[
			67,
			8
		],
		[
			66,
			16
		],
		[
			-28,
			9
		],
		[
			19,
			3
		],
		[
			22,
			-5
		],
		[
			25,
			7
		],
		[
			21,
			-3
		],
		[
			-16,
			-13
		],
		[
			58,
			10
		],
		[
			32,
			12
		],
		[
			29,
			-10
		],
		[
			-29,
			24
		],
		[
			18,
			-3
		],
		[
			40,
			4
		],
		[
			1,
			26
		],
		[
			63,
			39
		],
		[
			43,
			3
		],
		[
			33,
			-17
		],
		[
			-21,
			-13
		],
		[
			-24,
			-3
		],
		[
			82,
			-7
		],
		[
			6,
			-6
		],
		[
			-27,
			-21
		],
		[
			36,
			-1
		],
		[
			4,
			12
		],
		[
			38,
			1
		],
		[
			19,
			-4
		],
		[
			27,
			5
		],
		[
			47,
			-24
		],
		[
			3,
			-16
		],
		[
			19,
			4
		],
		[
			3,
			-28
		],
		[
			-21,
			5
		],
		[
			1,
			-12
		],
		[
			22,
			-1
		],
		[
			-2,
			-14
		],
		[
			-20,
			-17
		],
		[
			-20,
			-6
		],
		[
			-12,
			-13
		],
		[
			-47,
			-16
		],
		[
			-2,
			-9
		],
		[
			-32,
			-15
		],
		[
			-20,
			-19
		],
		[
			-27,
			-1
		],
		[
			-12,
			-18
		],
		[
			-17,
			-2
		],
		[
			-6,
			-15
		],
		[
			-15,
			-12
		],
		[
			23,
			6
		],
		[
			7,
			17
		],
		[
			37,
			-2
		],
		[
			15,
			8
		],
		[
			51,
			12
		],
		[
			23,
			10
		],
		[
			-7,
			6
		],
		[
			-25,
			-5
		],
		[
			-6,
			8
		],
		[
			13,
			10
		],
		[
			25,
			-6
		],
		[
			7,
			7
		],
		[
			8,
			-13
		],
		[
			19,
			-6
		],
		[
			22,
			5
		],
		[
			-2,
			12
		],
		[
			16,
			-20
		],
		[
			-8,
			-12
		],
		[
			44,
			9
		],
		[
			19,
			7
		],
		[
			100,
			-13
		],
		[
			-18,
			-4
		],
		[
			1,
			-11
		],
		[
			38,
			-12
		],
		[
			36,
			-5
		],
		[
			25,
			2
		],
		[
			21,
			-8
		],
		[
			-7,
			11
		],
		[
			19,
			-6
		],
		[
			11,
			17
		],
		[
			-8,
			10
		],
		[
			3,
			16
		],
		[
			17,
			-2
		],
		[
			10,
			10
		],
		[
			23,
			-14
		],
		[
			29,
			0
		],
		[
			12,
			-16
		],
		[
			7,
			15
		],
		[
			30,
			-4
		],
		[
			7,
			-12
		],
		[
			34,
			-14
		],
		[
			-34,
			-12
		],
		[
			30,
			-6
		],
		[
			-39,
			-3
		],
		[
			20,
			-10
		],
		[
			18,
			-1
		],
		[
			6,
			-12
		],
		[
			-15,
			-11
		],
		[
			-19,
			8
		],
		[
			27,
			-37
		],
		[
			13,
			-27
		],
		[
			40,
			-21
		],
		[
			13,
			12
		],
		[
			18,
			43
		],
		[
			10,
			14
		],
		[
			13,
			-19
		],
		[
			23,
			-12
		],
		[
			22,
			0
		],
		[
			4,
			6
		],
		[
			31,
			8
		],
		[
			22,
			-6
		],
		[
			19,
			-11
		],
		[
			11,
			-13
		],
		[
			7,
			27
		],
		[
			16,
			4
		],
		[
			12,
			-13
		],
		[
			17,
			2
		],
		[
			-3,
			27
		],
		[
			15,
			17
		],
		[
			-29,
			0
		],
		[
			12,
			16
		],
		[
			37,
			2
		],
		[
			4,
			10
		],
		[
			-12,
			9
		],
		[
			23,
			-1
		],
		[
			23,
			-9
		],
		[
			38,
			0
		],
		[
			50,
			-8
		],
		[
			39,
			-12
		],
		[
			-37,
			1
		],
		[
			-16,
			4
		],
		[
			-13,
			-15
		],
		[
			27,
			6
		],
		[
			42,
			2
		],
		[
			-26,
			-26
		],
		[
			10,
			16
		],
		[
			-12,
			4
		],
		[
			-3,
			-17
		],
		[
			-23,
			-12
		],
		[
			29,
			4
		],
		[
			30,
			31
		],
		[
			36,
			0
		],
		[
			34,
			-9
		],
		[
			13,
			-13
		],
		[
			-12,
			-9
		],
		[
			-7,
			7
		],
		[
			-9,
			-11
		],
		[
			25,
			-2
		],
		[
			-2,
			-11
		],
		[
			20,
			2
		],
		[
			0,
			-13
		],
		[
			24,
			3
		],
		[
			18,
			-20
		],
		[
			-13,
			0
		],
		[
			26,
			-9
		],
		[
			28,
			3
		],
		[
			65,
			12
		],
		[
			45,
			-1
		],
		[
			26,
			-6
		],
		[
			33,
			-17
		],
		[
			11,
			-25
		],
		[
			-11,
			-19
		],
		[
			3,
			-8
		],
		[
			31,
			-8
		],
		[
			3,
			-28
		],
		[
			11,
			-11
		],
		[
			-10,
			-25
		],
		[
			14,
			22
		],
		[
			-2,
			26
		],
		[
			19,
			17
		],
		[
			51,
			7
		],
		[
			23,
			-12
		],
		[
			23,
			2
		],
		[
			11,
			-5
		],
		[
			24,
			-1
		],
		[
			21,
			16
		],
		[
			16,
			-13
		],
		[
			2,
			-19
		],
		[
			29,
			-8
		],
		[
			7,
			-18
		],
		[
			22,
			4
		],
		[
			17,
			12
		],
		[
			-13,
			32
		],
		[
			-11,
			-1
		],
		[
			11,
			11
		],
		[
			-1,
			19
		],
		[
			41,
			-7
		],
		[
			22,
			-1
		],
		[
			17,
			-10
		],
		[
			1,
			9
		],
		[
			37,
			-6
		],
		[
			20,
			2
		],
		[
			28,
			-7
		],
		[
			71,
			-27
		],
		[
			17,
			-16
		],
		[
			-9958,
			-15
		],
		[
			3,
			-12
		],
		[
			28,
			-11
		],
		[
			2,
			-9
		],
		[
			12,
			1
		],
		[
			20,
			-19
		],
		[
			16,
			-2
		],
		[
			-10,
			-7
		],
		[
			12,
			-5
		],
		[
			0,
			10
		],
		[
			12,
			-7
		],
		[
			8,
			-20
		],
		[
			10,
			-2
		],
		[
			-3,
			-18
		],
		[
			5,
			-13
		],
		[
			-7,
			-6
		],
		[
			14,
			-8
		],
		[
			-1,
			-14
		],
		[
			17,
			13
		],
		[
			-11,
			3
		],
		[
			9,
			6
		],
		[
			-2,
			17
		],
		[
			-9,
			6
		],
		[
			27,
			1
		],
		[
			20,
			-12
		],
		[
			-5,
			9
		],
		[
			32,
			-6
		],
		[
			10,
			-17
		],
		[
			13,
			-7
		],
		[
			10,
			-17
		],
		[
			5,
			4
		],
		[
			17,
			-14
		],
		[
			-9,
			0
		],
		[
			-14,
			-11
		],
		[
			-5,
			-15
		],
		[
			-21,
			13
		],
		[
			11,
			-20
		],
		[
			-32,
			3
		],
		[
			4,
			-27
		],
		[
			-19,
			-12
		],
		[
			-8,
			-11
		],
		[
			16,
			-5
		],
		[
			6,
			-9
		],
		[
			-13,
			-1
		],
		[
			-12,
			-9
		],
		[
			-23,
			10
		],
		[
			-2,
			8
		],
		[
			-16,
			10
		],
		[
			-33,
			12
		],
		[
			-4,
			29
		],
		[
			-29,
			10
		],
		[
			-12,
			-10
		],
		[
			-30,
			4
		],
		[
			-11,
			27
		],
		[
			9,
			7
		],
		[
			2,
			15
		],
		[
			-7,
			-11
		],
		[
			-28,
			-4
		],
		[
			0,
			-16
		],
		[
			13,
			-11
		],
		[
			-7,
			-23
		],
		[
			9982,
			-11
		],
		[
			-10,
			-13
		],
		[
			-34,
			-9
		],
		[
			-21,
			8
		],
		[
			-1,
			8
		],
		[
			-16,
			9
		],
		[
			12,
			-16
		],
		[
			-24,
			2
		],
		[
			-11,
			7
		],
		[
			20,
			-23
		],
		[
			20,
			12
		],
		[
			-3,
			-16
		],
		[
			17,
			-17
		],
		[
			8,
			8
		],
		[
			12,
			-25
		],
		[
			2,
			-16
		],
		[
			-5,
			-13
		],
		[
			18,
			-9
		],
		[
			2,
			-20
		],
		[
			7,
			-16
		],
		[
			-12,
			-7
		],
		[
			0,
			-10
		],
		[
			-28,
			12
		],
		[
			-22,
			3
		],
		[
			-10,
			16
		],
		[
			2,
			-16
		],
		[
			-21,
			-16
		],
		[
			-25,
			-11
		],
		[
			-25,
			-18
		],
		[
			-12,
			2
		],
		[
			-7,
			-10
		],
		[
			-8,
			4
		],
		[
			-1,
			-10
		],
		[
			-10,
			-10
		],
		[
			-11,
			2
		],
		[
			5,
			-8
		],
		[
			-22,
			-13
		],
		[
			-3,
			-12
		],
		[
			-17,
			-4
		],
		[
			-1,
			-9
		],
		[
			-15,
			-7
		],
		[
			-10,
			-16
		],
		[
			-6,
			-18
		],
		[
			-8,
			8
		],
		[
			-7,
			21
		],
		[
			-13,
			9
		],
		[
			-32,
			0
		],
		[
			-35,
			-20
		],
		[
			-16,
			-23
		],
		[
			-4,
			0
		],
		[
			8,
			39
		],
		[
			-33,
			-24
		],
		[
			-5,
			-14
		],
		[
			-7,
			-2
		],
		[
			-2,
			11
		],
		[
			-30,
			3
		],
		[
			2,
			-9
		],
		[
			-9,
			-4
		],
		[
			-5,
			-19
		],
		[
			4,
			-12
		],
		[
			-12,
			-10
		],
		[
			4,
			-10
		],
		[
			-18,
			-16
		],
		[
			-10,
			-26
		],
		[
			1,
			-19
		],
		[
			13,
			-7
		],
		[
			1,
			11
		],
		[
			18,
			-8
		],
		[
			3,
			-6
		],
		[
			-15,
			-21
		],
		[
			1,
			-36
		],
		[
			11,
			1
		],
		[
			4,
			-32
		],
		[
			-9,
			-10
		],
		[
			-12,
			13
		],
		[
			8,
			11
		],
		[
			-6,
			4
		],
		[
			-8,
			-7
		],
		[
			6,
			-6
		],
		[
			-16,
			-12
		],
		[
			-7,
			-25
		],
		[
			-1,
			-16
		],
		[
			11,
			-34
		],
		[
			-11,
			-14
		],
		[
			-13,
			-1
		],
		[
			-6,
			6
		],
		[
			-15,
			-9
		],
		[
			-13,
			-15
		],
		[
			-6,
			-22
		],
		[
			4,
			-13
		],
		[
			-3,
			-6
		],
		[
			5,
			-22
		],
		[
			-13,
			10
		],
		[
			-9,
			-5
		],
		[
			-21,
			-25
		],
		[
			1,
			-26
		],
		[
			-7,
			-19
		],
		[
			-10,
			-20
		],
		[
			-11,
			-7
		],
		[
			-2,
			-8
		],
		[
			-17,
			-22
		],
		[
			-9,
			17
		],
		[
			-1,
			40
		],
		[
			-4,
			33
		],
		[
			-7,
			23
		],
		[
			-4,
			46
		],
		[
			-9,
			60
		],
		[
			-2,
			29
		],
		[
			4,
			46
		],
		[
			6,
			29
		],
		[
			6,
			15
		],
		[
			17,
			15
		],
		[
			7,
			17
		],
		[
			-5,
			22
		],
		[
			16,
			0
		],
		[
			7,
			14
		],
		[
			15,
			0
		],
		[
			20,
			19
		],
		[
			24,
			33
		],
		[
			3,
			13
		],
		[
			13,
			12
		],
		[
			5,
			12
		],
		[
			8,
			2
		],
		[
			18,
			25
		],
		[
			14,
			14
		],
		[
			-1,
			8
		],
		[
			30,
			21
		],
		[
			21,
			9
		],
		[
			-8,
			4
		],
		[
			15,
			18
		],
		[
			-7,
			9
		],
		[
			8,
			12
		],
		[
			2,
			33
		],
		[
			14,
			12
		],
		[
			17,
			-5
		],
		[
			-18,
			17
		],
		[
			-15,
			-1
		],
		[
			-22,
			-8
		],
		[
			3,
			-11
		],
		[
			-8,
			-6
		],
		[
			3,
			-9
		],
		[
			-6,
			-15
		],
		[
			10,
			-9
		],
		[
			-10,
			-7
		],
		[
			-5,
			11
		],
		[
			-10,
			-2
		],
		[
			-12,
			-18
		],
		[
			-32,
			-32
		],
		[
			-19,
			-14
		],
		[
			8,
			27
		],
		[
			-17,
			-7
		],
		[
			5,
			11
		],
		[
			-3,
			9
		],
		[
			14,
			29
		],
		[
			-3,
			10
		],
		[
			-12,
			-14
		],
		[
			-10,
			-2
		],
		[
			-3,
			12
		],
		[
			-13,
			2
		],
		[
			-26,
			-10
		],
		[
			-15,
			3
		],
		[
			-22,
			-15
		],
		[
			-1,
			-18
		],
		[
			-20,
			-20
		],
		[
			0,
			-9
		],
		[
			-27,
			-20
		],
		[
			-13,
			-28
		],
		[
			-7,
			-1
		],
		[
			-2,
			-23
		],
		[
			14,
			5
		],
		[
			16,
			-14
		],
		[
			-1,
			-7
		],
		[
			-11,
			-3
		],
		[
			-8,
			5
		],
		[
			-13,
			-10
		],
		[
			-19,
			11
		],
		[
			0,
			-8
		],
		[
			-10,
			-2
		],
		[
			-2,
			-8
		],
		[
			-16,
			8
		],
		[
			-9,
			-11
		],
		[
			-17,
			-2
		],
		[
			-9,
			15
		],
		[
			10,
			4
		],
		[
			18,
			-1
		],
		[
			6,
			4
		],
		[
			-15,
			8
		],
		[
			-10,
			14
		],
		[
			-13,
			-8
		],
		[
			-12,
			2
		],
		[
			-2,
			7
		],
		[
			-23,
			8
		],
		[
			-16,
			-8
		],
		[
			5,
			-5
		],
		[
			-14,
			-5
		],
		[
			6,
			-12
		],
		[
			-14,
			2
		],
		[
			-2,
			7
		],
		[
			-12,
			0
		],
		[
			-10,
			-9
		],
		[
			-31,
			13
		],
		[
			-3,
			-16
		],
		[
			-8,
			-3
		],
		[
			-6,
			9
		],
		[
			4,
			6
		],
		[
			-27,
			-1
		],
		[
			-32,
			2
		],
		[
			-19,
			-3
		],
		[
			-25,
			-13
		],
		[
			-19,
			-30
		],
		[
			-17,
			-11
		],
		[
			-8,
			-13
		],
		[
			-5,
			-20
		],
		[
			-15,
			-9
		],
		[
			-4,
			-11
		],
		[
			-11,
			-12
		],
		[
			-14,
			-9
		],
		[
			-22,
			-32
		],
		[
			-12,
			-26
		],
		[
			-26,
			-27
		],
		[
			-8,
			-4
		],
		[
			-15,
			-23
		],
		[
			-19,
			-15
		],
		[
			0,
			-12
		],
		[
			14,
			-9
		],
		[
			30,
			5
		],
		[
			0,
			-28
		],
		[
			-4,
			-21
		],
		[
			12,
			0
		],
		[
			5,
			14
		],
		[
			-6,
			6
		],
		[
			10,
			10
		],
		[
			8,
			-2
		],
		[
			-8,
			-11
		],
		[
			9,
			-11
		],
		[
			-12,
			-22
		],
		[
			16,
			4
		],
		[
			11,
			9
		],
		[
			7,
			14
		],
		[
			1,
			-9
		],
		[
			-10,
			-15
		],
		[
			7,
			-3
		],
		[
			8,
			26
		],
		[
			-1,
			20
		],
		[
			16,
			-8
		],
		[
			9,
			5
		],
		[
			17,
			-12
		],
		[
			0,
			-11
		],
		[
			27,
			-32
		],
		[
			6,
			-10
		],
		[
			-13,
			-12
		],
		[
			8,
			-5
		],
		[
			1,
			-15
		],
		[
			-4,
			-13
		],
		[
			11,
			-12
		],
		[
			-6,
			-3
		],
		[
			3,
			-9
		],
		[
			-9,
			-16
		],
		[
			-6,
			-3
		],
		[
			0,
			-12
		],
		[
			-6,
			-8
		],
		[
			0,
			-18
		],
		[
			-4,
			-4
		],
		[
			-3,
			-20
		],
		[
			1,
			-32
		],
		[
			3,
			-23
		],
		[
			-6,
			-17
		],
		[
			1,
			-17
		],
		[
			-6,
			-17
		],
		[
			0,
			-14
		],
		[
			-26,
			-38
		],
		[
			-7,
			-28
		],
		[
			-13,
			-18
		],
		[
			-5,
			-27
		],
		[
			-18,
			-41
		],
		[
			-15,
			-25
		],
		[
			-10,
			-11
		],
		[
			-8,
			-20
		],
		[
			-6,
			-6
		],
		[
			-5,
			-15
		],
		[
			-7,
			-5
		],
		[
			-11,
			-25
		],
		[
			-3,
			-14
		],
		[
			-5,
			0
		],
		[
			-1,
			-12
		],
		[
			-18,
			-20
		],
		[
			-9,
			-6
		],
		[
			-7,
			-11
		],
		[
			-8,
			0
		],
		[
			-12,
			-10
		],
		[
			-6,
			7
		],
		[
			-4,
			-4
		],
		[
			-12,
			10
		],
		[
			-3,
			-4
		],
		[
			-1,
			23
		],
		[
			-9,
			-11
		],
		[
			1,
			15
		],
		[
			-16,
			-21
		],
		[
			-1,
			-11
		],
		[
			-14,
			-11
		],
		[
			-4,
			-17
		]
	],
	[
		[
			7858,
			9748
		],
		[
			0,
			-12
		],
		[
			30,
			4
		],
		[
			14,
			-16
		],
		[
			16,
			-1
		],
		[
			8,
			-19
		],
		[
			-16,
			-10
		],
		[
			-31,
			-5
		],
		[
			-68,
			-3
		],
		[
			-33,
			-14
		],
		[
			-21,
			5
		],
		[
			21,
			17
		],
		[
			6,
			19
		],
		[
			36,
			39
		],
		[
			19,
			-6
		],
		[
			2,
			11
		],
		[
			17,
			-9
		]
	],
	[
		[
			7118,
			9769
		],
		[
			37,
			-6
		],
		[
			-27,
			-3
		],
		[
			-10,
			9
		]
	],
	[
		[
			7523,
			9794
		],
		[
			79,
			-8
		],
		[
			-18,
			-13
		],
		[
			-55,
			8
		],
		[
			-6,
			13
		]
	],
	[
		[
			6659,
			9787
		],
		[
			-27,
			3
		],
		[
			21,
			7
		],
		[
			6,
			-10
		]
	],
	[
		[
			7715,
			9797
		],
		[
			-5,
			-21
		],
		[
			25,
			17
		],
		[
			20,
			0
		],
		[
			24,
			-16
		],
		[
			-9,
			-24
		],
		[
			-19,
			-5
		],
		[
			25,
			-18
		],
		[
			-39,
			-10
		],
		[
			-38,
			4
		],
		[
			-11,
			8
		],
		[
			-50,
			2
		],
		[
			-18,
			12
		],
		[
			-1,
			14
		],
		[
			-33,
			3
		],
		[
			29,
			14
		],
		[
			23,
			19
		],
		[
			77,
			1
		]
	],
	[
		[
			6585,
			9810
		],
		[
			-4,
			-16
		],
		[
			-28,
			0
		],
		[
			1,
			14
		],
		[
			31,
			2
		]
	],
	[
		[
			6481,
			9813
		],
		[
			15,
			-7
		],
		[
			-35,
			-6
		],
		[
			20,
			13
		]
	],
	[
		[
			6646,
			9809
		],
		[
			-52,
			-12
		],
		[
			-13,
			20
		],
		[
			42,
			0
		],
		[
			23,
			-8
		]
	],
	[
		[
			6329,
			9836
		],
		[
			-38,
			-20
		],
		[
			-39,
			11
		],
		[
			77,
			9
		]
	],
	[
		[
			6729,
			9835
		],
		[
			-5,
			-10
		],
		[
			-29,
			-12
		],
		[
			-38,
			1
		],
		[
			-13,
			13
		],
		[
			14,
			11
		],
		[
			65,
			2
		],
		[
			6,
			-5
		]
	],
	[
		[
			6537,
			9839
		],
		[
			-13,
			-8
		],
		[
			-22,
			8
		],
		[
			35,
			0
		]
	],
	[
		[
			6388,
			9840
		],
		[
			7,
			-8
		],
		[
			30,
			3
		],
		[
			-9,
			-14
		],
		[
			-60,
			-9
		],
		[
			4,
			-14
		],
		[
			-38,
			-4
		],
		[
			16,
			15
		],
		[
			-22,
			8
		],
		[
			63,
			10
		],
		[
			-18,
			7
		],
		[
			27,
			6
		]
	],
	[
		[
			7225,
			9845
		],
		[
			-28,
			-9
		],
		[
			2,
			9
		],
		[
			26,
			0
		]
	],
	[
		[
			6560,
			9854
		],
		[
			57,
			-11
		],
		[
			-29,
			-1
		],
		[
			-28,
			12
		]
	],
	[
		[
			6542,
			9848
		],
		[
			13,
			2
		],
		[
			47,
			-13
		],
		[
			-19,
			-7
		],
		[
			-41,
			18
		]
	],
	[
		[
			6797,
			9859
		],
		[
			20,
			-16
		],
		[
			-28,
			-11
		],
		[
			-36,
			-3
		],
		[
			-17,
			9
		],
		[
			46,
			10
		],
		[
			15,
			11
		]
	],
	[
		[
			7536,
			9852
		],
		[
			-37,
			1
		],
		[
			2,
			7
		],
		[
			38,
			-2
		],
		[
			-3,
			-6
		]
	],
	[
		[
			7665,
			9859
		],
		[
			54,
			-29
		],
		[
			-20,
			-3
		],
		[
			0,
			-24
		],
		[
			-75,
			-6
		],
		[
			-22,
			-7
		],
		[
			-63,
			20
		],
		[
			36,
			9
		],
		[
			15,
			17
		],
		[
			-22,
			-3
		],
		[
			16,
			14
		],
		[
			81,
			12
		]
	],
	[
		[
			6577,
			9869
		],
		[
			28,
			-6
		],
		[
			-38,
			-6
		],
		[
			10,
			12
		]
	],
	[
		[
			6605,
			9878
		],
		[
			14,
			-9
		],
		[
			-44,
			4
		],
		[
			30,
			5
		]
	],
	[
		[
			5846,
			5121
		],
		[
			2,
			-14
		],
		[
			5,
			-5
		],
		[
			3,
			-11
		],
		[
			1,
			-26
		],
		[
			-1,
			-18
		],
		[
			-8,
			-2
		]
	],
	[
		[
			5801,
			5040
		],
		[
			6,
			7
		],
		[
			8,
			22
		],
		[
			-4,
			17
		]
	],
	[
		[
			5821,
			5103
		],
		[
			7,
			4
		],
		[
			4,
			-9
		],
		[
			5,
			7
		],
		[
			5,
			16
		],
		[
			4,
			0
		]
	],
	[
		[
			4526,
			6379
		],
		[
			-1,
			15
		],
		[
			2,
			22
		]
	],
	[
		[
			6163,
			6147
		],
		[
			4,
			4
		],
		[
			4,
			-6
		],
		[
			-8,
			2
		]
	],
	[
		[
			6345,
			6826
		],
		[
			6,
			-29
		],
		[
			6,
			-11
		],
		[
			0,
			-14
		],
		[
			11,
			-4
		],
		[
			-4,
			-5
		],
		[
			5,
			-5
		],
		[
			11,
			-23
		],
		[
			8,
			-6
		],
		[
			0,
			-16
		],
		[
			6,
			-10
		],
		[
			-2,
			-18
		],
		[
			-4,
			4
		],
		[
			7,
			-31
		],
		[
			8,
			-17
		],
		[
			0,
			-12
		],
		[
			8,
			-21
		]
	],
	[
		[
			6422,
			6601
		],
		[
			7,
			-4
		],
		[
			-5,
			-9
		],
		[
			8,
			-8
		]
	],
	[
		[
			6443,
			6277
		],
		[
			-4,
			-2
		],
		[
			-58,
			-16
		],
		[
			-17,
			-4
		],
		[
			-27,
			-27
		],
		[
			-16,
			-40
		],
		[
			-3,
			-19
		],
		[
			-9,
			-11
		],
		[
			-5,
			1
		],
		[
			-7,
			19
		],
		[
			-11,
			-3
		],
		[
			-25,
			5
		],
		[
			-5,
			6
		],
		[
			-16,
			1
		],
		[
			-15,
			-5
		],
		[
			-11,
			0
		],
		[
			-7,
			10
		],
		[
			-9,
			-11
		],
		[
			-1,
			-24
		],
		[
			2,
			-15
		],
		[
			-11,
			-16
		]
	],
	[
		[
			6188,
			6126
		],
		[
			-2,
			21
		],
		[
			-5,
			8
		],
		[
			0,
			8
		],
		[
			-6,
			9
		],
		[
			0,
			15
		],
		[
			-15,
			23
		],
		[
			-9,
			25
		],
		[
			0,
			8
		],
		[
			-7,
			16
		],
		[
			-2,
			14
		],
		[
			-11,
			49
		],
		[
			-18,
			29
		],
		[
			-9,
			3
		],
		[
			-6,
			13
		],
		[
			-13,
			43
		],
		[
			3,
			7
		],
		[
			-7,
			28
		],
		[
			4,
			20
		],
		[
			0,
			19
		],
		[
			-8,
			23
		],
		[
			0,
			8
		],
		[
			-14,
			46
		],
		[
			-18,
			21
		],
		[
			-2,
			-3
		],
		[
			-12,
			35
		],
		[
			3,
			0
		],
		[
			0,
			20
		],
		[
			-4,
			7
		],
		[
			-4,
			18
		],
		[
			-8,
			11
		],
		[
			1,
			11
		],
		[
			-5,
			5
		],
		[
			-8,
			30
		],
		[
			-4,
			7
		],
		[
			-8,
			26
		],
		[
			-7,
			15
		],
		[
			-6,
			24
		],
		[
			-8,
			14
		],
		[
			-6,
			-3
		],
		[
			-6,
			7
		],
		[
			5,
			20
		],
		[
			4,
			47
		]
	],
	[
		[
			6024,
			6449
		],
		[
			0,
			-20
		],
		[
			6,
			-21
		],
		[
			2,
			-34
		],
		[
			2,
			-65
		],
		[
			5,
			-40
		],
		[
			4,
			-8
		],
		[
			10,
			-8
		],
		[
			5,
			-9
		],
		[
			1,
			-10
		],
		[
			10,
			-6
		],
		[
			3,
			-8
		]
	],
	[
		[
			5946,
			5727
		],
		[
			-6,
			5
		],
		[
			3,
			17
		],
		[
			-2,
			21
		],
		[
			-20,
			35
		],
		[
			-3,
			45
		],
		[
			2,
			5
		],
		[
			2,
			31
		],
		[
			-13,
			0
		],
		[
			0,
			-12
		],
		[
			-18,
			0
		],
		[
			7,
			-17
		],
		[
			0,
			-27
		],
		[
			2,
			-11
		],
		[
			-14,
			-24
		],
		[
			-1,
			-9
		],
		[
			-18,
			-39
		],
		[
			-13,
			-4
		],
		[
			-14,
			23
		],
		[
			-7,
			8
		],
		[
			-11,
			-12
		],
		[
			-4,
			-17
		],
		[
			-13,
			-9
		],
		[
			-5,
			-10
		],
		[
			1,
			-6
		],
		[
			-23,
			0
		],
		[
			-4,
			15
		],
		[
			-22,
			1
		],
		[
			-14,
			-7
		],
		[
			-11,
			27
		],
		[
			-8,
			12
		],
		[
			-2,
			15
		],
		[
			-21,
			-7
		],
		[
			-3,
			-21
		],
		[
			-5,
			-6
		],
		[
			0,
			-19
		],
		[
			-3,
			-6
		],
		[
			-3,
			-29
		],
		[
			-11,
			-12
		]
	],
	[
		[
			5634,
			5812
		],
		[
			3,
			13
		],
		[
			-1,
			15
		],
		[
			-4,
			-1
		],
		[
			-7,
			16
		],
		[
			3,
			23
		],
		[
			-5,
			-2
		],
		[
			0,
			34
		],
		[
			-7,
			7
		],
		[
			-6,
			-7
		],
		[
			-5,
			9
		],
		[
			6,
			21
		],
		[
			7,
			14
		],
		[
			-5,
			25
		],
		[
			4,
			9
		],
		[
			9,
			9
		],
		[
			-4,
			7
		],
		[
			-1,
			18
		],
		[
			8,
			6
		],
		[
			0,
			10
		],
		[
			7,
			15
		],
		[
			2,
			15
		],
		[
			-2,
			11
		],
		[
			7,
			9
		],
		[
			12,
			2
		],
		[
			11,
			-2
		],
		[
			0,
			218
		]
	],
	[
		[
			5943,
			5426
		],
		[
			-14,
			-28
		],
		[
			-9,
			2
		],
		[
			-3,
			6
		],
		[
			-5,
			-5
		],
		[
			-13,
			-3
		],
		[
			-6,
			-13
		],
		[
			-7,
			5
		],
		[
			-4,
			12
		],
		[
			-7,
			-8
		],
		[
			-11,
			7
		],
		[
			-8,
			-17
		]
	],
	[
		[
			4535,
			5893
		],
		[
			-1,
			42
		]
	],
	[
		[
			4540,
			5965
		],
		[
			-5,
			11
		],
		[
			-1,
			13
		],
		[
			-14,
			41
		],
		[
			-8,
			3
		],
		[
			11,
			9
		],
		[
			8,
			18
		],
		[
			9,
			33
		]
	],
	[
		[
			7884,
			5266
		],
		[
			4,
			-3
		],
		[
			-4,
			-7
		],
		[
			-7,
			2
		],
		[
			7,
			8
		]
	],
	[
		[
			3953,
			2073
		],
		[
			22,
			-4
		],
		[
			11,
			-7
		],
		[
			17,
			-21
		],
		[
			3,
			-11
		],
		[
			-10,
			-7
		],
		[
			-10,
			20
		],
		[
			-12,
			11
		],
		[
			-22,
			11
		],
		[
			1,
			8
		]
	],
	[
		[
			9445,
			4521
		],
		[
			15,
			-17
		],
		[
			-6,
			0
		],
		[
			-3,
			9
		],
		[
			-8,
			4
		],
		[
			2,
			4
		]
	],
	[
		[
			9612,
			4569
		],
		[
			-6,
			-12
		],
		[
			-3,
			7
		],
		[
			9,
			5
		]
	],
	[
		[
			9481,
			4595
		],
		[
			13,
			-14
		],
		[
			8,
			0
		],
		[
			5,
			-13
		],
		[
			0,
			-8
		],
		[
			-12,
			4
		],
		[
			-9,
			10
		],
		[
			-1,
			11
		],
		[
			-6,
			3
		],
		[
			2,
			7
		]
	],
	[
		[
			9483,
			4641
		],
		[
			4,
			-12
		],
		[
			0,
			-10
		],
		[
			-5,
			7
		],
		[
			1,
			15
		]
	],
	[
		[
			9442,
			4640
		],
		[
			13,
			0
		],
		[
			11,
			-20
		],
		[
			-4,
			-9
		],
		[
			-10,
			7
		],
		[
			-13,
			1
		],
		[
			-6,
			13
		],
		[
			0,
			16
		],
		[
			3,
			2
		],
		[
			6,
			-10
		]
	],
	[
		[
			9388,
			4691
		],
		[
			3,
			-9
		],
		[
			-6,
			0
		],
		[
			3,
			9
		]
	],
	[
		[
			9371,
			4689
		],
		[
			-5,
			3
		],
		[
			5,
			6
		],
		[
			0,
			-9
		]
	],
	[
		[
			9466,
			4701
		],
		[
			6,
			-16
		],
		[
			-2,
			-11
		],
		[
			5,
			-5
		],
		[
			7,
			-34
		],
		[
			-14,
			21
		],
		[
			-3,
			10
		],
		[
			-5,
			37
		],
		[
			6,
			-2
		]
	],
	[
		[
			9378,
			4711
		],
		[
			4,
			-3
		],
		[
			3,
			-19
		],
		[
			-7,
			4
		],
		[
			-2,
			13
		],
		[
			-9,
			-2
		],
		[
			-1,
			6
		],
		[
			6,
			13
		],
		[
			5,
			-1
		],
		[
			1,
			-11
		]
	],
	[
		[
			9365,
			4716
		],
		[
			-5,
			1
		],
		[
			-1,
			9
		],
		[
			4,
			5
		],
		[
			2,
			-15
		]
	],
	[
		[
			9349,
			4747
		],
		[
			6,
			-9
		],
		[
			-4,
			-9
		],
		[
			-5,
			14
		],
		[
			3,
			4
		]
	],
	[
		[
			9405,
			4746
		],
		[
			4,
			0
		],
		[
			9,
			-16
		],
		[
			12,
			-12
		],
		[
			9,
			-15
		],
		[
			1,
			-13
		],
		[
			-7,
			12
		],
		[
			-11,
			9
		],
		[
			-18,
			25
		],
		[
			-3,
			13
		],
		[
			4,
			-3
		]
	],
	[
		[
			9349,
			4800
		],
		[
			13,
			-15
		],
		[
			3,
			-16
		],
		[
			10,
			-7
		],
		[
			-2,
			-7
		],
		[
			-15,
			13
		],
		[
			-7,
			18
		],
		[
			-6,
			9
		],
		[
			4,
			5
		]
	],
	[
		[
			4650,
			5621
		],
		[
			2,
			-12
		],
		[
			-12,
			10
		],
		[
			10,
			2
		]
	],
	[
		[
			4681,
			5581
		],
		[
			-6,
			9
		],
		[
			-23,
			18
		],
		[
			1,
			15
		],
		[
			-7,
			4
		],
		[
			-6,
			10
		],
		[
			2,
			3
		],
		[
			-3,
			18
		],
		[
			-5,
			-4
		],
		[
			-3,
			18
		],
		[
			7,
			1
		],
		[
			-6,
			7
		],
		[
			0,
			11
		],
		[
			4,
			7
		],
		[
			-6,
			5
		]
	],
	[
		[
			2560,
			5955
		],
		[
			-2,
			-14
		],
		[
			-12,
			0
		],
		[
			-13,
			5
		],
		[
			-14,
			14
		],
		[
			-14,
			2
		],
		[
			-8,
			11
		]
	],
	[
		[
			6359,
			5831
		],
		[
			0,
			-104
		],
		[
			-27,
			-84
		]
	],
	[
		[
			6201,
			5844
		],
		[
			18,
			-44
		],
		[
			13,
			-18
		],
		[
			15,
			0
		],
		[
			11,
			15
		],
		[
			4,
			0
		],
		[
			10,
			12
		],
		[
			11,
			-4
		],
		[
			6,
			-7
		],
		[
			6,
			4
		],
		[
			21,
			25
		],
		[
			8,
			-5
		],
		[
			14,
			3
		],
		[
			9,
			10
		],
		[
			12,
			-4
		]
	],
	[
		[
			6359,
			5831
		],
		[
			14,
			5
		],
		[
			4,
			7
		],
		[
			7,
			0
		],
		[
			12,
			7
		],
		[
			13,
			23
		],
		[
			15,
			-9
		],
		[
			-5,
			-19
		],
		[
			-1,
			-18
		],
		[
			2,
			-35
		],
		[
			8,
			-8
		],
		[
			-14,
			-6
		],
		[
			-3,
			-53
		],
		[
			-4,
			-8
		],
		[
			-1,
			-12
		],
		[
			-6,
			-10
		],
		[
			-3,
			-22
		],
		[
			-6,
			-20
		],
		[
			-8,
			-13
		],
		[
			0,
			-11
		],
		[
			-6,
			-25
		],
		[
			-10,
			-29
		],
		[
			-4,
			-29
		],
		[
			-12,
			-48
		],
		[
			-13,
			-33
		],
		[
			-7,
			-26
		],
		[
			-12,
			-30
		],
		[
			-14,
			-28
		],
		[
			-10,
			-24
		],
		[
			-9,
			-15
		],
		[
			-8,
			-19
		],
		[
			-21,
			-26
		],
		[
			-8,
			-7
		],
		[
			-18,
			-27
		],
		[
			-8,
			-17
		],
		[
			-10,
			-15
		],
		[
			-22,
			-48
		],
		[
			-11,
			-21
		],
		[
			-18,
			-49
		],
		[
			-9,
			-28
		]
	],
	[
		[
			5183,
			5187
		],
		[
			-3,
			-2
		],
		[
			-1,
			13
		],
		[
			5,
			8
		],
		[
			3,
			-11
		],
		[
			-4,
			-8
		]
	],
	[
		[
			3409,
			5499
		],
		[
			3,
			3
		],
		[
			1,
			20
		],
		[
			5,
			7
		],
		[
			8,
			-2
		],
		[
			20,
			-10
		],
		[
			2,
			10
		],
		[
			33,
			0
		],
		[
			18,
			-8
		],
		[
			-1,
			-20
		],
		[
			-3,
			-8
		]
	],
	[
		[
			5626,
			8009
		],
		[
			-12,
			-39
		]
	],
	[
		[
			5377,
			7802
		],
		[
			3,
			6
		]
	],
	[
		[
			5474,
			8485
		],
		[
			-7,
			-30
		],
		[
			-12,
			-34
		],
		[
			0,
			19
		],
		[
			19,
			45
		]
	],
	[
		[
			5521,
			8514
		],
		[
			8,
			1
		],
		[
			-8,
			-14
		],
		[
			-2,
			-22
		],
		[
			-10,
			-8
		],
		[
			-5,
			7
		],
		[
			-1,
			19
		],
		[
			10,
			16
		],
		[
			8,
			1
		]
	],
	[
		[
			5327,
			8537
		],
		[
			-2,
			-9
		],
		[
			-9,
			3
		],
		[
			11,
			6
		]
	],
	[
		[
			5671,
			8973
		],
		[
			-41,
			-2
		],
		[
			-9,
			5
		],
		[
			1,
			-19
		],
		[
			-16,
			0
		],
		[
			3,
			-8
		],
		[
			-13,
			0
		],
		[
			4,
			-13
		],
		[
			-10,
			-13
		],
		[
			-4,
			-15
		],
		[
			12,
			-15
		],
		[
			-17,
			-17
		],
		[
			-4,
			-15
		],
		[
			-13,
			-13
		],
		[
			-8,
			1
		],
		[
			-11,
			-13
		],
		[
			-32,
			-24
		],
		[
			0,
			-9
		],
		[
			-17,
			-3
		],
		[
			5,
			-11
		],
		[
			-5,
			-7
		],
		[
			-15,
			-2
		],
		[
			5,
			-14
		],
		[
			-5,
			-29
		],
		[
			-7,
			-9
		],
		[
			5,
			-32
		],
		[
			0,
			-18
		],
		[
			10,
			-10
		],
		[
			10,
			4
		],
		[
			14,
			-25
		],
		[
			9,
			-2
		],
		[
			6,
			-19
		],
		[
			-20,
			-23
		],
		[
			-6,
			3
		],
		[
			8,
			-16
		],
		[
			-17,
			-16
		],
		[
			-18,
			-13
		],
		[
			-13,
			-2
		],
		[
			8,
			-8
		],
		[
			-6,
			-3
		],
		[
			3,
			-15
		],
		[
			-10,
			-16
		],
		[
			6,
			-8
		],
		[
			0,
			-17
		],
		[
			-6,
			-10
		],
		[
			-3,
			-37
		],
		[
			-3,
			0
		],
		[
			-6,
			-23
		],
		[
			-5,
			-8
		],
		[
			-6,
			5
		],
		[
			-27,
			-3
		],
		[
			-11,
			-14
		],
		[
			-2,
			-11
		],
		[
			5,
			-10
		],
		[
			-6,
			-9
		],
		[
			-11,
			3
		],
		[
			-10,
			-5
		],
		[
			-14,
			2
		],
		[
			4,
			15
		],
		[
			-14,
			31
		],
		[
			8,
			6
		],
		[
			-6,
			8
		],
		[
			8,
			2
		],
		[
			-15,
			26
		],
		[
			-18,
			47
		],
		[
			4,
			27
		],
		[
			-4,
			8
		],
		[
			-9,
			-4
		],
		[
			-4,
			9
		],
		[
			-1,
			39
		],
		[
			6,
			-6
		]
	],
	[
		[
			5891,
			3637
		],
		[
			-3,
			2
		],
		[
			-1,
			-29
		],
		[
			-12,
			0
		],
		[
			-11,
			7
		],
		[
			-9,
			22
		],
		[
			0,
			24
		],
		[
			7,
			17
		],
		[
			1,
			10
		],
		[
			8,
			11
		],
		[
			14,
			-15
		],
		[
			2,
			2
		]
	],
	[
		[
			3249,
			6221
		],
		[
			-2,
			2
		]
	],
	[
		[
			5999,
			7178
		],
		[
			-3,
			27
		],
		[
			1,
			18
		],
		[
			-4,
			4
		],
		[
			1,
			20
		],
		[
			3,
			4
		]
	],
	[
		[
			5997,
			7251
		],
		[
			7,
			-5
		],
		[
			5,
			9
		],
		[
			0,
			11
		],
		[
			9,
			3
		],
		[
			-4,
			14
		],
		[
			4,
			21
		],
		[
			8,
			-5
		],
		[
			2,
			-7
		],
		[
			12,
			0
		],
		[
			5,
			6
		],
		[
			18,
			10
		],
		[
			10,
			-11
		],
		[
			16,
			-3
		],
		[
			21,
			8
		],
		[
			20,
			17
		],
		[
			22,
			-1
		],
		[
			16,
			7
		],
		[
			4,
			7
		],
		[
			4,
			-12
		]
	],
	[
		[
			5402,
			5930
		],
		[
			5,
			0
		],
		[
			0,
			13
		],
		[
			-4,
			3
		],
		[
			-6,
			-5
		],
		[
			2,
			-5
		]
	],
	[
		[
			5398,
			5936
		],
		[
			-1,
			0
		]
	],
	[
		[
			5044,
			5541
		],
		[
			-12,
			-7
		]
	],
	[
		[
			7728,
			5654
		],
		[
			6,
			-7
		],
		[
			0,
			-10
		],
		[
			-6,
			-6
		],
		[
			0,
			23
		]
	],
	[
		[
			7840,
			5883
		],
		[
			5,
			-11
		],
		[
			-4,
			1
		],
		[
			-1,
			10
		]
	],
	[
		[
			7858,
			5853
		],
		[
			-4,
			22
		],
		[
			-5,
			11
		],
		[
			-1,
			-7
		],
		[
			-12,
			18
		],
		[
			0,
			8
		],
		[
			-5,
			0
		],
		[
			-8,
			10
		],
		[
			-7,
			-5
		],
		[
			-16,
			5
		],
		[
			3,
			15
		],
		[
			-3,
			7
		],
		[
			4,
			21
		],
		[
			-11,
			5
		],
		[
			-15,
			-8
		],
		[
			-2,
			-9
		],
		[
			4,
			-13
		],
		[
			-4,
			-16
		],
		[
			0,
			-27
		],
		[
			2,
			-5
		],
		[
			-7,
			-15
		],
		[
			0,
			-11
		],
		[
			-4,
			-13
		],
		[
			-5,
			-20
		],
		[
			0,
			-15
		],
		[
			-9,
			-32
		],
		[
			2,
			-7
		],
		[
			-2,
			-27
		],
		[
			5,
			-21
		],
		[
			-3,
			-10
		],
		[
			16,
			5
		],
		[
			4,
			-12
		],
		[
			1,
			-29
		],
		[
			9,
			-16
		],
		[
			0,
			-12
		],
		[
			4,
			-37
		],
		[
			4,
			-16
		],
		[
			-4,
			4
		],
		[
			-3,
			29
		],
		[
			-6,
			-2
		],
		[
			2,
			-13
		],
		[
			6,
			-18
		],
		[
			6,
			0
		],
		[
			9,
			-18
		],
		[
			12,
			1
		],
		[
			6,
			-4
		],
		[
			6,
			-21
		],
		[
			7,
			-12
		]
	],
	[
		[
			7780,
			5554
		],
		[
			-4,
			13
		],
		[
			-8,
			12
		],
		[
			2,
			14
		],
		[
			-6,
			2
		],
		[
			-5,
			10
		],
		[
			-2,
			18
		],
		[
			-7,
			5
		],
		[
			1,
			7
		],
		[
			-5,
			11
		],
		[
			-4,
			1
		],
		[
			-3,
			18
		],
		[
			-5,
			-2
		],
		[
			-2,
			-12
		],
		[
			-4,
			5
		],
		[
			-2,
			18
		],
		[
			2,
			14
		],
		[
			4,
			19
		],
		[
			0,
			16
		],
		[
			3,
			16
		],
		[
			7,
			40
		]
	],
	[
		[
			6962,
			7540
		],
		[
			0,
			0
		]
	],
	[
		[
			6882,
			7324
		],
		[
			1,
			20
		],
		[
			12,
			24
		],
		[
			3,
			15
		],
		[
			-7,
			12
		],
		[
			-2,
			14
		],
		[
			4,
			10
		],
		[
			-2,
			9
		],
		[
			-12,
			1
		],
		[
			0,
			7
		],
		[
			-9,
			4
		],
		[
			2,
			16
		],
		[
			8,
			9
		],
		[
			18,
			-6
		],
		[
			7,
			6
		],
		[
			0,
			11
		],
		[
			8,
			4
		],
		[
			1,
			14
		],
		[
			-10,
			2
		],
		[
			13,
			4
		],
		[
			7,
			-3
		],
		[
			1,
			9
		],
		[
			-4,
			11
		],
		[
			5,
			14
		],
		[
			8,
			-8
		],
		[
			18,
			14
		],
		[
			5,
			7
		],
		[
			8,
			-18
		],
		[
			-11,
			-19
		],
		[
			7,
			-10
		],
		[
			9,
			3
		]
	],
	[
		[
			6497,
			7333
		],
		[
			-3,
			23
		],
		[
			2,
			30
		],
		[
			-1,
			22
		],
		[
			4,
			15
		],
		[
			-12,
			17
		],
		[
			0,
			9
		],
		[
			-11,
			0
		],
		[
			1,
			8
		],
		[
			14,
			2
		],
		[
			-9,
			14
		],
		[
			6,
			10
		],
		[
			-5,
			3
		],
		[
			-14,
			-3
		],
		[
			-5,
			6
		],
		[
			0,
			25
		],
		[
			4,
			9
		],
		[
			2,
			19
		],
		[
			4,
			-11
		],
		[
			13,
			-1
		],
		[
			5,
			-8
		],
		[
			16,
			6
		],
		[
			1,
			12
		],
		[
			8,
			-6
		],
		[
			3,
			14
		],
		[
			-19,
			23
		],
		[
			-4,
			34
		],
		[
			-6,
			5
		],
		[
			-16,
			-3
		],
		[
			-5,
			-6
		],
		[
			-5,
			-17
		],
		[
			4,
			0
		],
		[
			-3,
			-19
		],
		[
			-7,
			9
		],
		[
			-3,
			13
		]
	],
	[
		[
			6554,
			7562
		],
		[
			29,
			-5
		],
		[
			4,
			7
		],
		[
			-4,
			7
		],
		[
			-2,
			23
		],
		[
			4,
			3
		]
	],
	[
		[
			6585,
			7597
		],
		[
			4,
			-18
		],
		[
			11,
			-2
		],
		[
			7,
			14
		],
		[
			-6,
			6
		],
		[
			0,
			13
		]
	],
	[
		[
			6601,
			7610
		],
		[
			5,
			1
		],
		[
			4,
			19
		],
		[
			7,
			-2
		],
		[
			-3,
			10
		],
		[
			11,
			1
		],
		[
			2,
			6
		],
		[
			8,
			-12
		],
		[
			7,
			-2
		],
		[
			7,
			-14
		],
		[
			13,
			2
		],
		[
			5,
			-8
		],
		[
			-1,
			-12
		],
		[
			6,
			-8
		],
		[
			-5,
			-4
		],
		[
			4,
			-10
		],
		[
			-3,
			-10
		],
		[
			11,
			-11
		],
		[
			18,
			1
		],
		[
			6,
			-3
		],
		[
			7,
			6
		],
		[
			9,
			-10
		],
		[
			8,
			-36
		],
		[
			4,
			-2
		],
		[
			5,
			-29
		],
		[
			27,
			-31
		],
		[
			4,
			-10
		],
		[
			13,
			-16
		],
		[
			5,
			2
		],
		[
			10,
			-14
		],
		[
			27,
			-29
		],
		[
			7,
			1
		],
		[
			19,
			-14
		],
		[
			3,
			-4
		],
		[
			-4,
			-9
		],
		[
			0,
			-25
		]
	],
	[
		[
			8444,
			4645
		],
		[
			12,
			9
		]
	],
	[
		[
			8469,
			4667
		],
		[
			5,
			9
		],
		[
			1,
			10
		],
		[
			20,
			8
		],
		[
			10,
			-1
		],
		[
			6,
			5
		],
		[
			3,
			-4
		],
		[
			11,
			10
		],
		[
			11,
			-6
		],
		[
			-13,
			-19
		],
		[
			-8,
			-3
		],
		[
			-4,
			-9
		],
		[
			-7,
			-2
		],
		[
			-6,
			-8
		],
		[
			-10,
			-3
		],
		[
			-15,
			-17
		]
	],
	[
		[
			130,
			3966
		],
		[
			6,
			0
		],
		[
			-1,
			-7
		],
		[
			-5,
			7
		]
	],
	[
		[
			3308,
			5807
		],
		[
			-4,
			-9
		],
		[
			1,
			-31
		],
		[
			-4,
			-4
		],
		[
			-14,
			-1
		],
		[
			-5,
			4
		],
		[
			10,
			7
		],
		[
			0,
			20
		],
		[
			-5,
			5
		],
		[
			8,
			7
		],
		[
			13,
			2
		]
	],
	[
		[
			5303,
			7135
		],
		[
			4,
			-6
		],
		[
			-9,
			-6
		],
		[
			0,
			11
		],
		[
			5,
			1
		]
	],
	[
		[
			5238,
			7310
		],
		[
			7,
			2
		],
		[
			10,
			15
		],
		[
			13,
			6
		],
		[
			17,
			-9
		],
		[
			-4,
			-1
		],
		[
			6,
			-17
		],
		[
			-5,
			-4
		],
		[
			10,
			-3
		],
		[
			14,
			20
		],
		[
			3,
			-14
		],
		[
			-10,
			-23
		],
		[
			-6,
			-4
		],
		[
			-3,
			-16
		],
		[
			6,
			-18
		],
		[
			11,
			-10
		],
		[
			-1,
			-16
		],
		[
			3,
			-7
		],
		[
			-3,
			-11
		],
		[
			-12,
			-28
		],
		[
			-14,
			-14
		],
		[
			-2,
			-16
		],
		[
			4,
			-12
		],
		[
			9,
			-10
		],
		[
			6,
			4
		],
		[
			0,
			-13
		],
		[
			11,
			4
		],
		[
			2,
			-20
		],
		[
			9,
			-1
		]
	],
	[
		[
			5778,
			7600
		],
		[
			-2,
			-9
		],
		[
			6,
			-15
		],
		[
			20,
			-17
		],
		[
			6,
			-2
		],
		[
			-3,
			-13
		],
		[
			-14,
			-1
		],
		[
			-9,
			6
		],
		[
			-6,
			-7
		],
		[
			-12,
			1
		],
		[
			-9,
			-20
		],
		[
			-14,
			-10
		],
		[
			-15,
			-24
		],
		[
			2,
			17
		],
		[
			13,
			10
		],
		[
			3,
			7
		],
		[
			-20,
			-3
		],
		[
			-1,
			9
		]
	],
	[
		[
			5997,
			7251
		],
		[
			2,
			5
		],
		[
			-6,
			17
		],
		[
			12,
			18
		],
		[
			0,
			11
		],
		[
			-6,
			7
		],
		[
			-10,
			-18
		],
		[
			-8,
			-3
		],
		[
			-18,
			15
		],
		[
			-11,
			-13
		],
		[
			-17,
			-26
		],
		[
			-7,
			1
		],
		[
			-17,
			-8
		],
		[
			-13,
			9
		],
		[
			-7,
			18
		],
		[
			-21,
			18
		],
		[
			-18,
			5
		],
		[
			-3,
			-3
		],
		[
			0,
			-18
		],
		[
			-5,
			-18
		],
		[
			-4,
			6
		],
		[
			-13,
			-10
		],
		[
			-12,
			5
		],
		[
			-7,
			9
		],
		[
			0,
			16
		],
		[
			-7,
			-1
		],
		[
			-7,
			9
		],
		[
			-10,
			3
		],
		[
			-3,
			-6
		],
		[
			-11,
			1
		],
		[
			-2,
			-6
		],
		[
			-9,
			3
		],
		[
			8,
			5
		],
		[
			12,
			0
		],
		[
			-1,
			7
		],
		[
			8,
			7
		],
		[
			-15,
			-3
		],
		[
			-12,
			2
		],
		[
			-1,
			8
		],
		[
			7,
			-2
		],
		[
			-10,
			13
		],
		[
			0,
			14
		],
		[
			-5,
			5
		],
		[
			7,
			4
		],
		[
			-1,
			13
		],
		[
			-17,
			7
		],
		[
			-11,
			9
		],
		[
			7,
			6
		],
		[
			-4,
			14
		],
		[
			4,
			3
		],
		[
			5,
			-20
		],
		[
			14,
			8
		],
		[
			-7,
			0
		],
		[
			-5,
			16
		],
		[
			6,
			2
		],
		[
			3,
			10
		],
		[
			-6,
			-2
		],
		[
			0,
			14
		],
		[
			-6,
			9
		],
		[
			9,
			16
		],
		[
			-24,
			-6
		],
		[
			2,
			29
		],
		[
			16,
			25
		],
		[
			16,
			3
		],
		[
			2,
			-7
		],
		[
			11,
			-1
		],
		[
			-1,
			11
		],
		[
			8,
			-2
		],
		[
			-2,
			-7
		],
		[
			11,
			3
		],
		[
			19,
			-3
		],
		[
			1,
			7
		],
		[
			-8,
			3
		],
		[
			5,
			6
		],
		[
			27,
			5
		],
		[
			-15,
			3
		],
		[
			-11,
			13
		],
		[
			6,
			13
		],
		[
			19,
			-6
		],
		[
			11,
			5
		],
		[
			15,
			-8
		],
		[
			9,
			1
		],
		[
			7,
			11
		],
		[
			29,
			28
		],
		[
			14,
			6
		],
		[
			10,
			9
		],
		[
			28,
			-6
		],
		[
			10,
			0
		],
		[
			10,
			9
		],
		[
			1,
			-10
		],
		[
			6,
			-11
		],
		[
			9,
			-5
		],
		[
			10,
			6
		],
		[
			4,
			-16
		],
		[
			8,
			-13
		],
		[
			5,
			8
		],
		[
			12,
			-5
		],
		[
			0,
			-6
		],
		[
			13,
			-8
		],
		[
			8,
			0
		],
		[
			15,
			-7
		],
		[
			32,
			11
		],
		[
			4,
			-6
		],
		[
			14,
			-5
		],
		[
			12,
			7
		],
		[
			24,
			20
		],
		[
			3,
			7
		]
	],
	[
		[
			8378,
			6635
		],
		[
			10,
			-12
		],
		[
			-5,
			-8
		],
		[
			1,
			-22
		],
		[
			-6,
			-18
		],
		[
			-4,
			-43
		],
		[
			-3,
			-19
		],
		[
			-6,
			-20
		],
		[
			-4,
			-5
		],
		[
			-4,
			-17
		],
		[
			-1,
			-27
		],
		[
			-5,
			7
		],
		[
			-1,
			16
		],
		[
			-11,
			20
		],
		[
			-2,
			22
		],
		[
			-3,
			0
		],
		[
			2,
			15
		],
		[
			0,
			20
		],
		[
			17,
			58
		],
		[
			3,
			3
		],
		[
			4,
			18
		],
		[
			12,
			7
		],
		[
			2,
			9
		],
		[
			4,
			-4
		]
	],
	[
		[
			6108,
			4736
		],
		[
			-7,
			-14
		],
		[
			1,
			11
		],
		[
			6,
			3
		]
	],
	[
		[
			6093,
			4842
		],
		[
			6,
			-26
		],
		[
			-4,
			-4
		],
		[
			-7,
			16
		],
		[
			0,
			15
		],
		[
			5,
			-1
		]
	],
	[
		[
			6102,
			4899
		],
		[
			5,
			-11
		],
		[
			-3,
			-19
		],
		[
			-2,
			30
		]
	],
	[
		[
			5914,
			5071
		],
		[
			5,
			-1
		],
		[
			2,
			-12
		],
		[
			-9,
			7
		],
		[
			2,
			6
		]
	],
	[
		[
			5882,
			5125
		],
		[
			1,
			0
		]
	],
	[
		[
			5883,
			5125
		],
		[
			1,
			0
		]
	],
	[
		[
			5884,
			5125
		],
		[
			-1,
			-28
		],
		[
			-2,
			0
		],
		[
			-1,
			-30
		],
		[
			-2,
			-20
		],
		[
			4,
			2
		],
		[
			0,
			-28
		],
		[
			2,
			8
		],
		[
			4,
			-3
		],
		[
			0,
			13
		],
		[
			5,
			-3
		],
		[
			-3,
			10
		],
		[
			7,
			6
		],
		[
			2,
			-10
		],
		[
			12,
			-2
		],
		[
			8,
			5
		],
		[
			3,
			-7
		],
		[
			17,
			17
		],
		[
			-2,
			8
		],
		[
			-4,
			-6
		],
		[
			-10,
			4
		],
		[
			5,
			8
		],
		[
			-3,
			9
		],
		[
			5,
			-1
		],
		[
			5,
			9
		],
		[
			-1,
			12
		],
		[
			6,
			0
		],
		[
			-2,
			7
		],
		[
			8,
			17
		]
	],
	[
		[
			6088,
			4913
		],
		[
			1,
			-10
		],
		[
			-4,
			-16
		],
		[
			-3,
			-25
		],
		[
			-5,
			-21
		],
		[
			2,
			-26
		],
		[
			5,
			-5
		],
		[
			12,
			-22
		],
		[
			2,
			-15
		],
		[
			-4,
			-5
		],
		[
			-4,
			-23
		],
		[
			1,
			-10
		],
		[
			4,
			-2
		],
		[
			0,
			-13
		],
		[
			-4,
			-14
		],
		[
			2,
			-25
		],
		[
			4,
			-7
		],
		[
			0,
			-16
		],
		[
			4,
			-4
		],
		[
			0,
			-15
		],
		[
			4,
			-21
		],
		[
			-2,
			-8
		],
		[
			15,
			-16
		],
		[
			5,
			-14
		]
	],
	[
		[
			5971,
			4516
		],
		[
			-2,
			9
		]
	],
	[
		[
			5969,
			4527
		],
		[
			-5,
			7
		]
	],
	[
		[
			5964,
			4536
		],
		[
			-4,
			14
		],
		[
			2,
			20
		],
		[
			-2,
			4
		],
		[
			-1,
			30
		],
		[
			-7,
			20
		]
	],
	[
		[
			5949,
			4630
		],
		[
			-3,
			4
		]
	],
	[
		[
			5946,
			4635
		],
		[
			-4,
			-2
		],
		[
			-1,
			-10
		]
	],
	[
		[
			5914,
			4641
		],
		[
			-12,
			10
		],
		[
			-3,
			6
		],
		[
			-13,
			6
		],
		[
			-6,
			6
		],
		[
			-4,
			13
		],
		[
			-11,
			6
		]
	],
	[
		[
			5865,
			4688
		],
		[
			0,
			10
		],
		[
			-4,
			5
		],
		[
			-1,
			11
		],
		[
			-11,
			36
		],
		[
			1,
			11
		],
		[
			-3,
			8
		],
		[
			2,
			12
		],
		[
			-5,
			9
		],
		[
			-7,
			21
		],
		[
			-6,
			-1
		],
		[
			-6,
			12
		],
		[
			0,
			13
		],
		[
			6,
			7
		],
		[
			-5,
			32
		],
		[
			1,
			21
		],
		[
			-6,
			5
		],
		[
			2,
			27
		]
	],
	[
		[
			5846,
			5121
		],
		[
			10,
			4
		],
		[
			26,
			0
		]
	],
	[
		[
			5883,
			5125
		],
		[
			1,
			0
		]
	],
	[
		[
			5944,
			5197
		],
		[
			-8,
			-3
		],
		[
			1,
			8
		],
		[
			-8,
			-8
		],
		[
			-3,
			15
		],
		[
			-5,
			-3
		],
		[
			-2,
			-12
		],
		[
			-6,
			-7
		],
		[
			0,
			7
		],
		[
			-6,
			-6
		],
		[
			0,
			10
		],
		[
			-8,
			-17
		],
		[
			-9,
			0
		],
		[
			-4,
			-9
		],
		[
			3,
			-7
		],
		[
			-9,
			-26
		],
		[
			2,
			-14
		]
	],
	[
		[
			5823,
			5155
		],
		[
			5,
			6
		],
		[
			2,
			14
		],
		[
			-6,
			2
		]
	],
	[
		[
			5846,
			5254
		],
		[
			4,
			-12
		],
		[
			9,
			28
		],
		[
			10,
			11
		],
		[
			3,
			11
		],
		[
			-1,
			25
		],
		[
			-3,
			-9
		]
	],
	[
		[
			6061,
			7895
		],
		[
			-18,
			0
		],
		[
			-6,
			-11
		],
		[
			-4,
			2
		],
		[
			-12,
			-13
		],
		[
			-4,
			3
		],
		[
			-22,
			-8
		],
		[
			-14,
			-18
		],
		[
			-4,
			3
		],
		[
			-11,
			-12
		],
		[
			4,
			-22
		],
		[
			15,
			-28
		],
		[
			18,
			10
		],
		[
			13,
			-3
		],
		[
			-5,
			-9
		],
		[
			1,
			-11
		],
		[
			-17,
			-4
		],
		[
			-9,
			7
		],
		[
			-4,
			-10
		],
		[
			-23,
			-12
		],
		[
			-12,
			-18
		],
		[
			-10,
			-2
		],
		[
			-11,
			11
		],
		[
			5,
			5
		],
		[
			1,
			24
		],
		[
			-8,
			3
		],
		[
			-11,
			13
		],
		[
			-9,
			-2
		],
		[
			-1,
			8
		],
		[
			24,
			21
		],
		[
			8,
			2
		],
		[
			-1,
			14
		],
		[
			-6,
			-3
		],
		[
			-5,
			10
		],
		[
			-3,
			-6
		],
		[
			-18,
			-3
		],
		[
			-17,
			14
		],
		[
			4,
			8
		],
		[
			-7,
			6
		],
		[
			17,
			-5
		],
		[
			4,
			9
		],
		[
			-11,
			-4
		],
		[
			-6,
			5
		],
		[
			-25,
			-2
		],
		[
			-24,
			-46
		],
		[
			-5,
			1
		],
		[
			-10,
			-23
		],
		[
			4,
			2
		],
		[
			-3,
			-14
		]
	],
	[
		[
			5836,
			7853
		],
		[
			9,
			-17
		],
		[
			2,
			3
		],
		[
			-11,
			14
		]
	],
	[
		[
			5948,
			7848
		],
		[
			0,
			-9
		],
		[
			-11,
			7
		],
		[
			3,
			-13
		],
		[
			4,
			5
		],
		[
			21,
			-17
		],
		[
			6,
			-8
		],
		[
			4,
			-20
		],
		[
			9,
			-4
		],
		[
			-12,
			23
		],
		[
			-7,
			26
		],
		[
			-10,
			-6
		],
		[
			-7,
			16
		]
	],
	[
		[
			3523,
			3302
		],
		[
			-5,
			-5
		],
		[
			0,
			-12
		],
		[
			-8,
			-5
		],
		[
			3,
			-30
		]
	],
	[
		[
			3517,
			3240
		],
		[
			-4,
			-18
		],
		[
			-7,
			-13
		],
		[
			0,
			-7
		],
		[
			-13,
			-16
		],
		[
			-20,
			-17
		],
		[
			-12,
			10
		],
		[
			-14,
			0
		],
		[
			-7,
			-8
		],
		[
			-20,
			15
		],
		[
			-8,
			13
		],
		[
			-18,
			-1
		],
		[
			-16,
			29
		],
		[
			-2,
			10
		],
		[
			3,
			27
		],
		[
			-1,
			10
		],
		[
			9,
			9
		],
		[
			-4,
			31
		]
	],
	[
		[
			677,
			6342
		],
		[
			13,
			-11
		],
		[
			2,
			-12
		],
		[
			8,
			-13
		],
		[
			-6,
			-10
		],
		[
			-16,
			-13
		],
		[
			-3,
			-11
		],
		[
			-7,
			9
		],
		[
			1,
			15
		],
		[
			-4,
			25
		],
		[
			5,
			12
		],
		[
			-1,
			17
		],
		[
			8,
			-8
		]
	],
	[
		[
			649,
			6394
		],
		[
			3,
			-7
		],
		[
			7,
			2
		],
		[
			8,
			-8
		],
		[
			0,
			-7
		],
		[
			-9,
			-6
		],
		[
			-4,
			2
		],
		[
			0,
			10
		],
		[
			-7,
			7
		],
		[
			2,
			7
		]
	],
	[
		[
			631,
			6405
		],
		[
			16,
			-4
		],
		[
			-2,
			-5
		],
		[
			-15,
			2
		],
		[
			1,
			7
		]
	],
	[
		[
			613,
			6427
		],
		[
			6,
			-8
		],
		[
			1,
			-12
		],
		[
			-13,
			2
		],
		[
			-3,
			14
		],
		[
			7,
			10
		],
		[
			2,
			-6
		]
	],
	[
		[
			571,
			6463
		],
		[
			4,
			-3
		],
		[
			-1,
			-14
		],
		[
			-8,
			-3
		],
		[
			-6,
			11
		],
		[
			11,
			9
		]
	],
	[
		[
			2301,
			6687
		],
		[
			-6,
			35
		],
		[
			0,
			12
		],
		[
			6,
			-47
		]
	],
	[
		[
			2761,
			6828
		],
		[
			-2,
			-18
		],
		[
			-2,
			17
		],
		[
			4,
			1
		]
	],
	[
		[
			2366,
			6873
		],
		[
			3,
			-1
		],
		[
			-11,
			-13
		],
		[
			8,
			14
		]
	],
	[
		[
			1707,
			7111
		],
		[
			7,
			-9
		],
		[
			-6,
			0
		],
		[
			-1,
			9
		]
	],
	[
		[
			1671,
			7144
		],
		[
			8,
			-4
		],
		[
			-8,
			-2
		],
		[
			0,
			6
		]
	],
	[
		[
			2993,
			7551
		],
		[
			-6,
			-11
		],
		[
			8,
			7
		],
		[
			8,
			-1
		],
		[
			-20,
			-15
		],
		[
			-36,
			-12
		],
		[
			-4,
			1
		],
		[
			4,
			11
		],
		[
			7,
			6
		],
		[
			29,
			6
		],
		[
			10,
			8
		]
	],
	[
		[
			2582,
			7791
		],
		[
			0,
			-10
		],
		[
			-7,
			-17
		],
		[
			-3,
			8
		],
		[
			10,
			19
		]
	],
	[
		[
			2679,
			7836
		],
		[
			1,
			-8
		],
		[
			-10,
			3
		],
		[
			9,
			5
		]
	],
	[
		[
			2563,
			7913
		],
		[
			-19,
			-17
		],
		[
			-6,
			0
		],
		[
			5,
			14
		],
		[
			8,
			6
		],
		[
			12,
			-3
		]
	],
	[
		[
			2541,
			7956
		],
		[
			-2,
			-6
		],
		[
			-15,
			-14
		],
		[
			0,
			8
		],
		[
			17,
			12
		]
	],
	[
		[
			1595,
			7969
		],
		[
			-3,
			-9
		],
		[
			8,
			-13
		],
		[
			-1,
			-5
		],
		[
			-9,
			17
		],
		[
			5,
			10
		]
	],
	[
		[
			1582,
			8004
		],
		[
			-1,
			0
		]
	],
	[
		[
			2511,
			7947
		],
		[
			-14,
			-11
		],
		[
			-19,
			-11
		],
		[
			-20,
			-29
		],
		[
			-17,
			-21
		],
		[
			9,
			-3
		],
		[
			22,
			14
		],
		[
			6,
			0
		],
		[
			-5,
			-19
		],
		[
			14,
			-2
		],
		[
			11,
			5
		],
		[
			7,
			9
		],
		[
			14,
			4
		],
		[
			10,
			7
		],
		[
			7,
			13
		],
		[
			7,
			-14
		],
		[
			-1,
			-10
		],
		[
			10,
			6
		],
		[
			9,
			-1
		],
		[
			12,
			-22
		],
		[
			11,
			0
		],
		[
			9,
			-4
		],
		[
			14,
			14
		],
		[
			18,
			-2
		],
		[
			13,
			6
		],
		[
			0,
			-17
		],
		[
			15,
			-1
		]
	],
	[
		[
			2663,
			7852
		],
		[
			-3,
			-10
		],
		[
			9,
			-12
		],
		[
			-16,
			1
		],
		[
			-5,
			4
		],
		[
			-2,
			-11
		],
		[
			-7,
			9
		],
		[
			-15,
			5
		],
		[
			-3,
			-7
		],
		[
			-25,
			-7
		],
		[
			-13,
			0
		],
		[
			-15,
			-39
		],
		[
			-3,
			-12
		],
		[
			-10,
			-17
		],
		[
			2,
			-8
		],
		[
			10,
			17
		],
		[
			7,
			-3
		],
		[
			-11,
			-49
		],
		[
			1,
			-13
		],
		[
			-6,
			-26
		],
		[
			0,
			-14
		],
		[
			4,
			-15
		],
		[
			-2,
			-28
		],
		[
			9,
			-33
		],
		[
			8,
			-4
		],
		[
			16,
			14
		],
		[
			7,
			22
		],
		[
			5,
			26
		],
		[
			0,
			15
		],
		[
			-9,
			37
		],
		[
			3,
			10
		],
		[
			-3,
			17
		],
		[
			8,
			20
		],
		[
			0,
			14
		],
		[
			5,
			15
		],
		[
			7,
			2
		],
		[
			7,
			15
		],
		[
			-3,
			-22
		],
		[
			4,
			-4
		],
		[
			4,
			14
		],
		[
			0,
			16
		],
		[
			11,
			5
		],
		[
			-3,
			15
		],
		[
			9,
			10
		],
		[
			13,
			-8
		],
		[
			6,
			-11
		],
		[
			16,
			-7
		],
		[
			6,
			-13
		],
		[
			-4,
			-11
		],
		[
			4,
			-6
		],
		[
			-1,
			-28
		],
		[
			-6,
			-5
		],
		[
			-1,
			-13
		],
		[
			-7,
			-2
		],
		[
			-3,
			-18
		],
		[
			6,
			-5
		],
		[
			7,
			6
		],
		[
			6,
			16
		],
		[
			9,
			5
		],
		[
			7,
			-10
		],
		[
			4,
			-37
		],
		[
			3,
			-14
		]
	],
	[
		[
			2704,
			7634
		],
		[
			-5,
			5
		],
		[
			-3,
			-17
		],
		[
			-6,
			-8
		],
		[
			-3,
			-17
		],
		[
			-6,
			-12
		],
		[
			15,
			-11
		],
		[
			7,
			0
		],
		[
			5,
			-7
		],
		[
			9,
			4
		],
		[
			14,
			3
		],
		[
			9,
			12
		],
		[
			24,
			15
		],
		[
			26,
			21
		],
		[
			14,
			21
		],
		[
			5,
			2
		],
		[
			-1,
			17
		],
		[
			-5,
			3
		]
	],
	[
		[
			2804,
			7674
		],
		[
			10,
			6
		],
		[
			16,
			2
		],
		[
			13,
			-8
		],
		[
			18,
			0
		],
		[
			8,
			5
		],
		[
			15,
			19
		],
		[
			-3,
			9
		],
		[
			4,
			4
		],
		[
			-7,
			11
		],
		[
			15,
			16
		],
		[
			1,
			7
		]
	],
	[
		[
			3116,
			7818
		],
		[
			10,
			-9
		]
	],
	[
		[
			3134,
			7784
		],
		[
			3,
			-9
		],
		[
			-3,
			-20
		],
		[
			-20,
			-16
		],
		[
			-6,
			5
		],
		[
			-13,
			-5
		],
		[
			1,
			-9
		],
		[
			-12,
			11
		],
		[
			-3,
			-22
		],
		[
			-14,
			-14
		],
		[
			-10,
			3
		],
		[
			-8,
			-8
		],
		[
			1,
			-9
		],
		[
			-11,
			-15
		],
		[
			-6,
			-22
		],
		[
			1,
			-15
		],
		[
			5,
			1
		],
		[
			-13,
			-19
		],
		[
			9,
			-7
		],
		[
			5,
			-23
		],
		[
			17,
			-8
		],
		[
			-14,
			-3
		],
		[
			-6,
			-6
		],
		[
			0,
			11
		],
		[
			-15,
			-14
		],
		[
			0,
			12
		],
		[
			-5,
			5
		],
		[
			-1,
			-17
		],
		[
			-12,
			-9
		],
		[
			-29,
			-2
		],
		[
			-6,
			-9
		],
		[
			-8,
			-1
		],
		[
			-23,
			-27
		],
		[
			-1,
			-10
		],
		[
			8,
			-1
		],
		[
			-2,
			-29
		],
		[
			-3,
			-14
		],
		[
			-7,
			-9
		],
		[
			-1,
			-11
		],
		[
			-12,
			-24
		],
		[
			-1,
			15
		],
		[
			-7,
			2
		],
		[
			-10,
			13
		],
		[
			3,
			-23
		],
		[
			9,
			-21
		],
		[
			1,
			-16
		],
		[
			-10,
			-31
		],
		[
			-7,
			-13
		],
		[
			-8,
			-30
		],
		[
			-2,
			11
		],
		[
			4,
			20
		],
		[
			6,
			17
		],
		[
			-6,
			-2
		],
		[
			1,
			9
		],
		[
			-13,
			21
		],
		[
			-1,
			17
		],
		[
			4,
			11
		],
		[
			-2,
			15
		],
		[
			11,
			15
		],
		[
			-5,
			0
		],
		[
			-11,
			-10
		],
		[
			2,
			-16
		],
		[
			-4,
			-6
		],
		[
			0,
			-23
		],
		[
			4,
			-6
		],
		[
			1,
			-20
		],
		[
			-9,
			11
		],
		[
			-8,
			-2
		],
		[
			9,
			-4
		],
		[
			11,
			-13
		],
		[
			-2,
			-17
		],
		[
			-6,
			3
		],
		[
			8,
			-12
		],
		[
			-7,
			-12
		],
		[
			6,
			-8
		],
		[
			-4,
			-8
		],
		[
			12,
			-4
		],
		[
			5,
			-35
		],
		[
			7,
			-23
		],
		[
			-5,
			9
		],
		[
			-6,
			38
		],
		[
			-2,
			-15
		],
		[
			6,
			-17
		],
		[
			-9,
			5
		],
		[
			0,
			-7
		],
		[
			-15,
			-4
		],
		[
			-2,
			-6
		],
		[
			15,
			3
		],
		[
			13,
			-8
		],
		[
			-1,
			-17
		],
		[
			-3,
			2
		],
		[
			-5,
			-13
		],
		[
			-13,
			1
		],
		[
			-2,
			9
		],
		[
			-4,
			-8
		],
		[
			7,
			-6
		],
		[
			-2,
			-11
		],
		[
			-11,
			-8
		],
		[
			17,
			-2
		],
		[
			-7,
			-11
		],
		[
			-15,
			-4
		],
		[
			-15,
			-18
		],
		[
			-9,
			-27
		],
		[
			-11,
			1
		],
		[
			-13,
			-12
		],
		[
			-5,
			-10
		],
		[
			-4,
			-21
		],
		[
			-22,
			-32
		],
		[
			-14,
			-8
		],
		[
			1,
			-8
		],
		[
			-12,
			-15
		],
		[
			1,
			-5
		],
		[
			-11,
			-14
		],
		[
			-3,
			-12
		],
		[
			2,
			-18
		],
		[
			-4,
			-5
		],
		[
			-3,
			-19
		],
		[
			8,
			-63
		],
		[
			9,
			-38
		],
		[
			9,
			-26
		],
		[
			-5,
			0
		],
		[
			0,
			-10
		],
		[
			18,
			-75
		],
		[
			3,
			-31
		],
		[
			-2,
			-12
		],
		[
			-1,
			-28
		],
		[
			-4,
			-11
		],
		[
			-4,
			-29
		],
		[
			-12,
			-1
		],
		[
			-7,
			-4
		],
		[
			0,
			14
		],
		[
			-6,
			25
		],
		[
			-6,
			7
		],
		[
			-6,
			0
		],
		[
			-3,
			31
		],
		[
			-6,
			5
		],
		[
			0,
			20
		],
		[
			-7,
			-2
		],
		[
			-6,
			21
		],
		[
			-3,
			18
		],
		[
			7,
			15
		],
		[
			-1,
			8
		],
		[
			-7,
			6
		],
		[
			0,
			-19
		],
		[
			-5,
			8
		],
		[
			2,
			21
		],
		[
			4,
			14
		],
		[
			0,
			26
		],
		[
			-4,
			16
		],
		[
			-7,
			0
		],
		[
			-10,
			20
		],
		[
			-6,
			20
		],
		[
			-11,
			14
		],
		[
			-10,
			-4
		],
		[
			-10,
			-15
		],
		[
			-16,
			-5
		],
		[
			0,
			7
		],
		[
			-11,
			20
		],
		[
			-22,
			14
		],
		[
			-15,
			-1
		],
		[
			-2,
			9
		],
		[
			-4,
			-11
		],
		[
			-14,
			-5
		],
		[
			-4,
			7
		],
		[
			-1,
			16
		],
		[
			-3,
			2
		],
		[
			-2,
			-22
		],
		[
			-5,
			5
		],
		[
			-5,
			-5
		],
		[
			-10,
			6
		],
		[
			-14,
			-7
		],
		[
			-7,
			-9
		],
		[
			-11,
			7
		],
		[
			-4,
			7
		],
		[
			-8,
			-12
		],
		[
			2,
			-7
		],
		[
			10,
			-1
		],
		[
			3,
			4
		],
		[
			6,
			-14
		],
		[
			5,
			12
		],
		[
			3,
			-3
		],
		[
			-8,
			-29
		],
		[
			4,
			-8
		],
		[
			11,
			-5
		],
		[
			3,
			-9
		],
		[
			-4,
			-9
		],
		[
			-3,
			10
		],
		[
			-15,
			9
		],
		[
			2,
			4
		],
		[
			-12,
			11
		],
		[
			4,
			-9
		],
		[
			-2,
			-16
		],
		[
			-10,
			12
		],
		[
			-8,
			-14
		],
		[
			-15,
			9
		],
		[
			0,
			13
		],
		[
			-7,
			3
		],
		[
			-3,
			12
		],
		[
			-6,
			5
		],
		[
			-9,
			-8
		],
		[
			4,
			-6
		],
		[
			-13,
			-2
		],
		[
			-21,
			13
		],
		[
			-16,
			-5
		],
		[
			2,
			17
		],
		[
			-8,
			-18
		],
		[
			-17,
			-13
		],
		[
			-1,
			19
		],
		[
			-8,
			-5
		],
		[
			-1,
			-9
		],
		[
			4,
			-12
		],
		[
			-8,
			-12
		],
		[
			1,
			-4
		],
		[
			-14,
			-18
		],
		[
			-16,
			-9
		],
		[
			-12,
			8
		],
		[
			1,
			-9
		],
		[
			6,
			-8
		],
		[
			-7,
			-6
		],
		[
			-5,
			6
		],
		[
			1,
			-12
		],
		[
			-12,
			-8
		],
		[
			1,
			-14
		],
		[
			-7,
			-33
		],
		[
			-3,
			-26
		],
		[
			7,
			-32
		],
		[
			1,
			-16
		],
		[
			3,
			-1
		]
	],
	[
		[
			2245,
			6713
		],
		[
			1,
			7
		],
		[
			-9,
			21
		]
	],
	[
		[
			2193,
			6879
		],
		[
			-7,
			10
		]
	],
	[
		[
			1746,
			7056
		],
		[
			-4,
			10
		],
		[
			-2,
			27
		],
		[
			-8,
			16
		],
		[
			-15,
			18
		],
		[
			-6,
			2
		],
		[
			-3,
			12
		],
		[
			-9,
			0
		],
		[
			-10,
			6
		],
		[
			-10,
			18
		],
		[
			-21,
			3
		],
		[
			-9,
			5
		],
		[
			0,
			33
		],
		[
			-7,
			5
		],
		[
			0,
			12
		],
		[
			-12,
			15
		],
		[
			-5,
			18
		],
		[
			-9,
			13
		],
		[
			-4,
			23
		],
		[
			5,
			9
		],
		[
			-3,
			11
		],
		[
			-6,
			-1
		],
		[
			-8,
			13
		],
		[
			-3,
			21
		],
		[
			3,
			5
		],
		[
			9,
			-11
		],
		[
			-10,
			29
		],
		[
			8,
			6
		],
		[
			-7,
			6
		],
		[
			-2,
			-19
		],
		[
			-16,
			13
		],
		[
			5,
			3
		],
		[
			-7,
			20
		],
		[
			-7,
			6
		],
		[
			-10,
			20
		],
		[
			1,
			10
		],
		[
			-4,
			16
		],
		[
			2,
			10
		],
		[
			-2,
			15
		],
		[
			-7,
			17
		],
		[
			-8,
			9
		],
		[
			0,
			19
		],
		[
			8,
			15
		],
		[
			-2,
			17
		],
		[
			3,
			16
		],
		[
			-2,
			16
		],
		[
			-5,
			5
		],
		[
			3,
			12
		],
		[
			-5,
			8
		],
		[
			-1,
			32
		],
		[
			-5,
			10
		],
		[
			9,
			41
		],
		[
			4,
			25
		],
		[
			2,
			52
		],
		[
			2,
			11
		],
		[
			1,
			62
		],
		[
			13,
			7
		],
		[
			-14,
			-2
		],
		[
			1,
			29
		],
		[
			-4,
			-2
		],
		[
			6,
			13
		],
		[
			-7,
			6
		],
		[
			-10,
			44
		],
		[
			-7,
			20
		],
		[
			6,
			11
		],
		[
			15,
			-11
		],
		[
			24,
			0
		],
		[
			7,
			-6
		],
		[
			4,
			-14
		],
		[
			-9,
			-15
		],
		[
			12,
			8
		],
		[
			2,
			-20
		],
		[
			-7,
			-10
		],
		[
			2,
			-4
		],
		[
			10,
			14
		],
		[
			-1,
			29
		],
		[
			5,
			8
		],
		[
			-5,
			18
		],
		[
			-9,
			6
		],
		[
			8,
			12
		],
		[
			-10,
			16
		],
		[
			1,
			6
		]
	],
	[
		[
			60,
			8169
		],
		[
			1,
			-9
		],
		[
			-11,
			9
		],
		[
			10,
			0
		]
	],
	[
		[
			80,
			8161
		],
		[
			-11,
			0
		],
		[
			12,
			11
		],
		[
			-1,
			-11
		]
	],
	[
		[
			96,
			8175
		],
		[
			2,
			-14
		],
		[
			-10,
			0
		],
		[
			1,
			14
		],
		[
			7,
			0
		]
	],
	[
		[
			177,
			8186
		],
		[
			18,
			-5
		],
		[
			-12,
			-3
		],
		[
			-15,
			5
		],
		[
			9,
			3
		]
	],
	[
		[
			162,
			8200
		],
		[
			5,
			-4
		],
		[
			-4,
			-12
		],
		[
			-7,
			-4
		],
		[
			-27,
			-2
		],
		[
			22,
			6
		],
		[
			9,
			7
		],
		[
			-7,
			4
		],
		[
			9,
			5
		]
	],
	[
		[
			9827,
			8206
		],
		[
			-2,
			-8
		],
		[
			-9,
			2
		],
		[
			11,
			6
		]
	],
	[
		[
			9802,
			8235
		],
		[
			12,
			-10
		],
		[
			-11,
			-5
		],
		[
			-1,
			15
		]
	],
	[
		[
			332,
			8268
		],
		[
			5,
			-12
		],
		[
			-32,
			-29
		],
		[
			11,
			24
		],
		[
			7,
			1
		],
		[
			-1,
			9
		],
		[
			10,
			7
		]
	],
	[
		[
			367,
			8291
		],
		[
			6,
			-8
		],
		[
			9,
			8
		],
		[
			-9,
			-15
		],
		[
			8,
			1
		],
		[
			-14,
			-16
		],
		[
			-4,
			1
		],
		[
			-20,
			-13
		],
		[
			-6,
			4
		],
		[
			19,
			9
		],
		[
			1,
			25
		],
		[
			10,
			4
		]
	],
	[
		[
			391,
			8303
		],
		[
			7,
			-5
		],
		[
			-10,
			-3
		],
		[
			3,
			8
		]
	],
	[
		[
			451,
			8354
		],
		[
			5,
			-1
		],
		[
			6,
			-16
		],
		[
			-8,
			-9
		],
		[
			-16,
			0
		],
		[
			-4,
			-9
		],
		[
			-14,
			-3
		],
		[
			-3,
			11
		],
		[
			7,
			3
		],
		[
			10,
			16
		],
		[
			3,
			-2
		],
		[
			14,
			10
		]
	],
	[
		[
			1304,
			8361
		],
		[
			8,
			-30
		],
		[
			-14,
			25
		],
		[
			6,
			5
		]
	],
	[
		[
			558,
			8363
		],
		[
			-9,
			-20
		],
		[
			4,
			19
		],
		[
			5,
			1
		]
	],
	[
		[
			1355,
			8404
		],
		[
			7,
			-16
		],
		[
			-1,
			-16
		],
		[
			-6,
			-11
		],
		[
			-13,
			9
		],
		[
			-5,
			8
		],
		[
			5,
			20
		],
		[
			13,
			6
		]
	],
	[
		[
			1295,
			8417
		],
		[
			2,
			-9
		],
		[
			-14,
			-4
		],
		[
			5,
			11
		],
		[
			7,
			2
		]
	],
	[
		[
			1319,
			8419
		],
		[
			9,
			-1
		],
		[
			0,
			-12
		],
		[
			-13,
			5
		],
		[
			4,
			8
		]
	],
	[
		[
			1289,
			8428
		],
		[
			10,
			-1
		],
		[
			4,
			-16
		],
		[
			13,
			-7
		],
		[
			9,
			-30
		],
		[
			9,
			-9
		],
		[
			-1,
			-33
		],
		[
			-16,
			17
		],
		[
			2,
			8
		],
		[
			-21,
			10
		],
		[
			8,
			20
		],
		[
			-11,
			-1
		],
		[
			6,
			13
		],
		[
			-3,
			17
		],
		[
			-9,
			2
		],
		[
			0,
			10
		]
	],
	[
		[
			1315,
			8433
		],
		[
			-5,
			-12
		],
		[
			-6,
			8
		],
		[
			11,
			4
		]
	],
	[
		[
			1328,
			8428
		],
		[
			4,
			-13
		],
		[
			-9,
			9
		],
		[
			0,
			12
		],
		[
			5,
			-8
		]
	],
	[
		[
			1308,
			8454
		],
		[
			9,
			-14
		],
		[
			-10,
			-3
		],
		[
			1,
			17
		]
	],
	[
		[
			1278,
			8457
		],
		[
			7,
			-4
		],
		[
			1,
			-11
		],
		[
			-6,
			-6
		],
		[
			-6,
			-28
		],
		[
			-3,
			4
		],
		[
			0,
			20
		],
		[
			-4,
			26
		],
		[
			11,
			-1
		]
	],
	[
		[
			1283,
			8470
		],
		[
			24,
			-10
		],
		[
			-2,
			-17
		],
		[
			-9,
			13
		],
		[
			7,
			-18
		],
		[
			-16,
			-4
		],
		[
			0,
			23
		],
		[
			-10,
			9
		],
		[
			6,
			4
		]
	],
	[
		[
			745,
			8475
		],
		[
			8,
			0
		],
		[
			-14,
			-10
		],
		[
			6,
			10
		]
	],
	[
		[
			1234,
			8479
		],
		[
			-1,
			-12
		],
		[
			-6,
			-2
		],
		[
			-1,
			19
		],
		[
			8,
			-5
		]
	],
	[
		[
			1237,
			8491
		],
		[
			8,
			2
		],
		[
			9,
			-14
		],
		[
			7,
			-29
		],
		[
			-1,
			-30
		],
		[
			-5,
			0
		],
		[
			-13,
			33
		],
		[
			-1,
			15
		],
		[
			-10,
			18
		],
		[
			6,
			5
		]
	],
	[
		[
			749,
			8519
		],
		[
			11,
			0
		],
		[
			7,
			-8
		],
		[
			-2,
			-10
		],
		[
			8,
			0
		],
		[
			-4,
			-10
		],
		[
			-18,
			4
		],
		[
			10,
			-7
		],
		[
			-18,
			-9
		],
		[
			-14,
			-22
		],
		[
			-10,
			-6
		],
		[
			6,
			10
		],
		[
			-12,
			-1
		],
		[
			-12,
			22
		],
		[
			3,
			14
		],
		[
			7,
			7
		],
		[
			10,
			0
		],
		[
			7,
			-19
		],
		[
			-4,
			28
		],
		[
			5,
			5
		],
		[
			16,
			-5
		],
		[
			-3,
			10
		],
		[
			7,
			-3
		]
	],
	[
		[
			1229,
			8536
		],
		[
			23,
			-12
		],
		[
			-1,
			-13
		],
		[
			-7,
			-1
		],
		[
			-18,
			12
		],
		[
			14,
			-15
		],
		[
			13,
			1
		],
		[
			1,
			-16
		],
		[
			-7,
			0
		],
		[
			-19,
			17
		],
		[
			7,
			-17
		],
		[
			-4,
			-6
		],
		[
			-8,
			6
		],
		[
			-1,
			10
		],
		[
			-12,
			12
		],
		[
			1,
			20
		],
		[
			18,
			2
		]
	],
	[
		[
			1252,
			8544
		],
		[
			6,
			-11
		],
		[
			14,
			-6
		],
		[
			8,
			-16
		],
		[
			-2,
			-5
		],
		[
			2,
			-21
		],
		[
			-19,
			-19
		],
		[
			-1,
			12
		],
		[
			4,
			10
		],
		[
			-5,
			13
		],
		[
			-7,
			43
		]
	],
	[
		[
			761,
			8550
		],
		[
			18,
			-11
		],
		[
			-6,
			-8
		],
		[
			-18,
			-4
		],
		[
			-10,
			2
		],
		[
			1,
			9
		],
		[
			10,
			1
		],
		[
			5,
			11
		]
	],
	[
		[
			913,
			8659
		],
		[
			5,
			-3
		],
		[
			-25,
			-29
		],
		[
			20,
			32
		]
	],
	[
		[
			385,
			8661
		],
		[
			13,
			-6
		],
		[
			2,
			-22
		],
		[
			-19,
			-5
		],
		[
			-10,
			2
		],
		[
			-19,
			13
		],
		[
			-4,
			7
		],
		[
			16,
			0
		],
		[
			9,
			9
		],
		[
			12,
			2
		]
	],
	[
		[
			929,
			8665
		],
		[
			13,
			-4
		],
		[
			-15,
			-9
		],
		[
			2,
			13
		]
	],
	[
		[
			897,
			8667
		],
		[
			-2,
			-19
		],
		[
			-4,
			10
		],
		[
			6,
			9
		]
	],
	[
		[
			231,
			8857
		],
		[
			0,
			-6
		],
		[
			17,
			-7
		],
		[
			20,
			7
		],
		[
			23,
			-20
		],
		[
			21,
			-2
		],
		[
			-2,
			-9
		],
		[
			-15,
			1
		],
		[
			-9,
			-13
		],
		[
			-3,
			10
		],
		[
			-28,
			19
		],
		[
			-17,
			-8
		],
		[
			-13,
			10
		],
		[
			6,
			18
		]
	],
	[
		[
			1387,
			8402
		],
		[
			-3,
			-8
		],
		[
			4,
			-28
		],
		[
			-10,
			-21
		],
		[
			-9,
			-8
		],
		[
			-7,
			2
		],
		[
			-3,
			23
		],
		[
			6,
			6
		],
		[
			-1,
			24
		],
		[
			-15,
			16
		],
		[
			-8,
			-7
		],
		[
			-7,
			-22
		],
		[
			-9,
			13
		],
		[
			7,
			4
		],
		[
			5,
			24
		],
		[
			-18,
			22
		],
		[
			-11,
			25
		],
		[
			-19,
			8
		],
		[
			12,
			9
		],
		[
			-11,
			10
		],
		[
			-3,
			12
		],
		[
			14,
			-6
		],
		[
			-15,
			12
		],
		[
			-15,
			23
		],
		[
			-16,
			11
		],
		[
			-4,
			24
		],
		[
			-6,
			1
		],
		[
			-1,
			17
		],
		[
			-6,
			-11
		],
		[
			7,
			-17
		],
		[
			1,
			-24
		],
		[
			-13,
			11
		],
		[
			-8,
			-2
		],
		[
			2,
			13
		],
		[
			-8,
			12
		],
		[
			-3,
			-4
		],
		[
			-17,
			8
		],
		[
			19,
			-18
		],
		[
			2,
			-12
		],
		[
			-9,
			-4
		],
		[
			-20,
			5
		],
		[
			-23,
			23
		],
		[
			-9,
			16
		],
		[
			-34,
			19
		],
		[
			-11,
			9
		],
		[
			12,
			10
		],
		[
			-5,
			11
		],
		[
			-18,
			-12
		],
		[
			-9,
			0
		],
		[
			-21,
			9
		],
		[
			3,
			11
		],
		[
			-13,
			-5
		],
		[
			-31,
			8
		],
		[
			-30,
			-6
		],
		[
			-12,
			12
		],
		[
			-16,
			5
		],
		[
			3,
			18
		],
		[
			-11,
			-14
		],
		[
			-21,
			5
		],
		[
			9,
			13
		],
		[
			-18,
			-1
		],
		[
			-16,
			19
		],
		[
			-12,
			1
		],
		[
			-2,
			-7
		],
		[
			-15,
			-3
		],
		[
			-3,
			6
		],
		[
			9,
			19
		],
		[
			-17,
			-18
		],
		[
			2,
			-20
		],
		[
			8,
			-8
		],
		[
			-6,
			-3
		],
		[
			-8,
			-27
		],
		[
			-18,
			1
		],
		[
			-5,
			-5
		],
		[
			-2,
			13
		],
		[
			-12,
			-25
		],
		[
			-13,
			3
		],
		[
			-7,
			-13
		],
		[
			-19,
			-17
		],
		[
			-16,
			-2
		],
		[
			-6,
			6
		],
		[
			3,
			9
		],
		[
			19,
			10
		],
		[
			2,
			8
		],
		[
			-11,
			-6
		],
		[
			-10,
			7
		],
		[
			4,
			16
		],
		[
			8,
			10
		],
		[
			5,
			19
		],
		[
			-5,
			8
		],
		[
			27,
			21
		],
		[
			6,
			-6
		],
		[
			18,
			3
		],
		[
			-14,
			10
		],
		[
			4,
			5
		],
		[
			-19,
			4
		],
		[
			-15,
			-15
		],
		[
			-9,
			-2
		],
		[
			-20,
			-27
		],
		[
			-7,
			-16
		],
		[
			-11,
			-2
		],
		[
			9,
			-10
		],
		[
			-18,
			-24
		],
		[
			-11,
			0
		],
		[
			-4,
			-11
		],
		[
			-9,
			-5
		],
		[
			-3,
			-20
		],
		[
			10,
			3
		],
		[
			13,
			-8
		],
		[
			2,
			-6
		],
		[
			-11,
			-12
		],
		[
			-5,
			0
		],
		[
			-14,
			-31
		],
		[
			-4,
			7
		],
		[
			-2,
			-11
		],
		[
			-12,
			1
		],
		[
			-9,
			-17
		],
		[
			-9,
			2
		],
		[
			-2,
			-13
		],
		[
			-10,
			-1
		],
		[
			-14,
			-15
		],
		[
			7,
			-5
		],
		[
			-7,
			-12
		],
		[
			-5,
			4
		],
		[
			-12,
			-16
		],
		[
			-17,
			-5
		],
		[
			-2,
			-11
		],
		[
			-13,
			-1
		],
		[
			-4,
			-8
		],
		[
			7,
			-10
		],
		[
			-10,
			-4
		],
		[
			-1,
			-7
		],
		[
			-22,
			-6
		],
		[
			-5,
			-17
		],
		[
			-6,
			16
		],
		[
			-20,
			-21
		],
		[
			-10,
			2
		],
		[
			-12,
			-10
		],
		[
			-5,
			2
		],
		[
			6,
			12
		],
		[
			-10,
			1
		],
		[
			-6,
			-22
		],
		[
			-9,
			-11
		],
		[
			-12,
			8
		],
		[
			-4,
			-14
		],
		[
			-7,
			2
		],
		[
			-9,
			-9
		],
		[
			0,
			18
		],
		[
			10,
			3
		],
		[
			22,
			30
		],
		[
			12,
			12
		],
		[
			9,
			3
		],
		[
			34,
			-7
		],
		[
			-10,
			9
		],
		[
			5,
			17
		],
		[
			16,
			15
		],
		[
			24,
			17
		],
		[
			9,
			-4
		],
		[
			-1,
			15
		],
		[
			10,
			16
		],
		[
			18,
			15
		],
		[
			2,
			46
		],
		[
			12,
			18
		],
		[
			5,
			16
		],
		[
			-8,
			-7
		],
		[
			-25,
			-13
		],
		[
			-11,
			12
		],
		[
			1,
			10
		],
		[
			-9,
			-10
		],
		[
			4,
			-20
		],
		[
			-11,
			-2
		],
		[
			-14,
			29
		],
		[
			-8,
			-10
		],
		[
			-12,
			17
		],
		[
			-19,
			-11
		],
		[
			-20,
			-18
		],
		[
			-11,
			4
		],
		[
			11,
			7
		],
		[
			-1,
			13
		],
		[
			6,
			7
		],
		[
			-12,
			2
		],
		[
			0,
			15
		],
		[
			7,
			6
		],
		[
			-20,
			46
		],
		[
			-1,
			-17
		],
		[
			-16,
			-8
		],
		[
			-23,
			-4
		],
		[
			-9,
			6
		],
		[
			-13,
			23
		],
		[
			-19,
			12
		],
		[
			20,
			19
		],
		[
			18,
			-3
		],
		[
			7,
			-12
		],
		[
			9,
			7
		],
		[
			-4,
			7
		],
		[
			-29,
			2
		],
		[
			-20,
			20
		],
		[
			-7,
			-6
		],
		[
			-9,
			14
		],
		[
			0,
			21
		],
		[
			-6,
			7
		],
		[
			15,
			2
		],
		[
			-4,
			13
		],
		[
			18,
			26
		],
		[
			8,
			-3
		],
		[
			-3,
			14
		],
		[
			5,
			17
		],
		[
			11,
			0
		],
		[
			-8,
			7
		],
		[
			7,
			5
		],
		[
			17,
			0
		],
		[
			2,
			-11
		],
		[
			17,
			1
		],
		[
			20,
			24
		],
		[
			25,
			-1
		],
		[
			18,
			17
		],
		[
			-6,
			30
		],
		[
			-13,
			9
		],
		[
			10,
			4
		],
		[
			9,
			13
		],
		[
			-10,
			12
		],
		[
			-41,
			-24
		],
		[
			-17,
			-5
		],
		[
			-12,
			9
		],
		[
			-18,
			0
		],
		[
			-19,
			-8
		],
		[
			-33,
			8
		],
		[
			-8,
			6
		],
		[
			3,
			12
		],
		[
			-11,
			10
		],
		[
			7,
			9
		],
		[
			13,
			2
		],
		[
			-38,
			8
		],
		[
			-18,
			10
		],
		[
			37,
			28
		],
		[
			24,
			9
		],
		[
			16,
			13
		],
		[
			16,
			7
		],
		[
			29,
			2
		],
		[
			-7,
			-11
		],
		[
			7,
			-19
		],
		[
			26,
			2
		],
		[
			24,
			-8
		],
		[
			11,
			18
		],
		[
			13,
			-3
		],
		[
			-13,
			10
		],
		[
			-11,
			-2
		],
		[
			-2,
			11
		],
		[
			-15,
			10
		],
		[
			-5,
			9
		],
		[
			9,
			3
		],
		[
			7,
			-17
		],
		[
			12,
			-11
		],
		[
			10,
			4
		],
		[
			14,
			-9
		],
		[
			16,
			2
		],
		[
			-3,
			14
		],
		[
			-23,
			0
		],
		[
			-9,
			-7
		],
		[
			-10,
			10
		],
		[
			2,
			20
		],
		[
			-23,
			-2
		],
		[
			-30,
			5
		],
		[
			-10,
			27
		],
		[
			-34,
			25
		],
		[
			-20,
			9
		],
		[
			-16,
			11
		],
		[
			9,
			17
		],
		[
			0,
			14
		],
		[
			16,
			-2
		],
		[
			37,
			4
		],
		[
			19,
			11
		],
		[
			15,
			16
		],
		[
			2,
			19
		],
		[
			29,
			33
		],
		[
			26,
			0
		],
		[
			45,
			27
		],
		[
			39,
			4
		],
		[
			21,
			14
		],
		[
			12,
			13
		],
		[
			33,
			-7
		],
		[
			-12,
			-12
		],
		[
			11,
			-6
		],
		[
			16,
			16
		],
		[
			13,
			-7
		],
		[
			2,
			-12
		],
		[
			19,
			5
		],
		[
			38,
			-1
		],
		[
			9,
			-4
		],
		[
			-12,
			-15
		],
		[
			24,
			0
		],
		[
			-6,
			-6
		],
		[
			32,
			3
		],
		[
			11,
			-5
		],
		[
			30,
			5
		],
		[
			31,
			-8
		],
		[
			27,
			-11
		],
		[
			40,
			0
		],
		[
			30,
			-12
		],
		[
			40,
			9
		],
		[
			52,
			-27
		],
		[
			12,
			0
		]
	],
	[
		[
			2912,
			6333
		],
		[
			-2,
			-4
		]
	],
	[
		[
			2914,
			6329
		],
		[
			-1,
			4
		]
	],
	[
		[
			6651,
			7782
		],
		[
			-7,
			-26
		],
		[
			12,
			-19
		],
		[
			-3,
			-12
		],
		[
			11,
			5
		],
		[
			3,
			8
		],
		[
			-2,
			16
		],
		[
			3,
			11
		]
	],
	[
		[
			6601,
			7610
		],
		[
			-7,
			11
		],
		[
			-5,
			-2
		],
		[
			-4,
			-22
		]
	],
	[
		[
			6627,
			7805
		],
		[
			-10,
			-35
		],
		[
			2,
			-18
		],
		[
			4,
			-10
		],
		[
			9,
			17
		],
		[
			-3,
			20
		],
		[
			3,
			6
		],
		[
			-1,
			16
		]
	],
	[
		[
			3301,
			5940
		],
		[
			-4,
			4
		],
		[
			5,
			8
		],
		[
			-1,
			-12
		]
	],
	[
		[
			3313,
			5694
		],
		[
			1,
			-6
		],
		[
			-5,
			-8
		],
		[
			-9,
			-2
		],
		[
			1,
			7
		],
		[
			12,
			9
		]
	],
	[
		[
			3303,
			5691
		],
		[
			4,
			12
		],
		[
			2,
			-5
		],
		[
			-6,
			-7
		]
	],
	[
		[
			3228,
			5816
		],
		[
			-8,
			-8
		],
		[
			-9,
			6
		],
		[
			4,
			7
		],
		[
			6,
			-5
		],
		[
			4,
			10
		],
		[
			3,
			-10
		]
	],
	[
		[
			3018,
			5865
		],
		[
			-3,
			-7
		],
		[
			-14,
			-7
		],
		[
			0,
			-13
		],
		[
			10,
			-38
		],
		[
			-1,
			-16
		],
		[
			-4,
			-6
		],
		[
			-10,
			-30
		],
		[
			5,
			-18
		],
		[
			6,
			-7
		],
		[
			-1,
			-15
		],
		[
			6,
			-5
		],
		[
			9,
			7
		],
		[
			5,
			10
		],
		[
			-1,
			32
		],
		[
			-11,
			30
		],
		[
			-2,
			23
		],
		[
			3,
			10
		],
		[
			4,
			0
		],
		[
			12,
			13
		],
		[
			18,
			8
		],
		[
			5,
			9
		],
		[
			8,
			-2
		],
		[
			-2,
			13
		],
		[
			-11,
			-5
		],
		[
			-2,
			13
		],
		[
			2,
			16
		],
		[
			5,
			5
		],
		[
			6,
			-10
		],
		[
			2,
			-22
		],
		[
			4,
			-10
		],
		[
			12,
			3
		],
		[
			15,
			-10
		],
		[
			7,
			-12
		],
		[
			4,
			-15
		],
		[
			-2,
			-7
		],
		[
			5,
			-15
		],
		[
			8,
			-1
		],
		[
			17,
			4
		],
		[
			6,
			4
		],
		[
			21,
			2
		],
		[
			11,
			-20
		],
		[
			11,
			-9
		],
		[
			11,
			-5
		],
		[
			8,
			2
		],
		[
			4,
			9
		],
		[
			5,
			0
		],
		[
			2,
			8
		],
		[
			20,
			5
		],
		[
			-5,
			5
		],
		[
			-9,
			1
		],
		[
			10,
			6
		],
		[
			7,
			-3
		],
		[
			11,
			6
		],
		[
			12,
			1
		],
		[
			16,
			-4
		],
		[
			8,
			4
		],
		[
			-2,
			-6
		],
		[
			-10,
			-6
		],
		[
			-16,
			0
		],
		[
			1,
			-9
		],
		[
			5,
			-5
		],
		[
			1,
			-12
		],
		[
			-9,
			-1
		],
		[
			5,
			-4
		],
		[
			8,
			8
		],
		[
			5,
			-25
		],
		[
			2,
			17
		],
		[
			11,
			-10
		],
		[
			7,
			-3
		],
		[
			-2,
			7
		],
		[
			13,
			-19
		],
		[
			4,
			1
		],
		[
			7,
			-12
		],
		[
			-9,
			-24
		],
		[
			-3,
			-22
		],
		[
			-12,
			0
		],
		[
			10,
			-11
		],
		[
			3,
			6
		],
		[
			14,
			6
		],
		[
			6,
			-4
		],
		[
			3,
			6
		],
		[
			9,
			-4
		]
	],
	[
		[
			7888,
			5785
		],
		[
			0,
			-17
		],
		[
			-4,
			12
		],
		[
			4,
			5
		]
	],
	[
		[
			7999,
			6420
		],
		[
			-7,
			1
		],
		[
			-4,
			-12
		],
		[
			-7,
			-3
		],
		[
			1,
			-12
		],
		[
			-6,
			-6
		],
		[
			-5,
			4
		],
		[
			-9,
			-2
		],
		[
			4,
			-16
		],
		[
			-8,
			-8
		],
		[
			2,
			-17
		],
		[
			-7,
			-4
		],
		[
			-4,
			-11
		],
		[
			-7,
			-4
		],
		[
			-3,
			-15
		],
		[
			-1,
			-23
		],
		[
			-5,
			-13
		],
		[
			7,
			-30
		],
		[
			7,
			-15
		],
		[
			11,
			-17
		],
		[
			-1,
			-15
		],
		[
			8,
			-21
		],
		[
			9,
			-14
		],
		[
			4,
			-12
		],
		[
			16,
			-29
		],
		[
			6,
			-2
		],
		[
			16,
			-47
		],
		[
			8,
			-11
		],
		[
			1,
			-21
		],
		[
			5,
			-18
		],
		[
			-2,
			-5
		],
		[
			6,
			-25
		],
		[
			0,
			-35
		],
		[
			2,
			-3
		],
		[
			0,
			-23
		],
		[
			3,
			-13
		],
		[
			-6,
			-10
		],
		[
			0,
			-42
		],
		[
			-3,
			-5
		],
		[
			4,
			-7
		],
		[
			-4,
			-10
		],
		[
			-2,
			4
		],
		[
			0,
			-16
		],
		[
			-7,
			-2
		],
		[
			-2,
			-8
		],
		[
			-4,
			0
		],
		[
			-8,
			-14
		],
		[
			-6,
			-1
		],
		[
			-2,
			-13
		],
		[
			-5,
			0
		],
		[
			-11,
			-13
		],
		[
			-13,
			0
		],
		[
			-5,
			12
		],
		[
			1,
			-23
		],
		[
			-11,
			2
		],
		[
			11,
			-9
		],
		[
			-4,
			-11
		],
		[
			-6,
			4
		],
		[
			7,
			-11
		],
		[
			-3,
			-2
		],
		[
			-12,
			24
		],
		[
			0,
			-5
		],
		[
			10,
			-18
		],
		[
			2,
			-11
		],
		[
			-5,
			-6
		],
		[
			-10,
			15
		],
		[
			4,
			-19
		],
		[
			-1,
			-6
		],
		[
			-17,
			-13
		],
		[
			-12,
			-29
		],
		[
			-11,
			-2
		],
		[
			5,
			9
		],
		[
			-2,
			10
		],
		[
			0,
			36
		],
		[
			2,
			17
		],
		[
			6,
			7
		],
		[
			-10,
			15
		],
		[
			-5,
			-5
		],
		[
			-3,
			16
		]
	],
	[
		[
			9706,
			4050
		],
		[
			-7,
			13
		],
		[
			4,
			7
		],
		[
			3,
			-20
		]
	],
	[
		[
			9699,
			4104
		],
		[
			2,
			-14
		],
		[
			-8,
			6
		],
		[
			0,
			12
		],
		[
			6,
			-4
		]
	],
	[
		[
			9675,
			4172
		],
		[
			7,
			-8
		],
		[
			-6,
			-8
		],
		[
			-6,
			7
		],
		[
			5,
			9
		]
	],
	[
		[
			9671,
			4228
		],
		[
			8,
			-15
		],
		[
			-7,
			1
		],
		[
			-1,
			14
		]
	],
	[
		[
			9675,
			4243
		],
		[
			-6,
			-2
		],
		[
			-6,
			7
		],
		[
			7,
			9
		],
		[
			5,
			-14
		]
	],
	[
		[
			9650,
			4255
		],
		[
			10,
			-14
		],
		[
			1,
			-7
		],
		[
			-10,
			-6
		],
		[
			-4,
			27
		],
		[
			-5,
			1
		],
		[
			1,
			12
		],
		[
			4,
			-1
		],
		[
			3,
			-12
		]
	],
	[
		[
			9672,
			4262
		],
		[
			-3,
			21
		],
		[
			1,
			9
		],
		[
			3,
			-20
		],
		[
			-1,
			-10
		]
	],
	[
		[
			9662,
			4292
		],
		[
			-5,
			2
		],
		[
			9,
			9
		],
		[
			-4,
			-11
		]
	],
	[
		[
			9671,
			4298
		],
		[
			-2,
			1
		],
		[
			-1,
			24
		],
		[
			2,
			-2
		],
		[
			1,
			-23
		]
	],
	[
		[
			9633,
			4310
		],
		[
			4,
			2
		],
		[
			0,
			11
		],
		[
			5,
			-11
		],
		[
			3,
			-23
		],
		[
			-11,
			-7
		],
		[
			-7,
			15
		],
		[
			1,
			11
		],
		[
			-3,
			15
		],
		[
			1,
			17
		],
		[
			5,
			-11
		],
		[
			2,
			-19
		]
	],
	[
		[
			9653,
			4368
		],
		[
			1,
			-9
		],
		[
			-5,
			0
		],
		[
			4,
			9
		]
	],
	[
		[
			9654,
			4385
		],
		[
			-4,
			-3
		],
		[
			-1,
			10
		],
		[
			5,
			-7
		]
	],
	[
		[
			5917,
			7177
		],
		[
			-8,
			1
		]
	],
	[
		[
			233,
			4380
		],
		[
			5,
			-6
		],
		[
			-14,
			2
		],
		[
			-4,
			7
		],
		[
			7,
			5
		],
		[
			6,
			-8
		]
	],
	[
		[
			213,
			4406
		],
		[
			3,
			-6
		],
		[
			-1,
			-12
		],
		[
			-9,
			0
		],
		[
			-5,
			15
		],
		[
			12,
			3
		]
	],
	[
		[
			6488,
			5914
		],
		[
			7,
			-6
		],
		[
			7,
			6
		],
		[
			10,
			-9
		],
		[
			-9,
			-11
		],
		[
			-10,
			-3
		],
		[
			-6,
			2
		],
		[
			-5,
			12
		],
		[
			6,
			9
		]
	],
	[
		[
			6474,
			6141
		],
		[
			-14,
			-9
		],
		[
			-10,
			-18
		],
		[
			-2,
			-12
		],
		[
			2,
			-20
		],
		[
			-10,
			-7
		],
		[
			-13,
			-15
		],
		[
			-23,
			-11
		],
		[
			-11,
			-11
		],
		[
			-4,
			0
		],
		[
			-25,
			-18
		],
		[
			-3,
			-12
		],
		[
			-8,
			-16
		],
		[
			-6,
			-3
		],
		[
			-14,
			3
		],
		[
			-10,
			-9
		],
		[
			-6,
			-13
		],
		[
			-15,
			-8
		],
		[
			-5,
			-6
		],
		[
			-14,
			0
		],
		[
			-16,
			-6
		],
		[
			-7,
			-15
		],
		[
			-15,
			-17
		],
		[
			-7,
			3
		],
		[
			-4,
			-8
		],
		[
			-14,
			-5
		],
		[
			-10,
			9
		],
		[
			-3,
			-4
		],
		[
			-7,
			35
		],
		[
			2,
			25
		],
		[
			-6,
			21
		],
		[
			-2,
			16
		],
		[
			-3,
			43
		],
		[
			-6,
			7
		],
		[
			4,
			2
		],
		[
			-3,
			17
		],
		[
			3,
			18
		],
		[
			-1,
			29
		]
	],
	[
		[
			5913,
			3637
		],
		[
			-1,
			-16
		],
		[
			-5,
			-23
		],
		[
			-3,
			-38
		],
		[
			-5,
			-21
		],
		[
			-10,
			-19
		],
		[
			-7,
			-3
		],
		[
			-13,
			-27
		],
		[
			-21,
			-68
		],
		[
			-4,
			-16
		],
		[
			-15,
			-32
		],
		[
			-4,
			-4
		],
		[
			-16,
			-28
		],
		[
			-9,
			-21
		],
		[
			-13,
			-22
		],
		[
			-25,
			-35
		],
		[
			-27,
			-26
		],
		[
			-15,
			4
		],
		[
			-9,
			-9
		],
		[
			0,
			-11
		],
		[
			-17,
			5
		],
		[
			-4,
			-12
		],
		[
			-11,
			1
		],
		[
			-8,
			6
		],
		[
			-16,
			4
		],
		[
			-6,
			-7
		],
		[
			-23,
			6
		],
		[
			-10,
			-4
		],
		[
			-12,
			-19
		],
		[
			-7,
			3
		],
		[
			-6,
			-5
		],
		[
			-11,
			4
		],
		[
			-1,
			-6
		],
		[
			-11,
			0
		],
		[
			-14,
			-20
		],
		[
			-9,
			3
		],
		[
			-9,
			9
		],
		[
			0,
			11
		],
		[
			-6,
			4
		],
		[
			-8,
			-2
		],
		[
			0,
			17
		],
		[
			-10,
			-2
		],
		[
			0,
			-13
		],
		[
			-4,
			19
		],
		[
			5,
			10
		],
		[
			-2,
			12
		],
		[
			-7,
			16
		],
		[
			-4,
			20
		],
		[
			-4,
			-1
		],
		[
			1,
			18
		],
		[
			7,
			-2
		],
		[
			4,
			8
		],
		[
			1,
			20
		],
		[
			-2,
			22
		],
		[
			-4,
			17
		],
		[
			-9,
			20
		],
		[
			-7,
			28
		],
		[
			-8,
			24
		],
		[
			-6,
			42
		],
		[
			-6,
			29
		],
		[
			-7,
			15
		],
		[
			-3,
			15
		]
	],
	[
		[
			5815,
			3905
		],
		[
			12,
			3
		],
		[
			14,
			-12
		],
		[
			15,
			3
		],
		[
			13,
			-7
		]
	],
	[
		[
			5844,
			4282
		],
		[
			-15,
			1
		],
		[
			-13,
			-5
		],
		[
			-15,
			-18
		],
		[
			0,
			-21
		],
		[
			-3,
			-8
		]
	],
	[
		[
			5798,
			4231
		],
		[
			-3,
			3
		],
		[
			-13,
			-9
		],
		[
			-5,
			-13
		],
		[
			-12,
			-14
		],
		[
			-13,
			-38
		],
		[
			-2,
			-11
		]
	],
	[
		[
			5750,
			4149
		],
		[
			-9,
			-7
		],
		[
			-14,
			11
		],
		[
			-7,
			-7
		],
		[
			-7,
			11
		],
		[
			-12,
			1
		]
	],
	[
		[
			5792,
			4643
		],
		[
			5,
			5
		],
		[
			9,
			23
		],
		[
			3,
			15
		],
		[
			-7,
			8
		]
	],
	[
		[
			5849,
			4709
		],
		[
			-4,
			-14
		],
		[
			7,
			-1
		],
		[
			9,
			-18
		],
		[
			5,
			4
		],
		[
			-1,
			8
		]
	],
	[
		[
			5750,
			4149
		],
		[
			10,
			22
		],
		[
			5,
			5
		],
		[
			4,
			17
		],
		[
			11,
			9
		],
		[
			0,
			11
		],
		[
			8,
			0
		],
		[
			8,
			9
		],
		[
			1,
			-7
		],
		[
			8,
			12
		],
		[
			-7,
			4
		]
	]
];
var objects$2 = {
	units: {
		geometries: [
			{
				arcs: [
					[
						0,
						1,
						2,
						3,
						4,
						5
					]
				],
				id: "AFG",
				properties: {
					name: "Afghanistan"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							6,
							7,
							8,
							9
						]
					],
					[
						[
							10,
							11,
							12
						]
					]
				],
				id: "AGO",
				properties: {
					name: "Angola"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							13,
							14
						]
					],
					[
						[
							15,
							16
						]
					],
					[
						[
							17,
							18,
							19,
							20,
							21,
							22,
							23,
							24,
							25,
							26,
							27,
							28,
							29,
							30
						]
					]
				],
				id: "ALB",
				properties: {
					name: "Albania"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							31
						]
					]
				],
				id: "ALD",
				properties: {
					name: "Aland"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						32,
						33
					]
				],
				id: "AND",
				properties: {
					name: "Andorra"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							34
						]
					],
					[
						[
							35,
							36,
							37,
							38,
							39
						],
						[
							40
						]
					]
				],
				id: "ARE",
				properties: {
					name: "United Arab Emirates"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							41,
							42
						]
					],
					[
						[
							43,
							44
						]
					],
					[
						[
							45,
							46,
							47,
							48,
							49,
							50
						]
					]
				],
				id: "ARG",
				properties: {
					name: "Argentina"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							51
						]
					],
					[
						[
							52,
							53,
							54,
							55,
							56
						],
						[
							57
						],
						[
							58
						]
					]
				],
				id: "ARM",
				properties: {
					name: "Armenia"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							59
						]
					],
					[
						[
							60
						]
					],
					[
						[
							61
						]
					],
					[
						[
							62
						]
					],
					[
						[
							63
						]
					],
					[
						[
							64
						]
					],
					[
						[
							65
						]
					],
					[
						[
							66
						]
					],
					[
						[
							67
						]
					],
					[
						[
							68
						]
					],
					[
						[
							69
						]
					],
					[
						[
							70
						]
					],
					[
						[
							71
						]
					],
					[
						[
							72
						]
					],
					[
						[
							73
						]
					],
					[
						[
							74
						]
					],
					[
						[
							75
						]
					],
					[
						[
							76
						]
					],
					[
						[
							77
						]
					],
					[
						[
							78
						]
					],
					[
						[
							79
						]
					],
					[
						[
							80
						]
					],
					[
						[
							81
						]
					],
					[
						[
							82
						]
					],
					[
						[
							83
						]
					],
					[
						[
							84
						]
					],
					[
						[
							85
						]
					],
					[
						[
							86
						]
					],
					[
						[
							87
						]
					],
					[
						[
							88
						]
					],
					[
						[
							89
						]
					],
					[
						[
							90
						]
					],
					[
						[
							91
						]
					],
					[
						[
							92
						]
					],
					[
						[
							93
						]
					],
					[
						[
							94
						]
					],
					[
						[
							95
						]
					],
					[
						[
							96
						]
					],
					[
						[
							97
						]
					],
					[
						[
							98
						]
					],
					[
						[
							99
						]
					],
					[
						[
							100
						]
					],
					[
						[
							101
						]
					],
					[
						[
							102
						]
					],
					[
						[
							103
						]
					],
					[
						[
							104
						]
					],
					[
						[
							105
						]
					],
					[
						[
							106
						]
					],
					[
						[
							107
						]
					],
					[
						[
							108
						]
					],
					[
						[
							109
						]
					],
					[
						[
							110
						]
					],
					[
						[
							111
						]
					],
					[
						[
							112
						]
					],
					[
						[
							113
						]
					],
					[
						[
							114
						]
					],
					[
						[
							115
						]
					],
					[
						[
							116
						]
					],
					[
						[
							117
						]
					],
					[
						[
							118
						]
					],
					[
						[
							119
						]
					],
					[
						[
							120
						]
					]
				],
				id: "ATA",
				properties: {
					name: "Antarctica"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							121
						]
					]
				],
				id: "ATF",
				properties: {
					name: "Fr. S. Antarctic Lands"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							122
						]
					],
					[
						[
							123
						]
					],
					[
						[
							124
						]
					],
					[
						[
							125
						]
					],
					[
						[
							126
						]
					],
					[
						[
							127
						]
					],
					[
						[
							128
						]
					],
					[
						[
							129
						]
					],
					[
						[
							130
						]
					],
					[
						[
							131
						]
					],
					[
						[
							132
						]
					],
					[
						[
							133
						]
					],
					[
						[
							134
						]
					],
					[
						[
							135
						]
					],
					[
						[
							136
						]
					],
					[
						[
							137
						]
					],
					[
						[
							138
						]
					],
					[
						[
							139
						]
					],
					[
						[
							140
						]
					]
				],
				id: "AUS",
				properties: {
					name: "Australia"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						141,
						142,
						143,
						144,
						145,
						146,
						147,
						148,
						149,
						150
					]
				],
				id: "AUT",
				properties: {
					name: "Austria"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							151,
							152,
							-55
						]
					],
					[
						[
							-59
						]
					],
					[
						[
							-58
						]
					],
					[
						[
							153,
							154,
							155,
							-53,
							156
						],
						[
							-52
						]
					]
				],
				id: "AZE",
				properties: {
					name: "Azerbaijan"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						157,
						158,
						159,
						160
					]
				],
				id: "BDI",
				properties: {
					name: "Burundi"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						161,
						162,
						163,
						164,
						165,
						166,
						167
					]
				],
				id: "BEL",
				properties: {
					name: "Belgium"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						168,
						169,
						170,
						171,
						172
					]
				],
				id: "BEN",
				properties: {
					name: "Benin"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						173,
						-172,
						174,
						175,
						176,
						177
					]
				],
				id: "BFA",
				properties: {
					name: "Burkina Faso"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							178
						]
					],
					[
						[
							179
						]
					],
					[
						[
							180,
							181,
							182
						]
					]
				],
				id: "BGD",
				properties: {
					name: "Bangladesh"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						183,
						184,
						185,
						186,
						187,
						188
					]
				],
				id: "BGR",
				properties: {
					name: "Bulgaria"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						189
					]
				],
				id: "BHR",
				properties: {
					name: "Bahrain"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							190
						]
					],
					[
						[
							191
						]
					],
					[
						[
							192
						]
					],
					[
						[
							193
						]
					],
					[
						[
							194
						]
					],
					[
						[
							195
						]
					],
					[
						[
							196
						]
					],
					[
						[
							197
						]
					],
					[
						[
							198
						]
					],
					[
						[
							199
						]
					],
					[
						[
							200
						]
					]
				],
				id: "BHS",
				properties: {
					name: "Bahamas"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						201,
						202,
						203,
						204,
						205
					]
				],
				id: "BIH",
				properties: {
					name: "Bosnia and Herz."
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						206,
						207,
						208,
						209,
						210
					]
				],
				id: "BLR",
				properties: {
					name: "Belarus"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							211,
							212,
							213
						]
					]
				],
				id: "BLZ",
				properties: {
					name: "Belize"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							214,
							215
						]
					],
					[
						[
							216,
							-51,
							217,
							218,
							219,
							220,
							221
						]
					]
				],
				id: "BOL",
				properties: {
					name: "Bolivia"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							222
						]
					],
					[
						[
							223
						]
					],
					[
						[
							224
						]
					],
					[
						[
							225
						]
					],
					[
						[
							226
						]
					],
					[
						[
							227
						]
					],
					[
						[
							228
						]
					],
					[
						[
							229
						]
					],
					[
						[
							230
						]
					],
					[
						[
							231
						]
					],
					[
						[
							232
						]
					],
					[
						[
							233
						]
					],
					[
						[
							234
						]
					],
					[
						[
							235
						]
					],
					[
						[
							236
						]
					],
					[
						[
							237
						]
					],
					[
						[
							238,
							239,
							240,
							241,
							242,
							243,
							-47,
							244,
							245,
							246,
							-222,
							247,
							248,
							249,
							250
						]
					]
				],
				id: "BRA",
				properties: {
					name: "Brazil"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						251
					]
				],
				id: "BRB",
				properties: {
					name: "Barbados"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							252,
							253
						]
					],
					[
						[
							254,
							255
						]
					]
				],
				id: "BRN",
				properties: {
					name: "Brunei"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						256,
						257
					]
				],
				id: "BTN",
				properties: {
					name: "Bhutan"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						258,
						259,
						260
					]
				],
				id: "BWA",
				properties: {
					name: "Botswana"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						261,
						262,
						263,
						264,
						265,
						266
					]
				],
				id: "CAF",
				properties: {
					name: "Central African Rep."
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							267
						]
					],
					[
						[
							268
						]
					],
					[
						[
							269
						]
					],
					[
						[
							270
						]
					],
					[
						[
							271
						]
					],
					[
						[
							272
						]
					],
					[
						[
							273
						]
					],
					[
						[
							274,
							275,
							276,
							277
						]
					],
					[
						[
							278
						]
					],
					[
						[
							279
						]
					],
					[
						[
							280
						]
					],
					[
						[
							281
						]
					],
					[
						[
							282
						]
					],
					[
						[
							283
						]
					],
					[
						[
							284
						]
					],
					[
						[
							285
						]
					],
					[
						[
							286
						]
					],
					[
						[
							287
						]
					],
					[
						[
							288
						]
					],
					[
						[
							289
						]
					],
					[
						[
							290
						]
					],
					[
						[
							291
						]
					],
					[
						[
							292
						]
					],
					[
						[
							293
						]
					],
					[
						[
							294
						]
					],
					[
						[
							295
						]
					],
					[
						[
							296
						]
					],
					[
						[
							297
						]
					],
					[
						[
							298
						]
					],
					[
						[
							299
						]
					],
					[
						[
							300
						]
					],
					[
						[
							301
						]
					],
					[
						[
							302
						]
					],
					[
						[
							303
						]
					],
					[
						[
							304
						]
					],
					[
						[
							305
						]
					],
					[
						[
							306
						]
					],
					[
						[
							307
						]
					],
					[
						[
							308
						]
					],
					[
						[
							309
						]
					],
					[
						[
							310
						]
					],
					[
						[
							311
						]
					],
					[
						[
							312
						]
					],
					[
						[
							313
						]
					],
					[
						[
							314
						]
					],
					[
						[
							315
						]
					],
					[
						[
							316
						]
					],
					[
						[
							317
						]
					],
					[
						[
							318
						]
					],
					[
						[
							319
						]
					],
					[
						[
							320
						]
					],
					[
						[
							321
						]
					],
					[
						[
							322
						]
					],
					[
						[
							323
						]
					],
					[
						[
							324
						]
					],
					[
						[
							325
						]
					],
					[
						[
							326
						]
					],
					[
						[
							327
						]
					],
					[
						[
							328
						]
					],
					[
						[
							329
						]
					],
					[
						[
							330
						]
					],
					[
						[
							331
						]
					],
					[
						[
							332
						]
					],
					[
						[
							333,
							334,
							335,
							336,
							337,
							338,
							339,
							340,
							341,
							342,
							343,
							344,
							345,
							-346,
							346,
							347
						]
					],
					[
						[
							348
						]
					],
					[
						[
							349
						]
					],
					[
						[
							350
						]
					],
					[
						[
							351
						]
					],
					[
						[
							352
						]
					],
					[
						[
							353
						]
					],
					[
						[
							354
						]
					],
					[
						[
							355
						]
					],
					[
						[
							356
						]
					],
					[
						[
							357
						]
					],
					[
						[
							358
						]
					],
					[
						[
							359
						]
					],
					[
						[
							360
						]
					],
					[
						[
							361
						]
					],
					[
						[
							362
						]
					],
					[
						[
							363
						]
					],
					[
						[
							364
						]
					],
					[
						[
							365
						]
					],
					[
						[
							366
						]
					],
					[
						[
							367
						]
					],
					[
						[
							368
						]
					],
					[
						[
							369
						]
					],
					[
						[
							370
						]
					],
					[
						[
							371
						]
					],
					[
						[
							372
						]
					],
					[
						[
							373
						]
					],
					[
						[
							374
						]
					],
					[
						[
							375
						]
					],
					[
						[
							376
						]
					],
					[
						[
							377
						]
					],
					[
						[
							378
						]
					],
					[
						[
							379
						]
					],
					[
						[
							380
						]
					],
					[
						[
							381
						]
					],
					[
						[
							382
						]
					],
					[
						[
							383
						]
					],
					[
						[
							384
						]
					]
				],
				id: "CAN",
				properties: {
					name: "Canada"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						385,
						386,
						387,
						-148,
						388,
						-146,
						389,
						390,
						391,
						392,
						393
					]
				],
				id: "CHE",
				properties: {
					name: "Switzerland"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							394
						]
					],
					[
						[
							395
						]
					],
					[
						[
							396
						]
					],
					[
						[
							397
						]
					],
					[
						[
							398
						]
					],
					[
						[
							399
						]
					],
					[
						[
							400
						]
					],
					[
						[
							401
						]
					],
					[
						[
							402
						]
					],
					[
						[
							-44,
							403,
							-42,
							404
						]
					],
					[
						[
							405
						]
					],
					[
						[
							406
						]
					],
					[
						[
							407
						]
					],
					[
						[
							408
						]
					],
					[
						[
							409
						]
					],
					[
						[
							410
						]
					],
					[
						[
							411
						]
					],
					[
						[
							412
						]
					],
					[
						[
							413
						]
					],
					[
						[
							414
						]
					],
					[
						[
							415
						]
					],
					[
						[
							416
						]
					],
					[
						[
							417
						]
					],
					[
						[
							418
						]
					],
					[
						[
							419
						]
					],
					[
						[
							420
						]
					],
					[
						[
							421
						]
					],
					[
						[
							422
						]
					],
					[
						[
							423
						]
					],
					[
						[
							424
						]
					],
					[
						[
							425
						]
					],
					[
						[
							426
						]
					],
					[
						[
							427
						]
					],
					[
						[
							428
						]
					],
					[
						[
							429
						]
					],
					[
						[
							430
						]
					],
					[
						[
							431
						]
					],
					[
						[
							432
						]
					],
					[
						[
							433
						]
					],
					[
						[
							434
						]
					],
					[
						[
							435
						]
					],
					[
						[
							-50,
							436,
							437,
							-218
						]
					]
				],
				id: "CHL",
				properties: {
					name: "Chile"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							438
						]
					],
					[
						[
							439
						]
					],
					[
						[
							440
						]
					],
					[
						[
							441
						]
					],
					[
						[
							442,
							443,
							444,
							445,
							446,
							447,
							448,
							449,
							450,
							451,
							-258,
							452,
							453,
							454,
							455,
							456,
							-1,
							457,
							458,
							459,
							460,
							461,
							462,
							463,
							464
						]
					]
				],
				id: "CHN",
				properties: {
					name: "China"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							465,
							466
						]
					],
					[
						[
							-177,
							467,
							468,
							469,
							470,
							471
						]
					]
				],
				id: "CIV",
				properties: {
					name: "Côte d'Ivoire"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							472,
							-266,
							473,
							474,
							475,
							476,
							477,
							478,
							479
						]
					],
					[
						[
							480,
							481
						]
					]
				],
				id: "CMR",
				properties: {
					name: "Cameroon"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							482,
							483,
							484,
							485
						]
					],
					[
						[
							486,
							487,
							488,
							489
						]
					],
					[
						[
							490,
							491,
							492,
							493
						]
					]
				],
				id: "CNM",
				properties: {
					name: "Cyprus U.N. Buffer Zone"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							494
						]
					],
					[
						[
							495,
							496,
							497,
							498,
							499,
							500,
							501,
							502,
							503,
							-160,
							504,
							505,
							506,
							507,
							-10,
							508,
							-11,
							509,
							-264
						]
					]
				],
				id: "COD",
				properties: {
					name: "Dem. Rep. Congo"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						-510,
						-13,
						510,
						511,
						-474,
						-265
					]
				],
				id: "COG",
				properties: {
					name: "Congo"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							512,
							-249,
							513,
							514,
							515,
							516,
							517
						]
					]
				],
				id: "COL",
				properties: {
					name: "Colombia"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							518
						]
					],
					[
						[
							519
						]
					]
				],
				id: "COM",
				properties: {
					name: "Comoros"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							520
						]
					],
					[
						[
							521
						]
					],
					[
						[
							522
						]
					],
					[
						[
							523
						]
					]
				],
				id: "CPV",
				properties: {
					name: "Cape Verde"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							524,
							525,
							526,
							527
						]
					]
				],
				id: "CRI",
				properties: {
					name: "Costa Rica"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							528
						]
					],
					[
						[
							529
						]
					],
					[
						[
							530
						]
					],
					[
						[
							531,
							532,
							533,
							534
						]
					]
				],
				id: "CUB",
				properties: {
					name: "Cuba"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						535
					]
				],
				id: "CUW",
				properties: {
					name: "Curaçao"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							536,
							-488
						]
					],
					[
						[
							-486,
							537,
							-494,
							538
						]
					]
				],
				id: "CYN",
				properties: {
					name: "N. Cyprus"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							539,
							540
						]
					],
					[
						[
							541
						]
					],
					[
						[
							542,
							543,
							-484
						]
					],
					[
						[
							544,
							545,
							546,
							547,
							-490,
							548,
							-492
						]
					]
				],
				id: "CYP",
				properties: {
					name: "Cyprus"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						549,
						550,
						-151,
						551
					]
				],
				id: "CZE",
				properties: {
					name: "Czech Rep."
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							-387,
							552
						]
					],
					[
						[
							553,
							554
						]
					],
					[
						[
							555
						]
					],
					[
						[
							556,
							557,
							-552,
							-150,
							558,
							-394,
							559,
							560,
							-162,
							561,
							562,
							563
						]
					]
				],
				id: "DEU",
				properties: {
					name: "Germany"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						564,
						565,
						566,
						567,
						568,
						569
					]
				],
				id: "DJI",
				properties: {
					name: "Djibouti"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						570
					]
				],
				id: "DMA",
				properties: {
					name: "Dominica"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							571
						]
					],
					[
						[
							572
						]
					],
					[
						[
							573
						]
					],
					[
						[
							574
						]
					],
					[
						[
							575
						]
					],
					[
						[
							576
						]
					],
					[
						[
							577
						]
					],
					[
						[
							-564,
							578
						]
					]
				],
				id: "DNK",
				properties: {
					name: "Denmark"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							579,
							580,
							581,
							582,
							583,
							584
						]
					]
				],
				id: "DOM",
				properties: {
					name: "Dominican Rep."
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						585,
						586,
						587,
						588,
						589,
						590,
						591,
						592
					]
				],
				id: "DZA",
				properties: {
					name: "Algeria"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							593
						]
					],
					[
						[
							594
						]
					],
					[
						[
							595
						]
					],
					[
						[
							596
						]
					],
					[
						[
							597
						]
					],
					[
						[
							598
						]
					],
					[
						[
							599,
							600,
							-515
						]
					]
				],
				id: "ECU",
				properties: {
					name: "Ecuador"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							601,
							602,
							603,
							604,
							605,
							606
						]
					]
				],
				id: "EGY",
				properties: {
					name: "Egypt"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							607
						]
					],
					[
						[
							-569,
							608,
							609,
							610
						]
					]
				],
				id: "ERI",
				properties: {
					name: "Eritrea"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						-485,
						-544,
						611,
						-541,
						612,
						-545,
						-491,
						-538
					],
					[
						-542
					]
				],
				id: "ESB",
				properties: {
					name: "Dhekelia"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							613
						]
					],
					[
						[
							614
						]
					],
					[
						[
							615
						]
					],
					[
						[
							616
						]
					],
					[
						[
							617
						]
					],
					[
						[
							618
						]
					],
					[
						[
							619,
							620
						]
					],
					[
						[
							621,
							622
						]
					],
					[
						[
							623
						]
					],
					[
						[
							624
						]
					],
					[
						[
							625
						]
					],
					[
						[
							626
						]
					],
					[
						[
							627,
							-33,
							628,
							629,
							630,
							631,
							632,
							633
						]
					]
				],
				id: "ESP",
				properties: {
					name: "Spain"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							634
						]
					],
					[
						[
							635
						]
					],
					[
						[
							636,
							637,
							638,
							639,
							640,
							641,
							642,
							643,
							644
						]
					]
				],
				id: "EST",
				properties: {
					name: "Estonia"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						-568,
						645,
						-566,
						646,
						647,
						648,
						649,
						650,
						-609
					]
				],
				id: "ETH",
				properties: {
					name: "Ethiopia"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							651
						]
					],
					[
						[
							652,
							653,
							654,
							655
						]
					]
				],
				id: "FIN",
				properties: {
					name: "Finland"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							656
						]
					],
					[
						[
							657
						]
					],
					[
						[
							658
						]
					]
				],
				id: "FJI",
				properties: {
					name: "Fiji"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							659
						]
					],
					[
						[
							660
						]
					]
				],
				id: "FLK",
				properties: {
					name: "Falkland Is."
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							661
						]
					],
					[
						[
							662
						]
					],
					[
						[
							-240,
							663,
							664
						]
					],
					[
						[
							665
						]
					],
					[
						[
							666
						]
					],
					[
						[
							667
						]
					],
					[
						[
							668
						]
					],
					[
						[
							669,
							-560,
							-393,
							670,
							-391,
							671,
							672,
							673,
							674,
							-629,
							-34,
							-628,
							675,
							-164
						],
						[
							-627
						]
					]
				],
				id: "FRA",
				properties: {
					name: "France"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							676
						]
					],
					[
						[
							677
						]
					]
				],
				id: "FRO",
				properties: {
					name: "Faeroe Is."
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							678
						]
					]
				],
				id: "FSM",
				properties: {
					name: "Micronesia"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							-512,
							679,
							680,
							-475
						]
					]
				],
				id: "GAB",
				properties: {
					name: "Gabon"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							681
						]
					],
					[
						[
							682
						]
					],
					[
						[
							683,
							684
						]
					],
					[
						[
							685
						]
					],
					[
						[
							686
						]
					],
					[
						[
							687
						]
					],
					[
						[
							688
						]
					],
					[
						[
							689
						]
					],
					[
						[
							690
						]
					],
					[
						[
							691
						]
					],
					[
						[
							692
						]
					],
					[
						[
							693
						]
					],
					[
						[
							694
						]
					],
					[
						[
							695
						]
					]
				],
				id: "GBR",
				properties: {
					name: "United Kingdom"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						-157,
						-57,
						696,
						697,
						698
					]
				],
				id: "GEO",
				properties: {
					name: "Georgia"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						699,
						700,
						-466,
						701,
						-468,
						-176
					]
				],
				id: "GHA",
				properties: {
					name: "Ghana"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						-631,
						702
					]
				],
				id: "GIB",
				properties: {
					name: "Gibraltar"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						703,
						-471,
						704,
						705,
						706,
						707,
						708
					]
				],
				id: "GIN",
				properties: {
					name: "Guinea"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						709,
						710
					]
				],
				id: "GMB",
				properties: {
					name: "Gambia"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							711
						]
					],
					[
						[
							712,
							713,
							-708
						]
					]
				],
				id: "GNB",
				properties: {
					name: "Guinea-Bissau"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							-681,
							714,
							-476
						]
					],
					[
						[
							715
						]
					]
				],
				id: "GNQ",
				properties: {
					name: "Eq. Guinea"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							716
						]
					],
					[
						[
							717
						]
					],
					[
						[
							718
						]
					],
					[
						[
							719
						]
					],
					[
						[
							720
						]
					],
					[
						[
							721
						]
					],
					[
						[
							722
						]
					],
					[
						[
							723
						]
					],
					[
						[
							724
						]
					],
					[
						[
							725
						]
					],
					[
						[
							726
						]
					],
					[
						[
							727
						]
					],
					[
						[
							728
						]
					],
					[
						[
							729
						]
					],
					[
						[
							730
						]
					],
					[
						[
							731
						]
					],
					[
						[
							732,
							-186,
							733,
							734,
							-27,
							735,
							-25,
							736
						]
					]
				],
				id: "GRC",
				properties: {
					name: "Greece"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							737
						]
					]
				],
				id: "GRD",
				properties: {
					name: "Grenada"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							738
						]
					],
					[
						[
							739
						]
					],
					[
						[
							740
						]
					],
					[
						[
							741
						]
					],
					[
						[
							742
						]
					],
					[
						[
							743
						]
					],
					[
						[
							744
						]
					],
					[
						[
							745
						]
					],
					[
						[
							746
						]
					],
					[
						[
							747
						]
					],
					[
						[
							748
						]
					],
					[
						[
							749
						]
					],
					[
						[
							750
						]
					],
					[
						[
							751
						]
					],
					[
						[
							752
						]
					],
					[
						[
							753
						]
					],
					[
						[
							754
						]
					],
					[
						[
							755
						]
					],
					[
						[
							756
						]
					],
					[
						[
							757
						]
					],
					[
						[
							758
						]
					],
					[
						[
							759
						]
					],
					[
						[
							760
						]
					],
					[
						[
							761
						]
					],
					[
						[
							762
						]
					],
					[
						[
							763
						]
					]
				],
				id: "GRL",
				properties: {
					name: "Greenland"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						-213,
						764,
						765,
						766,
						767,
						768
					]
				],
				id: "GTM",
				properties: {
					name: "Guatemala"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						769
					]
				],
				id: "GUM",
				properties: {
					name: "Guam"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							770,
							-251,
							771,
							772
						]
					]
				],
				id: "GUY",
				properties: {
					name: "Guyana"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							773,
							-447
						]
					]
				],
				id: "HKG",
				properties: {
					name: "Hong Kong"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						774
					]
				],
				id: "HMD",
				properties: {
					name: "Heard I. and McDonald Is."
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							775,
							776,
							777,
							-766,
							778
						]
					]
				],
				id: "HND",
				properties: {
					name: "Honduras"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							-204,
							779,
							780
						]
					],
					[
						[
							781
						]
					],
					[
						[
							782
						]
					],
					[
						[
							783
						]
					],
					[
						[
							784
						]
					],
					[
						[
							785,
							786,
							-206,
							787,
							788
						]
					]
				],
				id: "HRV",
				properties: {
					name: "Croatia"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							-582,
							789
						]
					],
					[
						[
							790
						]
					],
					[
						[
							-584,
							791,
							-580,
							792
						]
					]
				],
				id: "HTI",
				properties: {
					name: "Haiti"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						793,
						794,
						795,
						-786,
						796,
						-143,
						797
					]
				],
				id: "HUN",
				properties: {
					name: "Hungary"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							798
						]
					],
					[
						[
							799
						]
					],
					[
						[
							800
						]
					],
					[
						[
							801,
							802,
							803,
							804
						]
					],
					[
						[
							805
						]
					],
					[
						[
							806
						]
					],
					[
						[
							807
						]
					],
					[
						[
							808
						]
					],
					[
						[
							809
						]
					],
					[
						[
							810
						]
					],
					[
						[
							811
						]
					],
					[
						[
							812
						]
					],
					[
						[
							813
						]
					],
					[
						[
							814
						]
					],
					[
						[
							815
						]
					],
					[
						[
							816
						]
					],
					[
						[
							817
						]
					],
					[
						[
							818
						]
					],
					[
						[
							819
						]
					],
					[
						[
							820
						]
					],
					[
						[
							821
						]
					],
					[
						[
							822
						]
					],
					[
						[
							823
						]
					],
					[
						[
							824
						]
					],
					[
						[
							825
						]
					],
					[
						[
							826
						]
					],
					[
						[
							827
						]
					],
					[
						[
							828
						]
					],
					[
						[
							829
						]
					],
					[
						[
							830
						]
					],
					[
						[
							831
						]
					],
					[
						[
							832
						]
					],
					[
						[
							833
						]
					],
					[
						[
							834
						]
					],
					[
						[
							835
						]
					],
					[
						[
							836
						]
					],
					[
						[
							837
						]
					],
					[
						[
							838
						]
					],
					[
						[
							839
						]
					],
					[
						[
							840
						]
					],
					[
						[
							841
						]
					],
					[
						[
							842
						]
					],
					[
						[
							843
						]
					],
					[
						[
							844
						]
					],
					[
						[
							845
						]
					],
					[
						[
							846
						]
					],
					[
						[
							847
						]
					],
					[
						[
							848
						]
					],
					[
						[
							849
						]
					],
					[
						[
							850
						]
					],
					[
						[
							851
						]
					],
					[
						[
							852
						]
					],
					[
						[
							853
						]
					],
					[
						[
							854
						]
					],
					[
						[
							855
						]
					],
					[
						[
							856
						]
					],
					[
						[
							857,
							858
						]
					],
					[
						[
							859
						]
					],
					[
						[
							860
						]
					],
					[
						[
							861
						]
					],
					[
						[
							862
						]
					],
					[
						[
							863
						]
					],
					[
						[
							864
						]
					],
					[
						[
							865
						]
					],
					[
						[
							866
						]
					],
					[
						[
							867
						]
					],
					[
						[
							868
						]
					],
					[
						[
							869
						]
					],
					[
						[
							870
						]
					],
					[
						[
							871
						]
					],
					[
						[
							872
						]
					],
					[
						[
							873
						]
					],
					[
						[
							874
						]
					],
					[
						[
							875
						]
					],
					[
						[
							876
						]
					],
					[
						[
							877
						]
					],
					[
						[
							878
						]
					],
					[
						[
							879
						]
					],
					[
						[
							880
						]
					],
					[
						[
							881,
							882
						]
					],
					[
						[
							883
						]
					],
					[
						[
							884,
							885
						]
					],
					[
						[
							886
						]
					],
					[
						[
							887
						]
					]
				],
				id: "IDN",
				properties: {
					name: "Indonesia"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						888
					]
				],
				id: "IMN",
				properties: {
					name: "Isle of Man"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							889
						]
					],
					[
						[
							890
						]
					],
					[
						[
							891
						]
					],
					[
						[
							892
						]
					],
					[
						[
							893,
							-453,
							-257,
							-452,
							894,
							-183,
							895,
							896,
							897,
							-455
						]
					]
				],
				id: "IND",
				properties: {
					name: "India"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							-684,
							898
						]
					]
				],
				id: "IRL",
				properties: {
					name: "Ireland"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							899
						]
					],
					[
						[
							-54,
							-156,
							900,
							901,
							-3,
							902,
							903,
							904,
							905,
							-152
						]
					]
				],
				id: "IRN",
				properties: {
					name: "Iran"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						-905,
						906,
						907,
						908,
						909,
						910,
						911,
						912,
						913
					]
				],
				id: "IRQ",
				properties: {
					name: "Iraq"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							914
						]
					]
				],
				id: "ISL",
				properties: {
					name: "Iceland"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						915,
						916,
						917,
						918,
						919,
						920,
						921,
						-603,
						922,
						923,
						924,
						925
					]
				],
				id: "ISR",
				properties: {
					name: "Israel"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							926
						]
					],
					[
						[
							927
						]
					],
					[
						[
							928,
							929,
							-672,
							-390,
							-145
						],
						[
							930
						],
						[
							931
						]
					]
				],
				id: "ITA",
				properties: {
					name: "Italy"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						932
					]
				],
				id: "JAM",
				properties: {
					name: "Jamaica"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						933,
						934,
						-921,
						935,
						-919,
						936,
						937,
						-916,
						938,
						-910
					]
				],
				id: "JOR",
				properties: {
					name: "Jordan"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							939
						]
					],
					[
						[
							940
						]
					],
					[
						[
							941
						]
					],
					[
						[
							942
						]
					],
					[
						[
							943
						]
					],
					[
						[
							944
						]
					],
					[
						[
							945
						]
					],
					[
						[
							946
						]
					],
					[
						[
							947
						]
					],
					[
						[
							948
						]
					],
					[
						[
							949
						]
					],
					[
						[
							950
						]
					],
					[
						[
							951
						]
					]
				],
				id: "JPN",
				properties: {
					name: "Japan"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						952
					]
				],
				id: "KAB",
				properties: {
					name: "Baikonur"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						-898,
						953,
						-456
					]
				],
				id: "KAS",
				properties: {
					name: "Siachen Glacier"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							954,
							955
						]
					],
					[
						[
							-460,
							956,
							957,
							958,
							959,
							960,
							961,
							962
						],
						[
							-953
						]
					]
				],
				id: "KAZ",
				properties: {
					name: "Kazakhstan"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							-649,
							963,
							964,
							965,
							966,
							967,
							968
						]
					]
				],
				id: "KEN",
				properties: {
					name: "Kenya"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						-459,
						969,
						970,
						-957
					],
					[
						971
					],
					[
						972
					],
					[
						973
					]
				],
				id: "KGZ",
				properties: {
					name: "Kyrgyzstan"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							974,
							975,
							976,
							977
						]
					]
				],
				id: "KHM",
				properties: {
					name: "Cambodia"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							978
						]
					]
				],
				id: "KIR",
				properties: {
					name: "Kiribati"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							979
						]
					],
					[
						[
							980
						]
					],
					[
						[
							981
						]
					],
					[
						[
							982,
							983
						]
					]
				],
				id: "KOR",
				properties: {
					name: "Korea"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						984,
						-18,
						985,
						986
					]
				],
				id: "XKX",
				properties: {
					name: "Kosovo"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							987
						]
					],
					[
						[
							988,
							-908,
							989
						]
					]
				],
				id: "KWT",
				properties: {
					name: "Kuwait"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						990,
						-977,
						991,
						992,
						-450
					]
				],
				id: "LAO",
				properties: {
					name: "Lao PDR"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						-925,
						993,
						994
					]
				],
				id: "LBN",
				properties: {
					name: "Lebanon"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						-470,
						995,
						996,
						-705
					]
				],
				id: "LBR",
				properties: {
					name: "Liberia"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						-606,
						997,
						998,
						999,
						-587,
						1000,
						1001
					]
				],
				id: "LBY",
				properties: {
					name: "Libya"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						1002
					]
				],
				id: "LCA",
				properties: {
					name: "Saint Lucia"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						-389,
						-147
					]
				],
				id: "LIE",
				properties: {
					name: "Liechtenstein"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							1003
						]
					]
				],
				id: "LKA",
				properties: {
					name: "Sri Lanka"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						1004
					]
				],
				id: "LSO",
				properties: {
					name: "Lesotho"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							1005,
							1006
						]
					],
					[
						[
							-210,
							1007,
							1008,
							1009,
							1010
						]
					]
				],
				id: "LTU",
				properties: {
					name: "Lithuania"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						-561,
						-670,
						-163
					]
				],
				id: "LUX",
				properties: {
					name: "Luxembourg"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						1011,
						-211,
						-1011,
						1012,
						-644
					]
				],
				id: "LVA",
				properties: {
					name: "Latvia"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						1013,
						1014
					]
				],
				id: "MAF",
				properties: {
					name: "St-Martin"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						-622,
						1015,
						-620,
						1016,
						-592,
						1017,
						1018
					]
				],
				id: "MAR",
				properties: {
					name: "Morocco"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						1019,
						-674
					]
				],
				id: "MCO",
				properties: {
					name: "Monaco"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						1020,
						1021
					]
				],
				id: "MDA",
				properties: {
					name: "Moldova"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							1022
						]
					],
					[
						[
							1023
						]
					]
				],
				id: "MDG",
				properties: {
					name: "Madagascar"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							1024
						]
					],
					[
						[
							1025
						]
					],
					[
						[
							1026
						]
					],
					[
						[
							1027
						]
					],
					[
						[
							1028
						]
					],
					[
						[
							1029,
							1030,
							1031,
							1032,
							1033,
							-214,
							-769,
							1034,
							1035
						],
						[
							1036
						]
					]
				],
				id: "MEX",
				properties: {
					name: "Mexico"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							-23,
							1037
						]
					],
					[
						[
							-187,
							-733,
							1038,
							-15,
							1039,
							-21,
							1040,
							-19,
							-985,
							1041
						]
					]
				],
				id: "MKD",
				properties: {
					name: "Macedonia"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						1042,
						-178,
						-472,
						-704,
						1043,
						1044,
						-589
					]
				],
				id: "MLI",
				properties: {
					name: "Mali"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							1045
						]
					],
					[
						[
							1046
						]
					],
					[
						[
							1047
						]
					],
					[
						[
							1048
						]
					],
					[
						[
							1049
						]
					],
					[
						[
							1050
						]
					],
					[
						[
							-993,
							1051,
							1052,
							-181,
							-895,
							-451
						]
					]
				],
				id: "MMR",
				properties: {
					name: "Myanmar"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						1053,
						-986,
						-31,
						1054,
						-16,
						1055,
						-29,
						1056,
						-780,
						-203
					]
				],
				id: "MNE",
				properties: {
					name: "Montenegro"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						-464,
						1057,
						-462,
						1058
					]
				],
				id: "MNG",
				properties: {
					name: "Mongolia"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							1059,
							1060,
							1061,
							1062,
							1063,
							1064,
							1065,
							1066,
							1067
						]
					]
				],
				id: "MOZ",
				properties: {
					name: "Mozambique"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							1068,
							1069,
							1070,
							-590,
							-1045
						]
					]
				],
				id: "MRT",
				properties: {
					name: "Mauritania"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							1071
						]
					]
				],
				id: "MUS",
				properties: {
					name: "Mauritius"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							1072,
							1073
						]
					],
					[
						[
							1074,
							1075
						]
					],
					[
						[
							1076,
							1077
						]
					],
					[
						[
							1078,
							1079
						]
					],
					[
						[
							1080,
							-1065,
							1081,
							1082
						]
					]
				],
				id: "MWI",
				properties: {
					name: "Malawi"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							1083
						]
					],
					[
						[
							-882,
							1084
						]
					],
					[
						[
							1085
						]
					],
					[
						[
							1086
						]
					],
					[
						[
							1087,
							1088
						]
					],
					[
						[
							-886,
							1089,
							-256,
							1090,
							-253,
							1091
						]
					],
					[
						[
							1092
						]
					]
				],
				id: "MYS",
				properties: {
					name: "Malaysia"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						1093,
						-261,
						1094,
						1095,
						-8
					]
				],
				id: "NAM",
				properties: {
					name: "Namibia"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							1096
						]
					],
					[
						[
							1097
						]
					],
					[
						[
							1098
						]
					]
				],
				id: "NCL",
				properties: {
					name: "New Caledonia"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						1099,
						1100,
						-173,
						-174,
						-1043,
						-588,
						-1000
					]
				],
				id: "NER",
				properties: {
					name: "Niger"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							1101,
							-478,
							1102,
							-169,
							-1101
						]
					]
				],
				id: "NGA",
				properties: {
					name: "Nigeria"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							1103,
							-528,
							1104,
							-776
						]
					]
				],
				id: "NIC",
				properties: {
					name: "Nicaragua"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							-166,
							1105
						]
					],
					[
						[
							1106
						]
					],
					[
						[
							-562,
							-168,
							1107
						],
						[
							1108
						]
					]
				],
				id: "NLD",
				properties: {
					name: "Netherlands"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							1109
						]
					],
					[
						[
							1110
						]
					],
					[
						[
							1111
						]
					],
					[
						[
							1112
						]
					],
					[
						[
							1113
						]
					],
					[
						[
							1114
						]
					],
					[
						[
							1115
						]
					],
					[
						[
							1116
						]
					],
					[
						[
							1117
						]
					],
					[
						[
							1118
						]
					],
					[
						[
							1119
						]
					],
					[
						[
							1120
						]
					],
					[
						[
							1121
						]
					],
					[
						[
							1122
						]
					],
					[
						[
							1123,
							-656,
							1124,
							1125
						]
					],
					[
						[
							1126
						]
					],
					[
						[
							1127
						]
					],
					[
						[
							1128
						]
					],
					[
						[
							1129
						]
					],
					[
						[
							1130
						]
					],
					[
						[
							1131
						]
					],
					[
						[
							1132
						]
					]
				],
				id: "NOR",
				properties: {
					name: "Norway"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						-894,
						-454
					]
				],
				id: "NPL",
				properties: {
					name: "Nepal"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							1133
						]
					],
					[
						[
							1134
						]
					],
					[
						[
							1135
						]
					],
					[
						[
							1136
						]
					],
					[
						[
							1137
						]
					],
					[
						[
							1138
						]
					]
				],
				id: "NZL",
				properties: {
					name: "New Zealand"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							1139
						]
					],
					[
						[
							1140,
							1141,
							-37,
							1142
						]
					],
					[
						[
							-41
						],
						[
							-35
						]
					],
					[
						[
							-40,
							1143
						]
					]
				],
				id: "OMN",
				properties: {
					name: "Oman"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							-954,
							-897,
							1144,
							-903,
							-2,
							-457
						]
					]
				],
				id: "PAK",
				properties: {
					name: "Pakistan"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							1145
						]
					],
					[
						[
							-517,
							1146,
							-526,
							1147
						]
					]
				],
				id: "PAN",
				properties: {
					name: "Panama"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							-248,
							-221,
							1148,
							-215,
							1149,
							-219,
							-438,
							1150,
							-600,
							-514
						]
					]
				],
				id: "PER",
				properties: {
					name: "Peru"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							1151
						]
					],
					[
						[
							1152
						]
					],
					[
						[
							1153
						]
					],
					[
						[
							1154
						]
					],
					[
						[
							1155
						]
					],
					[
						[
							1156
						]
					],
					[
						[
							1157
						]
					],
					[
						[
							1158
						]
					],
					[
						[
							1159
						]
					],
					[
						[
							1160
						]
					],
					[
						[
							1161
						]
					],
					[
						[
							1162
						]
					],
					[
						[
							1163
						]
					],
					[
						[
							1164
						]
					],
					[
						[
							1165
						]
					],
					[
						[
							1166
						]
					],
					[
						[
							1167
						]
					],
					[
						[
							1168
						]
					],
					[
						[
							1169
						]
					],
					[
						[
							1170
						]
					],
					[
						[
							1171
						]
					],
					[
						[
							1172
						]
					],
					[
						[
							1173
						]
					],
					[
						[
							1174
						]
					],
					[
						[
							1175
						]
					],
					[
						[
							1176
						]
					],
					[
						[
							1177
						]
					],
					[
						[
							1178
						]
					],
					[
						[
							1179
						]
					],
					[
						[
							1180
						]
					],
					[
						[
							1181
						]
					]
				],
				id: "PHL",
				properties: {
					name: "Philippines"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							1182
						]
					]
				],
				id: "PLW",
				properties: {
					name: "Palau"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							1183
						]
					],
					[
						[
							1184
						]
					],
					[
						[
							1185
						]
					],
					[
						[
							1186
						]
					],
					[
						[
							1187
						]
					],
					[
						[
							1188
						]
					],
					[
						[
							1189
						]
					],
					[
						[
							1190
						]
					],
					[
						[
							1191
						]
					],
					[
						[
							1192
						]
					],
					[
						[
							1193
						]
					],
					[
						[
							1194
						]
					],
					[
						[
							-858,
							1195
						]
					],
					[
						[
							1196
						]
					],
					[
						[
							1197
						]
					],
					[
						[
							1198
						]
					],
					[
						[
							1199
						]
					]
				],
				id: "PNG",
				properties: {
					name: "Papua New Guinea"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						1200,
						1201,
						1202,
						-1008,
						-209,
						1203,
						1204,
						-550,
						-558,
						1205,
						-554,
						1206
					]
				],
				id: "POL",
				properties: {
					name: "Poland"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							1207
						]
					]
				],
				id: "PRI",
				properties: {
					name: "Puerto Rico"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							1208,
							1209,
							-983,
							1210,
							-445
						]
					]
				],
				id: "PRK",
				properties: {
					name: "Dem. Rep. Korea"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							1211
						]
					],
					[
						[
							1212
						]
					],
					[
						[
							1213
						]
					],
					[
						[
							1214
						]
					],
					[
						[
							1215,
							-633
						]
					]
				],
				id: "PRT",
				properties: {
					name: "Portugal"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						-247,
						1216,
						-245,
						-46,
						-217
					]
				],
				id: "PRY",
				properties: {
					name: "Paraguay"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							-602,
							1217,
							-923
						]
					],
					[
						[
							-938,
							1218,
							-917
						]
					]
				],
				id: "PSX",
				properties: {
					name: "Palestine"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							1219
						]
					]
				],
				id: "PYF",
				properties: {
					name: "Fr. Polynesia"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						1220,
						1221
					]
				],
				id: "QAT",
				properties: {
					name: "Qatar"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						1222,
						1223,
						-189,
						1224,
						-795,
						1225,
						-1021
					]
				],
				id: "ROU",
				properties: {
					name: "Romania"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							1226
						]
					],
					[
						[
							1227
						]
					],
					[
						[
							1228
						]
					],
					[
						[
							1229
						]
					],
					[
						[
							1230
						]
					],
					[
						[
							1231
						]
					],
					[
						[
							1232
						]
					],
					[
						[
							1233
						]
					],
					[
						[
							1234
						]
					],
					[
						[
							1235
						]
					],
					[
						[
							1236
						]
					],
					[
						[
							-1203,
							1237,
							-1201,
							1238,
							-1006,
							1239,
							-1009
						]
					],
					[
						[
							1240
						]
					],
					[
						[
							1241
						]
					],
					[
						[
							1242,
							-639
						]
					],
					[
						[
							1243
						]
					],
					[
						[
							1244
						]
					],
					[
						[
							1245
						]
					],
					[
						[
							1246
						]
					],
					[
						[
							1247
						]
					],
					[
						[
							1248
						]
					],
					[
						[
							1249
						]
					],
					[
						[
							1250
						]
					],
					[
						[
							1251
						]
					],
					[
						[
							1252
						]
					],
					[
						[
							1253
						]
					],
					[
						[
							1254
						]
					],
					[
						[
							1255
						]
					],
					[
						[
							1256
						]
					],
					[
						[
							1257
						]
					],
					[
						[
							1258
						]
					],
					[
						[
							1259
						]
					],
					[
						[
							1260
						]
					],
					[
						[
							1261
						]
					],
					[
						[
							1262
						]
					],
					[
						[
							1263
						]
					],
					[
						[
							1264
						]
					],
					[
						[
							1265
						]
					],
					[
						[
							1266
						]
					],
					[
						[
							1267
						]
					],
					[
						[
							1268
						]
					],
					[
						[
							1269
						]
					],
					[
						[
							1270
						]
					],
					[
						[
							-1209,
							-444,
							1271,
							-465,
							-1059,
							-461,
							-963,
							1272,
							-154,
							-699,
							1273,
							1274,
							-207,
							-1012,
							-643,
							1275,
							-641,
							1276,
							-637,
							1277,
							-653,
							-1124,
							1278
						]
					],
					[
						[
							1279
						]
					],
					[
						[
							1280
						]
					],
					[
						[
							1281
						]
					],
					[
						[
							1282
						]
					],
					[
						[
							1283
						]
					],
					[
						[
							1284
						]
					],
					[
						[
							1285
						]
					],
					[
						[
							1286
						]
					],
					[
						[
							1287
						]
					],
					[
						[
							1288
						]
					],
					[
						[
							1289
						]
					],
					[
						[
							1290
						]
					],
					[
						[
							1291
						]
					],
					[
						[
							1292
						]
					],
					[
						[
							1293
						]
					],
					[
						[
							1294
						]
					],
					[
						[
							1295
						]
					],
					[
						[
							1296
						]
					],
					[
						[
							1297
						]
					],
					[
						[
							1298
						]
					]
				],
				id: "RUS",
				properties: {
					name: "Russia"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						1299,
						-161,
						-504,
						1300,
						-502,
						1301
					]
				],
				id: "RWA",
				properties: {
					name: "Rwanda"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						-591,
						-1071,
						1302,
						-1018
					]
				],
				id: "ESH",
				properties: {
					name: "W. Sahara"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							1303
						]
					],
					[
						[
							-989,
							1304,
							-1221,
							1305,
							-38,
							-1142,
							1306,
							1307,
							-934,
							-909
						]
					]
				],
				id: "SAU",
				properties: {
					name: "Saudi Arabia"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							1308,
							-610,
							-651,
							1309,
							-262,
							1310,
							-998,
							-605
						]
					]
				],
				id: "SDN",
				properties: {
					name: "Sudan"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						-650,
						-969,
						1311,
						-496,
						-263,
						-1310
					]
				],
				id: "SSD",
				properties: {
					name: "S. Sudan"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						-1044,
						-709,
						-714,
						1312,
						-711,
						1313,
						-1069
					]
				],
				id: "SEN",
				properties: {
					name: "Senegal"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						1314
					]
				],
				id: "SGP",
				properties: {
					name: "Singapore"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							1315
						]
					]
				],
				id: "SGS",
				properties: {
					name: "S. Geo. and S. Sandw. Is."
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							1316
						]
					],
					[
						[
							1317
						]
					],
					[
						[
							1318
						]
					],
					[
						[
							1319
						]
					],
					[
						[
							1320
						]
					],
					[
						[
							1321
						]
					],
					[
						[
							1322
						]
					],
					[
						[
							1323
						]
					],
					[
						[
							1324
						]
					],
					[
						[
							1325
						]
					],
					[
						[
							1326
						]
					],
					[
						[
							1327
						]
					],
					[
						[
							1328
						]
					]
				],
				id: "SLB",
				properties: {
					name: "Solomon Is."
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							1329
						]
					],
					[
						[
							-997,
							1330,
							-706
						]
					]
				],
				id: "SLE",
				properties: {
					name: "Sierra Leone"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							-778,
							1331,
							-767
						]
					]
				],
				id: "SLV",
				properties: {
					name: "El Salvador"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						-931
					]
				],
				id: "SMR",
				properties: {
					name: "San Marino"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						1332,
						-647,
						-565,
						1333
					]
				],
				id: "SOL",
				properties: {
					name: "Somaliland"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						-964,
						-648,
						-1333,
						1334
					]
				],
				id: "SOM",
				properties: {
					name: "Somalia"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						-1225,
						-188,
						-1042,
						-987,
						-1054,
						-202,
						-787,
						-796
					]
				],
				id: "SRB",
				properties: {
					name: "Serbia"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							1335
						]
					]
				],
				id: "STP",
				properties: {
					name: "São Tomé and Principe"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						-664,
						-239,
						-771,
						1336
					]
				],
				id: "SUR",
				properties: {
					name: "Suriname"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						1337,
						-798,
						-142,
						-551,
						-1205
					]
				],
				id: "SVK",
				properties: {
					name: "Slovakia"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						-789,
						1338,
						-929,
						-144,
						-797
					]
				],
				id: "SVN",
				properties: {
					name: "Slovenia"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							1339
						]
					],
					[
						[
							1340
						]
					],
					[
						[
							1341
						]
					],
					[
						[
							1342,
							-1125,
							-655
						]
					]
				],
				id: "SWE",
				properties: {
					name: "Sweden"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						-1061,
						1343
					]
				],
				id: "SWZ",
				properties: {
					name: "Swaziland"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						1344,
						-1014
					]
				],
				id: "SXM",
				properties: {
					name: "Sint Maarten"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						-913,
						911,
						-911,
						-939,
						-926,
						-995,
						1345,
						1346
					]
				],
				id: "SYR",
				properties: {
					name: "Syria"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						-1311,
						-267,
						-473,
						1347,
						-481,
						1348,
						-479,
						-1102,
						-1100,
						-999
					]
				],
				id: "TCD",
				properties: {
					name: "Chad"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						-171,
						1349,
						-700,
						-175
					]
				],
				id: "TGO",
				properties: {
					name: "Togo"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							1350
						]
					],
					[
						[
							1351
						]
					],
					[
						[
							-992,
							-976,
							1352,
							-1089,
							1353,
							-1052
						]
					]
				],
				id: "THA",
				properties: {
					name: "Thailand"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							-974
						]
					],
					[
						[
							1354
						]
					],
					[
						[
							-970,
							-458,
							-6,
							1355
						]
					]
				],
				id: "TJK",
				properties: {
					name: "Tajikistan"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							-4,
							-902,
							1356,
							-961,
							1357,
							1358,
							1359
						]
					]
				],
				id: "TKM",
				properties: {
					name: "Turkmenistan"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							1360,
							-803
						]
					],
					[
						[
							-805,
							1361
						]
					]
				],
				id: "TLS",
				properties: {
					name: "Timor-Leste"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							1362
						]
					]
				],
				id: "TON",
				properties: {
					name: "Tonga"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							1363
						]
					]
				],
				id: "TTO",
				properties: {
					name: "Trinidad and Tobago"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							1364
						]
					],
					[
						[
							-1001,
							-586,
							1365
						]
					]
				],
				id: "TUN",
				properties: {
					name: "Tunisia"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							1366,
							-734,
							-185
						]
					],
					[
						[
							-697,
							-56,
							-153,
							-906,
							-914,
							-1347,
							1367
						]
					]
				],
				id: "TUR",
				properties: {
					name: "Turkey"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							1368
						]
					]
				],
				id: "TWN",
				properties: {
					name: "Taiwan"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							1369
						]
					],
					[
						[
							1370
						]
					],
					[
						[
							1371
						]
					],
					[
						[
							1372
						]
					],
					[
						[
							1373,
							1374,
							1375,
							-966,
							1376,
							-1067,
							1377,
							-1074,
							1378,
							-1076,
							1379,
							-1078,
							1380,
							-1080,
							1381,
							-1083,
							1382,
							1383,
							-158,
							-1300,
							1384
						]
					]
				],
				id: "TZA",
				properties: {
					name: "Tanzania"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							-1375,
							1385
						]
					],
					[
						[
							1386,
							-1385,
							-1302,
							-501,
							1387,
							-499,
							1388,
							-497,
							-1312,
							-968
						]
					]
				],
				id: "UGA",
				properties: {
					name: "Uganda"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							1389,
							-1223,
							-1022,
							-1226,
							-794,
							-1338,
							-1204,
							-208,
							-1275
						],
						[
							1390
						],
						[
							1391
						]
					]
				],
				id: "UKR",
				properties: {
					name: "Ukraine"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						1392,
						-242,
						1393,
						-48,
						-244
					]
				],
				id: "URY",
				properties: {
					name: "Uruguay"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							1394
						]
					],
					[
						[
							1395
						]
					],
					[
						[
							1396
						]
					],
					[
						[
							1397
						]
					],
					[
						[
							1398
						]
					],
					[
						[
							1399
						]
					],
					[
						[
							1400
						]
					],
					[
						[
							1401
						]
					],
					[
						[
							1402
						]
					],
					[
						[
							1403
						]
					],
					[
						[
							1404
						]
					],
					[
						[
							1405
						]
					],
					[
						[
							1406
						]
					],
					[
						[
							1407
						]
					],
					[
						[
							1408
						]
					],
					[
						[
							1409
						]
					],
					[
						[
							1410,
							-344
						]
					],
					[
						[
							1411,
							-340,
							1412,
							-338,
							1413,
							-336,
							1414,
							-334,
							-278,
							1415,
							-276,
							1416,
							-1033,
							1417,
							-1031,
							1418,
							-1036,
							1419,
							-342
						]
					],
					[
						[
							1420
						]
					],
					[
						[
							1421
						]
					],
					[
						[
							1422
						]
					],
					[
						[
							1423
						]
					],
					[
						[
							1424
						]
					],
					[
						[
							1425
						]
					],
					[
						[
							1426
						]
					],
					[
						[
							1427
						]
					],
					[
						[
							1428
						]
					],
					[
						[
							1429
						]
					],
					[
						[
							1430
						]
					],
					[
						[
							1431
						]
					],
					[
						[
							1432
						]
					],
					[
						[
							1433
						]
					],
					[
						[
							1434
						]
					],
					[
						[
							1435
						]
					],
					[
						[
							1436
						]
					],
					[
						[
							1437
						]
					],
					[
						[
							1438
						]
					],
					[
						[
							1439
						]
					],
					[
						[
							1440
						]
					],
					[
						[
							1441
						]
					],
					[
						[
							1442
						]
					],
					[
						[
							1443
						]
					],
					[
						[
							1444
						]
					],
					[
						[
							1445
						]
					],
					[
						[
							1446
						]
					],
					[
						[
							1447
						]
					],
					[
						[
							1448
						]
					],
					[
						[
							1449
						]
					],
					[
						[
							1450
						]
					],
					[
						[
							1451
						]
					],
					[
						[
							1452
						]
					],
					[
						[
							1453
						]
					],
					[
						[
							-347,
							345,
							1454
						]
					]
				],
				id: "USA",
				properties: {
					name: "United States"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							-534,
							1455
						]
					],
					[
						[
							1456,
							-532
						]
					]
				],
				id: "USG",
				properties: {
					name: "USNB Guantanamo Bay"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							-973
						]
					],
					[
						[
							-972
						]
					],
					[
						[
							-955,
							1457,
							-958,
							-971,
							-1356,
							-5,
							-1360,
							1458,
							-1358,
							-960,
							1459
						],
						[
							-1355
						]
					]
				],
				id: "UZB",
				properties: {
					name: "Uzbekistan"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						-932
					]
				],
				id: "VAT",
				properties: {
					name: "Vatican"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							1460
						]
					]
				],
				id: "VCT",
				properties: {
					name: "St. Vin. and Gren."
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							1461
						]
					],
					[
						[
							1462
						]
					],
					[
						[
							1463
						]
					],
					[
						[
							-772,
							-250,
							-513,
							1464
						]
					]
				],
				id: "VEN",
				properties: {
					name: "Venezuela"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							1465
						]
					],
					[
						[
							1466,
							-978,
							-991,
							-449
						]
					]
				],
				id: "VNM",
				properties: {
					name: "Vietnam"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							1467
						]
					],
					[
						[
							1468
						]
					],
					[
						[
							1469
						]
					],
					[
						[
							1470
						]
					],
					[
						[
							1471
						]
					],
					[
						[
							1472
						]
					],
					[
						[
							1473
						]
					],
					[
						[
							1474
						]
					],
					[
						[
							1475
						]
					],
					[
						[
							1476
						]
					],
					[
						[
							1477
						]
					],
					[
						[
							1478
						]
					]
				],
				id: "VUT",
				properties: {
					name: "Vanuatu"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						1479,
						-547
					]
				],
				id: "WSB",
				properties: {
					name: "Akrotiri"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							1480
						]
					],
					[
						[
							1481
						]
					]
				],
				id: "WSM",
				properties: {
					name: "Samoa"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							1482
						]
					],
					[
						[
							1483,
							-1307,
							-1141
						]
					]
				],
				id: "YEM",
				properties: {
					name: "Yemen"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							-1062,
							-1344,
							-1060,
							1484,
							-1095,
							-260,
							1485
						],
						[
							-1005
						]
					]
				],
				id: "ZAF",
				properties: {
					name: "South Africa"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						-1383,
						-1082,
						-1064,
						1486,
						1487,
						1488,
						-1094,
						-7,
						-508,
						1489,
						-506,
						1490
					]
				],
				id: "ZMB",
				properties: {
					name: "Zambia"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						-1063,
						-1486,
						-259,
						-1489,
						1491,
						-1487
					]
				],
				id: "ZWE",
				properties: {
					name: "Zimbabwe"
				},
				type: "Polygon"
			}
		],
		type: "GeometryCollection"
	}
};
var transform$2 = {
	scale: [
		0.036003600360036005,
		0.01736514657995801
	],
	translate: [
		-180,
		-90
	]
};
var type$2 = "Topology";
var topology$2 = {
	arcs: arcs$2,
	objects: objects$2,
	transform: transform$2,
	type: type$2
};

var countriesAbbr = [
	{
		country: "Afghanistan",
		abbreviation: "AF"
	},
	{
		country: "Albania",
		abbreviation: "AL"
	},
	{
		country: "Algeria",
		abbreviation: "DZ"
	},
	{
		country: "American Samoa",
		abbreviation: "AS"
	},
	{
		country: "Andorra",
		abbreviation: "AD"
	},
	{
		country: "Angola",
		abbreviation: "AO"
	},
	{
		country: "Anguilla",
		abbreviation: "AI"
	},
	{
		country: "Antarctica",
		abbreviation: "AQ"
	},
	{
		country: "Antigua and Barbuda",
		abbreviation: "AG"
	},
	{
		country: "Argentina",
		abbreviation: "AR"
	},
	{
		country: "Armenia",
		abbreviation: "AM"
	},
	{
		country: "Aruba",
		abbreviation: "AW"
	},
	{
		country: "Australia",
		abbreviation: "AU"
	},
	{
		country: "Austria",
		abbreviation: "AT"
	},
	{
		country: "Azerbaijan",
		abbreviation: "AZ"
	},
	{
		country: "Bahamas",
		abbreviation: "BS"
	},
	{
		country: "Bahrain",
		abbreviation: "BH"
	},
	{
		country: "Bangladesh",
		abbreviation: "BD"
	},
	{
		country: "Barbados",
		abbreviation: "BB"
	},
	{
		country: "Belarus",
		abbreviation: "BY"
	},
	{
		country: "Belgium",
		abbreviation: "BE"
	},
	{
		country: "Belize",
		abbreviation: "BZ"
	},
	{
		country: "Benin",
		abbreviation: "BJ"
	},
	{
		country: "Bermuda",
		abbreviation: "BM"
	},
	{
		country: "Bhutan",
		abbreviation: "BT"
	},
	{
		country: "Bolivia",
		abbreviation: "BO"
	},
	{
		country: "Bosnia and Herzegovina",
		abbreviation: "BA"
	},
	{
		country: "Botswana",
		abbreviation: "BW"
	},
	{
		country: "Bouvet Island",
		abbreviation: "BV"
	},
	{
		country: "Brazil",
		abbreviation: "BR"
	},
	{
		country: "British Indian Ocean Territory",
		abbreviation: "IO"
	},
	{
		country: "Brunei",
		abbreviation: "BN"
	},
	{
		country: "Bulgaria",
		abbreviation: "BG"
	},
	{
		country: "Burkina Faso",
		abbreviation: "BF"
	},
	{
		country: "Burundi",
		abbreviation: "BI"
	},
	{
		country: "Cambodia",
		abbreviation: "KH"
	},
	{
		country: "Cameroon",
		abbreviation: "CM"
	},
	{
		country: "Canada",
		abbreviation: "CA"
	},
	{
		country: "Cape Verde",
		abbreviation: "CV"
	},
	{
		country: "Cayman Islands",
		abbreviation: "KY"
	},
	{
		country: "Central African Republic",
		abbreviation: "CF"
	},
	{
		country: "Chad",
		abbreviation: "TD"
	},
	{
		country: "Chile",
		abbreviation: "CL"
	},
	{
		country: "China",
		abbreviation: "CN"
	},
	{
		country: "Christmas Island",
		abbreviation: "CX"
	},
	{
		country: "Cocos (Keeling) Islands",
		abbreviation: "CC"
	},
	{
		country: "Colombia",
		abbreviation: "CO"
	},
	{
		country: "Comoros",
		abbreviation: "KM"
	},
	{
		country: "Congo",
		abbreviation: "CG"
	},
	{
		country: "Cook Islands",
		abbreviation: "CK"
	},
	{
		country: "Costa Rica",
		abbreviation: "CR"
	},
	{
		country: "Croatia",
		abbreviation: "HR"
	},
	{
		country: "Cuba",
		abbreviation: "CU"
	},
	{
		country: "Cyprus",
		abbreviation: "CY"
	},
	{
		country: "Czech Republic",
		abbreviation: "CZ"
	},
	{
		country: "Denmark",
		abbreviation: "DK"
	},
	{
		country: "Djibouti",
		abbreviation: "DJ"
	},
	{
		country: "Dominica",
		abbreviation: "DM"
	},
	{
		country: "Dominican Republic",
		abbreviation: "DO"
	},
	{
		country: "East Timor",
		abbreviation: "TP"
	},
	{
		country: "Ecuador",
		abbreviation: "EC"
	},
	{
		country: "Egypt",
		abbreviation: "EG"
	},
	{
		country: "El Salvador",
		abbreviation: "SV"
	},
	{
		country: "Equatorial Guinea",
		abbreviation: "GQ"
	},
	{
		country: "Eritrea",
		abbreviation: "ER"
	},
	{
		country: "Estonia",
		abbreviation: "EE"
	},
	{
		country: "Ethiopia",
		abbreviation: "ET"
	},
	{
		country: "Falkland Islands",
		abbreviation: "FK"
	},
	{
		country: "Faroe Islands",
		abbreviation: "FO"
	},
	{
		country: "Fiji Islands",
		abbreviation: "FJ"
	},
	{
		country: "Finland",
		abbreviation: "FI"
	},
	{
		country: "France",
		abbreviation: "FR"
	},
	{
		country: "French Guiana",
		abbreviation: "GF"
	},
	{
		country: "French Polynesia",
		abbreviation: "PF"
	},
	{
		country: "French Southern territories",
		abbreviation: "TF"
	},
	{
		country: "Gabon",
		abbreviation: "GA"
	},
	{
		country: "Gambia",
		abbreviation: "GM"
	},
	{
		country: "Georgia",
		abbreviation: "GE"
	},
	{
		country: "Germany",
		abbreviation: "DE"
	},
	{
		country: "Ghana",
		abbreviation: "GH"
	},
	{
		country: "Gibraltar",
		abbreviation: "GI"
	},
	{
		country: "Greece",
		abbreviation: "GR"
	},
	{
		country: "Greenland",
		abbreviation: "GL"
	},
	{
		country: "Grenada",
		abbreviation: "GD"
	},
	{
		country: "Guadeloupe",
		abbreviation: "GP"
	},
	{
		country: "Guam",
		abbreviation: "GU"
	},
	{
		country: "Guatemala",
		abbreviation: "GT"
	},
	{
		country: "Guernsey",
		abbreviation: "GG"
	},
	{
		country: "Guinea",
		abbreviation: "GN"
	},
	{
		country: "Guinea-Bissau",
		abbreviation: "GW"
	},
	{
		country: "Guyana",
		abbreviation: "GY"
	},
	{
		country: "Haiti",
		abbreviation: "HT"
	},
	{
		country: "Heard Island and McDonald Islands",
		abbreviation: "HM"
	},
	{
		country: "Holy See (Vatican City State)",
		abbreviation: "VA"
	},
	{
		country: "Honduras",
		abbreviation: "HN"
	},
	{
		country: "Hong Kong",
		abbreviation: "HK"
	},
	{
		country: "Hungary",
		abbreviation: "HU"
	},
	{
		country: "Iceland",
		abbreviation: "IS"
	},
	{
		country: "India",
		abbreviation: "IN"
	},
	{
		country: "Indonesia",
		abbreviation: "ID"
	},
	{
		country: "Iran",
		abbreviation: "IR"
	},
	{
		country: "Iraq",
		abbreviation: "IQ"
	},
	{
		country: "Ireland",
		abbreviation: "IE"
	},
	{
		country: "Isle of Man",
		abbreviation: "IM"
	},
	{
		country: "Israel",
		abbreviation: "IL"
	},
	{
		country: "Italy",
		abbreviation: "IT"
	},
	{
		country: "Ivory Coast",
		abbreviation: "CI"
	},
	{
		country: "Jamaica",
		abbreviation: "JM"
	},
	{
		country: "Japan",
		abbreviation: "JP"
	},
	{
		country: "Jersey",
		abbreviation: "JE"
	},
	{
		country: "Jordan",
		abbreviation: "JO"
	},
	{
		country: "Kazakhstan",
		abbreviation: "KZ"
	},
	{
		country: "Kenya",
		abbreviation: "KE"
	},
	{
		country: "Kiribati",
		abbreviation: "KI"
	},
	{
		country: "Kuwait",
		abbreviation: "KW"
	},
	{
		country: "Kyrgyzstan",
		abbreviation: "KG"
	},
	{
		country: "Laos",
		abbreviation: "LA"
	},
	{
		country: "Latvia",
		abbreviation: "LV"
	},
	{
		country: "Lebanon",
		abbreviation: "LB"
	},
	{
		country: "Lesotho",
		abbreviation: "LS"
	},
	{
		country: "Liberia",
		abbreviation: "LR"
	},
	{
		country: "Libyan Arab Jamahiriya",
		abbreviation: "LY"
	},
	{
		country: "Liechtenstein",
		abbreviation: "LI"
	},
	{
		country: "Lithuania",
		abbreviation: "LT"
	},
	{
		country: "Luxembourg",
		abbreviation: "LU"
	},
	{
		country: "Macao",
		abbreviation: "MO"
	},
	{
		country: "North Macedonia",
		abbreviation: "MK"
	},
	{
		country: "Madagascar",
		abbreviation: "MG"
	},
	{
		country: "Malawi",
		abbreviation: "MW"
	},
	{
		country: "Malaysia",
		abbreviation: "MY"
	},
	{
		country: "Maldives",
		abbreviation: "MV"
	},
	{
		country: "Mali",
		abbreviation: "ML"
	},
	{
		country: "Malta",
		abbreviation: "MT"
	},
	{
		country: "Marshall Islands",
		abbreviation: "MH"
	},
	{
		country: "Martinique",
		abbreviation: "MQ"
	},
	{
		country: "Mauritania",
		abbreviation: "MR"
	},
	{
		country: "Mauritius",
		abbreviation: "MU"
	},
	{
		country: "Mayotte",
		abbreviation: "YT"
	},
	{
		country: "Mexico",
		abbreviation: "MX"
	},
	{
		country: "Micronesia, Federated States of",
		abbreviation: "FM"
	},
	{
		country: "Moldova",
		abbreviation: "MD"
	},
	{
		country: "Monaco",
		abbreviation: "MC"
	},
	{
		country: "Mongolia",
		abbreviation: "MN"
	},
	{
		country: "Montenegro",
		abbreviation: "ME"
	},
	{
		country: "Montserrat",
		abbreviation: "MS"
	},
	{
		country: "Morocco",
		abbreviation: "MA"
	},
	{
		country: "Mozambique",
		abbreviation: "MZ"
	},
	{
		country: "Myanmar",
		abbreviation: "MM"
	},
	{
		country: "Namibia",
		abbreviation: "NA"
	},
	{
		country: "Nauru",
		abbreviation: "NR"
	},
	{
		country: "Nepal",
		abbreviation: "NP"
	},
	{
		country: "Netherlands",
		abbreviation: "NL"
	},
	{
		country: "Netherlands Antilles",
		abbreviation: "AN"
	},
	{
		country: "New Caledonia",
		abbreviation: "NC"
	},
	{
		country: "New Zealand",
		abbreviation: "NZ"
	},
	{
		country: "Nicaragua",
		abbreviation: "NI"
	},
	{
		country: "Niger",
		abbreviation: "NE"
	},
	{
		country: "Nigeria",
		abbreviation: "NG"
	},
	{
		country: "Niue",
		abbreviation: "NU"
	},
	{
		country: "Norfolk Island",
		abbreviation: "NF"
	},
	{
		country: "North Korea",
		abbreviation: "KP"
	},
	{
		country: "Northern Ireland",
		abbreviation: "GB"
	},
	{
		country: "Northern Mariana Islands",
		abbreviation: "MP"
	},
	{
		country: "Norway",
		abbreviation: "NO"
	},
	{
		country: "Oman",
		abbreviation: "OM"
	},
	{
		country: "Pakistan",
		abbreviation: "PK"
	},
	{
		country: "Palau",
		abbreviation: "PW"
	},
	{
		country: "Palestine",
		abbreviation: "PS"
	},
	{
		country: "Panama",
		abbreviation: "PA"
	},
	{
		country: "Papua New Guinea",
		abbreviation: "PG"
	},
	{
		country: "Paraguay",
		abbreviation: "PY"
	},
	{
		country: "Peru",
		abbreviation: "PE"
	},
	{
		country: "Philippines",
		abbreviation: "PH"
	},
	{
		country: "Pitcairn",
		abbreviation: "PN"
	},
	{
		country: "Poland",
		abbreviation: "PL"
	},
	{
		country: "Portugal",
		abbreviation: "PT"
	},
	{
		country: "Puerto Rico",
		abbreviation: "PR"
	},
	{
		country: "Qatar",
		abbreviation: "QA"
	},
	{
		country: "Reunion",
		abbreviation: "RE"
	},
	{
		country: "Romania",
		abbreviation: "RO"
	},
	{
		country: "Russian Federation",
		abbreviation: "RU"
	},
	{
		country: "Rwanda",
		abbreviation: "RW"
	},
	{
		country: "Saint Helena",
		abbreviation: "SH"
	},
	{
		country: "Saint Kitts and Nevis",
		abbreviation: "KN"
	},
	{
		country: "Saint Lucia",
		abbreviation: "LC"
	},
	{
		country: "Saint Pierre and Miquelon",
		abbreviation: "PM"
	},
	{
		country: "Saint Vincent and the Grenadines",
		abbreviation: "VC"
	},
	{
		country: "Samoa",
		abbreviation: "WS"
	},
	{
		country: "San Marino",
		abbreviation: "SM"
	},
	{
		country: "Sao Tome and Principe",
		abbreviation: "ST"
	},
	{
		country: "Saudi Arabia",
		abbreviation: "SA"
	},
	{
		country: "Senegal",
		abbreviation: "SN"
	},
	{
		country: "Serbia",
		abbreviation: "RS"
	},
	{
		country: "Seychelles",
		abbreviation: "SC"
	},
	{
		country: "Sierra Leone",
		abbreviation: "SL"
	},
	{
		country: "Singapore",
		abbreviation: "SG"
	},
	{
		country: "Slovakia",
		abbreviation: "SK"
	},
	{
		country: "Slovenia",
		abbreviation: "SI"
	},
	{
		country: "Solomon Islands",
		abbreviation: "SB"
	},
	{
		country: "Somalia",
		abbreviation: "SO"
	},
	{
		country: "South Africa",
		abbreviation: "ZA"
	},
	{
		country: "South Georgia and the South Sandwich Islands",
		abbreviation: "GS"
	},
	{
		country: "South Korea",
		abbreviation: "KR"
	},
	{
		country: "South Sudan",
		abbreviation: "SS"
	},
	{
		country: "Spain",
		abbreviation: "ES"
	},
	{
		country: "Sri Lanka",
		abbreviation: "LK"
	},
	{
		country: "Sudan",
		abbreviation: "SD"
	},
	{
		country: "Suriname",
		abbreviation: "SR"
	},
	{
		country: "Svalbard and Jan Mayen",
		abbreviation: "SJ"
	},
	{
		country: "Swaziland",
		abbreviation: "SZ"
	},
	{
		country: "Sweden",
		abbreviation: "SE"
	},
	{
		country: "Switzerland",
		abbreviation: "CH"
	},
	{
		country: "Syria",
		abbreviation: "SY"
	},
	{
		country: "Tajikistan",
		abbreviation: "TJ"
	},
	{
		country: "Tanzania",
		abbreviation: "TZ"
	},
	{
		country: "Thailand",
		abbreviation: "TH"
	},
	{
		country: "The Democratic Republic of Congo",
		abbreviation: "CD"
	},
	{
		country: "Timor-Leste",
		abbreviation: "TL"
	},
	{
		country: "Togo",
		abbreviation: "TG"
	},
	{
		country: "Tokelau",
		abbreviation: "TK"
	},
	{
		country: "Tonga",
		abbreviation: "TO"
	},
	{
		country: "Trinidad and Tobago",
		abbreviation: "TT"
	},
	{
		country: "Tunisia",
		abbreviation: "TN"
	},
	{
		country: "Turkey",
		abbreviation: "TR"
	},
	{
		country: "Turkmenistan",
		abbreviation: "TM"
	},
	{
		country: "Turks and Caicos Islands",
		abbreviation: "TC"
	},
	{
		country: "Tuvalu",
		abbreviation: "TV"
	},
	{
		country: "Uganda",
		abbreviation: "UG"
	},
	{
		country: "Ukraine",
		abbreviation: "UA"
	},
	{
		country: "United Arab Emirates",
		abbreviation: "AE"
	},
	{
		country: "United Kingdom",
		abbreviation: "UK"
	},
	{
		country: "United States",
		abbreviation: "US"
	},
	{
		country: "United States Minor Outlying Islands",
		abbreviation: "UM"
	},
	{
		country: "Uruguay",
		abbreviation: "UY"
	},
	{
		country: "Uzbekistan",
		abbreviation: "UZ"
	},
	{
		country: "Vanuatu",
		abbreviation: "VU"
	},
	{
		country: "Venezuela",
		abbreviation: "VE"
	},
	{
		country: "Vietnam",
		abbreviation: "VN"
	},
	{
		country: "Virgin Islands, British",
		abbreviation: "VG"
	},
	{
		country: "Virgin Islands, U.S.",
		abbreviation: "VI"
	},
	{
		country: "Wallis and Futuna",
		abbreviation: "WF"
	},
	{
		country: "Western Sahara",
		abbreviation: "EH"
	},
	{
		country: "Yemen",
		abbreviation: "YE"
	},
	{
		country: "Zambia",
		abbreviation: "ZM"
	},
	{
		country: "Zimbabwe",
		abbreviation: "ZW"
	}
];

function _templateObject$j() {
  var data = _taggedTemplateLiteralLoose(["\n  width: 100%;\n  height: 100%;\n  position: relative;\n  background-color: #ffffff;\n  padding: 10px;\n"]);

  _templateObject$j = function _templateObject() {
    return data;
  };

  return data;
}
var StyledWorldMapChartWrapper = styled__default.div(_templateObject$j());
var world = topojson.feature(topology$2, topology$2.objects.units);
var tooltipTimeout$b;

var WorldMapChart = function WorldMapChart(_ref) {
  var data = _ref.data,
      metric = _ref.metric,
      color = _ref.color,
      emptyDataMessage = _ref.emptyDataMessage;
  var svgRef = React.useRef(null);
  var chartId = React.useRef(uniqid());
  var isEmpty = !data || data.length === 0;

  var _useState = React.useState(0),
      width = _useState[0],
      setWidth = _useState[1];

  var _useState2 = React.useState(0),
      height = _useState2[0],
      setHeight = _useState2[1];

  var centerX = width / 2;
  var centerY = height / 2;
  var scale$1 = width / 630 * 100;
  var max = data && Math.max.apply(Math, data.map(function (item) {
    return item[metric];
  })) || 0;
  var min = data && Math.min.apply(Math, data.map(function (item) {
    return item[metric];
  })) || 0;

  var _useTooltip = tooltip.useTooltip(),
      tooltipOpen = _useTooltip.tooltipOpen,
      tooltipLeft = _useTooltip.tooltipLeft,
      tooltipTop = _useTooltip.tooltipTop,
      tooltipData = _useTooltip.tooltipData,
      hideTooltip = _useTooltip.hideTooltip,
      showTooltip = _useTooltip.showTooltip;

  var windowSize = useWindowSize();
  var chartRef = React.useCallback(function (node) {
    if (node != null) {
      setWidth(node.getBoundingClientRect().width);
      setHeight(node.getBoundingClientRect().height);
    }
  }, [windowSize]);
  var colorsRange = getMapColors(color);
  var colorScale = React.useMemo(function () {
    return scale.scaleLinear({
      domain: [metric === METRICS.AFFINITY ? min : min * 100, metric === METRICS.AFFINITY ? max : max * 100],
      range: colorsRange
    });
  }, [metric, min, max, color]);
  var getFillColor = React.useCallback(function (item) {
    if (!metric) {
      return '#d8d7ea';
    }

    var value = item[metric] || 0;

    if (metric !== METRICS.AFFINITY) {
      value = value * 100;
    }

    return colorScale(value);
  }, [metric, colorScale]);
  var handleMouseMove = React.useCallback(function (event$1, feature, color) {
    if (color === void 0) {
      color = '#000000';
    }

    if (tooltipTimeout$b) clearTimeout(tooltipTimeout$b);
    if (!svgRef.current) return;
    var point = event.localPoint(svgRef.current, event$1);
    showTooltip({
      tooltipData: _extends({}, feature, {
        color: color
      }),
      tooltipTop: point === null || point === void 0 ? void 0 : point.y,
      tooltipLeft: point === null || point === void 0 ? void 0 : point.x
    });
  }, [svgRef, showTooltip]);
  var handleMouseLeave = React.useCallback(function (event) {
    tooltipTimeout$b = window.setTimeout(function () {
      hideTooltip();
    }, 0);
  }, [hideTooltip]);

  if (isEmpty) {
    return /*#__PURE__*/React__default.createElement(StyledWorldMapChartWrapper, null, /*#__PURE__*/React__default.createElement(hxReactComponents.Box, {
      minWidth: "100%"
    }, /*#__PURE__*/React__default.createElement(hxReactComponents.EmptyState, {
      icon: "analytics",
      mainText: emptyDataMessage,
      size: "large"
    })));
  }

  var checkGreatBritain = function checkGreatBritain(featureId, itemId) {
    return featureId === 'UK' && itemId === 'GB';
  };

  return /*#__PURE__*/React__default.createElement(StyledWorldMapChartWrapper, {
    ref: chartRef
  }, /*#__PURE__*/React__default.createElement("svg", {
    width: width,
    height: height,
    ref: svgRef
  }, /*#__PURE__*/React__default.createElement("rect", {
    x: 0,
    y: 0,
    width: width,
    height: height,
    fill: "#ffffff",
    rx: 14
  }), /*#__PURE__*/React__default.createElement(geo.Mercator, {
    data: world.features,
    scale: scale$1,
    translate: [centerX, centerY + 50]
  }, function (mercator) {
    return /*#__PURE__*/React__default.createElement(group.Group, {
      key: "group-" + chartId.current
    }, mercator.features.map(function (_ref2, i) {
      var feature = _ref2.feature,
          path = _ref2.path;
      var abbr = countriesAbbr.find(function (abbr) {
        return abbr.country === feature.properties.name;
      });
      var included = data && data.find(function (item) {
        return abbr && (item.id === abbr.abbreviation || checkGreatBritain(abbr.abbreviation, item.id));
      });

      if (included) {
        return /*#__PURE__*/React__default.createElement("path", {
          key: "map-feature-" + i,
          d: path || '',
          fill: getFillColor(included),
          stroke: "#ffffff",
          strokeWidth: 0.5,
          onMouseOver: function onMouseOver(event) {
            return handleMouseMove(event, included, getFillColor(included));
          },
          onMouseMove: function onMouseMove(event) {
            return handleMouseMove(event, included, getFillColor(included));
          },
          onMouseLeave: function onMouseLeave(event) {
            return handleMouseLeave(event);
          }
        });
      }

      if (abbr && abbr.country === 'Antarctica') {
        return null;
      }

      return /*#__PURE__*/React__default.createElement("path", {
        key: "map-feature-" + i,
        d: path || '',
        fill: "#d8d7ea",
        stroke: "#ffffff",
        strokeWidth: 0.5
      });
    }));
  }), metric && /*#__PURE__*/React__default.createElement(group.Group, {
    top: height - 40,
    left: centerX - 100
  }, /*#__PURE__*/React__default.createElement(gradient.LinearGradient, {
    from: colorsRange[0],
    to: colorsRange[1],
    id: "legend-gradient-" + color,
    vertical: false
  }), /*#__PURE__*/React__default.createElement(text.Text, {
    fontSize: "10px",
    fontWeight: "bold",
    textAnchor: "middle",
    verticalAnchor: "middle",
    fill: "#000000",
    width: 100,
    height: 20,
    x: 0,
    y: -10
  }, FormatUtils.formattedValue(min, metric)), /*#__PURE__*/React__default.createElement(text.Text, {
    fontSize: "10px",
    fontWeight: "bold",
    textAnchor: "middle",
    verticalAnchor: "middle",
    fill: "#000000",
    width: 100,
    height: 20,
    x: 200,
    y: -10
  }, "" + FormatUtils.formattedValue(max, metric)), /*#__PURE__*/React__default.createElement("rect", {
    width: 200,
    height: 20,
    fill: "url(#legend-gradient-" + color + ")"
  }), /*#__PURE__*/React__default.createElement(text.Text, {
    fontSize: "10px",
    fontWeight: "bold",
    textAnchor: "middle",
    verticalAnchor: "middle",
    fill: "#000000",
    width: 100,
    height: 20,
    x: 100,
    y: 30
  }, MAP_CHART_FIELDS_LABEL[metric]))), tooltipOpen && tooltipData && /*#__PURE__*/React__default.createElement(ChartTooltip, {
    opened: tooltipOpen,
    top: tooltipTop || 0,
    left: tooltipLeft || 0,
    data: tooltipData
  }, isReach(metric) && /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Reach: "), FormatUtils.formattedValue(getPopulationPerc(tooltipData), METRICS.REACH)), metric === METRICS.AFFINITY && /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Affinity: "), FormatUtils.formattedValue(tooltipData.target_audience_affinity, METRICS.AFFINITY)), metric === METRICS.BASE && /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Base: "), FormatUtils.formattedValue(tooltipData.base_population_perc, METRICS.BASE)), metric === METRICS.PENETRATION && /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Penetration: "), FormatUtils.formattedValue(tooltipData.penetration, METRICS.PENETRATION)), metric === METRICS.RELEVANCY && /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Relevance: "), FormatUtils.formattedValue(tooltipData.relevancy, METRICS.RELEVANCY))));
};

var MultipleBubbleChart = function MultipleBubbleChart(props) {
  var isEmpty = !props.data || props.data.length === 0;
  var keys = !isEmpty && Object.keys(props.data[0].metrics) || [];
  var bubbles = React.useMemo(function () {
    if (isEmpty) {
      return [];
    }

    var filteredData = props.limit && props.limit !== 'auto' ? props.data.slice(0, props.limit) : props.data;
    var items = filteredData.reduce(function (items, item) {
      keys.forEach(function (key) {
        items.push(_extends({
          id: key + "_" + item.id,
          label: item.label,
          pic: item.pic,
          color: props.colors[key]
        }, item.metrics[key]));
      });
      return items;
    }, []);
    return items;
  }, [isEmpty, props.data, keys, props.colors, props.limit]);
  return /*#__PURE__*/React__default.createElement(BubbleChart, _extends({}, props, {
    data: bubbles,
    limit: "auto"
  }));
};

function _templateObject$k() {
  var data = _taggedTemplateLiteralLoose(["\n  position: relative;\n  width: 100%;\n  height: 100%;\n"]);

  _templateObject$k = function _templateObject() {
    return data;
  };

  return data;
}
var StyledMultipleCloudChartWrapper = styled__default.div(_templateObject$k());

var CloudTooltipContent = function CloudTooltipContent(_ref) {
  var data = _ref.data,
      chartId = _ref.chartId,
      bars = _ref.bars;
  return /*#__PURE__*/React__default.createElement(React__default.Fragment, null, data.map(function (item, index) {
    return /*#__PURE__*/React__default.createElement("div", {
      style: {
        margin: '5px',
        paddingLeft: '5px',
        borderLeft: "3px solid " + item.color
      },
      key: "mosaic-tooltip-content-" + chartId + "-item-" + item.id + "-" + index
    }, /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Reach: "), FormatUtils.formattedValue(getPopulationPerc(item), METRICS.REACH)), /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Affinity: "), FormatUtils.formattedValue(item.target_audience_affinity, METRICS.AFFINITY)), /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Base: "), FormatUtils.formattedValue(item.base_population_perc, METRICS.BASE)), /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Penetration: "), FormatUtils.formattedValue(item.penetration, METRICS.PENETRATION)));
  }), /*#__PURE__*/React__default.createElement("div", {
    style: {
      display: 'flex',
      paddingLeft: '5px'
    }
  }, bars.map(function (bar, index) {
    return /*#__PURE__*/React__default.createElement("div", {
      key: "rect-" + chartId + "-item-" + index,
      style: {
        height: '15px',
        width: bar.width + "%",
        backgroundColor: bar.color
      }
    });
  })));
};

var tooltipTimeout$c;

var MultipleCloudChart = function MultipleCloudChart(_ref) {
  var data = _ref.data,
      metric = _ref.metric,
      emptyDataMessage = _ref.emptyDataMessage,
      colors = _ref.colors,
      _ref$limit = _ref.limit,
      limit = _ref$limit === void 0 ? 'auto' : _ref$limit,
      sortTarget = _ref.sortTarget,
      labels = _ref.labels,
      skip = _ref.skip;
  var svgRef = React.useRef(null);
  var chartId = React.useRef(uniqid());

  var _useState = React.useState(0),
      width = _useState[0],
      setWidth = _useState[1];

  var _useState2 = React.useState(0),
      height = _useState2[0],
      setHeight = _useState2[1];

  var isEmpty = !data || data.length === 0;
  var targets = !isEmpty && Object.keys(data[0].metrics) || [];
  var sort = sortTarget || 'similar';

  var _useTooltip = tooltip.useTooltip(),
      tooltipOpen = _useTooltip.tooltipOpen,
      tooltipLeft = _useTooltip.tooltipLeft,
      tooltipTop = _useTooltip.tooltipTop,
      tooltipData = _useTooltip.tooltipData,
      hideTooltip = _useTooltip.hideTooltip,
      showTooltip = _useTooltip.showTooltip;

  var windowSize = useWindowSize();
  var chartRef = React.useCallback(function (node) {
    if (node != null) {
      setWidth(node.getBoundingClientRect().width);
      setHeight(node.getBoundingClientRect().height);
    }
  }, [windowSize]);
  var handleMouseLeave = React.useCallback(function (event) {
    tooltipTimeout$c = window.setTimeout(function () {
      hideTooltip();
    }, 0);
  }, [hideTooltip]);
  var handleMouseMove = React.useCallback(function (event$1, id) {
    var item = data.find(function (item) {
      return item.id === id;
    });
    if (tooltipTimeout$c) clearTimeout(tooltipTimeout$c);
    var eventSvgCoords = event.localPoint(svgRef.current, event$1);
    showTooltip({
      tooltipData: _extends({}, item),
      tooltipTop: eventSvgCoords === null || eventSvgCoords === void 0 ? void 0 : eventSvgCoords.y,
      tooltipLeft: eventSvgCoords === null || eventSvgCoords === void 0 ? void 0 : eventSvgCoords.x
    });
  }, [data, showTooltip, svgRef.current]);
  var getTooltipContent = React.useCallback(function (item) {
    return targets.map(function (key) {
      return _extends({
        id: item.id,
        color: colors[key]
      }, item.metrics[key]);
    });
  }, [targets, colors]);
  var getMultiTargetBars = React.useCallback(function (item) {
    var bars = [];

    if (item && item.metrics) {
      var sum = [].concat(targets.map(function (key) {
        return item.metrics[key][metric];
      })).reduce(function (total, value) {
        return total + value;
      }, 0);
      bars = targets.map(function (target) {
        return {
          color: colors[target],
          width: item.metrics[target][metric] / sum * 100
        };
      });
    }

    return bars;
  }, [metric, targets, colors]);
  var packData = React.useMemo(function () {
    if (isEmpty) {
      return [];
    }

    var filteredData = limit !== 'auto' ? data.slice(0, limit) : data;
    var keys = sort === 'different' ? targets : ['single'];
    var chartData = keys.reduce(function (acc, targetId, targetIndex) {
      var list = filteredData.reduce(function (list, item, index) {
        var id = item.id,
            label = item.label,
            pic = item.pic,
            metrics = item.metrics;
        var children = [];
        var slices = [];
        var target = !['similar', 'different'].includes(sort) ? sort : targetId;

        if (sort !== 'different' || sort === 'different' && (1 * skip + index) % keys.length === targetIndex) {
          var _list$push;

          if (sort && !['similar', 'different'].includes(sort)) {
            children = targets.map(function (key, index) {
              var _ref2;

              var mainValue = metrics[sort] && metrics[sort][metric] || 0;
              var value = metrics[key] && metrics[key][metric] || 0;
              var diff = Math.abs(mainValue - value);
              var sign = value && value > mainValue ? '+' : '-';
              return _ref2 = {
                id: id,
                target: key,
                label: diff > 0 ? sign + FormatUtils.formattedValue(diff, metric) : FormatUtils.formattedValue(diff, metric)
              }, _ref2[metric] = metrics[key][metric], _ref2.parent = sort, _ref2.color = colors[key], _ref2;
            }).filter(function (key) {
              return key.target !== sort;
            });
          }

          if (sort === 'similar') {
            var sum = 0;
            Object.values(item.metrics).forEach(function (target) {
              sum += target[metric];
            });
            var rotate = 0;
            Object.entries(item.metrics).forEach(function (_ref3) {
              var key = _ref3[0],
                  value = _ref3[1];
              var angle = value[metric] / sum * 360;

              while (angle > 90) {
                slices.push({
                  rotate: rotate,
                  skew: 0,
                  color: colors[key]
                });
                rotate += 90;
                angle -= 90;
              }

              slices.push({
                rotate: rotate - 1,
                skew: 89 - angle,
                color: colors[key]
              });
              rotate += angle;
            });
          }

          list.push((_list$push = {
            id: id,
            label: label
          }, _list$push[metric] = metrics[target] && metrics[target][metric] || 1, _list$push.pic = pic, _list$push.target = target, _list$push.color = colors[target] || '#000', _list$push.children = children, _list$push.slices = slices, _list$push));
        }

        return list;
      }, []);
      acc[targetId] = list;
      return acc;
    }, {});
    return chartData;
  }, [data, limit, metric, colors, skip, sort, isEmpty, targets]);

  if (isEmpty) {
    return /*#__PURE__*/React__default.createElement(StyledMultipleCloudChartWrapper, null, /*#__PURE__*/React__default.createElement(hxReactComponents.Box, {
      minWidth: "100%"
    }, /*#__PURE__*/React__default.createElement(hxReactComponents.EmptyState, {
      icon: "analytics",
      mainText: emptyDataMessage,
      size: "large"
    })));
  }

  var getRoot = React.useCallback(function (root) {
    var _pack;

    var pack = (_pack = {
      children: packData[root],
      name: 'root'
    }, _pack[metric] = 0, _pack);
    return hierarchy.hierarchy(pack).sum(function (d) {
      return d[metric];
    });
  }, [packData]);
  return /*#__PURE__*/React__default.createElement(StyledMultipleCloudChartWrapper, {
    ref: chartRef
  }, /*#__PURE__*/React__default.createElement("svg", {
    width: width,
    height: height,
    ref: svgRef
  }, /*#__PURE__*/React__default.createElement("rect", {
    fill: "white",
    width: width,
    height: height,
    rx: 14
  }), /*#__PURE__*/React__default.createElement(group.Group, {
    top: 0,
    left: 0,
    key: "group-" + chartId.current
  }, sort === 'different' ? /*#__PURE__*/React__default.createElement("foreignObject", {
    x: "0",
    y: "0",
    width: width,
    height: height
  }, /*#__PURE__*/React__default.createElement(hxReactComponents.Row, {
    valign: "equal",
    halign: "left",
    style: {
      height: '100%',
      width: '100%'
    }
  }, targets.map(function (key, index) {
    return /*#__PURE__*/React__default.createElement(hxReactComponents.Col, {
      span: 12 / targets.length,
      key: "col-" + chartId.current + "-" + index,
      style: {
        height: '100%',
        width: '100%'
      }
    }, /*#__PURE__*/React__default.createElement("div", {
      style: {
        display: 'flex',
        flexDirection: 'column',
        justifyContent: 'space-between',
        height: '100%',
        width: '100%'
      }
    }, /*#__PURE__*/React__default.createElement("div", {
      style: {
        width: '100%',
        height: '80px',
        maxHeight: '80px',
        minHeight: '80px',
        display: 'flex',
        justifyContent: 'center',
        alignItems: 'center'
      }
    }, /*#__PURE__*/React__default.createElement(hxReactComponents.Text, {
      weight: "bold",
      lettercase: "uppercase",
      align: "center",
      size: "small",
      style: {
        color: colors[key],
        maxWidth: '100%',
        textOverflow: 'ellipsis',
        overflow: 'hidden'
      }
    }, labels[key])), /*#__PURE__*/React__default.createElement("div", {
      style: {
        backgroundColor: colors[key] + '40'
      }
    }, /*#__PURE__*/React__default.createElement("svg", {
      width: width > 0 ? width / targets.length - 20 : width,
      height: height - 80
    }, /*#__PURE__*/React__default.createElement(hierarchy.Pack, {
      root: getRoot(key),
      size: [width > 0 ? width / targets.length - 20 : width, height - 80]
    }, function (packData) {
      var circles = packData.descendants().slice(1);
      return /*#__PURE__*/React__default.createElement("foreignObject", {
        x: "0",
        y: "0",
        width: width > 0 ? width / targets.length - 20 : width,
        height: height
      }, circles.map(function (circle, i) {
        if (circle.x >= 0 && circle.y >= 0 && circle.r >= 0 && !circle.data.parent) {
          var id = circle.data && circle.data.id;
          return /*#__PURE__*/React__default.createElement("div", {
            key: "circle-" + chartId.current + "-" + i,
            onMouseMove: function onMouseMove(event) {
              return handleMouseMove(event, id);
            },
            onMouseLeave: function onMouseLeave(event) {
              return handleMouseLeave(event);
            }
          }, /*#__PURE__*/React__default.createElement(CloudChartImage, {
            radius: circle.r,
            x: circle.x,
            y: circle.y,
            label: circle.data && circle.data.label,
            color: circle.data && circle.data.color || '#c6c6c6',
            pic: circle.data && circle.data.pic,
            children: circle.data.children,
            slices: circle.data.slices
          }));
        }
      }));
    })))));
  }))) : /*#__PURE__*/React__default.createElement("foreignObject", {
    x: "0",
    y: "0",
    width: width,
    height: height
  }, /*#__PURE__*/React__default.createElement(hxReactComponents.Box, {
    style: {
      height: '100%',
      width: '100%'
    }
  }, /*#__PURE__*/React__default.createElement(hierarchy.Pack, {
    root: getRoot('single'),
    size: [width, height]
  }, function (packData) {
    var circles = packData.descendants().slice(1);
    return /*#__PURE__*/React__default.createElement("svg", {
      width: width,
      height: height
    }, /*#__PURE__*/React__default.createElement("foreignObject", {
      x: "0",
      y: "0",
      width: width,
      height: height
    }, circles.map(function (circle, i) {
      if (circle.x >= 0 && circle.y >= 0 && circle.r >= 0 && !circle.data.parent) {
        var id = circle.data && circle.data.id;
        return /*#__PURE__*/React__default.createElement("div", {
          key: "circle-" + chartId.current + "-" + i,
          onMouseMove: function onMouseMove(event) {
            return handleMouseMove(event, id);
          },
          onMouseLeave: function onMouseLeave(event) {
            return handleMouseLeave(event);
          }
        }, /*#__PURE__*/React__default.createElement(CloudChartImage, {
          radius: circle.r,
          x: circle.x,
          y: circle.y,
          label: circle.data && circle.data.label,
          color: circle.data && circle.data.color || '#c6c6c6',
          pic: circle.data && circle.data.pic,
          children: circle.data.children,
          slices: circle.data.slices
        }));
      }
    })));
  }))))), tooltipOpen && tooltipData && /*#__PURE__*/React__default.createElement(ChartTooltip, {
    opened: tooltipOpen,
    top: tooltipTop || 0,
    left: tooltipLeft || 0,
    data: tooltipData
  }, /*#__PURE__*/React__default.createElement(CloudTooltipContent, {
    data: getTooltipContent(tooltipData),
    chartId: chartId.current,
    bars: getMultiTargetBars(tooltipData)
  })));
};

function _templateObject$l() {
  var data = _taggedTemplateLiteralLoose(["\n  width: 100%;\n  height: 100%;\n  position: relative;\n  background-color: #ffffff;\n  padding: 10px;\n"]);

  _templateObject$l = function _templateObject() {
    return data;
  };

  return data;
}
var StyledMultipleColumnChartWrapper = styled__default.div(_templateObject$l());
var defaultMargin$9 = {
  top: 50,
  right: 50,
  bottom: 50,
  left: 100
};
var tooltipTimeout$d;

var MultipleColumnChart = function MultipleColumnChart(_ref) {
  var data = _ref.data,
      yAxis = _ref.yAxis,
      zAxis = _ref.zAxis,
      limit = _ref.limit,
      _ref$margin = _ref.margin,
      margin = _ref$margin === void 0 ? defaultMargin$9 : _ref$margin,
      showItemsPreview = _ref.showItemsPreview,
      showValuesOn100 = _ref.showValuesOn100,
      emptyDataMessage = _ref.emptyDataMessage,
      colors = _ref.colors;
  var svgRef = React.useRef(null);
  var chartId = React.useRef(uniqid());

  var _useState = React.useState(0),
      width = _useState[0],
      setWidth = _useState[1];

  var _useState2 = React.useState(0),
      height = _useState2[0],
      setHeight = _useState2[1];

  var isEmpty = !data || data.length === 0;

  var _useTooltip = tooltip.useTooltip(),
      tooltipOpen = _useTooltip.tooltipOpen,
      tooltipLeft = _useTooltip.tooltipLeft,
      tooltipTop = _useTooltip.tooltipTop,
      tooltipData = _useTooltip.tooltipData,
      hideTooltip = _useTooltip.hideTooltip,
      showTooltip = _useTooltip.showTooltip;

  var windowSize = useWindowSize();
  var chartRef = React.useCallback(function (node) {
    if (node != null) {
      setWidth(node.getBoundingClientRect().width);
      setHeight(node.getBoundingClientRect().height);
    }
  }, [windowSize]);
  var keys = !isEmpty && Object.keys(data[0].metrics) || [];
  var colorScale = React.useMemo(function () {
    return scale.scaleOrdinal({
      domain: Object.keys(colors),
      range: Object.values(colors)
    });
  }, [colors]);
  var filteredData = React.useMemo(function () {
    if (isEmpty) {
      return [];
    }

    return limit !== 'auto' ? data.slice(0, limit) : data;
  }, [isEmpty, data, limit]);
  var barGroupData = React.useMemo(function () {
    return filteredData.map(function (d) {
      var item = {
        id: d.id
      };
      keys.forEach(function (key) {
        item[key] = d.metrics[key][yAxis];
      });
      return item;
    });
  }, [filteredData, keys, yAxis, showValuesOn100]);
  var minMaxValues = React.useMemo(function () {
    return {
      yMin: isReach(yAxis) || showValuesOn100 ? 0 : Math.min.apply(Math, filteredData.map(function (d) {
        return Math.min.apply(Math, keys.map(function (key) {
          return d.metrics[key][yAxis];
        }));
      })),
      yMax: Math.max.apply(Math, filteredData.map(function (d) {
        return Math.max.apply(Math, keys.map(function (key) {
          return d.metrics[key][yAxis];
        }));
      })),
      zMin: isReach(yAxis) || showValuesOn100 ? Math.min.apply(Math, filteredData.map(function (d) {
        return Math.min.apply(Math, keys.map(function (key) {
          return d.metrics[key][zAxis];
        }));
      })) : 0,
      zMax: isReach(yAxis) || showValuesOn100 ? Math.max.apply(Math, filteredData.map(function (d) {
        return Math.max.apply(Math, keys.map(function (key) {
          return d.metrics[key][zAxis];
        }));
      })) : 0
    };
  }, [yAxis, zAxis, showValuesOn100, filteredData, keys]);
  var yzDiff = Math.max(minMaxValues.yMax - minMaxValues.yMin, minMaxValues.zMax - minMaxValues.zMin, 0);
  var yzMin = Math.min(minMaxValues.yMin, minMaxValues.zMin);
  var yzMax = Math.max(minMaxValues.yMax, minMaxValues.zMax);
  var yDomain = React.useMemo(function () {
    return [yzMin - yzDiff / 3 < 0 ? 0 : yzMin - yzDiff / 3, showValuesOn100 || yAxis !== METRICS.AFFINITY && yzMax + yzDiff / 3 > 1 ? 1 : yzMax + yzDiff / 3];
  }, [minMaxValues, yzDiff, showValuesOn100, yzMin, yzMax, yAxis]);
  var yScale = React.useMemo(function () {
    return scale.scaleLinear({
      domain: yDomain,
      range: [0, showValuesOn100 || yzMax > 1 ? 1 : yzMax],
      nice: true
    });
  }, [yzMax, yDomain, showValuesOn100]);
  var x0Scale = React.useMemo(function () {
    return scale.scaleBand({
      domain: filteredData && filteredData.map(function (item) {
        return item.id;
      }) || [],
      padding: 0.2
    });
  }, [filteredData]);
  var x1Scale = React.useMemo(function () {
    return scale.scaleBand({
      domain: keys,
      padding: 0.1
    });
  }, [keys]);
  var xMax = width - margin.left - margin.right;
  var yMax = height - margin.top - margin.bottom;
  x0Scale.rangeRound([0, xMax]);
  x1Scale.rangeRound([0, x0Scale.bandwidth()]);
  yScale.range([yMax, 0]);
  var getZValue = React.useCallback(function (index) {
    return Math.max.apply(Math, keys.map(function (key) {
      return filteredData[index].metrics[key][zAxis];
    }));
  }, [zAxis, filteredData, keys]);
  var getZBar = React.useCallback(function (index, x0) {
    var _yScale;

    var zValue = getZValue(index);
    var barZWidth = x0Scale.bandwidth() + 5;
    var barZHeight = yMax - ((_yScale = yScale(zValue)) != null ? _yScale : 0);
    var barZ = yMax - barZHeight;

    if (x0 > 0 && barZ > 0 && isReach(yAxis)) {
      return /*#__PURE__*/React__default.createElement(shape.BarRounded, {
        x: x0 - 5,
        y: barZ,
        all: true,
        radius: barZWidth / 4,
        width: barZWidth,
        height: barZHeight,
        fill: "#0ABAA6",
        fillOpacity: 0.4
      });
    }
  }, [filteredData, getZValue, x0Scale, yScale]);
  var getTickInsightType = React.useCallback(function (d) {
    var item = filteredData.find(function (i) {
      return i.id === d;
    });
    return item && item.insight_type || '';
  }, [filteredData]);
  var getTickImage = React.useCallback(function (d) {
    var item = filteredData.find(function (i) {
      return i.id === d;
    });
    return item && item.pic || '';
  }, [filteredData]);
  var getTickLabel = React.useCallback(function (d) {
    var item = filteredData.find(function (i) {
      return i.id === d;
    });
    return item && item.label || '';
  }, [filteredData]);
  var getGroupContent = React.useCallback(function (group, groups, index) {
    var options = groups.tickLabelProps(group.value);

    var props = _extends({}, options, {
      x: group.to.x,
      y: 10 + group.to.y,
      index: index
    });

    return groups.tickComponent(props);
  }, []);
  var getTickComponent = React.useCallback(function (d) {
    return /*#__PURE__*/React__default.createElement(React__default.Fragment, {
      key: "multiple-column-" + chartId.current + "-category-" + d.id
    }, /*#__PURE__*/React__default.createElement(ColumnChartImage, {
      d: d,
      color: colorScale(d.index),
      showItemsPreview: showItemsPreview,
      chartId: chartId.current
    }));
  }, [showItemsPreview, chartId.current]);
  var handleMouseLeave = React.useCallback(function (event) {
    tooltipTimeout$d = window.setTimeout(function () {
      hideTooltip();
    }, 0);
  }, [hideTooltip]);
  var handleMouseMove = React.useCallback(function (event$1, index, targetId, color) {
    if (color === void 0) {
      color = '#26a65b';
    }

    if (tooltipTimeout$d) clearTimeout(tooltipTimeout$d);
    var eventSvgCoords = event.localPoint(event$1);
    showTooltip({
      tooltipData: _extends({}, filteredData[index].metrics[targetId], {
        label: filteredData[index].label,
        color: color
      }),
      tooltipTop: eventSvgCoords === null || eventSvgCoords === void 0 ? void 0 : eventSvgCoords.y,
      tooltipLeft: eventSvgCoords === null || eventSvgCoords === void 0 ? void 0 : eventSvgCoords.x
    });
  }, [showTooltip, filteredData]);

  if (isEmpty) {
    return /*#__PURE__*/React__default.createElement(StyledMultipleColumnChartWrapper, null, /*#__PURE__*/React__default.createElement(hxReactComponents.Box, {
      minWidth: "100%"
    }, /*#__PURE__*/React__default.createElement(hxReactComponents.EmptyState, {
      icon: "analytics",
      mainText: emptyDataMessage,
      size: "large"
    })));
  }

  return /*#__PURE__*/React__default.createElement(StyledMultipleColumnChartWrapper, {
    ref: chartRef
  }, /*#__PURE__*/React__default.createElement("svg", {
    ref: svgRef,
    width: width,
    height: height
  }, /*#__PURE__*/React__default.createElement("rect", {
    width: width,
    height: height,
    fill: "#ffffff",
    rx: 14
  }), /*#__PURE__*/React__default.createElement(grid.Grid, {
    top: margin.top,
    left: margin.left,
    xScale: x0Scale,
    yScale: yScale,
    width: xMax,
    height: yMax
  }), /*#__PURE__*/React__default.createElement(group.Group, {
    top: margin.top,
    left: margin.left
  }, /*#__PURE__*/React__default.createElement(shape.BarGroup, {
    data: barGroupData,
    keys: keys,
    height: yMax,
    x0: function x0(item) {
      return item.id;
    },
    x0Scale: x0Scale,
    x1Scale: x1Scale,
    yScale: yScale,
    color: colorScale
  }, function (barGroups) {
    return barGroups.map(function (barGroup) {
      return /*#__PURE__*/React__default.createElement(group.Group, {
        key: "multiple-column-" + chartId.current + "-bar-group-" + barGroup.index + "-" + barGroup.x0,
        left: barGroup.x0
      }, getZBar(barGroup.index, barGroup.bars[0].x), barGroup.bars.map(function (bar) {
        return /*#__PURE__*/React__default.createElement(React__default.Fragment, {
          key: "multiple-column-" + chartId.current + "-bar-" + barGroup.index + "-" + bar.index + "-" + bar.value + "-" + bar.key
        }, bar.value && bar.value >= 0 && bar.height >= 0 && /*#__PURE__*/React__default.createElement(shape.BarRounded, {
          x: bar.x,
          y: bar.y,
          width: bar.width,
          height: bar.height,
          radius: bar.width / 4,
          all: true,
          fill: bar.color,
          fillOpacity: isReach(yAxis) ? 0.7 : 1,
          onMouseMove: function onMouseMove(event) {
            return handleMouseMove(event, barGroup.index, bar.key, bar.color);
          },
          onMouseLeave: function onMouseLeave(event) {
            return handleMouseLeave(event);
          },
          onTouchMove: function onTouchMove(event) {
            return handleMouseMove(event, barGroup.index, bar.key, bar.color);
          },
          onTouchEnd: function onTouchEnd(event) {
            return handleMouseLeave(event);
          }
        }));
      }));
    });
  }), /*#__PURE__*/React__default.createElement(axis.AxisLeft, {
    label: MAP_CHART_FIELDS_LABEL[yAxis],
    scale: yScale,
    stroke: "#9493A6",
    tickStroke: "#9493A6",
    tickFormat: function tickFormat(d) {
      return FormatUtils.formattedValue(d, yAxis);
    },
    tickLabelProps: function tickLabelProps() {
      return {
        fill: '#9493A6',
        fontSize: 11,
        textAnchor: 'end',
        dy: '0.33em',
        dx: '-0.33em',
        fontWeight: 'bold'
      };
    },
    labelProps: {
      fill: 'black',
      textAnchor: 'middle',
      fontSize: 14,
      fontWeight: 'bold',
      dx: '-1.2em'
    }
  }), /*#__PURE__*/React__default.createElement(axis.AxisBottom, {
    top: yMax,
    scale: x0Scale,
    tickLabelProps: function tickLabelProps(d) {
      return {
        fontSize: '11px',
        pic: getTickImage(d),
        id: d,
        label: getTickLabel(d),
        insight_type: getTickInsightType(d)
      };
    },
    tickComponent: function tickComponent(d) {
      return getTickComponent(d);
    }
  }, function (axisGroups) {
    return /*#__PURE__*/React__default.createElement(React__default.Fragment, null, axisGroups.ticks.map(function (group$1, index) {
      return /*#__PURE__*/React__default.createElement(group.Group, {
        key: "multiple-column-" + chartId.current + "-axis-group-" + index
      }, getGroupContent(group$1, axisGroups, index));
    }));
  }))), tooltipOpen && tooltipData && /*#__PURE__*/React__default.createElement(ChartTooltip, {
    opened: tooltipOpen,
    top: tooltipTop || 0,
    left: tooltipLeft || 0,
    data: tooltipData
  }, /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Reach: "), FormatUtils.formattedValue(getPopulationPerc(tooltipData), METRICS.REACH)), /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Affinity: "), FormatUtils.formattedValue(tooltipData.target_audience_affinity, METRICS.AFFINITY)), /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Base: "), FormatUtils.formattedValue(tooltipData.base_population_perc, METRICS.BASE)), /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Penetration: "), FormatUtils.formattedValue(tooltipData.penetration, METRICS.PENETRATION))));
};

function _templateObject$m() {
  var data = _taggedTemplateLiteralLoose(["\n  width: 100%;\n  height: 100%;\n  position: relative;\n  background-color: #ffffff;\n  padding: 10px;\n"]);

  _templateObject$m = function _templateObject() {
    return data;
  };

  return data;
}
var StyledMultipleStackedChartWrapper = styled__default.div(_templateObject$m());
var defaultMargin$a = {
  top: 50,
  right: 50,
  bottom: 50,
  left: 100
};
var tooltipTimeout$e;

var MultipleStackedChart = function MultipleStackedChart(_ref) {
  var _ref$margin = _ref.margin,
      margin = _ref$margin === void 0 ? defaultMargin$a : _ref$margin,
      data = _ref.data,
      xAxis = _ref.xAxis,
      zAxis = _ref.zAxis,
      emptyDataMessage = _ref.emptyDataMessage,
      _ref$limit = _ref.limit,
      limit = _ref$limit === void 0 ? 'auto' : _ref$limit,
      showAxisLeft = _ref.showAxisLeft,
      showItemsPreview = _ref.showItemsPreview,
      colors = _ref.colors,
      limitText = _ref.limitText,
      textWidth = _ref.textWidth;
  var svgRef = React.useRef(null);
  var chartId = React.useRef(uniqid());
  var isEmpty = !data || data.length === 0;

  var _useState = React.useState(0),
      width = _useState[0],
      setWidth = _useState[1];

  var _useState2 = React.useState(0),
      height = _useState2[0],
      setHeight = _useState2[1];

  var _useTooltip = tooltip.useTooltip(),
      tooltipOpen = _useTooltip.tooltipOpen,
      tooltipLeft = _useTooltip.tooltipLeft,
      tooltipTop = _useTooltip.tooltipTop,
      tooltipData = _useTooltip.tooltipData,
      hideTooltip = _useTooltip.hideTooltip,
      showTooltip = _useTooltip.showTooltip;

  var windowSize = useWindowSize();
  var chartRef = React.useCallback(function (node) {
    if (node != null) {
      setWidth(node.getBoundingClientRect().width);
      setHeight(node.getBoundingClientRect().height);
    }
  }, [windowSize]);
  var keys = !isEmpty && Object.keys(data[0].metrics) || [];
  var colorScale = React.useMemo(function () {
    return scale.scaleOrdinal({
      domain: Object.keys(colors),
      range: Object.values(colors)
    });
  }, [colors]);
  var filteredData = React.useMemo(function () {
    if (isEmpty) {
      return [];
    }

    return limit !== 'auto' ? data.slice(0, limit) : data;
  }, [isEmpty, data, limit]);
  var minMaxValues = React.useMemo(function () {
    return {
      xMin: Math.min.apply(Math, filteredData.map(function (d) {
        return Math.min.apply(Math, keys.map(function (key) {
          return d.metrics[key][xAxis];
        }));
      })),
      xMax: Math.max.apply(Math, filteredData.map(function (d) {
        return Math.max.apply(Math, keys.map(function (key) {
          return d.metrics[key][xAxis];
        }));
      })),
      zMin: isReach(xAxis) ? Math.min.apply(Math, filteredData.map(function (d) {
        return Math.min.apply(Math, keys.map(function (key) {
          return d.metrics[key][zAxis];
        }));
      })) : Math.min.apply(Math, filteredData.map(function (d) {
        return Math.min.apply(Math, keys.map(function (key) {
          return d.metrics[key][xAxis];
        }));
      })),
      zMax: isReach(xAxis) ? Math.max.apply(Math, filteredData.map(function (d) {
        return Math.max.apply(Math, keys.map(function (key) {
          return d.metrics[key][zAxis];
        }));
      })) : Math.max.apply(Math, filteredData.map(function (d) {
        return Math.max.apply(Math, keys.map(function (key) {
          return d.metrics[key][xAxis];
        }));
      }))
    };
  }, [filteredData, keys, xAxis, zAxis]);
  var xzDiff = Math.max(minMaxValues.xMax - minMaxValues.xMin, minMaxValues.zMax - minMaxValues.zMin, 0);
  var xzMin = Math.min(minMaxValues.xMin, minMaxValues.zMin);
  var xzMax = Math.max(minMaxValues.xMax, minMaxValues.zMax);
  var offsetXZMin = MAP_CHART_FIELDS_THRESHOLD[xAxis] > 0 && xzMin >= MAP_CHART_FIELDS_THRESHOLD[xAxis] ? MAP_CHART_FIELDS_THRESHOLD[xAxis] : (xzMin - xzDiff) / 10;
  var offsetXZMax = MAP_CHART_FIELDS_THRESHOLD[xAxis] > 0 && xzMax + xzDiff / 10 < MAP_CHART_FIELDS_THRESHOLD[xAxis] ? MAP_CHART_FIELDS_THRESHOLD[xAxis] : xzMax + xzDiff / 10;
  var xDomain = React.useMemo(function () {
    return [METRICS.AFFINITY !== xAxis || offsetXZMin < 0 ? 0 : offsetXZMin, offsetXZMax];
  }, [offsetXZMin, offsetXZMax, xAxis]);
  var xScale = React.useMemo(function () {
    return scale.scaleLinear({
      domain: xDomain,
      range: [0, xzMax]
    });
  }, [xDomain, xzMax]);
  var getZValue = React.useCallback(function (index) {
    return Math.max.apply(Math, keys.map(function (key) {
      return filteredData[index].metrics[key][zAxis];
    }));
  }, [zAxis, filteredData, keys]);
  var y0Scale = React.useMemo(function () {
    return scale.scaleBand({
      domain: filteredData && filteredData.map(function (item) {
        return item.id;
      }) || [],
      padding: 0.1
    });
  }, [filteredData]);
  var y1Scale = React.useMemo(function () {
    return scale.scaleBand({
      domain: keys,
      padding: 0.25
    });
  }, [keys]);
  var xTicks = React.useMemo(function () {
    var min = xzDiff < 1 ? 5 : xzDiff + 4;

    if (xAxis !== METRICS.AFFINITY) {
      min = xzDiff <= 0.01 ? 1 : xzDiff * 100;
    }

    if (width < 520) {
      return Math.min(min, 2);
    }

    return Math.min(min, 10);
  }, [xzDiff, xAxis, width]);
  var getGroupContent = React.useCallback(function (group, groups, index) {
    var options = groups.tickLabelProps(group.value);

    var props = _extends({}, options, {
      x: group.to.x,
      y: 10 + group.to.y,
      index: index
    });

    return groups.tickComponent(props);
  }, []);
  var getTickComponent = React.useCallback(function (d) {
    return /*#__PURE__*/React__default.createElement(React__default.Fragment, {
      key: "multiple-stacked-" + chartId.current + "-category-" + d.id
    }, /*#__PURE__*/React__default.createElement(StackedChartImage, {
      d: d,
      chartId: chartId.current,
      color: "#e6e6e6",
      showItemsPreview: showItemsPreview,
      setMinFontSize: filteredData && filteredData.length > 5,
      limitText: limitText,
      textWidth: textWidth
    }));
  }, [filteredData, showItemsPreview, chartId.current]);
  var getTickImage = React.useCallback(function (d) {
    var item = filteredData.find(function (i) {
      return i.id === d;
    });
    return item && item.pic || '';
  }, [filteredData]);
  var getTickLabel = React.useCallback(function (d) {
    var item = filteredData.find(function (i) {
      return i.id === d;
    });
    return item && item.label || '';
  }, [filteredData]);
  var barGroupData = React.useMemo(function () {
    return filteredData.map(function (d) {
      var item = {
        id: d.id
      };
      keys.forEach(function (key) {
        item[key] = d.metrics[key][xAxis];
      });
      return item;
    });
  }, [filteredData, keys, xAxis]);
  var handleMouseLeave = React.useCallback(function (event) {
    tooltipTimeout$e = window.setTimeout(function () {
      hideTooltip();
    }, 0);
  }, [hideTooltip]);
  var handleMouseMove = React.useCallback(function (event$1, index, targetId, color) {
    if (color === void 0) {
      color = '#26a65b';
    }

    if (tooltipTimeout$e) clearTimeout(tooltipTimeout$e);
    var eventSvgCoords = event.localPoint(event$1);
    showTooltip({
      tooltipData: _extends({}, filteredData[index].metrics[targetId], {
        label: filteredData[index].label,
        color: color
      }),
      tooltipTop: eventSvgCoords === null || eventSvgCoords === void 0 ? void 0 : eventSvgCoords.y,
      tooltipLeft: eventSvgCoords === null || eventSvgCoords === void 0 ? void 0 : eventSvgCoords.x
    });
  }, [showTooltip, filteredData]);
  var getZBar = React.useCallback(function (index) {
    var barZValue = getZValue(index);
    var barHeight = y0Scale.bandwidth();
    var barZWidth = barZValue < MAP_CHART_FIELDS_THRESHOLD[zAxis] ? xScale(MAP_CHART_FIELDS_THRESHOLD[zAxis]) - xScale(barZValue) : xScale(barZValue) - xScale(MAP_CHART_FIELDS_THRESHOLD[zAxis]);
    var barZ = barZValue < MAP_CHART_FIELDS_THRESHOLD[zAxis] ? xScale(barZValue) : xScale(MAP_CHART_FIELDS_THRESHOLD[zAxis]);

    if (barZ >= 0 && barZWidth > 0 && isReach(xAxis)) {
      return /*#__PURE__*/React__default.createElement(shape.BarRounded, {
        x: barZ,
        y: 0,
        all: true,
        radius: barZWidth / 4,
        width: barZWidth,
        height: barHeight,
        fill: "#0ABAA6",
        fillOpacity: 0.4
      });
    }
  }, [filteredData, getZValue, y0Scale, xScale, xAxis]);
  var xMax = width - margin.left - margin.right;
  var yMax = height - margin.top - margin.bottom;
  y0Scale.rangeRound([0, yMax]);
  y1Scale.rangeRound([0, y0Scale.bandwidth()]);
  xScale.rangeRound([0, xMax]);

  if (isEmpty) {
    return /*#__PURE__*/React__default.createElement(StyledMultipleStackedChartWrapper, null, /*#__PURE__*/React__default.createElement(hxReactComponents.Box, {
      minWidth: "100%"
    }, /*#__PURE__*/React__default.createElement(hxReactComponents.EmptyState, {
      icon: "analytics",
      mainText: emptyDataMessage,
      size: "large"
    })));
  }

  return /*#__PURE__*/React__default.createElement(StyledMultipleStackedChartWrapper, {
    ref: chartRef
  }, /*#__PURE__*/React__default.createElement("svg", {
    ref: svgRef,
    width: width,
    height: height
  }, /*#__PURE__*/React__default.createElement("rect", {
    width: width,
    height: height,
    fill: "#ffffff",
    rx: 14
  }), /*#__PURE__*/React__default.createElement(grid.GridRows, {
    top: margin.top,
    left: margin.left,
    scale: y0Scale,
    width: xMax,
    height: yMax
  }), /*#__PURE__*/React__default.createElement(group.Group, {
    top: margin.top,
    left: margin.left
  }, /*#__PURE__*/React__default.createElement(shape.BarGroupHorizontal, {
    data: barGroupData,
    keys: keys,
    width: xMax,
    y0: function y0(item) {
      return item.id;
    },
    y0Scale: y0Scale,
    y1Scale: y1Scale,
    xScale: xScale,
    color: colorScale
  }, function (barGroups) {
    return barGroups.map(function (barGroup) {
      return /*#__PURE__*/React__default.createElement(group.Group, {
        key: "multiple-stacked-" + chartId.current + "-bar-group-" + barGroup.index + "-" + barGroup.y0,
        top: barGroup.y0
      }, getZBar(barGroup.index), barGroup.bars.map(function (bar) {
        var barWidth = bar.value < MAP_CHART_FIELDS_THRESHOLD[xAxis] ? xScale(MAP_CHART_FIELDS_THRESHOLD[xAxis]) - xScale(bar.value) : xScale(bar.value) - xScale(MAP_CHART_FIELDS_THRESHOLD[xAxis]);
        var barX = bar.value < MAP_CHART_FIELDS_THRESHOLD[xAxis] ? xScale(bar.value) : xScale(MAP_CHART_FIELDS_THRESHOLD[xAxis]);
        return /*#__PURE__*/React__default.createElement(React__default.Fragment, {
          key: "multiple-stacked-" + chartId.current + "-bar-" + barGroup.index + "-" + bar.index + "-" + bar.key
        }, barX >= 0 && bar.y > 0 && barWidth > 0 && /*#__PURE__*/React__default.createElement(shape.BarRounded, {
          x: barX,
          y: bar.y,
          all: true,
          width: barWidth,
          height: bar.height,
          fill: bar.color,
          fillOpacity: isReach(xAxis) ? 0.7 : 1,
          radius: barWidth / 4,
          onMouseMove: function onMouseMove(event) {
            return handleMouseMove(event, barGroup.index, bar.key, bar.color);
          },
          onMouseLeave: function onMouseLeave(event) {
            return handleMouseLeave(event);
          },
          onTouchMove: function onTouchMove(event) {
            return handleMouseMove(event, barGroup.index, bar.key, bar.color);
          },
          onTouchEnd: function onTouchEnd(event) {
            return handleMouseLeave(event);
          }
        }), /*#__PURE__*/React__default.createElement(StackedBarValue, {
          threshold: {
            x: xScale(MAP_CHART_FIELDS_THRESHOLD[xAxis]),
            value: MAP_CHART_FIELDS_THRESHOLD[xAxis]
          },
          bar: {
            x: barX,
            y: bar.y,
            height: bar.height,
            width: barWidth,
            value: bar.value,
            color: bar.color,
            formattedValue: !bar.value && xAxis === METRICS.AFFINITY ? '0x' : FormatUtils.formattedValue(bar.value, xAxis)
          },
          onMove: function onMove(event) {
            return handleMouseMove(event, barGroup.index, bar.key, bar.color);
          },
          onLeave: function onLeave(event) {
            return handleMouseLeave(event);
          }
        }));
      }));
    });
  }), /*#__PURE__*/React__default.createElement(shape.Line, {
    from: {
      x: xScale(MAP_CHART_FIELDS_THRESHOLD[xAxis]),
      y: 0
    },
    to: {
      x: xScale(MAP_CHART_FIELDS_THRESHOLD[xAxis]),
      y: yMax
    },
    stroke: "#9493A6",
    strokeWidth: "1",
    strokeOpacity: 0.5
  }), showAxisLeft && /*#__PURE__*/React__default.createElement(axis.AxisLeft, {
    scale: y0Scale,
    tickLabelProps: function tickLabelProps(d) {
      return {
        fontSize: '11px',
        pic: getTickImage(d),
        id: d,
        label: getTickLabel(d)
      };
    },
    tickComponent: function tickComponent(d) {
      return getTickComponent(d);
    }
  }, function (axisGroups) {
    return /*#__PURE__*/React__default.createElement(React__default.Fragment, null, axisGroups.ticks.map(function (group$1, index) {
      return /*#__PURE__*/React__default.createElement(group.Group, {
        key: "multiple-stacked-" + chartId.current + "-axis-group-" + index
      }, getGroupContent(group$1, axisGroups, index));
    }));
  }), /*#__PURE__*/React__default.createElement(axis.AxisTop, {
    label: MAP_CHART_FIELDS_LABEL[xAxis],
    top: 0,
    scale: xScale,
    numTicks: xTicks,
    stroke: "#9493A6",
    tickStroke: "#9493A6",
    tickFormat: function tickFormat(d) {
      return FormatUtils.formattedValue(d, xAxis);
    },
    tickLabelProps: function tickLabelProps() {
      return {
        fill: '#9493A6',
        fontSize: 11,
        textAnchor: 'middle',
        fontWeight: 'bold',
        dy: -2
      };
    },
    labelProps: {
      fill: 'black',
      textAnchor: 'middle',
      fontSize: 14,
      fontWeight: 'bold',
      dy: -5
    }
  }))), tooltipOpen && tooltipData && /*#__PURE__*/React__default.createElement(ChartTooltip, {
    opened: tooltipOpen,
    top: tooltipTop || 0,
    left: tooltipLeft || 0,
    data: tooltipData
  }, /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Reach: "), FormatUtils.formattedValue(getPopulationPerc(tooltipData), METRICS.REACH)), /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Affinity: "), FormatUtils.formattedValue(tooltipData.target_audience_affinity, METRICS.AFFINITY)), /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Base: "), FormatUtils.formattedValue(tooltipData.base_population_perc, METRICS.BASE)), /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Penetration: "), FormatUtils.formattedValue(tooltipData.penetration, METRICS.PENETRATION))));
};

function _templateObject$n() {
  var data = _taggedTemplateLiteralLoose(["\n  display: flex;\n  flex-direction: row;\n  width: 100%;\n  height: 100%;\n  position: relative;\n  background-color: #ffffff;\n  padding: 10px;\n"]);

  _templateObject$n = function _templateObject() {
    return data;
  };

  return data;
}
var StyledMultipleDoubleChartWrapper = styled__default.div(_templateObject$n());
var defaultMargin$b = {
  left: {
    top: 50,
    right: 50,
    bottom: 50,
    left: 100
  },
  right: {
    top: 50,
    right: 50,
    bottom: 50,
    left: 20
  }
};

var MultipleDoubleChart = function MultipleDoubleChart(_ref) {
  var _ref$margin = _ref.margin,
      margin = _ref$margin === void 0 ? defaultMargin$b : _ref$margin,
      data = _ref.data,
      x1Axis = _ref.x1Axis,
      x2Axis = _ref.x2Axis,
      zAxis = _ref.zAxis,
      emptyDataMessage = _ref.emptyDataMessage,
      _ref$limit = _ref.limit,
      limit = _ref$limit === void 0 ? 'auto' : _ref$limit,
      showItemsPreview = _ref.showItemsPreview,
      colors = _ref.colors,
      limitText = _ref.limitText,
      textWidth = _ref.textWidth;
  var chartId = React.useRef(uniqid());
  var isEmpty = !data || data.length === 0;

  if (isEmpty) {
    return /*#__PURE__*/React__default.createElement(StyledMultipleDoubleChartWrapper, null, /*#__PURE__*/React__default.createElement(hxReactComponents.Box, {
      minWidth: "100%"
    }, /*#__PURE__*/React__default.createElement(hxReactComponents.EmptyState, {
      icon: "analytics",
      mainText: emptyDataMessage,
      size: "large"
    })));
  }

  return /*#__PURE__*/React__default.createElement(StyledMultipleDoubleChartWrapper, null, /*#__PURE__*/React__default.createElement("div", {
    style: {
      width: '50%',
      height: '100%'
    }
  }, /*#__PURE__*/React__default.createElement(MultipleStackedChart, {
    key: "stacked-bar-left-" + chartId.current,
    limit: limit,
    xAxis: x1Axis,
    data: data,
    margin: margin.left,
    showAxisLeft: true,
    showItemsPreview: showItemsPreview,
    colors: colors,
    limitText: limitText,
    zAxis: zAxis,
    textWidth: textWidth
  })), /*#__PURE__*/React__default.createElement("div", {
    style: {
      width: '50%',
      height: '100%'
    }
  }, /*#__PURE__*/React__default.createElement(MultipleStackedChart, {
    key: "stacked-bar-right-" + chartId.current,
    limit: limit,
    xAxis: x2Axis,
    data: data,
    margin: margin.right,
    showAxisLeft: false,
    showItemsPreview: showItemsPreview,
    colors: colors,
    limitText: limitText,
    zAxis: zAxis,
    textWidth: textWidth
  })));
};

function _templateObject9$2() {
  var data = _taggedTemplateLiteralLoose(["\n  flex-basis: 50%;\n"]);

  _templateObject9$2 = function _templateObject9() {
    return data;
  };

  return data;
}

function _templateObject8$3() {
  var data = _taggedTemplateLiteralLoose(["\n  width: 30%;\n  display: flex;\n  align-items: left;\n  flex-direction: column;\n  padding-left: 10px;\n  font-size: 14px;\n  font-weight: 400;\n  margin-right: 10px;\n  color: ", ";\n"]);

  _templateObject8$3 = function _templateObject8() {
    return data;
  };

  return data;
}

function _templateObject7$3() {
  var data = _taggedTemplateLiteralLoose(["\n  width: 30%;\n  display: flex;\n  align-items: left;\n  flex-direction: column;\n  padding-left: 10px;\n  font-size: 16px;\n  font-weight: 500;\n  color: rgb(148, 147, 166);\n"]);

  _templateObject7$3 = function _templateObject7() {
    return data;
  };

  return data;
}

function _templateObject6$5() {
  var data = _taggedTemplateLiteralLoose(["\n  width: 100%;\n  display: flex;\n  align-items: center;\n  justify-content: space-between;\n  flex-direction: row;\n"]);

  _templateObject6$5 = function _templateObject6() {
    return data;
  };

  return data;
}

function _templateObject5$5() {
  var data = _taggedTemplateLiteralLoose(["\n  width: 100%;\n  height: 95px;\n  padding-top: 10px;\n  border-bottom: 1px solid #cdcdcd;\n  position: relative;\n"]);

  _templateObject5$5 = function _templateObject5() {
    return data;
  };

  return data;
}

function _templateObject4$7() {
  var data = _taggedTemplateLiteralLoose(["\n  font-size: 14px;\n  font-weight: 500;\n  color: rgb(148, 147, 166);\n  margin-right: 10px;\n  text-align: end;\n"]);

  _templateObject4$7 = function _templateObject4() {
    return data;
  };

  return data;
}

function _templateObject3$a() {
  var data = _taggedTemplateLiteralLoose(["\n  height: 100%;\n  overflow: hidden auto;\n"]);

  _templateObject3$a = function _templateObject3() {
    return data;
  };

  return data;
}

function _templateObject2$a() {
  var data = _taggedTemplateLiteralLoose(["\n  z-index: 1;\n"]);

  _templateObject2$a = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$o() {
  var data = _taggedTemplateLiteralLoose(["\n  width: 100%;\n  height: 100%;\n  position: relative;\n  background-color: #ffffff;\n  padding: 10px;\n"]);

  _templateObject$o = function _templateObject() {
    return data;
  };

  return data;
}
var StyledMultipleListChartWrapper = styled__default.div(_templateObject$o());
var StyledMultipleListChartSvg = styled__default.svg(_templateObject2$a());
var StyledMultipleListChartContent = styled__default.div(_templateObject3$a());
var StyledMultipleListChartMetric = styled__default.div(_templateObject4$7());
var StyledMultipleListItem = styled__default.div(_templateObject5$5());
var StyledMultipleListItemContent = styled__default.div(_templateObject6$5());
var StyledMultipleListItemTitle = styled__default.div(_templateObject7$3());
var StyledMultipleListItemValue = styled__default.div(_templateObject8$3(), function (props) {
  return props.color;
});
var StyledMultipleListItemSlider = styled__default.div(_templateObject9$2());

var ListTooltipContent = function ListTooltipContent(_ref) {
  var data = _ref.data,
      chartId = _ref.chartId,
      bars = _ref.bars;
  return /*#__PURE__*/React__default.createElement(React__default.Fragment, null, data.map(function (item, index) {
    return /*#__PURE__*/React__default.createElement("div", {
      style: {
        margin: '5px',
        paddingLeft: '5px',
        borderLeft: "3px solid " + item.color
      },
      key: "list-tooltip-content-" + chartId + "-item-" + item.id + "-" + index
    }, /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Reach: "), FormatUtils.formattedValue(getPopulationPerc(item), METRICS.REACH)), /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Affinity: "), FormatUtils.formattedValue(item.target_audience_affinity, METRICS.AFFINITY)), /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Base: "), FormatUtils.formattedValue(item.base_population_perc, METRICS.BASE)), /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Penetration: "), FormatUtils.formattedValue(item.penetration, METRICS.PENETRATION)));
  }), /*#__PURE__*/React__default.createElement("div", {
    style: {
      display: 'flex',
      paddingLeft: '5px'
    }
  }, bars.map(function (bar, index) {
    return /*#__PURE__*/React__default.createElement("div", {
      key: "rect-" + chartId + "-item-" + index,
      style: {
        height: '15px',
        width: bar.width + "%",
        backgroundColor: bar.color
      }
    });
  })));
};

function _templateObject4$8() {
  var data = _taggedTemplateLiteralLoose(["\n  position: absolute;\n  height: 1em;\n  z-index: 1;\n  width: 1em;\n  border: 2px solid #fff;\n  border-radius: 50%;\n  top: -5px;\n  background: #fff;\n  box-shadow: 0 0 6px 2px rgb(0 0 0 / 20%);\n  left: ", ";\n  background-color: ", ";\n"]);

  _templateObject4$8 = function _templateObject4() {
    return data;
  };

  return data;
}

function _templateObject3$b() {
  var data = _taggedTemplateLiteralLoose(["\n  position: absolute;\n  top: 2em;\n  min-width: 50px;\n  text-align: center;\n  font-size: 8px;\n  left: ", ";\n\n  &:before {\n    content: '';\n    display: inline-block;\n    height: 2em;\n    width: 1px;\n    position: absolute;\n    top: -2.4em;\n    left: 50%;\n    background-color: #697c91;\n  }\n"]);

  _templateObject3$b = function _templateObject3() {
    return data;
  };

  return data;
}

function _templateObject2$b() {
  var data = _taggedTemplateLiteralLoose(["\n  position: relative;\n  height: 2px;\n  background-color: #697c91;\n  width: 100%;\n  margin-right: 20px;\n"]);

  _templateObject2$b = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$p() {
  var data = _taggedTemplateLiteralLoose(["\n  display: flex;\n  justify-content: center;\n  align-items: center;\n  height: 60px;\n  width: 100%;\n"]);

  _templateObject$p = function _templateObject() {
    return data;
  };

  return data;
}
var StyledSliderWrapper = styled__default.div(_templateObject$p());
var StyledSliderContent = styled__default.div(_templateObject2$b());
var StyledSliderTick = styled__default.div(_templateObject3$b(), function (props) {
  return "calc(" + props.left + "% - 25px)";
});
var StyledSliderHandle = styled__default.div(_templateObject4$8(), function (props) {
  return "calc(" + props.left + "% - 5px)";
}, function (props) {
  return props.color;
});

var Slider = function Slider(_ref) {
  var id = _ref.id,
      min = _ref.min,
      max = _ref.max,
      metric = _ref.metric,
      values = _ref.values;
  var diff = max * 100 < 1 ? 1 - min : max - min;
  var ticks = React.useMemo(function () {
    var list = Array.from({
      length: 3
    }, function (_, i) {
      var value = Math.round((i * (diff / 2) + min) * 100) / 100;
      return {
        value: value,
        displayValue: metric === METRICS.AFFINITY ? FormatUtils.formattedValue(value, METRICS.AFFINITY) : FormatUtils.formattedValue(value)
      };
    });
    var minPerc = min / diff;
    return list.map(function (item, i) {
      var value = item.value;
      var x = (value / diff - minPerc) * 100;
      return /*#__PURE__*/React__default.createElement(StyledSliderTick, {
        key: "slider-tick-" + id + "-" + i,
        left: x
      }, item.displayValue);
    });
  }, [min, id, metric]);
  var handles = React.useMemo(function () {
    var minPerc = min / diff;
    return values.map(function (item, i) {
      var p = item.value;
      var x = (p / diff - minPerc) * 100;
      return /*#__PURE__*/React__default.createElement(StyledSliderHandle, {
        key: "slider-handle-" + id + "-" + i,
        left: x,
        color: item.color
      });
    });
  }, [values, min, id]);
  return /*#__PURE__*/React__default.createElement(StyledSliderWrapper, null, /*#__PURE__*/React__default.createElement(StyledSliderContent, null, ticks, handles));
};

var ListChartContent = function ListChartContent(_ref) {
  var data = _ref.data,
      sortTarget = _ref.sortTarget,
      metric = _ref.metric,
      minMaxValues = _ref.minMaxValues,
      colors = _ref.colors,
      _onMouseMove = _ref.onMouseMove,
      onMouseLeave = _ref.onMouseLeave;
  var isEmpty = !data || data.length === 0;
  var keys = !isEmpty && Object.keys(data[0].metrics) || [];
  var getSliderValues = React.useCallback(function (item) {
    return keys.map(function (key) {
      return {
        color: colors[key],
        value: item.metrics[key][metric]
      };
    });
  }, [keys, metric, colors]);
  return /*#__PURE__*/React__default.createElement(React__default.Fragment, null, data && data.map(function (item) {
    return /*#__PURE__*/React__default.createElement(StyledMultipleListItem, {
      key: "list-chart-item-" + item.id,
      onMouseMove: function onMouseMove(event) {
        return _onMouseMove(event, item);
      },
      onMouseLeave: onMouseLeave
    }, /*#__PURE__*/React__default.createElement(StyledMultipleListItemContent, null, /*#__PURE__*/React__default.createElement(ListChartImage, {
      image: item.pic,
      color: "#d6d6d6",
      index: item.index
    }), item.label && /*#__PURE__*/React__default.createElement(StyledMultipleListItemTitle, null, item.label), item.values.map(function (value, indx) {
      return /*#__PURE__*/React__default.createElement(StyledMultipleListItemValue, {
        key: "target-value-" + indx,
        color: colors[value.id]
      }, isReach(metric) && /*#__PURE__*/React__default.createElement("div", null, FormatUtils.formattedValue(getPopulationPerc(value), METRICS.REACH)), metric === METRICS.AFFINITY && /*#__PURE__*/React__default.createElement("div", null, FormatUtils.formattedValue(value.target_audience_affinity, METRICS.AFFINITY)), metric === METRICS.BASE && /*#__PURE__*/React__default.createElement("div", null, FormatUtils.formattedValue(value.base_population_perc, METRICS.BASE)), metric === METRICS.PENETRATION && /*#__PURE__*/React__default.createElement("div", null, FormatUtils.formattedValue(value.penetration, METRICS.PENETRATION)), metric === METRICS.RELEVANCY && /*#__PURE__*/React__default.createElement("div", null, FormatUtils.formattedValue(value.relevancy, METRICS.RELEVANCY)));
    }), sortTarget && !['similar', 'different'].includes(sortTarget) && /*#__PURE__*/React__default.createElement(StyledMultipleListItemSlider, null, /*#__PURE__*/React__default.createElement(Slider, {
      id: item.id,
      metric: metric,
      min: minMaxValues.min,
      max: minMaxValues.max,
      values: getSliderValues(item)
    }))), sortTarget === 'similar' && /*#__PURE__*/React__default.createElement("div", {
      style: {
        display: 'flex',
        paddingLeft: '5px'
      }
    }, item.bars.map(function (bar, index) {
      return /*#__PURE__*/React__default.createElement("div", {
        key: "rect-item-" + index,
        style: {
          height: '15px',
          width: bar.width + "%",
          backgroundColor: bar.color
        }
      });
    })));
  }));
};

var tooltipTimeout$f;

var MultipleListChart = function MultipleListChart(_ref) {
  var data = _ref.data,
      metric = _ref.metric,
      colors = _ref.colors,
      labels = _ref.labels,
      skip = _ref.skip,
      sortTarget = _ref.sortTarget,
      emptyDataMessage = _ref.emptyDataMessage;
  var svgRef = React.useRef(null);
  var chartId = React.useRef(uniqid());
  var isEmpty = !data || data.length === 0;
  var targets = !isEmpty && Object.keys(data[0].metrics) || [];
  var sort = sortTarget || 'similar';

  var _useState = React.useState(0),
      width = _useState[0],
      setWidth = _useState[1];

  var _useState2 = React.useState(0),
      height = _useState2[0],
      setHeight = _useState2[1];

  var windowSize = useWindowSize();

  var _useTooltip = tooltip.useTooltip(),
      tooltipOpen = _useTooltip.tooltipOpen,
      tooltipLeft = _useTooltip.tooltipLeft,
      tooltipTop = _useTooltip.tooltipTop,
      tooltipData = _useTooltip.tooltipData,
      hideTooltip = _useTooltip.hideTooltip,
      showTooltip = _useTooltip.showTooltip;

  var chartRef = React.useCallback(function (node) {
    if (node != null) {
      setWidth(node.getBoundingClientRect().width);
      setHeight(node.getBoundingClientRect().height);
    }
  }, [windowSize]);
  var minMaxValues = React.useMemo(function () {
    if (isEmpty) {
      return {
        min: 0,
        max: 0
      };
    }

    return {
      min: Math.min.apply(Math, data.map(function (d) {
        return Math.min.apply(Math, targets.map(function (key) {
          return d.metrics[key][metric];
        }));
      }).concat([0])),
      max: Math.max.apply(Math, data.map(function (d) {
        return Math.max.apply(Math, targets.map(function (key) {
          return d.metrics[key][metric];
        }));
      }).concat([0]))
    };
  }, [data, metric, targets]);
  var handleMouseLeave = React.useCallback(function (event) {
    tooltipTimeout$f = window.setTimeout(function () {
      hideTooltip();
    }, 0);
  }, [hideTooltip]);
  var handleMouseMove = React.useCallback(function (event$1, item) {
    if (tooltipTimeout$f) clearTimeout(tooltipTimeout$f);
    var eventSvgCoords = event.localPoint(svgRef.current, event$1);
    showTooltip({
      tooltipData: _extends({}, item, {
        label: item.description
      }),
      tooltipTop: eventSvgCoords === null || eventSvgCoords === void 0 ? void 0 : eventSvgCoords.y,
      tooltipLeft: eventSvgCoords === null || eventSvgCoords === void 0 ? void 0 : eventSvgCoords.x
    });
  }, [showTooltip, svgRef.current]);
  var getTooltipContent = React.useCallback(function (item) {
    return targets.map(function (key) {
      return _extends({
        id: item.id,
        color: colors[key]
      }, item.metrics[key]);
    });
  }, [targets, colors]);
  var getMultiTargetBars = React.useCallback(function (item) {
    var bars = [];

    if (item && item.metrics) {
      var sum = [].concat(targets.map(function (key) {
        return item.metrics[key][metric];
      })).reduce(function (total, value) {
        return total + value;
      }, 0);
      bars = targets.map(function (target) {
        return {
          color: colors[target],
          width: item.metrics[target][metric] / sum * 100
        };
      });
    }

    return bars;
  }, [metric, targets, colors]);
  var listChartData = React.useMemo(function () {
    if (isEmpty) {
      return [];
    }

    var keys = sort === 'different' ? targets : ['single'];
    return keys.reduce(function (acc, targetId, targetIndex) {
      var list = data.reduce(function (list, d, index) {
        if (sort !== 'different' || sort === 'different' && (1 * skip + index) % keys.length === targetIndex) {
          var values = Object.entries(d.metrics).reduce(function (values, _ref2) {
            var key = _ref2[0];

            if (key === sort || sort === 'similar' || sort === 'different' && key === targetId) {
              var _values$push;

              values.push((_values$push = {
                id: key,
                color: colors[key]
              }, _values$push[metric] = d.metrics[key][metric], _values$push));
            }

            return values;
          }, []);

          var item = _extends({}, d, {
            label: sort !== 'different' && d.label,
            description: d.label,
            index: sort !== 'different' && d.index + 1,
            bars: getMultiTargetBars(d),
            values: values
          });

          list.push(item);
        }

        return list;
      }, []);
      acc[targetId] = list;
      return acc;
    }, {});
  }, [isEmpty, sort, targets, data, skip, metric, getMultiTargetBars]);

  if (isEmpty) {
    return /*#__PURE__*/React__default.createElement(StyledMultipleListChartWrapper, null, /*#__PURE__*/React__default.createElement(hxReactComponents.Box, {
      minWidth: "100%"
    }, /*#__PURE__*/React__default.createElement(hxReactComponents.EmptyState, {
      icon: "analytics",
      mainText: emptyDataMessage,
      size: "large"
    })));
  }

  return /*#__PURE__*/React__default.createElement(StyledMultipleListChartWrapper, {
    ref: chartRef
  }, /*#__PURE__*/React__default.createElement(StyledMultipleListChartSvg, {
    ref: svgRef,
    width: width,
    height: height
  }, /*#__PURE__*/React__default.createElement("rect", {
    width: width,
    height: height,
    fill: "#ffffff"
  }), /*#__PURE__*/React__default.createElement(group.Group, {
    top: 0,
    left: 0,
    key: "group-" + chartId.current
  }, /*#__PURE__*/React__default.createElement("rect", {
    fill: "#ffffff",
    width: width,
    height: height
  }), /*#__PURE__*/React__default.createElement("foreignObject", {
    x: "0",
    y: "0",
    width: width,
    height: height
  }, /*#__PURE__*/React__default.createElement(StyledMultipleListChartContent, null, /*#__PURE__*/React__default.createElement(StyledMultipleListChartMetric, null, MAP_CHART_FIELDS_LABEL[metric]), sort === 'different' ? /*#__PURE__*/React__default.createElement(hxReactComponents.Row, {
    valign: "equal",
    halign: "left",
    style: {
      height: '100%',
      width: '100%'
    }
  }, targets.map(function (key, index) {
    return /*#__PURE__*/React__default.createElement(hxReactComponents.Col, {
      span: 12 / targets.length,
      key: "col-" + chartId.current + "-" + index,
      style: {
        height: '100%',
        width: '100%'
      }
    }, /*#__PURE__*/React__default.createElement("div", {
      style: {
        display: 'flex',
        flexDirection: 'column',
        justifyContent: 'space-between',
        height: '100%',
        width: '100%'
      }
    }, /*#__PURE__*/React__default.createElement("div", {
      style: {
        width: '100%',
        height: '80px',
        maxHeight: '80px',
        minHeight: '80px',
        display: 'flex',
        justifyContent: 'center',
        alignItems: 'center'
      }
    }, /*#__PURE__*/React__default.createElement(hxReactComponents.Text, {
      weight: "bold",
      lettercase: "uppercase",
      align: "center",
      size: "small",
      style: {
        color: colors[key],
        maxWidth: '100%',
        textOverflow: 'ellipsis',
        overflow: 'hidden'
      }
    }, labels[key])), /*#__PURE__*/React__default.createElement("div", {
      style: {
        backgroundColor: colors[key] + '40'
      }
    }, /*#__PURE__*/React__default.createElement(ListChartContent, {
      data: listChartData[key],
      sortTarget: sort,
      onMouseMove: function onMouseMove(event, item) {
        return handleMouseMove(event, item);
      },
      onMouseLeave: function onMouseLeave(event) {
        return handleMouseLeave(event);
      },
      metric: metric,
      colors: colors,
      minMaxValues: minMaxValues
    }))));
  })) : /*#__PURE__*/React__default.createElement(hxReactComponents.Box, {
    style: {
      height: '100%',
      width: '100%'
    }
  }, /*#__PURE__*/React__default.createElement(ListChartContent, {
    data: listChartData.single,
    sortTarget: sort,
    onMouseMove: function onMouseMove(event, item) {
      return handleMouseMove(event, item);
    },
    onMouseLeave: function onMouseLeave(event) {
      return handleMouseLeave(event);
    },
    metric: metric,
    colors: colors,
    minMaxValues: minMaxValues
  })))))), tooltipOpen && tooltipData && /*#__PURE__*/React__default.createElement(ChartTooltip, {
    opened: tooltipOpen,
    top: tooltipTop || 0,
    left: tooltipLeft || 0,
    data: tooltipData
  }, /*#__PURE__*/React__default.createElement(ListTooltipContent, {
    data: getTooltipContent(tooltipData),
    chartId: chartId.current,
    bars: getMultiTargetBars(tooltipData)
  })));
};

var MosaicTooltipContent = function MosaicTooltipContent(_ref) {
  var data = _ref.data,
      chartId = _ref.chartId;
  return /*#__PURE__*/React__default.createElement(React__default.Fragment, null, data.tooltip.map(function (item, index) {
    return /*#__PURE__*/React__default.createElement("div", {
      style: {
        margin: '5px',
        paddingLeft: '5px',
        borderLeft: "3px solid " + item.color
      },
      key: "mosaic-tooltip-content-" + chartId + "-item-" + item.id + "-" + index
    }, /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Reach: "), FormatUtils.formattedValue(getPopulationPerc(item), METRICS.REACH)), /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Affinity: "), FormatUtils.formattedValue(item.target_audience_affinity, METRICS.AFFINITY)), /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Base: "), FormatUtils.formattedValue(item.base_population_perc, METRICS.BASE)), /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Penetration: "), FormatUtils.formattedValue(item.penetration, METRICS.PENETRATION)));
  }), /*#__PURE__*/React__default.createElement("div", {
    style: {
      display: 'flex',
      paddingLeft: '5px'
    }
  }, data.bars.map(function (bar, index) {
    return /*#__PURE__*/React__default.createElement("div", {
      key: "rect-" + chartId + "-item-" + index,
      style: {
        height: '15px',
        width: bar.width + "%",
        backgroundColor: bar.color
      }
    });
  })));
};

function _templateObject2$c() {
  var data = _taggedTemplateLiteralLoose(["\n  z-index: 1;\n"]);

  _templateObject2$c = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$q() {
  var data = _taggedTemplateLiteralLoose(["\n  width: 100%;\n  height: 100%;\n  position: relative;\n  background-color: #ffffff;\n  overflow: hidden;\n  z-index: 0;\n"]);

  _templateObject$q = function _templateObject() {
    return data;
  };

  return data;
}
var StyledContentWrapper = styled__default.div(_templateObject$q());
var StyledMultipleMosaicChartSvg = styled__default.svg(_templateObject2$c());

var MosaicContent = function MosaicContent(_ref) {
  var sort = _ref.sort,
      chartId = _ref.chartId,
      data = _ref.data,
      color = _ref.color,
      margin = _ref.margin,
      showItemsPreview = _ref.showItemsPreview,
      handleMouseMove = _ref.handleMouseMove,
      handleMouseLeave = _ref.handleMouseLeave;

  var _useState = React.useState(0),
      width = _useState[0],
      setWidth = _useState[1];

  var _useState2 = React.useState(0),
      height = _useState2[0],
      setHeight = _useState2[1];

  var windowSize = useWindowSize();
  var svgRef = React.useRef(null);
  var chartRef = React.useCallback(function (node) {
    if (node != null) {
      setWidth(node.getBoundingClientRect().width);
      setHeight(node.getBoundingClientRect().height);
    }
  }, [windowSize, data]);
  var getMultiTargetBars = React.useCallback(function (item, x, y, width) {
    var rectX = x;
    var bars = item.bars;
    return bars.map(function (bar, index) {
      var rectWidth = bar.width / 100 * width;
      var rect = /*#__PURE__*/React__default.createElement("rect", {
        key: "multiple-mosaic-" + chartId + "-rect-" + index + "-" + x + "-" + y,
        x: rectX,
        y: y,
        width: rectWidth,
        height: 15,
        fill: bar.color
      });
      rectX += rectWidth;
      return rect;
    });
  }, [chartId]);
  var numColumns = sort !== 'similar' ? 2 : 5;
  var numRows = 5;
  var rowHeight = Math.max(height / numRows, 0);
  return /*#__PURE__*/React__default.createElement(StyledContentWrapper, {
    ref: chartRef
  }, /*#__PURE__*/React__default.createElement(StyledMultipleMosaicChartSvg, {
    ref: svgRef,
    width: width,
    height: Math.floor((data.length - 1) / numColumns) * rowHeight + rowHeight
  }, /*#__PURE__*/React__default.createElement("rect", {
    width: width,
    height: height,
    fill: "#ffffff"
  }), /*#__PURE__*/React__default.createElement(group.Group, {
    top: margin.top,
    left: margin.left,
    key: "group-" + chartId.current
  }, data.map(function (item, index) {
    var numRows = 5;
    var rowHeight = Math.max(height / numRows, 0);
    var numColumns = sort !== 'similar' ? 2 : 5;
    var columnWidth = Math.max(width / numColumns, 0);
    var columnIndex = index % numColumns;
    var rowIndex = Math.floor(index / numColumns);
    return /*#__PURE__*/React__default.createElement(React__default.Fragment, {
      key: "multiple-mosaic-" + chartId + "-item-" + index + "-" + rowIndex + "-" + columnIndex
    }, /*#__PURE__*/React__default.createElement("svg", {
      onMouseMove: function onMouseMove(event) {
        return handleMouseMove(event, item);
      },
      onMouseLeave: function onMouseLeave(event) {
        return handleMouseLeave(event);
      },
      onMouseOver: function onMouseOver(event) {
        return handleMouseMove(event, item);
      }
    }, /*#__PURE__*/React__default.createElement(MosaicChartImage, {
      id: "multiple-mosaic-" + chartId + "-item-icon-" + index + "-" + rowIndex + "-" + columnIndex,
      pic: item.pic,
      label: item.label,
      width: columnWidth,
      height: sort !== 'similar' || rowHeight <= 0 ? rowHeight : rowHeight - 15,
      x: columnIndex * columnWidth,
      y: rowIndex * rowHeight,
      color: color,
      showItemsPreview: showItemsPreview
    }), sort === 'similar' && columnWidth > 0 && getMultiTargetBars(item, columnIndex * columnWidth, rowIndex * rowHeight + (rowHeight - 15), columnWidth)));
  }), /*#__PURE__*/React__default.createElement("rect", {
    x: 0,
    y: 0,
    width: width,
    height: height,
    fill: color,
    fillOpacity: sort === 'different' ? 0.5 : 0,
    stroke: color,
    strokeWidth: 3,
    strokeOpacity: sort === 'different' ? 0.5 : 0,
    style: {
      pointerEvents: 'none'
    }
  }))));
};

function _templateObject2$d() {
  var data = _taggedTemplateLiteralLoose(["\n  z-index: 1;\n"]);

  _templateObject2$d = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$r() {
  var data = _taggedTemplateLiteralLoose(["\n  width: 100%;\n  height: 100%;\n  position: relative;\n  background-color: #ffffff;\n  overflow: ", ";\n  z-index: 0;\n"]);

  _templateObject$r = function _templateObject() {
    return data;
  };

  return data;
}
var StyledMultipleMosaicChartWrapper = styled__default.div(_templateObject$r(), function (props) {
  return props.isScrollable ? 'hidden auto' : 'hidden';
});
var StyledMultipleMosaicChartSvg$1 = styled__default.svg(_templateObject2$d());
var tooltipTimeout$g;
var defaultMargin$c = {
  top: 0,
  right: 0,
  bottom: 0,
  left: 0
};

var MultipleMosaicChart = function MultipleMosaicChart(_ref) {
  var data = _ref.data,
      _ref$margin = _ref.margin,
      margin = _ref$margin === void 0 ? defaultMargin$c : _ref$margin,
      metric = _ref.metric,
      emptyDataMessage = _ref.emptyDataMessage,
      colors = _ref.colors,
      sortTarget = _ref.sortTarget,
      skip = _ref.skip,
      labels = _ref.labels;

  var _useTooltip = tooltip.useTooltip(),
      tooltipOpen = _useTooltip.tooltipOpen,
      tooltipLeft = _useTooltip.tooltipLeft,
      tooltipTop = _useTooltip.tooltipTop,
      tooltipData = _useTooltip.tooltipData,
      hideTooltip = _useTooltip.hideTooltip,
      showTooltip = _useTooltip.showTooltip;

  var _useState = React.useState(0),
      width = _useState[0],
      setWidth = _useState[1];

  var _useState2 = React.useState(0),
      height = _useState2[0],
      setHeight = _useState2[1];

  var windowSize = useWindowSize();
  var svgRef = React.useRef(null);
  var isEmpty = !data || data.length === 0;
  var chartRef = React.useCallback(function (node) {
    if (node != null) {
      setWidth(node.getBoundingClientRect().width);
      setHeight(node.getBoundingClientRect().height);
    }
  }, [windowSize]);
  var targets = !isEmpty && Object.keys(data[0].metrics) || [];
  var chartId = React.useRef(uniqid());
  var sort = sortTarget || 'similar';
  var getTooltipContent = React.useCallback(function (item) {
    return targets.map(function (key) {
      return _extends({
        id: item.id,
        color: colors[key]
      }, item.metrics[key]);
    });
  }, [targets, colors]);
  var mosaicChartData = React.useMemo(function () {
    var keys = sort !== 'similar' ? targets : ['similar'];
    var chartData = keys.reduce(function (acc, targetId, targetIndex) {
      var list = data.reduce(function (list, d, index) {
        if (sort !== 'different' || sort === 'different' && (1 * skip + index) % keys.length === targetIndex) {
          var label = d.label;

          if (!['different', 'similar'].includes(sort) && sort !== targetId) {
            var mainValue = d.metrics[sort] && d.metrics[sort][metric] || 0;
            var value = d.metrics[targetId][metric] || 0;
            var diff = Math.abs(mainValue - value);
            var sign = value && value > mainValue ? '+' : '-';
            label = diff > 0 ? sign + FormatUtils.formattedValue(diff, metric) : FormatUtils.formattedValue(diff, metric);
          }

          var bars = [];

          if (d && d.metrics) {
            var sum = [].concat(targets.map(function (targetId) {
              return d.metrics[targetId][metric];
            })).reduce(function (total, value) {
              return total + value;
            }, 0);
            bars = targets.map(function (target) {
              return {
                color: colors[target],
                width: sum > 0 ? d.metrics[target][metric] / sum * 100 : 0
              };
            });
          }

          var item = _extends({
            id: d.id,
            target: targetId,
            insight_type: d.insight_type,
            label: label,
            description: d.label,
            pic: d.pic,
            bars: bars,
            tooltip: getTooltipContent(d)
          }, d.metrics[targetId]);

          list.push(item);
        }

        return list;
      }, []);
      acc[targetId] = list;
      return acc;
    }, {});
    return chartData;
  }, [data, sort, metric, skip, colors, targets]);
  var handleMouseLeave = React.useCallback(function (event) {
    tooltipTimeout$g = window.setTimeout(function () {
      hideTooltip();
    }, 0);
  }, [hideTooltip]);
  var handleMouseMove = React.useCallback(function (event$1, item) {
    var coords = event.localPoint(svgRef.current, event$1);
    if (tooltipTimeout$g) clearTimeout(tooltipTimeout$g);
    showTooltip({
      tooltipData: _extends({}, item, {
        label: item.description
      }),
      tooltipTop: coords === null || coords === void 0 ? void 0 : coords.y,
      tooltipLeft: coords === null || coords === void 0 ? void 0 : coords.x
    });
  }, [showTooltip, svgRef.current]);

  if (isEmpty) {
    return /*#__PURE__*/React__default.createElement(StyledMultipleMosaicChartWrapper, null, /*#__PURE__*/React__default.createElement(hxReactComponents.Box, {
      minWidth: "100%"
    }, /*#__PURE__*/React__default.createElement(hxReactComponents.EmptyState, {
      icon: "analytics",
      mainText: emptyDataMessage,
      size: "large"
    })));
  }

  return /*#__PURE__*/React__default.createElement(StyledMultipleMosaicChartWrapper, {
    ref: chartRef
  }, /*#__PURE__*/React__default.createElement(StyledMultipleMosaicChartSvg$1, {
    ref: svgRef,
    width: width,
    height: height
  }, /*#__PURE__*/React__default.createElement("foreignObject", {
    x: "0",
    y: "0",
    width: width,
    height: height
  }, sort !== 'similar' ? /*#__PURE__*/React__default.createElement(hxReactComponents.Row, {
    valign: "equal",
    halign: "left",
    style: {
      height: '100%',
      width: '100%'
    }
  }, targets.map(function (key, index) {
    return /*#__PURE__*/React__default.createElement(hxReactComponents.Col, {
      span: sort !== 'similar' ? 12 / targets.length : 12,
      key: "col-" + chartId.current + "-" + index,
      style: {
        height: '100%',
        width: '100%'
      }
    }, /*#__PURE__*/React__default.createElement("div", {
      style: {
        display: 'flex',
        flexDirection: 'column',
        justifyContent: 'space-between',
        height: '100%',
        width: '100%'
      }
    }, /*#__PURE__*/React__default.createElement("div", {
      style: {
        width: '100%',
        height: '80px',
        maxHeight: '80px',
        minHeight: '80px',
        display: 'flex',
        justifyContent: 'center',
        alignItems: 'center'
      }
    }, /*#__PURE__*/React__default.createElement(hxReactComponents.Text, {
      weight: "bold",
      lettercase: "uppercase",
      align: "center",
      size: "small",
      style: {
        color: colors[key],
        maxWidth: '100%',
        textOverflow: 'ellipsis',
        overflow: 'hidden'
      }
    }, labels[key])), /*#__PURE__*/React__default.createElement(MosaicContent, {
      margin: margin,
      data: mosaicChartData[key],
      color: colors[key],
      sort: sort,
      chartId: chartId.current,
      showItemsPreview: sort === 'different' || sort === key,
      handleMouseMove: handleMouseMove,
      handleMouseLeave: handleMouseLeave
    })));
  })) : /*#__PURE__*/React__default.createElement(hxReactComponents.Box, {
    style: {
      height: '100%',
      width: '100%'
    }
  }, /*#__PURE__*/React__default.createElement(MosaicContent, {
    width: width,
    height: height,
    margin: margin,
    data: mosaicChartData.similar,
    colors: "#d6d6d6",
    sort: sort,
    chartId: chartId.current,
    showItemsPreview: true,
    handleMouseMove: handleMouseMove,
    handleMouseLeave: handleMouseLeave
  })))), tooltipOpen && tooltipData && /*#__PURE__*/React__default.createElement(ChartTooltip, {
    opened: tooltipOpen,
    top: tooltipTop || 0,
    left: tooltipLeft || 0,
    data: tooltipData
  }, /*#__PURE__*/React__default.createElement(MosaicTooltipContent, {
    data: tooltipData,
    chartId: chartId.current
  })));
};

function _templateObject$s() {
  var data = _taggedTemplateLiteralLoose(["\n  width: 100%;\n  height: 100%;\n  position: relative;\n  background-color: #ffffff;\n  padding: 10px;\n"]);

  _templateObject$s = function _templateObject() {
    return data;
  };

  return data;
}
var StyledMultiplePieChartWrapper = styled__default.div(_templateObject$s());
var defaultMargin$d = {
  top: 50,
  right: 50,
  bottom: 50,
  left: 80
};

var MultiplePieChart = function MultiplePieChart(_ref) {
  var data = _ref.data,
      _ref$limit = _ref.limit,
      limit = _ref$limit === void 0 ? 'auto' : _ref$limit,
      metric = _ref.metric,
      _ref$margin = _ref.margin,
      margin = _ref$margin === void 0 ? defaultMargin$d : _ref$margin,
      hasInnerRadius = _ref.hasInnerRadius,
      emptyDataMessage = _ref.emptyDataMessage,
      horizontalLayout = _ref.horizontalLayout,
      showItemsPreview = _ref.showItemsPreview,
      colors = _ref.colors;
  var chartId = React.useRef(uniqid());
  var isEmpty = !data || data.length === 0;
  var keys = !isEmpty && Object.keys(data[0].metrics) || [];
  var filteredData = React.useMemo(function () {
    if (isEmpty) {
      return [];
    }

    return limit !== 'auto' ? data.slice(0, limit) : data;
  }, [isEmpty, data, limit]);
  var getPieChartData = React.useCallback(function (key) {
    var items = filteredData.map(function (d) {
      return _extends({
        id: d.id,
        insight_type: d.insight_type,
        label: d.label,
        pic: d.pic
      }, d.metrics[key]);
    });
    return items.filter(function (d) {
      return d[metric] && d[metric] > 0;
    });
  }, [filteredData, metric]);

  if (isEmpty) {
    return /*#__PURE__*/React__default.createElement(StyledMultiplePieChartWrapper, null, /*#__PURE__*/React__default.createElement(hxReactComponents.Box, {
      minWidth: "100%"
    }, /*#__PURE__*/React__default.createElement(hxReactComponents.EmptyState, {
      icon: "analytics",
      mainText: emptyDataMessage,
      size: "large"
    })));
  }

  return /*#__PURE__*/React__default.createElement(StyledMultiplePieChartWrapper, null, /*#__PURE__*/React__default.createElement(hxReactComponents.Row, {
    valign: "equal",
    halign: horizontalLayout ? 'left' : 'center',
    style: {
      height: '100%'
    }
  }, keys.map(function (key, index) {
    return /*#__PURE__*/React__default.createElement(hxReactComponents.Col, {
      span: horizontalLayout && keys.length > 2 ? 4 : 6,
      key: "multiple-pie-chart-" + chartId.current + "-" + index
    }, /*#__PURE__*/React__default.createElement(hxReactComponents.Box, {
      style: {
        height: '100%'
      }
    }, /*#__PURE__*/React__default.createElement(PieChart, {
      margin: margin,
      data: getPieChartData(key),
      hasInnerRadius: hasInnerRadius,
      metric: metric,
      color: colors[key],
      emptyDataMessage: emptyDataMessage,
      limit: limit,
      showItemsPreview: showItemsPreview,
      limitText: 10
    })));
  })));
};

function _templateObject$t() {
  var data = _taggedTemplateLiteralLoose(["\n  width: 100%;\n  height: 100%;\n  position: relative;\n  background-color: #ffffff;\n  padding: 10px;\n"]);

  _templateObject$t = function _templateObject() {
    return data;
  };

  return data;
}
var StyledMultipleUkMapChartWrapper = styled__default.div(_templateObject$t());

var MultipleUkMapChart = function MultipleUkMapChart(_ref) {
  var data = _ref.data,
      metric = _ref.metric,
      showMoreDetail = _ref.showMoreDetail,
      onItemClick = _ref.onItemClick,
      emptyDataMessage = _ref.emptyDataMessage,
      horizontalLayout = _ref.horizontalLayout,
      colors = _ref.colors;
  var chartId = React.useRef(uniqid());
  var isEmpty = !data || data.length === 0;
  var keys = !isEmpty && Object.keys(data[0].metrics) || [];
  var getUkMapChartData = React.useCallback(function (key) {
    return data.map(function (d) {
      return _extends({
        id: d.id,
        insight_type: d.insight_type,
        label: d.label,
        pic: d.pic
      }, d.metrics[key]);
    });
  }, [data, metric]);

  if (isEmpty) {
    return /*#__PURE__*/React__default.createElement(StyledMultipleUkMapChartWrapper, null, /*#__PURE__*/React__default.createElement(hxReactComponents.Box, {
      minWidth: "100%"
    }, /*#__PURE__*/React__default.createElement(hxReactComponents.EmptyState, {
      icon: "analytics",
      mainText: emptyDataMessage,
      size: "large"
    })));
  }

  return /*#__PURE__*/React__default.createElement(StyledMultipleUkMapChartWrapper, null, /*#__PURE__*/React__default.createElement(hxReactComponents.Row, {
    valign: "equal",
    halign: horizontalLayout ? 'left' : 'center',
    style: {
      height: '100%'
    }
  }, keys.map(function (key, index) {
    return /*#__PURE__*/React__default.createElement(hxReactComponents.Col, {
      span: horizontalLayout && keys.length > 2 ? 4 : 6,
      key: "multiple-uk-map-chart-" + chartId.current + "-" + index
    }, /*#__PURE__*/React__default.createElement(hxReactComponents.Box, {
      style: {
        height: '100%'
      }
    }, /*#__PURE__*/React__default.createElement(UkMapChart, {
      data: getUkMapChartData(key),
      metric: metric,
      showMoreDetail: showMoreDetail,
      onItemClick: onItemClick,
      color: colors[key],
      emptyDataMessage: emptyDataMessage,
      positionLegend: horizontalLayout ? 'bottom' : 'left'
    })));
  })));
};

function _templateObject$u() {
  var data = _taggedTemplateLiteralLoose(["\n  width: 100%;\n  height: 100%;\n  position: relative;\n  background-color: #ffffff;\n  padding: 10px;\n"]);

  _templateObject$u = function _templateObject() {
    return data;
  };

  return data;
}
var StyledMultipleUsaMapChartWrapper = styled__default.div(_templateObject$u());

var MultipleUsaMapChart = function MultipleUsaMapChart(_ref) {
  var _ref$type = _ref.type,
      type = _ref$type === void 0 ? 'states' : _ref$type,
      data = _ref.data,
      metric = _ref.metric,
      showMoreDetail = _ref.showMoreDetail,
      onItemClick = _ref.onItemClick,
      emptyDataMessage = _ref.emptyDataMessage,
      horizontalLayout = _ref.horizontalLayout,
      colors = _ref.colors;
  var chartId = React.useRef(uniqid());
  var isEmpty = !data || data.length === 0;
  var keys = !isEmpty && Object.keys(data[0].metrics) || [];
  var getUsaMapChartData = React.useCallback(function (key) {
    return data.map(function (d) {
      return _extends({
        id: d.id,
        insight_type: d.insight_type,
        label: d.label,
        pic: d.pic
      }, d.metrics[key]);
    });
  }, [data, metric]);

  if (isEmpty) {
    return /*#__PURE__*/React__default.createElement(StyledMultipleUsaMapChartWrapper, null, /*#__PURE__*/React__default.createElement(hxReactComponents.Box, {
      minWidth: "100%"
    }, /*#__PURE__*/React__default.createElement(hxReactComponents.EmptyState, {
      icon: "analytics",
      mainText: emptyDataMessage,
      size: "large"
    })));
  }

  return /*#__PURE__*/React__default.createElement(StyledMultipleUsaMapChartWrapper, null, /*#__PURE__*/React__default.createElement(hxReactComponents.Row, {
    valign: "equal",
    halign: horizontalLayout ? 'left' : 'center',
    style: {
      height: '100%'
    }
  }, keys.map(function (key, index) {
    return /*#__PURE__*/React__default.createElement(hxReactComponents.Col, {
      span: horizontalLayout && keys.length > 2 ? 4 : 6,
      key: "multiple-usa-map-chart-" + chartId.current + "-" + index
    }, /*#__PURE__*/React__default.createElement(hxReactComponents.Box, {
      style: {
        height: '100%'
      }
    }, /*#__PURE__*/React__default.createElement(UsaMapChart, {
      type: type,
      data: getUsaMapChartData(key),
      metric: metric,
      showMoreDetail: showMoreDetail,
      onItemClick: onItemClick,
      color: colors[key],
      emptyDataMessage: emptyDataMessage
    })));
  })));
};

function _templateObject$v() {
  var data = _taggedTemplateLiteralLoose(["\n  width: 100%;\n  height: 100%;\n  position: relative;\n  background-color: #ffffff;\n  padding: 10px;\n"]);

  _templateObject$v = function _templateObject() {
    return data;
  };

  return data;
}
var StyledMultipleWorldMapChartWrapper = styled__default.div(_templateObject$v());

var MultipleWorldMapChart = function MultipleWorldMapChart(_ref) {
  var data = _ref.data,
      metric = _ref.metric,
      emptyDataMessage = _ref.emptyDataMessage,
      horizontalLayout = _ref.horizontalLayout,
      colors = _ref.colors;
  var chartId = React.useRef(uniqid());
  var isEmpty = !data || data.length === 0;
  var keys = !isEmpty && Object.keys(data[0].metrics) || [];
  var getWorldMapChartData = React.useCallback(function (key) {
    return data.map(function (d) {
      return _extends({
        id: d.id,
        insight_type: d.insight_type,
        label: d.label,
        pic: d.pic
      }, d.metrics[key]);
    });
  }, [data, metric]);

  if (isEmpty) {
    return /*#__PURE__*/React__default.createElement(StyledMultipleWorldMapChartWrapper, null, /*#__PURE__*/React__default.createElement(hxReactComponents.Box, {
      minWidth: "100%"
    }, /*#__PURE__*/React__default.createElement(hxReactComponents.EmptyState, {
      icon: "analytics",
      mainText: emptyDataMessage,
      size: "large"
    })));
  }

  return /*#__PURE__*/React__default.createElement(StyledMultipleWorldMapChartWrapper, null, /*#__PURE__*/React__default.createElement(hxReactComponents.Row, {
    valign: "equal",
    halign: horizontalLayout ? 'left' : 'center',
    style: {
      height: '100%'
    }
  }, keys.map(function (key, index) {
    return /*#__PURE__*/React__default.createElement(hxReactComponents.Col, {
      span: horizontalLayout && keys.length > 2 ? 4 : 6,
      key: "multiple-world-map-chart-" + chartId.current + "-" + index
    }, /*#__PURE__*/React__default.createElement(hxReactComponents.Box, {
      style: {
        height: '100%'
      }
    }, /*#__PURE__*/React__default.createElement(WorldMapChart, {
      data: getWorldMapChartData(key),
      metric: metric,
      color: colors[key],
      emptyDataMessage: emptyDataMessage
    })));
  })));
};

exports.BarGroupChart = BarGroupChart$1;
exports.BubbleChart = BubbleChart;
exports.ChartTooltip = ChartTooltip;
exports.CloudChart = CloudChart;
exports.ColumnChart = ColumnChart;
exports.DonutChart = DonutChart$1;
exports.DotsChart = DotsChart$1;
exports.DoubleChart = DoubleChart;
exports.LineChart = LineChart$1;
exports.ListChart = ListChart;
exports.MosaicChart = MosaicChart;
exports.MultipleBubbleChart = MultipleBubbleChart;
exports.MultipleCloudChart = MultipleCloudChart;
exports.MultipleColumnChart = MultipleColumnChart;
exports.MultipleDoubleChart = MultipleDoubleChart;
exports.MultipleListChart = MultipleListChart;
exports.MultipleMosaicChart = MultipleMosaicChart;
exports.MultiplePieChart = MultiplePieChart;
exports.MultipleStackedChart = MultipleStackedChart;
exports.MultipleUkMapChart = MultipleUkMapChart;
exports.MultipleUsaMapChart = MultipleUsaMapChart;
exports.MultipleWorldMapChart = MultipleWorldMapChart;
exports.PieChart = PieChart;
exports.SpiderChart = SpiderChart;
exports.StackedChart = StackedChart;
exports.UkMapChart = UkMapChart;
exports.UsaMapChart = UsaMapChart;
exports.VennDiagram = VennDiagram;
exports.WorldMapChart = WorldMapChart;
//# sourceMappingURL=index.js.map
